/**
  ******************************************************************************
  * @file           : ms60f3xxx_adc.h
  * @author         : sinomcu.com-SA
  * @brief          :  Header file of ADC module.
  * @gcc            : toolchain version 5 or 6
  *
  ******************************************************************************
  * @attention
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with
 * basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */
#ifndef MS60F3XXX_ADC_H
#define MS60F3XXX_ADC_H

#ifdef __cplusplus
extern "C" {
#endif

#include "ms60f3xxx.h"

#define ADC_MAX_CHANNEL_NUMBER 16
#define ADC_MAX_JCHANNEL_NUMER 4
#define Reg_ADC_GAIN_CCR    *(volatile unsigned long *)0x4900B40C
#define	ADC_ADON						1
#define ADC_PTCR_EN 0x1
#define ADC_PTCR_DIS 0x2
#define CR2_RSTCAL_Set              ((uint32_t)0x00010000)
/* ADC SWSTART mask */
#define CR2_SWSTART_Set             (1ul<<22)
/* ADC Software start mask */
#define CR2_EXTTRIG_SWSTART_Set     (1ul<<22)
#define CR2_EXTTRIG_SWSTART_Reset   (0ul<<22)
/* ADC JEXTSEL mask */
#define CR2_JEXTSEL_Reset           ((uint32_t)0xFFFFF0FF)

typedef enum/**< \brief ADC_ TPS temperature sensor reference voltage selection */
{
    ADC_VREF2V4 = 0,
    ADC_VREF1V8 = 1,
    ADC_VREFAVDD = 2
} ADC_VREF_Enum;

typedef enum/**< \brief (ADC_CR2) External trigger signal for channel group conversion */
{
    ADC_REGULAR_SOFTWARE_TRIGER =	(1ul << 22),
    ADC_REGULAR_TIM0_0_RISING = (1ul << 20),
    ADC_REGULAR_TIM0_0_FALLING = (2ul << 20),
    ADC_REGULAR_TIM0_0_BOTH = (3ul << 20),
    ADC_REGULAR_TIM0_1_RISING = ((1ul << 20) | (1ul << 16)),
    ADC_REGULAR_TIM0_1_FALLING = ((2ul << 20) | (1ul << 16)),
    ADC_REGULAR_TIM0_1_BOTH = ((3ul << 20) | (1ul << 16)),
    ADC_REGULAR_TIM0_2_RISING = ((1ul << 20) | (2ul << 16)),
    ADC_REGULAR_TIM0_2_FALLING = ((2ul << 20) | (2ul << 16)),
    ADC_REGULAR_TIM0_2_BOTH = ((3ul << 20) | (2ul << 16)),
    ADC_REGULAR_TIM1_0_RISING = ((1ul << 20) | (3ul << 16)),
    ADC_REGULAR_TIM1_0_FALLING = ((2ul << 20) | (3ul << 16)),
    ADC_REGULAR_TIM1_0_BOTH = ((3ul << 20) | (3ul << 16)),
    ADC_REGULAR_TIM1_1_RISING = ((1ul << 20) | (4ul << 16)),
    ADC_REGULAR_TIM1_1_FALLING = ((2ul << 20) | (4ul << 16)),
    ADC_REGULAR_TIM1_1_BOTH = ((3ul << 20) | (4ul << 16)),
    ADC_REGULAR_TIM1_2_RISING = ((1ul << 20) | (5ul << 16)),
    ADC_REGULAR_TIM1_2_FALLING = ((2ul << 20) | (5ul << 16)),
    ADC_REGULAR_TIM1_2_BOTH = ((3ul << 20) | (5ul << 16)),
    ADC_REGULAR_PWM_EVENT0_RISING = ((1ul << 20) | (6ul << 16)),
    ADC_REGULAR_PWM_EVENT0_FALLING = ((2ul << 20) | (6ul << 16)),
    ADC_REGULAR_PWM_EVENT0_BOTH = ((3ul << 20) | (6ul << 16)),
    ADC_REGULAR_PWM_EVENT1_RISING = ((1ul << 20) | (7ul << 16)),
    ADC_REGULAR_PWM_EVENT1_FALLING = ((2ul << 20) | (7ul << 16)),
    ADC_REGULAR_PWM_EVENT1_BOTH = ((3ul << 20) | (7ul << 16)),
    ADC_INJECTION_SOFTWARE_TRIGER =	(1ul << 14),
    ADC_INJECTION_TIM0_0_RISING = (1ul << 12),
    ADC_INJECTION_TIM0_0_FALLING = (2ul << 12),
    ADC_INJECTION_TIM0_0_BOTH = (3ul << 12),
    ADC_INJECTION_TIM0_1_RISING = ((1ul << 12) | (1ul << 8)),
    ADC_INJECTION_TIM0_1_FALLING = ((2ul << 12) | (1ul << 8)),
    ADC_INJECTION_TIM0_1_BOTH = ((3ul << 12) | (1ul << 8)),
    ADC_INJECTION_TIM0_2_RISING = ((1ul << 12) | (2ul << 8)),
    ADC_INJECTION_TIM0_2_FALLING = ((2ul << 12) | (2ul << 8)),
    ADC_INJECTION_TIM0_2_BOTH = ((3ul << 12) | (2ul << 8)),
    ADC_INJECTION_TIM1_0_RISING = ((1ul << 12) | (3ul << 8)),
    ADC_INJECTION_TIM1_0_FALLING = ((2ul << 12) | (3ul << 8)),
    ADC_INJECTION_TIM1_0_BOTH = ((3ul << 12) | (3ul << 8)),
    ADC_INJECTION_TIM1_1_RISING = ((1ul << 12) | (4ul << 8)),
    ADC_INJECTION_TIM1_1_FALLING = ((2ul << 12) | (4ul << 8)),
    ADC_INJECTION_TIM1_1_BOTH = ((3ul << 12) | (4ul << 8)),
    ADC_INJECTION_TIM1_2_RISING = ((1ul << 12) | (5ul << 8)),
    ADC_INJECTION_TIM1_2_FALLING = ((2ul << 12) | (5ul << 8)),
    ADC_INJECTION_TIM1_2_BOTH = ((3ul << 12) | (5ul << 8)),
    ADC_INJECTION_PWM_EVENT0_RISING = ((1ul << 12) | (6ul << 8)),
    ADC_INJECTION_PWM_EVENT0_FALLING = ((2ul << 12) | (6ul << 8)),
    ADC_INJECTION_PWM_EVENT0_BOTH = ((3ul << 12) | (6ul << 8)),
    ADC_INJECTION_PWM_EVENT1_RISING = ((1ul << 12) | (7ul << 8)),
    ADC_INJECTION_PWM_EVENT1_BOTH = ((3ul << 12) | (7ul << 7)),
    ADC_INJECTION_PWM_EVENT1_FALLING = ((2ul << 12) | (7ul << 8)),
} ADC_TRIGER_MODE_Enum;

typedef enum/**< \brief (ADC_CR2) Set ADC data alignment */
{
    ADC_DataAlign_Right = (0 << 6),
    ADC_DataAlign_Left  = (1ul << 6),
} ADC_ALIGN_Enum;

typedef enum/**< \brief (ADC_CR2) Set DMA transmission data bits */
{
    ADC_DMA_ENABLE_16BIT = 0x0,
    ADC_DMA_ENABLE_32BIT = 0x8,
} ADC_DMA_SIZE_EN_Enum;

typedef enum/**< \brief (ADC_CR2) Set ADC single conversion or continuous conversion mode */
{
    ADC_SIGNEL   = 0,
    ADC_CONTINUE = 0x02,
} ADC_CONVERSION_MODE_Enum;

typedef enum/**< \brief (ADC_SMPR) Set ADC channel sampling time */
{
    ADC_SampleTime_2Cycles = 0,
    ADC_SampleTime_4Cycles,
    ADC_SampleTime_6Cycles,
    ADC_SampleTime_8Cycles,
    ADC_SampleTime_16Cycles,
    ADC_SampleTime_32Cycles,
    ADC_SampleTime_64Cycles,
    ADC_SampleTime_128Cycles,
} ADC_SMP_Enum;

typedef enum/**< \brief (ADC_CCR) Set ADC clock prescaler */
{
    ADC_CLK_Div1,
    ADC_CLK_Div2,
    ADC_CLK_Div4,
    ADC_CLK_Div6,
    ADC_CLK_Div8,
    ADC_CLK_Div10,
    ADC_CLK_Div12,
    ADC_CLK_Div16,
} ADC_CLK_Enum;

typedef enum/**< \brief (ADC_CR2) Set ADC converter switch */
{
    ADC_OFF = 0,
    ADC_ON  = 0x01,
} ADC_ON_Enum;

typedef enum/**< \brief (ADC_CR1) Set ADC resolution selection bit */
{
    ADC_RESOLUTION_12B = 0,
    ADC_RESOLUTION_10B = (1ul << 14),
    ADC_RESOLUTION_8B  = (2ul << 14),
    ADC_RESOLUTION_6B  = (3ul << 14),
} ADC_RESOLUTION_Enum;

typedef enum/**< \brief (ADC_CR1) Set ADC working mode */
{
    ADC_SINGLE_MOD  = 0,
    ADC_PDIFF_MOD   = (1ul << 12),
    ADC_DIFF_MOD    = (2ul << 12),
    ADC_CLEAR_MOD	  = (3ul << 12),
} ADC_MODE_Enum;

typedef enum/**< \brief (ADC_CR1) Set ADC rule channel interrupt mode enable bit */
{
    ADC_DISCON_DISABLE  = 0,
    ADC_DISCON_ENALBE   = (1ul << 11),
} ADC_DISCON_ENABLE_Enum;

typedef enum/**< \brief (ADC_CR1) Set ADC automatic injection channel group conversion */
{
    ADC_JAUTO_DISABLE  = 0,
    ADC_JAUTO_ENALBE   = (1ul << 10),
} ADC_INJECTION_AUTO_Enum;

typedef enum/**< \brief (TPS_CR) Set ADC TPSCR General Register Configuration */
{
    ADC_TPS_EN     =   (1 << 0),
    ADC_BG_EN      =   (1 << 3),
    ADC_VREFBUF_EN =   (1 << 5),
} ADC_TPSCR_Enum;

typedef enum/**< \brief (ADC_CR1) Set ADC scanning mode to enable or disable */
{
    ADC_SCAN_DISABLE = 0,
    ADC_SCAN_ENALBE = (1ul << 8),
} ADC_SCAN_MODE_Enum;

typedef enum/**< \brief (ADC_CR1) Set ADC rule group to simulate watchdog enable or disable */
{
    ADC_AWD_DISABLE = 0,
    ADC_AWD_ENALBE  = (1ul << 6),
} ADC_AWD_ENABLE_Enum;

typedef enum/**< \brief (ADC_CR1) Set ADC injection group to simulate watchdog enable or disable */
{
    ADC_JAWD_DISABLE = 0,
    ADC_JAWD_ENALBE  = (1ul << 5),
} ADC_JAWD_ENABLE_Enum;

typedef enum/**< \brief (ADC_SQR1) Set ADC Setting Rules Channel Sequence Length */
{
    ADC_SQLNUM_2CH =  (0ul << 21),
    ADC_SQLNUM_4CH =  (1ul << 21),
    ADC_SQLNUM_6CH =  (2ul << 21),
    ADC_SQLNUM_8CH =  (3ul << 21),
    ADC_SQLNUM_10CH = (4ul << 21),
    ADC_SQLNUM_12CH = (5ul << 21),
    ADC_SQLNUM_14CH = (6ul << 21),
    ADC_SQLNUM_16CH = (7ul << 21),
} ADC_SQL_Enum;

typedef enum/**< \brief (ADC_IER) ADC interrupt enable type */
{
    ADC_IER_AWD    = (1 << 0),
    ADC_IER_EOC    = (1 << 1),
    ADC_IER_JEOC   = (1 << 2),
    ADC_IER_OVR    = (1 << 5),
    ADC_IER_ENDRX  = (1 << 6),
    ADC_IER_RXBUFF = (1 << 7),
} ADC_INTERRUPT_Enum;

typedef enum/**< \brief (ADC_CR1) Set ADC simulation watchdog to function on all channels or a single channel */
{
    ADC_AWD_ALLCH = 0,
    ADC_AWD_SINGLECH = 1ul << 9,
} ADC_AWD_CONFIG_Enum;

typedef enum/**< \brief (ADC_CR1) Set ADC special function configuration  */
{
    ADC_JAWDEN = (1ul << 5),
    ADC_AWDEN =  (1ul << 6),
    ADC_SCAN =  (1ul << 8),
    ADC_AWDSGL = (1ul << 9),
    ADC_JAUTO = (1ul << 10),
    ADC_DISCEN =  (1ul << 11),
} ADC_function_Enum;

typedef enum/**< \brief (ADC_SR) Set ADC status value configuration */
{
    ADC_SR_AWD =   (1 << 0),
    ADC_SR_EOC =    (1 << 1),
    ADC_SR_JEOC =  (1 << 2),
    ADC_SR_OVR =   (1 << 5),
    ADC_SR_ENDRX =  (1 << 6),
    ADC_SR_RXBUFF = (1 << 7),
} ADC_SR_Enum;

typedef enum/**< \brief (ADC_SR) Clear ADC status value configuration */
{
    ADC_CLEAR_SR_AWD =   (1 << 0),
    ADC_CLEAR_SR_EOC =    (1 << 1),
    ADC_CLEAR_SR_JEOC =  (1 << 2),
    ADC_CLEAR_SR_OVR =   (1 << 5),
    ADC_CLEAR_SR_ENDRX =  (1 << 6),
    ADC_CLEAR_SR_RXBUFF = (1 << 7),
} ADC_CLEAR_SR_Enum;

typedef enum/**< \brief (ADC_JSQR) Set ADC injection channel sequence length */
{
    ADC_JSQL_2 =   (0 << 20),
    ADC_JSQL_4 =   (1 << 20),
} ADC_JSQL_Enum;

typedef enum/**< \brief (ADC_CCR) Set ADC interval mode segment*/
{
    ADC_DISCNUM1 =  0,
    ADC_DISCNUM2 =  1,
    ADC_DISCNUM3 =  2,
    ADC_DISCNUM4 =  3,
} ADC_DISNUMX_Enum;

typedef enum/**< \brief (ADC_CCR) Select the conversion channel length corresponding to the ADC interval mode segment*/
{
    ADC_DISNUM_2CH =  0,
    ADC_DISNUM_4CH =  1,
    ADC_DISNUM_6CH =  2,
    ADC_DISNUM_8CH =  3,
} ADC_DISNUM_Enum;

typedef enum/**< \brief (ADC_DRX) ADC Rule Group Conversion Data Register*/
{
    ADC_DR1 = 0,
    ADC_DR2 = 1,
    ADC_DR3 = 2,
    ADC_DR4 = 3,
    ADC_DR5 = 4,
    ADC_DR6 = 5,
    ADC_DR7 = 6,
    ADC_DR8 = 7,
    ADC_DR9 = 8,
    ADC_DR10 = 9,
    ADC_DR11 = 10,
    ADC_DR12 = 11,
    ADC_DR13 = 12,
    ADC_DR14 = 13,
    ADC_DR15 = 14,
    ADC_DR16 = 15,
} ADC_DR_Enum;

typedef enum/**< \brief (ADC_JDRX) ADC injection group conversion data register*/
{
    ADC_JDR1 = 0,
    ADC_JDR2 = 1,
    ADC_JDR3 = 2,
    ADC_JDR4 = 3,
} ADC_JDR_Enum;

typedef enum/**< \brief (ADC_CR1) ADC chooses to use watchdog on a single channel*/
{
    ADC_AWDCH0 = 0,
    ADC_AWDCH1	,
    ADC_AWDCH2	,
    ADC_AWDCH3	,
    ADC_AWDCH4	,
    ADC_AWDCH5	,
    ADC_AWDCH6	,
    ADC_AWDCH7	,
    ADC_AWDCH8	,
    ADC_AWDCH9	,
    ADC_AWDCH11	,
    ADC_AWDCH12	,
    ADC_AWDCH13	,
    ADC_AWDCH14	,
    ADC_AWDCH15	,
    ADC_AWDCH16	,
} ADC_AWD_CHANNEL_ENUM;

typedef enum/**< \brief (ADC_SQR3) ADC Select Even Channel Input Signal Source Selection*/
{
    ADC_PA12_CHANNEL = 0,
    ADC_PA11_CHANNEL,
    ADC_PA10_CHANNEL,
    ADC_PA9_CHANNEL,
    ADC_PB1_CHANNEL,
    ADC_PB0_CHANNEL,
    ADC_PA4_CHANNEL,
    ADC_PB13_CHANNEL,
    ADC_PB12_CHANNEL,
    ADC_PC1_CHANNEL,
    ADC_PC0_CHANNEL,
    ADC_PGA1_CHANNEL,
    ADC_AVDD1_CHNNEL,
    ADC_VREF1_CHNNEL,
    ADC_GND1_CHNNEL,
    ADC_TPS1_CHNNEL,
} ADC_EVEN_CHANNEL_Enum;

typedef enum/**< \brief (ADC_SQR3) ADC Select Odd Channel Input Signal Source Selection*/
{
    ADC_PB11_CHANNEL = 0,
    ADC_PB6_CHANNEL,
    ADC_PB5_CHANNEL,
    ADC_PB4_CHANNEL,
    ADC_PB3_CHANNEL,
    ADC_PB2_CHANNEL,
    ADC_PA15_CHANNEL,
    ADC_PA14_CHANNEL,
    ADC_PA13_CHANNEL,
    ADC_PB14_CHANNEL,
    ADC_PC2_CHANNEL,
    ADC_PGA0_CHANNEL,
    ADC_AVDD0_CHNNEL,
    ADC_VREF0_CHNNEL,
    ADC_GND0_CHNNEL,
    ADC_TPS0_CHNNEL,
} ADC_ODD_CHANNEL_Enum;

typedef enum/**< \brief  ADC Vref Selection Type Configuration*/
{
    ADC_VREF_OUT_NO = 0,
    ADC_VREF_OUT_VDD = 1,
    ADC_VREF_OUT_1v8 = (1ul << 5),
    ADC_VREF_OUT_2v4 = (3ul << 5),
    ADC_VREF_OUT_2v4_TPS = (1ul | (3ul << 5)),
    ADC_VREF_OUT_1v8_TPS = (1ul | (1ul << 5)),
} ADC_VREF_OUT_Enum;

typedef enum/**< \brief (ADC_CR3) ADC reference source selection*/
{
    ADC_VREF_SEL = 0,
    ADC_AVDD_SEL = (1ul << 4),
} ADC_REF_SEL_Enum;

typedef enum/**< \brief  ADC clock source selection*/
{
    ADC_BUS_CLK_SEL = 0,
    ADC_PLL_CLK_SEL = (1ul << 20),
} ADC_CLK_SEL_Enum;

typedef struct
{
    ADC_RESOLUTION_Enum        ADC_Resolution;
    ADC_SCAN_MODE_Enum         ADC_ScanConvMode;
    ADC_CONVERSION_MODE_Enum   ADC_ContinuousConvMode;
    ADC_ALIGN_Enum             ADC_DataAlign;
    ADC_MODE_Enum              ADC_Mode;
    ADC_CLK_Enum               ADC_Prescaler;
    ADC_DMA_SIZE_EN_Enum       ADC_DMAAccessMode;
    ADC_CLK_SEL_Enum           ADC_CLK_SEL;
} ADC_Init_T;

void ADC_DeInit(void);

void ADC_Init(ADC_Type* ADCx, ADC_Init_T* ADC_InitConfig);

void	ADC_VREF_OUT(ADC_VREF_OUT_Enum vref, ADC_REF_SEL_Enum ref_sel);

void ADC_RegularNbrOfChannel(ADC_SQL_Enum  ADC_NbrOfChannel);

void ADC_InjectedNbrOfChannel(ADC_JSQL_Enum  ADC_NbrOfChannel);

void ADC_Cmd(ADC_Type* ADCx, FunctionalState NewState);

void ADC_DMACmd(ADC_Type* ADCx, FunctionalState NewState);

void ADC_Enable_IT(ADC_Type* ADCx, ADC_INTERRUPT_Enum ADC_IT);
void ADC_Disable_IT(ADC_Type* ADCx, ADC_INTERRUPT_Enum ADC_IT);

void ADC_SoftwareStartConvCmd(ADC_Type* ADCx, FunctionalState NewState);

void ADC_ExternalTrigConv(ADC_TRIGER_MODE_Enum  ADC_ExternalTrigConv)  ;

FlagStatus ADC_GetSoftwareStartConvStatus(ADC_Type* ADCx);

void ADC_DISCNUMConfig(ADC_DISNUMX_Enum  UM, ADC_DISNUM_Enum Channel_Sum);

void ADC_DiscModeCmd(ADC_Type* ADCx, FunctionalState NewState);

void ADC_RegularOddChannelConfig(ADC_Type* ADCx, ADC_ODD_CHANNEL_Enum channel, uint8_t rank, ADC_SMP_Enum ADC_SampleTime);

void ADC_RegularEvenChannelConfig(ADC_Type* ADCx,  ADC_EVEN_CHANNEL_Enum channel, uint8_t rank, ADC_SMP_Enum sample_time);

uint16_t ADC_GetConversionValue(ADC_Type* ADCx, ADC_DR_Enum DRX);

void ADC_AutoInjectedConvCmd(ADC_Type* ADCx, FunctionalState NewState);

FlagStatus ADC_GetSoftwareStartInjectedConvCmdStatus(ADC_Type* ADCx);

void ADC_InjectedOddChannelConfig(ADC_Type* ADCx,  ADC_ODD_CHANNEL_Enum channel, uint8_t rank, ADC_SMP_Enum sample_time);

void ADC_InjectedEvenChannelConfig(ADC_Type* ADCx,  ADC_EVEN_CHANNEL_Enum channel, uint8_t rank, ADC_SMP_Enum sample_time);

void ADC_InjectedSequencerLengthConfig(ADC_Type* ADCx, ADC_JSQL_Enum Length);

uint16_t ADC_GetInjectedConversionValue(ADC_Type* ADCx,  ADC_JDR_Enum JDRX);

void ADC_AnalogWatchdogCmd(ADC_function_Enum ADC_AnalogWatchdog, ADC_AWD_CONFIG_Enum AWD_CONFIG, ADC_AWD_CHANNEL_ENUM AWD_CHANNEL);

void ADC_AnalogWatchdogThresholdsConfig(ADC_Type* ADCx, uint16_t HighThreshold, uint16_t LowThreshold);

FlagStatus ADC_GetFlagStatus(ADC_Type* ADCx, ADC_SR_Enum ADC_FLAG);

void ADC_ClearFlag(ADC_Type* ADCx, ADC_CLEAR_SR_Enum ADC_FLAG);

uint8_t ADC_GetITStatus(ADC_Type* ADCx, ADC_INTERRUPT_Enum ADC_IT);

void ADC_DMA_Configure(uint8_t len, uint16_t *buffer);

int16_t ADC_Get_Temperature(unsigned short result, ADC_VREF_Enum vreftype);

#ifdef __cplusplus
}
#endif
#endif

