/**
  ******************************************************************************
  * @file           : ms60f3xxx_comp.h
  * @author         : sinomcu.com-SA
  * @brief          : Header file of COMP module.
  * @gcc            : toolchain version 5 or 6
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with 
 * basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
*/

#ifndef MS60F3XXX_COMP_H
#define MS60F3XXX_COMP_H

#ifdef __cplusplus

 extern "C" {
#endif

#include "ms60f3xxx.h"
#include <stdio.h>

typedef enum/**< \brief (COMP_IER) Comparator output rising or falling edge interrupt enable */
{
    COMP0_FE  = 0x01,
    COMP0_RE  = 0x02,
    COMP1_FE  = 0x04,
    COMP1_RE  = 0x08,
} COMPx_elem;

typedef enum/**< \brief (COMP_LOOPDATX) Comparator output X */
{
    COMP_DAT0  = 0x1,
    COMP_DAT1  = 0x2,
    COMP_DAT2  = 0x4,
} COMPx_output;

typedef enum/**< \brief (COM_DAC_CR) Reference reference selection control signal for internal DACx */
{
    COMP_VDD    = 0x0,
    COMP_VREF   = 0x1,
} VREF_output;

typedef enum/**< \brief (COM_DAC_CR) Control code for internal DACx */
{
    COMP_DAC0   = 0,
    COMP_DAC1   = 1,
} COMP_DAC_Enum;

typedef enum/**< \brief (COMP_LOOPCRx) Comparator input negative terminal selection */
{
    COMPN_NSEL0 = 0x01,
    COMPN_NSEL1 = 0x100,
    COMPN_NSEL2 = 0x10000,
} COMPN_in;

typedef enum/**< \brief (COMP_LOOPCRx) Positive end selection of comparator input */
{
    COMPP_PSEL0 = 0x10,
    COMPP_PSEL1 = 0x1000,
    COMPP_PSEL2 = 0x100000,
} COMPP_in;

typedef enum/**< \brief (COMP_CRx) COMP0 or COMP1 selection */
{
    COMP0       = 0x0,
    COMP1       = 0x1,
} COMP_Enum;

typedef enum/**< \brief (COMP_CRx) Comparator polarity sexual selection */
{
    COMP_NORMAL         = 0,
    COMP_REVERSE        = 1 << 15,
} COMP_POLAR_Enum;

typedef enum/**< \brief (COMP_CRx) Comparator enable */
{
    COMP_DISABLE        = 0,
    COMP_ENABLE         = 1 << 8,
} COMP_EN_Enum;

typedef enum/**< \brief (COMP_LOOPCRx) Automatic rotation comparison enable */
{
    COMP0_LOOP_EN       = 1 << 28,
    COMP1_LOOP_EN       = 1 << 28,
} COMP_LOOP_Enum;

typedef enum/**< \brief (COMP_CRx) Final negative input selection control of comparator */
{
    COMP_NMUx           = 0,
    COMP_NAVSS          = 1 << 9,
    COMP_NDAC           = 2 << 9,
} COMP_NFISL_Enum;

typedef enum/**< \brief (COMP_CRx) Final positive input selection control of comparator */
{
    COMP_PMUx           = 0,
    COMP_PDAC           = 1 << 11,
} COMP_PFISL_Enum;

typedef enum/**< \brief (COMP_CRx) Comparator output filtering cycle selection bit */
{
    COMP_Pclk_1         = 0x0 << 17,
    COMP_Pclk_4         = 0x1 << 17,
    COMP_Pclk_16        = 0x2 << 17,
    COMP_Pclk_32        = 0x3 << 17,
    COMP_Pclk_64        = 0x4 << 17,
    COMP_Pclk_128       = 0x5 << 17,
    COMP_Pclk_256       = 0x6 << 17,
    COMP_Pclk_512       = 0x7 << 17,
} COMP_FILT_N_Enum;

typedef enum/**< \brief (COMP_CRx) Comparator response speed control signal */
{
    COMP_Response_0       = 0,
    COMP_Response_1       = 0x1 << 12,
    COMP_Response_2       = 0x2 << 12,
    COMP_Response_3       = 0x3 << 12,
    COMP_Response_4       = 0x4 << 12,
    COMP_Response_5       = 0x5 << 12,
    COMP_Response_6       = 0x6 << 12,
    COMP_Response_7       = 0x7 << 12,
} COMP_Response_Enum;

typedef enum/**< \brief (COMP_CRx) Comparator hysteresis voltage selection */
{
    COMP_CR_HYST0   = 0x0 << 20,
    COMP_CR_HYST1   = 0x1 << 20,
    COMP_CR_HYST2   = 0x2 << 20,
    COMP_CR_HYST3   = 0x3 << 20,
    COMP_CR_HYST4   = 0x4 << 20,
    COMP_CR_HYST5   = 0x5 << 20,
    COMP_CR_HYST6   = 0x6 << 20,
    COMP_CR_HYST7   = 0x7 << 20,
    COMP_CR_HYST8   = 0x8 << 20,
    COMP_CR_HYST9   = 0x9 << 20,
    COMP_CR_HYST10  = 0xA << 20,
    COMP_CR_HYST11  = 0xB << 20,
    COMP_CR_HYST12  = 0xC << 20,
    COMP_CR_HYST13  = 0xD << 20,
} COMP_HYST_Enum;

typedef enum/**< \brief (COMP_CRx) Comparator 0 input negative terminal selection */
{
    COMP0_N_PB11    = 0x0,
    COMP0_N_PB6     = 0x1,
    COMP0_N_PB5     = 0x2,
    COMP0_N_PB4     = 0x3,
    COMP0_N_PB3     = 0x4,
    COMP0_N_PB2     = 0x5,
    COMP0_N_PA15    = 0x6,
    COMP0_N_PA14    = 0x7,
    COMP0_N_PA13    = 0x8,
    COMP0_N_PB14    = 0x9,
    COMP0_N_PC2     = 0xA,
    COMP0_N_VREFP   = 0xB,
    COMP0_N_AGND    = 0xC,
    COMP0_N_AVDD    = 0xD,
} COMP0_N_Enum;

typedef enum/**< \brief (COMP_CRx) Comparator 1 input negative terminal selection */
{
    COMP1_N_PA12    = 0,
    COMP1_N_PA11    = 0x1,
    COMP1_N_PA10    = 0x2,
    COMP1_N_PA9 	  = 0x3,
    COMP1_N_PB1 	  = 0x4,
    COMP1_N_PB0 	  = 0x5,
    COMP1_N_PA4 	  = 0x6,
    COMP1_N_PB13    = 0x7,
    COMP1_N_PB12    = 0x8,
    COMP1_N_PC1     = 0x9,
    COMP1_N_PC0     = 0xA,
    COMP1_N_VREFP   = 0xB,
    COMP1_N_AGND    = 0xC,
    COMP1_N_AVDD    = 0xD,
} COMP1_N_Enum;

typedef enum/**< \brief (COMP_CRx) Comparator 0 input positive terminal selection */
{
    COMP0_P_PB11     = 0,
    COMP0_P_PB6      = 0x1 << 4,
    COMP0_P_PB5      = 0x2 << 4,
    COMP0_P_PB4      = 0x3 << 4,
    COMP0_P_PB3      = 0x4 << 4,
    COMP0_P_PB2      = 0x5 << 4,
    COMP0_P_PA15     = 0x6 << 4,
    COMP0_P_PA14     = 0x7 << 4,
    COMP0_P_PA13     = 0x8 << 4,
    COMP0_P_PB14     = 0x9 << 4,
    COMP0_P_PC2      = 0xA << 4,
    COMP0_P_PGA0_OUT = 0xB << 4,
    COMP0_P_PGA1_OUT = 0xC << 4,
    COMP0_P_AVDD     = 0xD << 4,
    COMP0_P_DVDD15   = 0xE << 4,
} COMP0_P_Enum;

typedef enum/**< \brief (COMP_CRx) Comparator 1 input positive terminal selection */
{
    COMP1_P_PA12     = 0x0,
    COMP1_P_PA11     = 0x1 << 4,
    COMP1_P_PA10     = 0x2 << 4,
    COMP1_P_PA9      = 0x3 << 4,
    COMP1_P_PB1      = 0x4 << 4,
    COMP1_P_PB0      = 0x5 << 4,
    COMP1_P_PA4      = 0x6 << 4,
    COMP1_P_PB13     = 0x7 << 4,
    COMP1_P_PB12     = 0x8 << 4,
    COMP1_P_PC1      = 0x9 << 4,
    COMP1_P_PC0  	   = 0xA << 4,
    COMP1_P_PGA0_OUT = 0xB << 4,
    COMP1_P_PGA1_OUT = 0xC << 4,
    COMP1_P_AVDD     = 0xD << 4,
    COMP1_P_DVDD15   = 0xE << 4,
} COMP1_P_Enum;

typedef enum/**< \brief (COMP_LOOPCRx) Comparison interval is xxx system cycles */
{
    COMP_GAP_16x1_Systemcycle   = 0x0 << 24,
    COMP_GAP_16x2_Systemcycle   = 0x1 << 24,
    COMP_GAP_16x3_Systemcycle   = 0x2 << 24,
    COMP_GAP_16x4_Systemcycle   = 0x3 << 24,
    COMP_GAP_16x5_Systemcycle   = 0x4 << 24,
    COMP_GAP_16x6_Systemcycle   = 0x5 << 24,
    COMP_GAP_16x7_Systemcycle   = 0x6 << 24,
    COMP_GAP_16x8_Systemcycle   = 0x7 << 24,
    COMP_GAP_16x10_Systemcycle  = 0x8 << 24,
    COMP_GAP_16x12_Systemcycle  = 0x9 << 24,
    COMP_GAP_16x14_Systemcycle  = 0xA << 24,
    COMP_GAP_16x16_Systemcycle  = 0xB << 24,
    COMP_GAP_16x20_Systemcycle  = 0xC << 24,
    COMP_GAP_16x24_Systemcycle  = 0xD << 24,
    COMP_GAP_16x28_Systemcycle  = 0xE << 24,
    COMP_GAP_16x32_Systemcycle  = 0xF << 24,
} COMP_GAP_Enum;

typedef struct
{
    COMP_FILT_N_Enum       FILT_N;
    COMP_HYST_Enum         HYST;

    COMP_POLAR_Enum        POLAR;
    COMP_Response_Enum     VEL_CTL;
    COMP_NFISL_Enum        NFISL;
    COMP_PFISL_Enum        PFISL;
    COMP_EN_Enum   		     COMP_en;

    COMP0_P_Enum  		     COMP0_P;
    COMP1_P_Enum	         COMP1_P;
    COMP0_N_Enum 	         COMP0_N;
    COMP1_N_Enum           COMP1_N;
    COMP_Enum              COMPSelect;
} COMP_Init_T;

typedef struct
{
    COMP0_P_Enum  	COMP0_PSEL0;
    COMP0_P_Enum 		COMP0_PSEL1;
    COMP0_P_Enum 		COMP0_PSEL2;
    COMP0_N_Enum 		COMP0_NSEL0;
    COMP0_N_Enum 		COMP0_NSEL1;
    COMP0_N_Enum 		COMP0_NSEL2;
    COMP1_P_Enum  	COMP1_PSEL0;
    COMP1_P_Enum 		COMP1_PSEL1;
    COMP1_P_Enum 		COMP1_PSEL2;
    COMP1_N_Enum 		COMP1_NSEL0;
    COMP1_N_Enum 		COMP1_NSEL1;
    COMP1_N_Enum 		COMP1_NSEL2;
    COMP_GAP_Enum   GAP;
} COMP_LOOPCR_T;

void COMP_Init(COMP_Init_T* COMP_InitStruct);

void COMP_DAC_INPUT(uint8_t  VALUE, COMP_DAC_Enum  comp, VREF_output VREF_OUT);

void COMP_Enable_IT(COMPx_elem  p_comp);

void COMP_Disable_IT(COMPx_elem  p_comp);

void  COMP_IFR_Clear_flag(COMPx_elem  p_comp);

booltyped  COMP_DataOut(COMP_Enum COMPSelect);

void  COMP_LOOPCR_Init(COMP_LOOPCR_T *COMP_InitStruct);

void  COMP_LOOPCRCmd(COMP_LOOP_Enum  COMP_en, FunctionalState NewState);

booltyped  COMP_LOOPoutput(COMP_Enum COMPx, COMPx_output output);

#ifdef __cplusplus
}
#endif
#endif
