/**
  ******************************************************************************
  * @file           : main.c
  * @author         : sinomcu.com-SA
  * @brief          : Main program file.
  * @gcc            : toolchain version   5 or 6
  *
  ******************************************************************************
  * @attention
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with
	* basic chip information support
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */

#ifndef MS60F3XXX_CORDIC_H
#define MS60F3XXX_CORDIC_H

#ifdef __cplusplus
extern "C" {
#endif

#include "ms60f3xxx.h"


#define CORDIC_START   0x01

typedef enum /**< \brief (MODE0) CORDIC mode0 register   */
{
    SINCOS_MODE = 1,
    SQRT_MODE	   = 0x19
} CORDIC_CIRCLE_MODE_Enum;

typedef enum /**< \brief (MODE0) Control Register  */
{
    HSINCOS_MODE = 5,
    HSQRT_MODE	   = 0x0D
} CORDIC_HYPOBOLIC_MODE_Enum;

typedef enum /**< \brief (CR) Control Register  */
{
    CORDIC_EN  = 1,
    DIV_EN  = 2,
    ALL_UNIT_EN    = 0x03
} CORDIC_EN_Enum;

typedef enum /**< \brief (IE)interrupt enable register */
{
    CORDIC_DONE_IE = 0x01,
    CORDIC_ERR_IE  = 0x02,
    DIV_DONE_IE = 0x04,
    CORDIC1_ERR_IE  = 0x08,
} CORDIC_INT_Enum;

typedef enum /**< \brief (STA)CORDIC STATUS */
{

    CORDIC_DONE0IF  = 1,
    CORDIC_ERR0IF  = 2,
    DIV_DONEIF  = 4,
    DIV_ERRIF  = 8,

} CORDIC_IF_Enum;

typedef struct
{
    int32_t value;
    union
    {
        uint32_t value1: 23;
        uint32_t signnal: 1;
    };
} int24_t;
typedef struct
{
    int32_t value;
    union
    {
        uint32_t value1: 24;
    };
} uint24_t;

typedef struct
{
    __IOM uint32_t  DX;                          /*!< (@ 0x00000030) CORDIC 2 input x                                           */
    __IOM uint32_t  DY;                          /*!< (@ 0x00000034) CORDIC 2 input y                                           */
    __IOM uint32_t  DZ;                          /*!< (@ 0x00000038) CORDIC 2 input Z                                           */
    __IOM uint32_t MODE;                       /*!< (@ 0x0000003C) CORDIC 2 mode register                                     */

} CORDIC_UNIT_T;

#define CORDIC_UNIT0_BASE                        CORDIC_BASE+0x08
#define CORDIC_UNIT0  ((CORDIC_UNIT_TYPE*)       CORDIC_UNIT0_BASE)
#define CORDIC_UNIT1  ((CORDIC_UNIT_TYPE*)       CORDIC_UNIT0_BASE+0x10)
#define CORDIC_UNIT2  ((CORDIC_UNIT_TYPE*)       CORDIC_UNIT0_BASE+0x20)
#define CORDIC_UNIT3  ((CORDIC_UNIT_TYPE*)       CORDIC_UNIT0_BASE+0x30)
#define CORDIC_UNIT4  ((CORDIC_UNIT_TYPE*)       CORDIC_UNIT0_BASE+0x40)
#define CORDIC_UNIT5  ((CORDIC_UNIT_TYPE*)       CORDIC_UNIT0_BASE+0x50)


void CORDIC_Init(void);
void CORDIC_Enable_IT(uint8_t cordic_int);
void CORDIC_Disable_IT(uint8_t cordic_int);
uint16_t CORDIC_GetIf(void);
int32_t CORDIC_DivFun(int32_t *dividend, int32_t *divisor);
int32_t CORDIC_SinCosFun(int24_t *rad, int24_t *sint, int24_t *cost);
uint32_t CORDIC_SqrtFun(uint24_t *x, uint24_t *y, uint24_t *rad);
int32_t CODIC_HsincosFun(int24_t *hcos, int24_t *hsin, int24_t *rad);
int32_t CODIC_HsqrtFun(int24_t *x, int24_t *y, int24_t *rad);
void cordic_test(void);

#ifdef __cplusplus
}
#endif

#endif


