/**
  ******************************************************************************
  * @file           : ms60f3xxx_dac.h
  * @author         : sinomcu.com-SA
  * @brief          :  Header file of DAC module.
  * @gcc            : toolchain version 5 or 6
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with 
 * basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
*/
#ifndef MS60F3XXX_DAC_H
#define MS60F3XXX_DAC_H
#ifdef __cplusplus
 extern "C" {
#endif
#include "ms60f3xxx.h"
#define DAC_TYPE DAC0_Type
typedef enum/**< \brief (DACx_CR2) DAC reference selection */
{
    DAC_Refsel_VREF = 0,
    DAC_Refsel_VDD
} DAC_REF_Enum;

typedef enum/**< \brief (DACx_CR2) DAC_ DHR data transfer to register DAC_ DOR bit alignment */
{
    DAC_RIGHT_LIGN = 0,
    DAC_LEFT_LIGN  = (1 << 2),
    DAC_RIGHT_8bit_LIGN = (2 << 2),
} DAC_LIGN_Enum;

typedef enum/**< \brief (DACx_CR1) DAC  Enable or Disable */
{
    DAC_DISABLE = 0,
    DAC_ENABLE  = 1,
} DAC_EN_Enum;

typedef enum/**< \brief (DACx_CR1)DAC channel trigger enable or Disable */
{
    DISABLE_TEN = 0,
    ENABLE_TEN = (1 << 2),
} DAC_TEN_Enum;

typedef enum/**< \brief (DACx_CR1) DAC channel trigger selection */
{
    TIM0_0_TIOA = 0,
    TIM0_1_TIOA = (1 << 4),
    TIM0_2_TIOA = (2 << 4),
    TIM1_0_TIOA = (3 << 4),
    TIM1_1_TIOA = (4 << 4),
    TIM1_2_TIOA = (5 << 4),
    PWM_EVENT1  = (6 << 4),
    PWM_EVENT2  = (7 << 4),
    EXTI0_0SEL  = (8 << 4),
    EXTI1_2SEL  = (9 << 4),
    EXTI3_4SEL  = (10 << 4),
    EXTI5_15SEL = (11 << 4),
    DAC_TIMER_SEL = (14 << 4),
    DAC_SOFT_SEL  = (15 << 4)
} DAC_TSEL_Enum;

typedef struct
{
    DAC_REF_Enum   dac_ref;
    DAC_LIGN_Enum  dac_lign;
    DAC_TEN_Enum   dac_ten;
    DAC_TSEL_Enum  dac_tsel;
    DAC_EN_Enum    dac_en;
} DAC_Init_T;
void DAC_LOAD(DAC_Type *dac, uint16_t value);
void DAC_INIT(DAC_Type *dac, DAC_Init_T *dac_init);


#ifdef __cplusplus
}
#endif

#endif
