/**
  ******************************************************************************
  * @file           : ms60f3xxx_exti.h
  * @author         : sinomcu.com-SA
  * @brief          : Header file of exti module.
  * @gcc            : toolchain version 5 or 6
  *
  ******************************************************************************
  * @attention
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with
	* basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */
#ifndef  MS60F3XXX_EXTI_H
#define  MS60F3XXX_EXTI_H

#ifdef __cplusplus
extern "C" {
#endif

#include "ms60f3xxx.h"
#include "ms60f3xxx_gpio.h"

/* =========================================================================================================================== */
/* ================                                           EXTI                                            ================ */
/* =========================================================================================================================== */

/* ==========================================================  IER  ========================================================== */
#define EXTI_IER_EXTI0_Pos                (0ul)                     /*!< EXTI0 (Bit 0)                                         */
#define EXTI_IER_EXTI0_Msk                (0x1ul)                   /*!< EXTI0 (Bitfield-Mask: 0x01)                           */
#define EXTI_IER_EXTI0                    EXTI_IER_EXTI0_Msk
#define EXTI_IER_EXTI1_Pos                (1ul)                     /*!< EXTI1 (Bit 1)                                         */
#define EXTI_IER_EXTI1_Msk                (0x2ul)                   /*!< EXTI1 (Bitfield-Mask: 0x01)                           */
#define EXTI_IER_EXTI1                    EXTI_IER_EXTI1_Msk
#define EXTI_IER_EXTI2_Pos                (2ul)                     /*!< EXTI2 (Bit 2)                                         */
#define EXTI_IER_EXTI2_Msk                (0x4ul)                   /*!< EXTI2 (Bitfield-Mask: 0x01)                           */
#define EXTI_IER_EXTI2                    EXTI_IER_EXTI2_Msk
#define EXTI_IER_EXTI3_Pos                (3ul)                     /*!< EXTI3 (Bit 3)                                         */
#define EXTI_IER_EXTI3_Msk                (0x8ul)                   /*!< EXTI3 (Bitfield-Mask: 0x01)                           */
#define EXTI_IER_EXTI3                    EXTI_IER_EXTI3_Msk
#define EXTI_IER_EXTI4_Pos                (4ul)                     /*!< EXTI4 (Bit 4)                                         */
#define EXTI_IER_EXTI4_Msk                (0x10ul)                  /*!< EXTI4 (Bitfield-Mask: 0x01)                           */
#define EXTI_IER_EXTI4                    EXTI_IER_EXTI4_Msk
#define EXTI_IER_EXTI5_Pos                (5ul)                     /*!< EXTI5 (Bit 5)                                         */
#define EXTI_IER_EXTI5_Msk                (0x20ul)                  /*!< EXTI5 (Bitfield-Mask: 0x01)                           */
#define EXTI_IER_EXTI5                    EXTI_IER_EXTI5_Msk
#define EXTI_IER_EXTI6_Pos                (6ul)                     /*!< EXTI6 (Bit 6)                                         */
#define EXTI_IER_EXTI6_Msk                (0x40ul)                  /*!< EXTI6 (Bitfield-Mask: 0x01)                           */
#define EXTI_IER_EXTI6                    EXTI_IER_EXTI6_Msk
#define EXTI_IER_EXTI7_Pos                (7ul)                     /*!< EXTI7 (Bit 7)                                         */
#define EXTI_IER_EXTI7_Msk                (0x80ul)                  /*!< EXTI7 (Bitfield-Mask: 0x01)                           */
#define EXTI_IER_EXTI7                    EXTI_IER_EXTI7_Msk
#define EXTI_IER_EXTI8_Pos                (8ul)                     /*!< EXTI8 (Bit 8)                                         */
#define EXTI_IER_EXTI8_Msk                (0x100ul)                 /*!< EXTI8 (Bitfield-Mask: 0x01)                           */
#define EXTI_IER_EXTI8                    EXTI_IER_EXTI8_Msk
#define EXTI_IER_EXTI9_Pos                (9ul)                     /*!< EXTI9 (Bit 9)                                         */
#define EXTI_IER_EXTI9_Msk                (0x200ul)                 /*!< EXTI9 (Bitfield-Mask: 0x01)                           */
#define EXTI_IER_EXTI9                    EXTI_IER_EXTI9_Msk
#define EXTI_IER_EXTI10_Pos               (10ul)                    /*!< EXTI10 (Bit 10)                                       */
#define EXTI_IER_EXTI10_Msk               (0x400ul)                 /*!< EXTI10 (Bitfield-Mask: 0x01)                          */
#define EXTI_IER_EXTI10                   EXTI_IER_EXTI10_Msk
#define EXTI_IER_EXTI11_Pos               (11ul)                    /*!< EXTI11 (Bit 11)                                       */
#define EXTI_IER_EXTI11_Msk               (0x800ul)                 /*!< EXTI11 (Bitfield-Mask: 0x01)                          */
#define EXTI_IER_EXTI11                   EXTI_IER_EXTI11_Msk
#define EXTI_IER_EXTI12_Pos               (12ul)                    /*!< EXTI12 (Bit 12)                                       */
#define EXTI_IER_EXTI12_Msk               (0x1000ul)                /*!< EXTI12 (Bitfield-Mask: 0x01)                          */
#define EXTI_IER_EXTI12                   EXTI_IER_EXTI12_Msk
#define EXTI_IER_EXTI13_Pos               (13ul)                    /*!< EXTI13 (Bit 13)                                       */
#define EXTI_IER_EXTI13_Msk               (0x2000ul)                /*!< EXTI13 (Bitfield-Mask: 0x01)                          */
#define EXTI_IER_EXTI13                   EXTI_IER_EXTI13_Msk
#define EXTI_IER_EXTI14_Pos               (14ul)                    /*!< EXTI14 (Bit 14)                                       */
#define EXTI_IER_EXTI14_Msk               (0x4000ul)                /*!< EXTI14 (Bitfield-Mask: 0x01)                          */
#define EXTI_IER_EXTI14                   EXTI_IER_EXTI14_Msk
#define EXTI_IER_EXTI15_Pos               (15ul)                    /*!< EXTI15 (Bit 15)                                       */
#define EXTI_IER_EXTI15_Msk               (0x8000ul)                /*!< EXTI15 (Bitfield-Mask: 0x01)                          */
#define EXTI_IER_EXTI15                   EXTI_IER_EXTI15_Msk
/* ==========================================================  IDR  ========================================================== */
#define EXTI_IDR_EXTI0_Pos                (0ul)                     /*!< EXTI0 (Bit 0)                                         */
#define EXTI_IDR_EXTI0_Msk                (0x1ul)                   /*!< EXTI0 (Bitfield-Mask: 0x01)                           */
#define EXTI_IDR_EXTI0                    EXTI_IDR_EXTI0_Msk
#define EXTI_IDR_EXTI1_Pos                (1ul)                     /*!< EXTI1 (Bit 1)                                         */
#define EXTI_IDR_EXTI1_Msk                (0x2ul)                   /*!< EXTI1 (Bitfield-Mask: 0x01)                           */
#define EXTI_IDR_EXTI1                    EXTI_IDR_EXTI1_Msk
#define EXTI_IDR_EXTI2_Pos                (2ul)                     /*!< EXTI2 (Bit 2)                                         */
#define EXTI_IDR_EXTI2_Msk                (0x4ul)                   /*!< EXTI2 (Bitfield-Mask: 0x01)                           */
#define EXTI_IDR_EXTI2                    EXTI_IDR_EXTI2_Msk
#define EXTI_IDR_EXTI3_Pos                (3ul)                     /*!< EXTI3 (Bit 3)                                         */
#define EXTI_IDR_EXTI3_Msk                (0x8ul)                   /*!< EXTI3 (Bitfield-Mask: 0x01)                           */
#define EXTI_IDR_EXTI3                    EXTI_IDR_EXTI3_Msk
#define EXTI_IDR_EXTI4_Pos                (4ul)                     /*!< EXTI4 (Bit 4)                                         */
#define EXTI_IDR_EXTI4_Msk                (0x10ul)                  /*!< EXTI4 (Bitfield-Mask: 0x01)                           */
#define EXTI_IDR_EXTI4                    EXTI_IDR_EXTI4_Msk
#define EXTI_IDR_EXTI5_Pos                (5ul)                     /*!< EXTI5 (Bit 5)                                         */
#define EXTI_IDR_EXTI5_Msk                (0x20ul)                  /*!< EXTI5 (Bitfield-Mask: 0x01)                           */
#define EXTI_IDR_EXTI5                    EXTI_IDR_EXTI5_Msk
#define EXTI_IDR_EXTI6_Pos                (6ul)                     /*!< EXTI6 (Bit 6)                                         */
#define EXTI_IDR_EXTI6_Msk                (0x40ul)                  /*!< EXTI6 (Bitfield-Mask: 0x01)                           */
#define EXTI_IDR_EXTI6                    EXTI_IDR_EXTI6_Msk
#define EXTI_IDR_EXTI7_Pos                (7ul)                     /*!< EXTI7 (Bit 7)                                         */
#define EXTI_IDR_EXTI7_Msk                (0x80ul)                  /*!< EXTI7 (Bitfield-Mask: 0x01)                           */
#define EXTI_IDR_EXTI7                    EXTI_IDR_EXTI7_Msk
#define EXTI_IDR_EXTI8_Pos                (8ul)                     /*!< EXTI8 (Bit 8)                                         */
#define EXTI_IDR_EXTI8_Msk                (0x100ul)                 /*!< EXTI8 (Bitfield-Mask: 0x01)                           */
#define EXTI_IDR_EXTI8                    EXTI_IDR_EXTI8_Msk
#define EXTI_IDR_EXTI9_Pos                (9ul)                     /*!< EXTI9 (Bit 9)                                         */
#define EXTI_IDR_EXTI9_Msk                (0x200ul)                 /*!< EXTI9 (Bitfield-Mask: 0x01)                           */
#define EXTI_IDR_EXTI9                    EXTI_IDR_EXTI9_Msk
#define EXTI_IDR_EXTI10_Pos               (10ul)                    /*!< EXTI10 (Bit 10)                                       */
#define EXTI_IDR_EXTI10_Msk               (0x400ul)                 /*!< EXTI10 (Bitfield-Mask: 0x01)                          */
#define EXTI_IDR_EXTI10                   EXTI_IDR_EXTI10_Msk
#define EXTI_IDR_EXTI11_Pos               (11ul)                    /*!< EXTI11 (Bit 11)                                       */
#define EXTI_IDR_EXTI11_Msk               (0x800ul)                 /*!< EXTI11 (Bitfield-Mask: 0x01)                          */
#define EXTI_IDR_EXTI11                   EXTI_IDR_EXTI11_Msk
#define EXTI_IDR_EXTI12_Pos               (12ul)                    /*!< EXTI12 (Bit 12)                                       */
#define EXTI_IDR_EXTI12_Msk               (0x1000ul)                /*!< EXTI12 (Bitfield-Mask: 0x01)                          */
#define EXTI_IDR_EXTI12                   EXTI_IDR_EXTI12_Msk
#define EXTI_IDR_EXTI13_Pos               (13ul)                    /*!< EXTI13 (Bit 13)                                       */
#define EXTI_IDR_EXTI13_Msk               (0x2000ul)                /*!< EXTI13 (Bitfield-Mask: 0x01)                          */
#define EXTI_IDR_EXTI13 							    EXTI_IDR_EXTI13_Msk
#define EXTI_IDR_EXTI14_Pos               (14ul)                    /*!< EXTI14 (Bit 14)                                       */
#define EXTI_IDR_EXTI14_Msk               (0x4000ul)                /*!< EXTI14 (Bitfield-Mask: 0x01)                          */
#define EXTI_IDR_EXTI14                   EXTI_IDR_EXTI14_Msk
#define EXTI_IDR_EXTI15_Pos               (15ul)                    /*!< EXTI15 (Bit 15)                                       */
#define EXTI_IDR_EXTI15_Msk               (0x8000ul)                /*!< EXTI15 (Bitfield-Mask: 0x01)                          */
#define EXTI_IDR_EXTI15                   EXTI_IDR_EXTI15_Msk
/* ==========================================================  IMR  ========================================================== */
#define EXTI_IMR_EXTI0_Pos                (0ul)                     /*!< EXTI0 (Bit 0)                                         */
#define EXTI_IMR_EXTI0_Msk                (0x1ul)                   /*!< EXTI0 (Bitfield-Mask: 0x01)                           */
#define EXTI_IMR_EXTI0                    EXTI_IMR_EXTI0_Msk
#define EXTI_IMR_EXTI1_Pos                (1ul)                     /*!< EXTI1 (Bit 1)                                         */
#define EXTI_IMR_EXTI1_Msk                (0x2ul)                   /*!< EXTI1 (Bitfield-Mask: 0x01)                           */
#define EXTI_IMR_EXTI1                    EXTI_IMR_EXTI1_Msk
#define EXTI_IMR_EXTI2_Pos                (2ul)                     /*!< EXTI2 (Bit 2)                                         */
#define EXTI_IMR_EXTI2_Msk                (0x4ul)                   /*!< EXTI2 (Bitfield-Mask: 0x01)                           */
#define EXTI_IMR_EXTI2                    EXTI_IMR_EXTI2_Msk
#define EXTI_IMR_EXTI3_Pos                (3ul)                     /*!< EXTI3 (Bit 3)                                         */
#define EXTI_IMR_EXTI3_Msk                (0x8ul)                   /*!< EXTI3 (Bitfield-Mask: 0x01)                           */
#define EXTI_IMR_EXTI3                    EXTI_IMR_EXTI3_Msk
#define EXTI_IMR_EXTI4_Pos                (4ul)                     /*!< EXTI4 (Bit 4)                                         */
#define EXTI_IMR_EXTI4_Msk                (0x10ul)                  /*!< EXTI4 (Bitfield-Mask: 0x01)                           */
#define EXTI_IMR_EXTI4                    EXTI_IMR_EXTI4_Msk
#define EXTI_IMR_EXTI5_Pos                (5ul)                     /*!< EXTI5 (Bit 5)                                         */
#define EXTI_IMR_EXTI5_Msk                (0x20ul)                  /*!< EXTI5 (Bitfield-Mask: 0x01)                           */
#define EXTI_IMR_EXTI5                    EXTI_IMR_EXTI5_Msk
#define EXTI_IMR_EXTI6_Pos                (6ul)                     /*!< EXTI6 (Bit 6)                                         */
#define EXTI_IMR_EXTI6_Msk                (0x40ul)                  /*!< EXTI6 (Bitfield-Mask: 0x01)                           */
#define EXTI_IMR_EXTI6                    EXTI_IMR_EXTI6_Msk
#define EXTI_IMR_EXTI7_Pos                (7ul)                     /*!< EXTI7 (Bit 7)                                         */
#define EXTI_IMR_EXTI7_Msk                (0x80ul)                  /*!< EXTI7 (Bitfield-Mask: 0x01)                           */
#define EXTI_IMR_EXTI7                    EXTI_IMR_EXTI7_Msk
#define EXTI_IMR_EXTI8_Pos                (8ul)                     /*!< EXTI8 (Bit 8)                                         */
#define EXTI_IMR_EXTI8_Msk                (0x100ul)                 /*!< EXTI8 (Bitfield-Mask: 0x01)                           */
#define EXTI_IMR_EXTI8                    EXTI_IMR_EXTI8_Msk
#define EXTI_IMR_EXTI9_Pos                (9ul)                     /*!< EXTI9 (Bit 9)                                         */
#define EXTI_IMR_EXTI9_Msk                (0x200ul)                 /*!< EXTI9 (Bitfield-Mask: 0x01)                           */
#define EXTI_IMR_EXTI9                    EXTI_IMR_EXTI9_Msk
#define EXTI_IMR_EXTI10_Pos               (10ul)                    /*!< EXTI10 (Bit 10)                                       */
#define EXTI_IMR_EXTI10_Msk               (0x400ul)                 /*!< EXTI10 (Bitfield-Mask: 0x01)                          */
#define EXTI_IMR_EXTI10                   EXTI_IMR_EXTI10_Msk
#define EXTI_IMR_EXTI11_Pos               (11ul)                    /*!< EXTI11 (Bit 11)                                       */
#define EXTI_IMR_EXTI11_Msk               (0x800ul)                 /*!< EXTI11 (Bitfield-Mask: 0x01)                          */
#define EXTI_IMR_EXTI11                   EXTI_IMR_EXTI11_Msk
#define EXTI_IMR_EXTI12_Pos               (12ul)                    /*!< EXTI12 (Bit 12)                                       */
#define EXTI_IMR_EXTI12_Msk               (0x1000ul)                /*!< EXTI12 (Bitfield-Mask: 0x01)                          */
#define EXTI_IMR_EXTI12                   EXTI_IMR_EXTI12_Msk
#define EXTI_IMR_EXTI13_Pos               (13ul)                    /*!< EXTI13 (Bit 13)                                       */
#define EXTI_IMR_EXTI13_Msk               (0x2000ul)                /*!< EXTI13 (Bitfield-Mask: 0x01)                          */
#define EXTI_IMR_EXTI13                   EXTI_IMR_EXTI13_Msk
#define EXTI_IMR_EXTI14_Pos               (14ul)                    /*!< EXTI14 (Bit 14)                                       */
#define EXTI_IMR_EXTI14_Msk               (0x4000ul)                /*!< EXTI14 (Bitfield-Mask: 0x01)                          */
#define EXTI_IMR_EXTI14                   EXTI_IMR_EXTI14_Msk
#define EXTI_IMR_EXTI15_Pos               (15ul)                    /*!< EXTI15 (Bit 15)                                       */
#define EXTI_IMR_EXTI15_Msk               (0x8000ul)                /*!< EXTI15 (Bitfield-Mask: 0x01)                          */
#define EXTI_IMR_EXTI15                   EXTI_IMR_EXTI15_Msk
/* ==========================================================  EER  ========================================================== */
#define EXTI_EER_EXTI0_Pos                (0ul)                     /*!< EXTI0 (Bit 0)                                         */
#define EXTI_EER_EXTI0_Msk                (0x1ul)                   /*!< EXTI0 (Bitfield-Mask: 0x01)                           */
#define EXTI_EER_EXTI0                    EXTI_EER_EXTI0_Msk
#define EXTI_EER_EXTI1_Pos                (1ul)                     /*!< EXTI1 (Bit 1)                                         */
#define EXTI_EER_EXTI1_Msk                (0x2ul)                   /*!< EXTI1 (Bitfield-Mask: 0x01)                           */
#define EXTI_EER_EXTI1                    EXTI_EER_EXTI1_Msk
#define EXTI_EER_EXTI2_Pos                (2ul)                     /*!< EXTI2 (Bit 2)                                         */
#define EXTI_EER_EXTI2_Msk                (0x4ul)                   /*!< EXTI2 (Bitfield-Mask: 0x01)                           */
#define EXTI_EER_EXTI2                    EXTI_EER_EXTI2_Msk
#define EXTI_EER_EXTI3_Pos                (3ul)                     /*!< EXTI3 (Bit 3)                                         */
#define EXTI_EER_EXTI3_Msk                (0x8ul)                   /*!< EXTI3 (Bitfield-Mask: 0x01)                           */
#define EXTI_EER_EXTI3                    EXTI_EER_EXTI3_Msk
#define EXTI_EER_EXTI4_Pos                (4ul)                     /*!< EXTI4 (Bit 4)                                         */
#define EXTI_EER_EXTI4_Msk                (0x10ul)                  /*!< EXTI4 (Bitfield-Mask: 0x01)                           */
#define EXTI_EER_EXTI4                    EXTI_EER_EXTI4_Msk
#define EXTI_EER_EXTI5_Pos                (5ul)                     /*!< EXTI5 (Bit 5)                                         */
#define EXTI_EER_EXTI5_Msk                (0x20ul)                  /*!< EXTI5 (Bitfield-Mask: 0x01)                           */
#define EXTI_EER_EXTI5                    EXTI_EER_EXTI5_Msk
#define EXTI_EER_EXTI6_Pos                (6ul)                     /*!< EXTI6 (Bit 6)                                         */
#define EXTI_EER_EXTI6_Msk                (0x40ul)                  /*!< EXTI6 (Bitfield-Mask: 0x01)                           */
#define EXTI_EER_EXTI6                    EXTI_EER_EXTI6Msk
#define EXTI_EER_EXTI7_Pos                (7ul)                     /*!< EXTI7 (Bit 7)                                         */
#define EXTI_EER_EXTI7_Msk                (0x80ul)                  /*!< EXTI7 (Bitfield-Mask: 0x01)                           */
#define EXTI_EER_EXTI7                    EXTI_EER_EXTI7_Msk
#define EXTI_EER_EXTI8_Pos                (8ul)                     /*!< EXTI8 (Bit 8)                                         */
#define EXTI_EER_EXTI8_Msk                (0x100ul)                 /*!< EXTI8 (Bitfield-Mask: 0x01)                           */
#define EXTI_EER_EXTI8                    EXTI_EER_EXTI8_Msk
#define EXTI_EER_EXTI9_Pos                (9ul)                     /*!< EXTI9 (Bit 9)                                         */
#define EXTI_EER_EXTI9_Msk                (0x200ul)                 /*!< EXTI9 (Bitfield-Mask: 0x01)                           */
#define EXTI_EER_EXTI9                    EXTI_EER_EXTI9_Msk
#define EXTI_EER_EXTI10_Pos               (10ul)                    /*!< EXTI10 (Bit 10)                                       */
#define EXTI_EER_EXTI10_Msk               (0x400ul)                 /*!< EXTI10 (Bitfield-Mask: 0x01)                          */
#define EXTI_EER_EXTI10                   EXTI_EER_EXTI10_Msk
#define EXTI_EER_EXTI11_Pos               (11ul)                    /*!< EXTI11 (Bit 11)                                       */
#define EXTI_EER_EXTI11_Msk               (0x800ul)                 /*!< EXTI11 (Bitfield-Mask: 0x01)                          */
#define EXTI_EER_EXTI11                   EXTI_EER_EXTI11_Msk
#define EXTI_EER_EXTI12_Pos               (12ul)                    /*!< EXTI12 (Bit 12)                                       */
#define EXTI_EER_EXTI12_Msk               (0x1000ul)                /*!< EXTI12 (Bitfield-Mask: 0x01)                          */
#define EXTI_EER_EXTI12                   EXTI_EER_EXTI12_Msk
#define EXTI_EER_EXTI13_Pos               (13ul)                    /*!< EXTI13 (Bit 13)                                       */
#define EXTI_EER_EXTI13_Msk               (0x2000ul)                /*!< EXTI13 (Bitfield-Mask: 0x01)                          */
#define EXTI_EER_EXTI13                   EXTI_EER_EXTI13_Msk
#define EXTI_EER_EXTI14_Pos               (14ul)                    /*!< EXTI14 (Bit 14)                                       */
#define EXTI_EER_EXTI14_Msk               (0x4000ul)                /*!< EXTI14 (Bitfield-Mask: 0x01)                          */
#define EXTI_EER_EXTI14                   EXTI_EER_EXTI14_Msk
#define EXTI_EER_EXTI15_Pos               (15ul)                    /*!< EXTI15 (Bit 15)                                       */
#define EXTI_EER_EXTI15_Msk               (0x8000ul)                /*!< EXTI15 (Bitfield-Mask: 0x01)                          */
#define EXTI_EER_EXTI15                   EXTI_EER_EXTI15_Msk 
/* ==========================================================  EDR  ========================================================== */
#define EXTI_EDR_EXTI0_Pos                (0ul)                     /*!< EXTI0 (Bit 0)                                         */
#define EXTI_EDR_EXTI0_Msk                (0x1ul)                   /*!< EXTI0 (Bitfield-Mask: 0x01)                           */
#define EXTI_EDR_EXTI0                    EXTI_EDR_EXTI0_Msk
#define EXTI_EDR_EXTI1_Pos                (1ul)                     /*!< EXTI1 (Bit 1)                                         */
#define EXTI_EDR_EXTI1_Msk                (0x2ul)                   /*!< EXTI1 (Bitfield-Mask: 0x01)                           */
#define EXTI_EDR_EXTI1                    EXTI_EDR_EXTI1_Msk
#define EXTI_EDR_EXTI2_Pos                (2ul)                     /*!< EXTI2 (Bit 2)                                         */
#define EXTI_EDR_EXTI2_Msk                (0x4ul)                   /*!< EXTI2 (Bitfield-Mask: 0x01)                           */
#define EXTI_EDR_EXTI2                    EXTI_EDR_EXTI2_Msk
#define EXTI_EDR_EXTI3_Pos                (3ul)                     /*!< EXTI3 (Bit 3)                                         */
#define EXTI_EDR_EXTI3_Msk                (0x8ul)                   /*!< EXTI3 (Bitfield-Mask: 0x01)                           */
#define EXTI_EDR_EXTI3                    EXTI_EDR_EXTI3_Msk
#define EXTI_EDR_EXTI4_Pos                (4ul)                     /*!< EXTI4 (Bit 4)                                         */
#define EXTI_EDR_EXTI4_Msk                (0x10ul)                  /*!< EXTI4 (Bitfield-Mask: 0x01)                           */
#define EXTI_EDR_EXTI4                    EXTI_EDR_EXTI4_Msk
#define EXTI_EDR_EXTI5_Pos                (5ul)                     /*!< EXTI5 (Bit 5)                                         */
#define EXTI_EDR_EXTI5_Msk                (0x20ul)                  /*!< EXTI5 (Bitfield-Mask: 0x01)                           */
#define EXTI_EDR_EXTI5                    EXTI_EDR_EXTI5_Msk
#define EXTI_EDR_EXTI6_Pos                (6ul)                     /*!< EXTI6 (Bit 6)                                         */
#define EXTI_EDR_EXTI6_Msk                (0x40ul)                  /*!< EXTI6 (Bitfield-Mask: 0x01)                           */
#define EXTI_EDR_EXTI6                    EXTI_EDR_EXTI6_Msk
#define EXTI_EDR_EXTI7_Pos                (7ul)                     /*!< EXTI7 (Bit 7)                                         */
#define EXTI_EDR_EXTI7_Msk                (0x80ul)                  /*!< EXTI7 (Bitfield-Mask: 0x01)                           */
#define EXTI_EDR_EXTI7                    EXTI_EDR_EXTI7_Msk
#define EXTI_EDR_EXTI8_Pos                (8ul)                     /*!< EXTI8 (Bit 8)                                         */
#define EXTI_EDR_EXTI8_Msk                (0x100ul)                 /*!< EXTI8 (Bitfield-Mask: 0x01)                           */
#define EXTI_EDR_EXTI8                    EXTI_EDR_EXTI8_Msk
#define EXTI_EDR_EXTI9_Pos                (9ul)                     /*!< EXTI9 (Bit 9)                                         */
#define EXTI_EDR_EXTI9_Msk                (0x200ul)                 /*!< EXTI9 (Bitfield-Mask: 0x01)                           */
#define EXTI_EDR_EXTI9                    EXTI_EDR_EXTI9_Msk
#define EXTI_EDR_EXTI10_Pos               (10ul)                    /*!< EXTI10 (Bit 10)                                       */
#define EXTI_EDR_EXTI10_Msk               (0x400ul)                 /*!< EXTI10 (Bitfield-Mask: 0x01)                          */
#define EXTI_EDR_EXTI10                   EXTI_EDR_EXTI10_Msk
#define EXTI_EDR_EXTI11_Pos               (11ul)                    /*!< EXTI11 (Bit 11)                                       */
#define EXTI_EDR_EXTI11_Msk               (0x800ul)                 /*!< EXTI11 (Bitfield-Mask: 0x01)                          */
#define EXTI_EDR_EXTI11                   EXTI_EDR_EXTI11_Msk
#define EXTI_EDR_EXTI12_Pos               (12ul)                    /*!< EXTI12 (Bit 12)                                       */
#define EXTI_EDR_EXTI12_Msk               (0x1000ul)                /*!< EXTI12 (Bitfield-Mask: 0x01)                          */
#define EXTI_EDR_EXTI12                   EXTI_EDR_EXTI12_Msk
#define EXTI_EDR_EXTI13_Pos               (13ul)                    /*!< EXTI13 (Bit 13)                                       */
#define EXTI_EDR_EXTI13_Msk               (0x2000ul)                /*!< EXTI13 (Bitfield-Mask: 0x01)                          */
#define EXTI_EDR_EXTI13                   EXTI_EDR_EXTI13_Msk
#define EXTI_EDR_EXTI14_Pos               (14ul)                    /*!< EXTI14 (Bit 14)                                       */
#define EXTI_EDR_EXTI14_Msk               (0x4000ul)                /*!< EXTI14 (Bitfield-Mask: 0x01)                          */
#define EXTI_EDR_EXTI14                   EXTI_EDR_EXTI14_Msk
#define EXTI_EDR_EXTI15_Pos               (15ul)                    /*!< EXTI15 (Bit 15)                                       */
#define EXTI_EDR_EXTI15_Msk               (0x8000ul)                /*!< EXTI15 (Bitfield-Mask: 0x01)                          */
#define EXTI_EDR_EXTI15                   EXTI_EDR_EXTI15_Msk
/* ==========================================================  EMR  ========================================================== */
#define EXTI_EMR_EXTI0_Pos                (0ul)                     /*!< EXTI0 (Bit 0)                                         */
#define EXTI_EMR_EXTI0_Msk                (0x1ul)                   /*!< EXTI0 (Bitfield-Mask: 0x01)                           */
#define EXTI_EMR_EXTI0                    EXTI_EDR_EXTI0_Msk
#define EXTI_EMR_EXTI1_Pos                (1ul)                     /*!< EXTI1 (Bit 1)                                         */
#define EXTI_EMR_EXTI1_Msk                (0x2ul)                   /*!< EXTI1 (Bitfield-Mask: 0x01)                           */
#define EXTI_EMR_EXTI1                    EXTI_EDR_EXTI1_Msk
#define EXTI_EMR_EXTI2_Pos                (2ul)                     /*!< EXTI2 (Bit 2)                                         */
#define EXTI_EMR_EXTI2_Msk                (0x4ul)                   /*!< EXTI2 (Bitfield-Mask: 0x01)                           */
#define EXTI_EMR_EXTI2                    EXTI_EDR_EXTI2_Msk
#define EXTI_EMR_EXTI3_Pos                (3ul)                     /*!< EXTI3 (Bit 3)                                         */
#define EXTI_EMR_EXTI3_Msk                (0x8ul)                   /*!< EXTI3 (Bitfield-Mask: 0x01)                           */
#define EXTI_EMR_EXTI3                    EXTI_EDR_EXTI3_Msk
#define EXTI_EMR_EXTI4_Pos                (4ul)                     /*!< EXTI4 (Bit 4)                                         */
#define EXTI_EMR_EXTI4_Msk                (0x10ul)                  /*!< EXTI4 (Bitfield-Mask: 0x01)                           */
#define EXTI_EMR_EXTI4                    EXTI_EDR_EXTI4_Msk
#define EXTI_EMR_EXTI5_Pos                (5ul)                     /*!< EXTI5 (Bit 5)                                         */
#define EXTI_EMR_EXTI5_Msk                (0x20ul)                  /*!< EXTI5 (Bitfield-Mask: 0x01)                           */
#define EXTI_EMR_EXTI5                    EXTI_EDR_EXTI5_Msk
#define EXTI_EMR_EXTI6_Pos                (6ul)                     /*!< EXTI6 (Bit 6)                                         */
#define EXTI_EMR_EXTI6_Msk                (0x40ul)                  /*!< EXTI6 (Bitfield-Mask: 0x01)                           */
#define EXTI_EMR_EXTI6                    EXTI_EDR_EXTI6_Msk
#define EXTI_EMR_EXTI7_Pos                (7ul)                     /*!< EXTI7 (Bit 7)                                         */
#define EXTI_EMR_EXTI7_Msk                (0x80ul)                  /*!< EXTI7 (Bitfield-Mask: 0x01)                           */
#define EXTI_EMR_EXTI7                    EXTI_EDR_EXTI7_Msk
#define EXTI_EMR_EXTI8_Pos                (8ul)                     /*!< EXTI8 (Bit 8)                                         */
#define EXTI_EMR_EXTI8_Msk                (0x100ul)                 /*!< EXTI8 (Bitfield-Mask: 0x01)                           */
#define EXTI_EMR_EXTI8                    EXTI_EDR_EXTI8_Msk
#define EXTI_EMR_EXTI9_Pos                (9ul)                     /*!< EXTI9 (Bit 9)                                         */
#define EXTI_EMR_EXTI9_Msk                (0x200ul)                 /*!< EXTI9 (Bitfield-Mask: 0x01)                           */
#define EXTI_EMR_EXTI9                    EXTI_EDR_EXTI9_Msk
#define EXTI_EMR_EXTI10_Pos               (10ul)                    /*!< EXTI10 (Bit 10)                                       */
#define EXTI_EMR_EXTI10_Msk               (0x400ul)                 /*!< EXTI10 (Bitfield-Mask: 0x01)                          */
#define EXTI_EMR_EXTI10                   EXTI_EDR_EXTI10_Msk
#define EXTI_EMR_EXTI11_Pos               (11ul)                    /*!< EXTI11 (Bit 11)                                       */
#define EXTI_EMR_EXTI11_Msk               (0x800ul)                 /*!< EXTI11 (Bitfield-Mask: 0x01)                          */
#define EXTI_EMR_EXTI11                   EXTI_EDR_EXTI11_Msk
#define EXTI_EMR_EXTI12_Pos               (12ul)                    /*!< EXTI12 (Bit 12)                                       */
#define EXTI_EMR_EXTI12_Msk               (0x1000ul)                /*!< EXTI12 (Bitfield-Mask: 0x01)                          */
#define EXTI_EMR_EXTI12                   EXTI_EDR_EXTI12_Msk
#define EXTI_EMR_EXTI13_Pos               (13ul)                    /*!< EXTI13 (Bit 13)                                       */
#define EXTI_EMR_EXTI13_Msk               (0x2000ul)                /*!< EXTI13 (Bitfield-Mask: 0x01)                          */
#define EXTI_EMR_EXTI13                   EXTI_EDR_EXTI13_Msk
#define EXTI_EMR_EXTI14_Pos               (14ul)                    /*!< EXTI14 (Bit 14)                                       */
#define EXTI_EMR_EXTI14_Msk               (0x4000ul)                /*!< EXTI14 (Bitfield-Mask: 0x01)                          */
#define EXTI_EMR_EXTI14                   EXTI_EDR_EXTI14_Msk
#define EXTI_EMR_EXTI15_Pos               (15ul)                    /*!< EXTI15 (Bit 15)                                       */
#define EXTI_EMR_EXTI15_Msk               (0x8000ul)                /*!< EXTI15 (Bitfield-Mask: 0x01)                          */
#define EXTI_EMR_EXTI15                   EXTI_EDR_EXTI5_Msk
/* =========================================================  RTSR  ========================================================== */
#define EXTI_RTSR_EXTI0_Pos               (0ul)                     /*!< EXTI0 (Bit 0)                                         */
#define EXTI_RTSR_EXTI0_Msk               (0x1ul)                   /*!< EXTI0 (Bitfield-Mask: 0x01)                           */
#define EXTI_RTSR_EXTI0                   EXTI_RTSR_EXTI0_Msk
#define EXTI_RTSR_EXTI1_Pos               (1ul)                     /*!< EXTI1 (Bit 1)                                         */
#define EXTI_RTSR_EXTI1_Msk               (0x2ul)                   /*!< EXTI1 (Bitfield-Mask: 0x01)                           */
#define EXTI_RTSR_EXTI1                   EXTI_RTSR_EXTI1_Msk
#define EXTI_RTSR_EXTI2_Pos               (2ul)                     /*!< EXTI2 (Bit 2)                                         */
#define EXTI_RTSR_EXTI2_Msk               (0x4ul)                   /*!< EXTI2 (Bitfield-Mask: 0x01)                           */
#define EXTI_RTSR_EXTI2                   EXTI_RTSR_EXTI2_Msk
#define EXTI_RTSR_EXTI3_Pos               (3ul)                     /*!< EXTI3 (Bit 3)                                         */
#define EXTI_RTSR_EXTI3_Msk               (0x8ul)                   /*!< EXTI3 (Bitfield-Mask: 0x01)                           */
#define EXTI_RTSR_EXTI3                   EXTI_RTSR_EXTI3_Msk
#define EXTI_RTSR_EXTI4_Pos               (4ul)                     /*!< EXTI4 (Bit 4)                                         */
#define EXTI_RTSR_EXTI4_Msk               (0x10ul)                  /*!< EXTI4 (Bitfield-Mask: 0x01)                           */
#define EXTI_RTSR_EXTI4                   EXTI_RTSR_EXTI4_Msk
#define EXTI_RTSR_EXTI5_Pos               (5ul)                     /*!< EXTI5 (Bit 5)                                         */
#define EXTI_RTSR_EXTI5_Msk               (0x20ul)                  /*!< EXTI5 (Bitfield-Mask: 0x01)                           */
#define EXTI_RTSR_EXTI5                   EXTI_RTSR_EXTI5_Msk
#define EXTI_RTSR_EXTI6_Pos               (6ul)                     /*!< EXTI6 (Bit 6)                                         */
#define EXTI_RTSR_EXTI6_Msk               (0x40ul)                  /*!< EXTI6 (Bitfield-Mask: 0x01)                           */
#define EXTI_RTSR_EXTI6                   EXTI_RTSR_EXTI6_Msk
#define EXTI_RTSR_EXTI7_Pos               (7ul)                     /*!< EXTI7 (Bit 7)                                         */
#define EXTI_RTSR_EXTI7_Msk               (0x80ul)                  /*!< EXTI7 (Bitfield-Mask: 0x01)                           */
#define EXTI_RTSR_EXTI7                   EXTI_RTSR_EXTI7_Msk
#define EXTI_RTSR_EXTI8_Pos               (8ul)                     /*!< EXTI8 (Bit 8)                                         */
#define EXTI_RTSR_EXTI8_Msk               (0x100ul)                 /*!< EXTI8 (Bitfield-Mask: 0x01)                           */
#define EXTI_RTSR_EXTI8                   EXTI_RTSR_EXTI8_Msk
#define EXTI_RTSR_EXTI9_Pos               (9ul)                     /*!< EXTI9 (Bit 9)                                         */
#define EXTI_RTSR_EXTI9_Msk               (0x200ul)                 /*!< EXTI9 (Bitfield-Mask: 0x01)                           */
#define EXTI_RTSR_EXTI9                   EXTI_RTSR_EXTI9_Msk
#define EXTI_RTSR_EXTI10_Pos              (10ul)                    /*!< EXTI10 (Bit 10)                                       */
#define EXTI_RTSR_EXTI10_Msk              (0x400ul)                 /*!< EXTI10 (Bitfield-Mask: 0x01)                          */
#define EXTI_RTSR_EXTI10                  EXTI_RTSR_EXTI10_Msk
#define EXTI_RTSR_EXTI11_Pos              (11ul)                    /*!< EXTI11 (Bit 11)                                       */
#define EXTI_RTSR_EXTI11_Msk              (0x800ul)                 /*!< EXTI11 (Bitfield-Mask: 0x01)                          */
#define EXTI_RTSR_EXTI11                  EXTI_RTSR_EXTI11_Msk
#define EXTI_RTSR_EXTI12_Pos              (12ul)                    /*!< EXTI12 (Bit 12)                                       */
#define EXTI_RTSR_EXTI12_Msk              (0x1000ul)                /*!< EXTI12 (Bitfield-Mask: 0x01)                          */
#define EXTI_RTSR_EXTI12                  EXTI_RTSR_EXTI12_Msk
#define EXTI_RTSR_EXTI13_Pos              (13ul)                    /*!< EXTI13 (Bit 13)                                       */
#define EXTI_RTSR_EXTI13_Msk              (0x2000ul)                /*!< EXTI13 (Bitfield-Mask: 0x01)                          */
#define EXTI_RTSR_EXTI13                  EXTI_RTSR_EXTI13_Msk
#define EXTI_RTSR_EXTI14_Pos              (14ul)                    /*!< EXTI14 (Bit 14)                                       */
#define EXTI_RTSR_EXTI14_Msk              (0x4000ul)                /*!< EXTI14 (Bitfield-Mask: 0x01)                          */
#define EXTI_RTSR_EXTI14                  EXTI_RTSR_EXTI14_Msk
#define EXTI_RTSR_EXTI15_Pos              (15ul)                    /*!< EXTI15 (Bit 15)                                       */
#define EXTI_RTSR_EXTI15_Msk              (0x8000ul)                /*!< EXTI15 (Bitfield-Mask: 0x01)                          */
#define EXTI_RTSR_EXTI15                  EXTI_RTSR_EXTI15_Msk
/* =========================================================  FTSR  ========================================================== */
#define EXTI_FTSR_EXTI0_Pos               (0ul)                     /*!< EXTI0 (Bit 0)                                         */
#define EXTI_FTSR_EXTI0_Msk               (0x1ul)                   /*!< EXTI0 (Bitfield-Mask: 0x01)                           */
#define EXTI_FTSR_EXTI0                   EXTI_FTSR_EXTI0_Msk
#define EXTI_FTSR_EXTI1_Pos               (1ul)                     /*!< EXTI1 (Bit 1)                                         */
#define EXTI_FTSR_EXTI1_Msk               (0x2ul)                   /*!< EXTI1 (Bitfield-Mask: 0x01)                           */
#define EXTI_FTSR_EXTI1                   EXTI_FTSR_EXTI1_Msk
#define EXTI_FTSR_EXTI2_Pos               (2ul)                     /*!< EXTI2 (Bit 2)                                         */
#define EXTI_FTSR_EXTI2_Msk               (0x4ul)                   /*!< EXTI2 (Bitfield-Mask: 0x01)                           */
#define EXTI_FTSR_EXTI2                   EXTI_FTSR_EXTI2_Msk
#define EXTI_FTSR_EXTI3_Pos               (3ul)                     /*!< EXTI3 (Bit 3)                                         */
#define EXTI_FTSR_EXTI3_Msk               (0x8ul)                   /*!< EXTI3 (Bitfield-Mask: 0x01)                           */
#define EXTI_FTSR_EXTI3                   EXTI_FTSR_EXTI3_Msk
#define EXTI_FTSR_EXTI4_Pos               (4ul)                     /*!< EXTI4 (Bit 4)                                         */
#define EXTI_FTSR_EXTI4_Msk               (0x10ul)                  /*!< EXTI4 (Bitfield-Mask: 0x01)                           */
#define EXTI_FTSR_EXTI4                   EXTI_FTSR_EXTI4_Msk
#define EXTI_FTSR_EXTI5_Pos               (5ul)                     /*!< EXTI5 (Bit 5)                                         */
#define EXTI_FTSR_EXTI5_Msk               (0x20ul)                  /*!< EXTI5 (Bitfield-Mask: 0x01)                           */
#define EXTI_FTSR_EXTI5                   EXTI_FTSR_EXTI5_Msk
#define EXTI_FTSR_EXTI6_Pos               (6ul)                     /*!< EXTI6 (Bit 6)                                         */
#define EXTI_FTSR_EXTI6_Msk               (0x40ul)                  /*!< EXTI6 (Bitfield-Mask: 0x01)                           */
#define EXTI_FTSR_EXTI6                   EXTI_FTSR_EXTI6_Msk
#define EXTI_FTSR_EXTI7_Pos               (7ul)                     /*!< EXTI7 (Bit 7)                                         */
#define EXTI_FTSR_EXTI7_Msk               (0x80ul)                  /*!< EXTI7 (Bitfield-Mask: 0x01)                           */
#define EXTI_FTSR_EXTI7                   EXTI_FTSR_EXTI7_Msk
#define EXTI_FTSR_EXTI8_Pos               (8ul)                     /*!< EXTI8 (Bit 8)                                         */
#define EXTI_FTSR_EXTI8_Msk               (0x100ul)                 /*!< EXTI8 (Bitfield-Mask: 0x01)                           */
#define EXTI_FTSR_EXTI8                   EXTI_FTSR_EXTI8_Msk
#define EXTI_FTSR_EXTI9_Pos               (9ul)                     /*!< EXTI9 (Bit 9)                                         */
#define EXTI_FTSR_EXTI9_Msk               (0x200ul)                 /*!< EXTI9 (Bitfield-Mask: 0x01)                           */
#define EXTI_FTSR_EXTI9                   EXTI_FTSR_EXTI9_Msk
#define EXTI_FTSR_EXTI10_Pos              (10ul)                    /*!< EXTI10 (Bit 10)                                       */
#define EXTI_FTSR_EXTI10_Msk              (0x400ul)                 /*!< EXTI10 (Bitfield-Mask: 0x01)                          */
#define EXTI_FTSR_EXTI10                  EXTI_FTSR_EXTI10_Msk
#define EXTI_FTSR_EXTI11_Pos              (11ul)                    /*!< EXTI11 (Bit 11)                                       */
#define EXTI_FTSR_EXTI11_Msk              (0x800ul)                 /*!< EXTI11 (Bitfield-Mask: 0x01)                          */
#define EXTI_FTSR_EXTI11                  EXTI_FTSR_EXTI11_Msk
#define EXTI_FTSR_EXTI12_Pos              (12ul)                    /*!< EXTI12 (Bit 12)                                       */
#define EXTI_FTSR_EXTI12_Msk              (0x1000ul)                /*!< EXTI12 (Bitfield-Mask: 0x01)                          */
#define EXTI_FTSR_EXTI12                  EXTI_FTSR_EXTI12_Msk
#define EXTI_FTSR_EXTI13_Pos              (13ul)                    /*!< EXTI13 (Bit 13)                                       */
#define EXTI_FTSR_EXTI13_Msk              (0x2000ul)                /*!< EXTI13 (Bitfield-Mask: 0x01)                          */
#define EXTI_FTSR_EXTI13                  EXTI_FTSR_EXTI13_Msk
#define EXTI_FTSR_EXTI14_Pos              (14ul)                    /*!< EXTI14 (Bit 14)                                       */
#define EXTI_FTSR_EXTI14_Msk              (0x4000ul)                /*!< EXTI14 (Bitfield-Mask: 0x01)                          */
#define EXTI_FTSR_EXTI14                  EXTI_FTSR_EXTI14_Msk
#define EXTI_FTSR_EXTI15_Pos              (15ul)                    /*!< EXTI15 (Bit 15)                                       */
#define EXTI_FTSR_EXTI15_Msk              (0x8000ul)                /*!< EXTI15 (Bitfield-Mask: 0x01)                          */
#define EXTI_FTSR_EXTI15                  EXTI_FTSR_EXTI15_Msk
/* =========================================================  SWIER  ========================================================= */
#define EXTI_SWIER_EXTI0_Pos              (0ul)                     /*!< EXTI0 (Bit 0)                                         */
#define EXTI_SWIER_EXTI0_Msk              (0x1ul)                   /*!< EXTI0 (Bitfield-Mask: 0x01)                           */
#define EXTI_SWIER_EXTI0                  EXTI_SWIER_EXTI0_Msk
#define EXTI_SWIER_EXTI1_Pos              (1ul)                     /*!< EXTI1 (Bit 1)                                         */
#define EXTI_SWIER_EXTI1_Msk              (0x2ul)                   /*!< EXTI1 (Bitfield-Mask: 0x01)                           */
#define EXTI_SWIER_EXTI1                  EXTI_SWIER_EXTI1_Msk
#define EXTI_SWIER_EXTI2_Pos              (2ul)                     /*!< EXTI2 (Bit 2)                                         */
#define EXTI_SWIER_EXTI2_Msk              (0x4ul)                   /*!< EXTI2 (Bitfield-Mask: 0x01)                           */
#define EXTI_SWIER_EXTI2                  EXTI_SWIER_EXTI2_Msk
#define EXTI_SWIER_EXTI3_Pos              (3ul)                     /*!< EXTI3 (Bit 3)                                         */
#define EXTI_SWIER_EXTI3_Msk              (0x8ul)                   /*!< EXTI3 (Bitfield-Mask: 0x01)                           */
#define EXTI_SWIER_EXTI3                  EXTI_SWIER_EXTI3_Msk
#define EXTI_SWIER_EXTI4_Pos              (4ul)                     /*!< EXTI4 (Bit 4)                                         */
#define EXTI_SWIER_EXTI4_Msk              (0x10ul)                  /*!< EXTI4 (Bitfield-Mask: 0x01)                           */
#define EXTI_SWIER_EXTI4                  EXTI_SWIER_EXTI4_Msk
#define EXTI_SWIER_EXTI5_Pos              (5ul)                     /*!< EXTI5 (Bit 5)                                         */
#define EXTI_SWIER_EXTI5_Msk              (0x20ul)                  /*!< EXTI5 (Bitfield-Mask: 0x01)                           */
#define EXTI_SWIER_EXTI5                  EXTI_SWIER_EXTI5_Msk
#define EXTI_SWIER_EXTI6_Pos              (6ul)                     /*!< EXTI6 (Bit 6)                                         */
#define EXTI_SWIER_EXTI6_Msk              (0x40ul)                  /*!< EXTI6 (Bitfield-Mask: 0x01)                           */
#define EXTI_SWIER_EXTI6                  EXTI_SWIER_EXTI6_Msk
#define EXTI_SWIER_EXTI7_Pos              (7ul)                     /*!< EXTI7 (Bit 7)                                         */
#define EXTI_SWIER_EXTI7_Msk              (0x80ul)                  /*!< EXTI7 (Bitfield-Mask: 0x01)                           */
#define EXTI_SWIER_EXTI7                  EXTI_SWIER_EXTI7_Msk
#define EXTI_SWIER_EXTI8_Pos              (8ul)                     /*!< EXTI8 (Bit 8)                                         */
#define EXTI_SWIER_EXTI8_Msk              (0x100ul)                 /*!< EXTI8 (Bitfield-Mask: 0x01)                           */
#define EXTI_SWIER_EXTI8                  EXTI_SWIER_EXTI8_Msk
#define EXTI_SWIER_EXTI9_Pos              (9ul)                     /*!< EXTI9 (Bit 9)                                         */
#define EXTI_SWIER_EXTI9_Msk              (0x200ul)                 /*!< EXTI9 (Bitfield-Mask: 0x01)                           */
#define EXTI_SWIER_EXTI9                  EXTI_SWIER_EXTI9_Msk
#define EXTI_SWIER_EXTI10_Pos             (10ul)                    /*!< EXTI10 (Bit 10)                                       */
#define EXTI_SWIER_EXTI10_Msk             (0x400ul)                 /*!< EXTI10 (Bitfield-Mask: 0x01)                          */
#define EXTI_SWIER_EXTI10                 EXTI_SWIER_EXTI10_Msk     
#define EXTI_SWIER_EXTI11_Pos             (11ul)                    /*!< EXTI11 (Bit 11)                                       */
#define EXTI_SWIER_EXTI11_Msk             (0x800ul)                 /*!< EXTI11 (Bitfield-Mask: 0x01)                          */
#define EXTI_SWIER_EXTI11                 EXTI_SWIER_EXTI11_Msk
#define EXTI_SWIER_EXTI12_Pos             (12ul)                    /*!< EXTI12 (Bit 12)                                       */
#define EXTI_SWIER_EXTI12_Msk             (0x1000ul)                /*!< EXTI12 (Bitfield-Mask: 0x01)                          */
#define EXTI_SWIER_EXTI12                 EXTI_SWIER_EXTI12_Msk
#define EXTI_SWIER_EXTI13_Pos             (13ul)                    /*!< EXTI13 (Bit 13)                                       */
#define EXTI_SWIER_EXTI13_Msk             (0x2000ul)                /*!< EXTI13 (Bitfield-Mask: 0x01)                          */
#define EXTI_SWIER_EXTI13                 EXTI_SWIER_EXTI13_Msk
#define EXTI_SWIER_EXTI14_Pos             (14ul)                    /*!< EXTI14 (Bit 14)                                       */
#define EXTI_SWIER_EXTI14_Msk             (0x4000ul)                /*!< EXTI14 (Bitfield-Mask: 0x01)                          */
#define EXTI_SWIER_EXTI14                 EXTI_SWIER_EXTI14_Msk
#define EXTI_SWIER_EXTI15_Pos             (15ul)                    /*!< EXTI15 (Bit 15)                                       */
#define EXTI_SWIER_EXTI15_Msk             (0x8000ul)                /*!< EXTI15 (Bitfield-Mask: 0x01)                          */
#define EXTI_SWIER_EXTI15                 EXTI_SWIER_EXTI15_Msk
/* ==========================================================  ISR  ========================================================== */
#define EXTI_ISR_EXTI0_Pos                (0ul)                     /*!< EXTI0 (Bit 0)                                         */
#define EXTI_ISR_EXTI0_Msk                (0x1ul)                   /*!< EXTI0 (Bitfield-Mask: 0x01)                           */
#define EXTI_ISR_EXTI0                    EXTI_ISR_EXTI0_Msk
#define EXTI_ISR_EXTI1_Pos                (1ul)                     /*!< EXTI1 (Bit 1)                                         */
#define EXTI_ISR_EXTI1_Msk                (0x2ul)                   /*!< EXTI1 (Bitfield-Mask: 0x01)                           */
#define EXTI_ISR_EXTI1                    EXTI_ISR_EXTI1_Msk
#define EXTI_ISR_EXTI2_Pos                (2ul)                     /*!< EXTI2 (Bit 2)                                         */
#define EXTI_ISR_EXTI2_Msk                (0x4ul)                   /*!< EXTI2 (Bitfield-Mask: 0x01)                           */
#define EXTI_ISR_EXTI2                    EXTI_ISR_EXTI2_Msk
#define EXTI_ISR_EXTI3_Pos                (3ul)                     /*!< EXTI3 (Bit 3)                                         */
#define EXTI_ISR_EXTI3_Msk                (0x8ul)                   /*!< EXTI3 (Bitfield-Mask: 0x01)                           */
#define EXTI_ISR_EXTI3                    EXTI_ISR_EXTI3_Msk
#define EXTI_ISR_EXTI4_Pos                (4ul)                     /*!< EXTI4 (Bit 4)                                         */
#define EXTI_ISR_EXTI4_Msk                (0x10ul)                  /*!< EXTI4 (Bitfield-Mask: 0x01)                           */
#define EXTI_ISR_EXTI4                    EXTI_ISR_EXTI4_Msk
#define EXTI_ISR_EXTI5_Pos                (5ul)                     /*!< EXTI5 (Bit 5)                                         */
#define EXTI_ISR_EXTI5_Msk                (0x20ul)                  /*!< EXTI5 (Bitfield-Mask: 0x01)                           */
#define EXTI_ISR_EXTI5                    EXTI_ISR_EXTI5_Msk
#define EXTI_ISR_EXTI6_Pos                (6ul)                     /*!< EXTI6 (Bit 6)                                         */
#define EXTI_ISR_EXTI6_Msk                (0x40ul)                  /*!< EXTI6 (Bitfield-Mask: 0x01)                           */
#define EXTI_ISR_EXTI6                    EXTI_ISR_EXTI6_Msk
#define EXTI_ISR_EXTI7_Pos                (7ul)                     /*!< EXTI7 (Bit 7)                                         */
#define EXTI_ISR_EXTI7_Msk                (0x80ul)                  /*!< EXTI7 (Bitfield-Mask: 0x01)                           */
#define EXTI_ISR_EXTI7                    EXTI_ISR_EXTI7_Msk
#define EXTI_ISR_EXTI8_Pos                (8ul)                     /*!< EXTI8 (Bit 8)                                         */
#define EXTI_ISR_EXTI8_Msk                (0x100ul)                 /*!< EXTI8 (Bitfield-Mask: 0x01)                           */
#define EXTI_ISR_EXTI8                    EXTI_ISR_EXTI8_Msk
#define EXTI_ISR_EXTI9_Pos                (9ul)                     /*!< EXTI9 (Bit 9)                                         */
#define EXTI_ISR_EXTI9_Msk                (0x200ul)                 /*!< EXTI9 (Bitfield-Mask: 0x01)                           */
#define EXTI_ISR_EXTI9                    EXTI_ISR_EXTI9_Msk
#define EXTI_ISR_EXTI10_Pos               (10ul)                    /*!< EXTI10 (Bit 10)                                       */
#define EXTI_ISR_EXTI10_Msk               (0x400ul)                 /*!< EXTI10 (Bitfield-Mask: 0x01)                          */
#define EXTI_ISR_EXTI10                   EXTI_ISR_EXTI10_Msk
#define EXTI_ISR_EXTI11_Pos               (11ul)                    /*!< EXTI11 (Bit 11)                                       */
#define EXTI_ISR_EXTI11_Msk               (0x800ul)                 /*!< EXTI11 (Bitfield-Mask: 0x01)                          */
#define EXTI_ISR_EXTI11                   EXTI_ISR_EXTI11_Msk
#define EXTI_ISR_EXTI12_Pos               (12ul)                    /*!< EXTI12 (Bit 12)                                       */
#define EXTI_ISR_EXTI12_Msk               (0x1000ul)                /*!< EXTI12 (Bitfield-Mask: 0x01)                          */
#define EXTI_ISR_EXTI12                   EXTI_ISR_EXTI12_Msk
#define EXTI_ISR_EXTI13_Pos               (13ul)                    /*!< EXTI13 (Bit 13)                                       */
#define EXTI_ISR_EXTI13_Msk               (0x2000ul)                /*!< EXTI13 (Bitfield-Mask: 0x01)                          */
#define EXTI_ISR_EXTI13                   EXTI_ISR_EXTI13_Msk
#define EXTI_ISR_EXTI14_Pos               (14ul)                    /*!< EXTI14 (Bit 14)                                       */
#define EXTI_ISR_EXTI14_Msk               (0x4000ul)                /*!< EXTI14 (Bitfield-Mask: 0x01)                          */
#define EXTI_ISR_EXTI14                   EXTI_ISR_EXTI14_Msk
#define EXTI_ISR_EXTI15_Pos               (15ul)                    /*!< EXTI15 (Bit 15)                                       */
#define EXTI_ISR_EXTI15_Msk               (0x8000ul)                /*!< EXTI15 (Bitfield-Mask: 0x01)                          */
#define EXTI_ISR_EXTI15                   EXTI_ISR_EXTI15_Msk
/* =========================================================  CFGR1  ========================================================= */
#define EXTI_CFGR1_EXTI0_Pos              (0ul)                     /*!< EXTI0 (Bit 0)                                         */
#define EXTI_CFGR1_EXTI0_Msk              (0x7ul)                   /*!< EXTI0 (Bitfield-Mask: 0x07)                           */
#define EXTI_CFGR1_EXTI0                  EXTI_CFGR1_EXTI0_Msk
#define EXTI_CFGR1_EXTI1_Pos              (3ul)                     /*!< EXTI1 (Bit 3)                                         */
#define EXTI_CFGR1_EXTI1_Msk              (0x38ul)                  /*!< EXTI1 (Bitfield-Mask: 0x07)                           */
#define EXTI_CFGR1_EXTI1                  EXTI_CFGR1_EXTI1_Msk
#define EXTI_CFGR1_EXTI2_Pos              (6ul)                     /*!< EXTI2 (Bit 6)                                         */
#define EXTI_CFGR1_EXTI2_Msk              (0x1C0ul)                 /*!< EXTI2 (Bitfield-Mask: 0x07)                           */
#define EXTI_CFGR1_EXTI2                  EXTI_CFGR1_EXTI2_Msk
#define EXTI_CFGR1_EXTI3_Pos              (9ul)                     /*!< EXTI3 (Bit 9)                                         */
#define EXTI_CFGR1_EXTI3_Msk              (0xE00ul)                 /*!< EXTI3 (Bitfield-Mask: 0x07)                           */
#define EXTI_CFGR1_EXTI3                  EXTI_CFGR1_EXTI3_Msk
#define EXTI_CFGR1_EXTI4_Pos              (12ul)                    /*!< EXTI4 (Bit 12)                                        */
#define EXTI_CFGR1_EXTI4_Msk              (0x7000ul)                /*!< EXTI4 (Bitfield-Mask: 0x07)                           */
#define EXTI_CFGR1_EXTI4                  EXTI_CFGR1_EXTI4_Msk
#define EXTI_CFGR1_EXTI5_Pos              (15ul)                    /*!< EXTI5 (Bit 15)                                        */
#define EXTI_CFGR1_EXTI5_Msk              (0x38000ul)               /*!< EXTI5 (Bitfield-Mask: 0x07)                           */
#define EXTI_CFGR1_EXTI5                  EXTI_CFGR1_EXTI5_Msk
#define EXTI_CFGR1_EXTI6_Pos              (18ul)                    /*!< EXTI6 (Bit 18)                                        */
#define EXTI_CFGR1_EXTI6_Msk              (0x1C0000ul)              /*!< EXTI6 (Bitfield-Mask: 0x07)                           */
#define EXTI_CFGR1_EXTI6                  EXTI_CFGR1_EXTI6_Msk
#define EXTI_CFGR1_EXTI7_Pos              (21ul)                    /*!< EXTI7 (Bit 21)                                        */
#define EXTI_CFGR1_EXTI7_Msk              (0xe00000ul)              /*!< EXTI7 (Bitfield-Mask: 0x07)                           */
#define EXTI_CFGR1_EXTI7                  EXTI_CFGR1_EXTI7_Msk
/* =========================================================  CFGR2  ========================================================= */
#define EXTI_CFGR2_EXTI8_Pos              (0ul)                     /*!< EXTI8 (Bit 0)                                         */
#define EXTI_CFGR2_EXTI8_Msk              (0x7ul)                   /*!< EXTI8 (Bitfield-Mask: 0x07)                           */
#define EXTI_CFGR2_EXTI8                  EXTI_CFGR2_EXTI8_Msk
#define EXTI_CFGR2_EXTI9_Pos              (3ul)                     /*!< EXTI9 (Bit 3)                                         */
#define EXTI_CFGR2_EXTI9_Msk              (0x38ul)                  /*!< EXTI9 (Bitfield-Mask: 0x07)                           */
#define EXTI_CFGR2_EXTI9                  EXTI_CFGR2_EXTI9_Msk
#define EXTI_CFGR2_EXTI10_Pos             (6ul)                     /*!< EXTI10 (Bit 6)                                        */
#define EXTI_CFGR2_EXTI10_Msk             (0x1C0ul)                 /*!< EXTI10 (Bitfield-Mask: 0x07)                          */
#define EXTI_CFGR2_EXTI10                 EXTI_CFGR2_EXTI10_Msk
#define EXTI_CFGR2_EXTI11_Pos             (9ul)                     /*!< EXTI11 (Bit 9)                                        */
#define EXTI_CFGR2_EXTI11_Msk             (0xE00ul)                 /*!< EXTI11 (Bitfield-Mask: 0x07)                          */
#define EXTI_CFGR2_EXTI11                 EXTI_CFGR2_EXTI11_Msk
#define EXTI_CFGR2_EXTI12_Pos             (12ul)                    /*!< EXTI12 (Bit 12)                                       */
#define EXTI_CFGR2_EXTI12_Msk             (0x7000ul)                /*!< EXTI12 (Bitfield-Mask: 0x07)                          */
#define EXTI_CFGR2_EXTI12                 EXTI_CFGR2_EXTI12_Msk
#define EXTI_CFGR2_EXTI13_Pos             (15ul)                    /*!< EXTI13 (Bit 15)                                       */
#define EXTI_CFGR2_EXTI13_Msk             (0x38000ul)               /*!< EXTI13 (Bitfield-Mask: 0x07)                          */
#define EXTI_CFGR2_EXTI13                 EXTI_CFGR2_EXTI13_Msk
#define EXTI_CFGR2_EXTI14_Pos             (18ul)                    /*!< EXTI14 (Bit 18)                                       */
#define EXTI_CFGR2_EXTI14_Msk             (0x1C0000ul)              /*!< EXTI14 (Bitfield-Mask: 0x07)                          */
#define EXTI_CFGR2_EXTI14                 EXTI_CFGR2_EXTI14_Msk
#define EXTI_CFGR2_EXTI15_Pos             (21ul)                    /*!< EXTI15 (Bit 21)                                       */
#define EXTI_CFGR2_EXTI15_Msk             (0xe00000ul)              /*!< EXTI15 (Bitfield-Mask: 0x07)                          */
#define EXTI_CFGR2_EXTI15                 EXTI_CFGR2_EXTI15_Msk
/* =========================================================  CFGR1  ========================================================= */
typedef enum   /**< \brief (EXTI.CFGR1 EXTI0 */
{
    EXTI_CFGR1_EXTI0_PA0   = 0 << EXTI_CFGR1_EXTI0_Pos,
    EXTI_CFGR1_EXTI0_PB0   = 1 << EXTI_CFGR1_EXTI0_Pos,
    EXTI_CFGR1_EXTI0_PC0   = 2 << EXTI_CFGR1_EXTI0_Pos,
    EXTI_CFGR1_EXTI0_PD0   = 3 << EXTI_CFGR1_EXTI0_Pos,
} EXTI_CFGR1_EXTI0_Enum;

typedef enum   /**< \brief (EXTI.CFGR1 EXTI1 */
{
    EXTI_CFGR1_EXTI1_PA1    = 0 << EXTI_CFGR1_EXTI1_Pos,
    EXTI_CFGR1_EXTI1_PB1    = 1 << EXTI_CFGR1_EXTI1_Pos,
    EXTI_CFGR1_EXTI1_PC1    = 2 << EXTI_CFGR1_EXTI1_Pos,
    EXTI_CFGR1_EXTI1_PD1    = 3 << EXTI_CFGR1_EXTI1_Pos,
} EXTI_CFGR1_EXTI1_Enum;

typedef enum   /**< \brief (EXTI.CFGR1 EXTI2 */
{
    EXTI_CFGR1_EXTI2_PA2    = 0 << EXTI_CFGR1_EXTI2_Pos,
    EXTI_CFGR1_EXTI2_PB2    = 1 << EXTI_CFGR1_EXTI2_Pos,
    EXTI_CFGR1_EXTI2_PC2    = 2 << EXTI_CFGR1_EXTI2_Pos,
    EXTI_CFGR1_EXTI2_PD2    = 3 << EXTI_CFGR1_EXTI2_Pos,
} EXTI_CFGR1_EXTI2_Enum;

typedef enum   /**< \brief (EXTI.CFGR1 EXTI3 */
{
    EXTI_CFGR1_EXTI3_PA3    = 0 << EXTI_CFGR1_EXTI3_Pos,
    EXTI_CFGR1_EXTI3_PB3    = 1 << EXTI_CFGR1_EXTI3_Pos,
    EXTI_CFGR1_EXTI3_PC3    = 2 << EXTI_CFGR1_EXTI3_Pos,
    EXTI_CFGR1_EXTI3_PD3    = 3 << EXTI_CFGR1_EXTI3_Pos,
} EXTI_CFGR1_EXTI3_Enum;

typedef enum   /**< \brief (EXTI.CFGR1 EXTI4 */
{
    EXTI_CFGR1_EXTI4_PA4    = 0 << EXTI_CFGR1_EXTI4_Pos,
    EXTI_CFGR1_EXTI4_PB4    = 1 << EXTI_CFGR1_EXTI4_Pos,
    EXTI_CFGR1_EXTI4_PC4    = 2 << EXTI_CFGR1_EXTI4_Pos,
    EXTI_CFGR1_EXTI4_PD4    = 3 << EXTI_CFGR1_EXTI4_Pos,
} EXTI_CFGR1_EXTI4_Enum;

typedef enum   /**< \brief (EXTI.CFGR1 EXTI5 */
{
    EXTI_CFGR1_EXTI5_PA5    = 0 << EXTI_CFGR1_EXTI5_Pos,
    EXTI_CFGR1_EXTI5_PB5    = 1 << EXTI_CFGR1_EXTI5_Pos,
    EXTI_CFGR1_EXTI5_PC5    = 2 << EXTI_CFGR1_EXTI5_Pos,
    EXTI_CFGR1_EXTI5_PD5    = 3 << EXTI_CFGR1_EXTI5_Pos,
} EXTI_CFGR1_EXTI5_Enum;

typedef enum   /**< \brief (EXTI.CFGR1 EXTI6 */
{
    EXTI_CFGR1_EXTI6_PA6    = 0 << EXTI_CFGR1_EXTI6_Pos,
    EXTI_CFGR1_EXTI6_PB6    = 1 << EXTI_CFGR1_EXTI6_Pos,
    EXTI_CFGR1_EXTI6_PC6    = 2 << EXTI_CFGR1_EXTI6_Pos,
    EXTI_CFGR1_EXTI6_PD6    = 3 << EXTI_CFGR1_EXTI6_Pos,
} EXTI_CFGR1_EXTI6_Enum;

typedef enum   /**< \brief (EXTI.CFGR1 EXTI7 */
{
    EXTI_CFGR1_EXTI7_PA7    = 0 << EXTI_CFGR1_EXTI7_Pos,
    EXTI_CFGR1_EXTI7_PB7    = 1 << EXTI_CFGR1_EXTI7_Pos,
    EXTI_CFGR1_EXTI7_PC7    = 2 << EXTI_CFGR1_EXTI7_Pos,
    EXTI_CFGR1_EXTI7_PD7    = 3 << EXTI_CFGR1_EXTI7_Pos,
} EXTI_CFGR1_EXTI7_Enum;

/* ============================================  CFGR2  ========================================================= */
typedef enum   /**< \brief (EXTI.CFGR1 EXTI8 */
{
    EXTI_CFGR2_EXTI8_PA8    = 0 << EXTI_CFGR2_EXTI8_Pos,
    EXTI_CFGR2_EXTI8_PB8    = 1 << EXTI_CFGR2_EXTI8_Pos,
    EXTI_CFGR2_EXTI8_PC8    = 2 << EXTI_CFGR2_EXTI8_Pos,
    EXTI_CFGR2_EXTI8_PD8    = 3 << EXTI_CFGR2_EXTI8_Pos,
} EXTI_CFGR2_EXTI8_Enum;

typedef enum   /**< \brief (EXTI.CFGR1 EXTI9 */
{
    EXTI_CFGR2_EXTI9_PA9    = 0 << EXTI_CFGR2_EXTI9_Pos,
    EXTI_CFGR2_EXTI9_PB9    = 1 << EXTI_CFGR2_EXTI9_Pos,
    EXTI_CFGR2_EXTI9_PC9    = 2 << EXTI_CFGR2_EXTI9_Pos,
    EXTI_CFGR2_EXTI9_PD9    = 3 << EXTI_CFGR2_EXTI9_Pos,
} EXTI_CFGR2_EXTI9_Enum;

typedef enum   /**< \brief (EXTI.CFGR1 EXTI10 */
{
    EXTI_CFGR2_EXTI10_PA10  = 0 << EXTI_CFGR2_EXTI10_Pos,
    EXTI_CFGR2_EXTI10_PB10  = 1 << EXTI_CFGR2_EXTI10_Pos,
    EXTI_CFGR2_EXTI10_PC10  = 2 << EXTI_CFGR2_EXTI10_Pos,
    EXTI_CFGR2_EXTI10_PD10  = 3 << EXTI_CFGR2_EXTI10_Pos,
} EXTI_CFGR2_EXTI10_Enum;

typedef enum   /**< \brief (EXTI.CFGR1 EXTI11 */
{
    EXTI_CFGR2_EXTI11_PA11  = 0 << EXTI_CFGR2_EXTI11_Pos,
    EXTI_CFGR2_EXTI11_PB11  = 1 << EXTI_CFGR2_EXTI11_Pos,
    EXTI_CFGR2_EXTI11_PC11  = 2 << EXTI_CFGR2_EXTI11_Pos,
    EXTI_CFGR2_EXTI11_PD11  = 3 << EXTI_CFGR2_EXTI11_Pos,
} EXTI_CFGR2_EXTI11_Enum;

typedef enum   /**< \brief (EXTI.CFGR1 EXTI12 */
{
    EXTI_CFGR2_EXTI12_PA12  = 0 << EXTI_CFGR2_EXTI12_Pos,
    EXTI_CFGR2_EXTI12_PB12  = 1 << EXTI_CFGR2_EXTI12_Pos,
    EXTI_CFGR2_EXTI12_PC12  = 2 << EXTI_CFGR2_EXTI12_Pos,
    EXTI_CFGR2_EXTI12_PD12  = 3 << EXTI_CFGR2_EXTI12_Pos,
} EXTI_CFGR2_EXTI12_Enum;

typedef enum   /**< \brief (EXTI.CFGR1 EXTI13 */
{
    EXTI_CFGR2_EXTI13_PA13  = 0 << EXTI_CFGR2_EXTI13_Pos,
    EXTI_CFGR2_EXTI13_PB13  = 1 << EXTI_CFGR2_EXTI13_Pos,
    EXTI_CFGR2_EXTI13_PC13  = 2 << EXTI_CFGR2_EXTI13_Pos,
    EXTI_CFGR2_EXTI13_PD13  = 3 << EXTI_CFGR2_EXTI13_Pos,
} EXTI_CFGR2_EXTI13_Enum;

typedef enum   /**< \brief (EXTI.CFGR1 EXTI15 */
{
    EXTI_CFGR2_EXTI14_PA14  = 0 << EXTI_CFGR2_EXTI14_Pos,
    EXTI_CFGR2_EXTI14_PB14  = 1 << EXTI_CFGR2_EXTI14_Pos,
    EXTI_CFGR2_EXTI14_PC14  = 2 << EXTI_CFGR2_EXTI14_Pos,
    EXTI_CFGR2_EXTI14_PD14  = 3 << EXTI_CFGR2_EXTI14_Pos,
} EXTI_CFGR2_EXTI14_Enum;

typedef enum   /**< \brief (EXTI.CFGR1 EXTI5 */
{
    EXTI_CFGR2_EXTI15_PA15  = 0 << EXTI_CFGR2_EXTI15_Pos,
    EXTI_CFGR2_EXTI15_PB15  = 1 << EXTI_CFGR2_EXTI15_Pos,
    EXTI_CFGR2_EXTI15_PC15  = 2 << EXTI_CFGR2_EXTI15_Pos,
    EXTI_CFGR2_EXTI15_PD15  = 3 << EXTI_CFGR2_EXTI15_Pos,
} EXTI_CFGR2_EXTI15_Enum;

typedef enum /**< \brief Non register operation,only an enumeration variable for EXTI Trigger*/
{
    EXTI_Trigger_NO         = 0,
    EXTI_Trigger_Rising     = 0x01,
    EXTI_Trigger_Falling    = 0x02,
    EXTI_Trigger_Bothedging = 0x03,
} EXTI_Trigger_Enum;
typedef enum /**< \brief Non register operation,only an enumeration variable for EXTI Trigger*/
{
    EXTI_Event_Mode                  = 0,
    EXTI_Interrupt_Mode              = 0x01,
    EXTI_EventAndInterrupt_Mode      = 0x02,

} EXTI_Mode_Enum;

typedef enum /**< \brief Non register operation,only an enumeration variable for EXTI Event*/
{
    EXTI_LINE0    = 0x1ul,                             
    EXTI_LINE1    = 0x2ul,                  
    EXTI_LINE2    = 0x4ul,                 
    EXTI_LINE3    = 0x8ul,               
    EXTI_LINE4    = 0x10ul,                  
    EXTI_LINE5    = 0x20ul,                
    EXTI_LINE6    = 0x40ul,                  
    EXTI_LINE7    = 0x80ul,                 
    EXTI_LINE8    = 0x100ul,                 
    EXTI_LINE9    = 0x200ul,               
    EXTI_LINE10   = 0x400ul,               
    EXTI_LINE11   = 0x800ul,                
    EXTI_LINE12   = 0x1000ul,               
    EXTI_LINE13   = 0x2000ul,               
    EXTI_LINE14   = 0x4000ul,                
    EXTI_LINE15   = 0x8000ul,
	  EXTI_LINE_ALL = 0xFFFFul,
} EXTI_Line_Enum;
typedef enum /**< \brief Non register operation,only an enumeration variable for EXTIGROUP*/
{
    EXTI_GROUPA = 0,
    EXTI_GROUPB = 1,
    EXTI_GROUPC = 2,
    EXTI_GROUPD = 3,
} EXTI_GROUP_Enum;
typedef struct
{
    EXTI_Line_Enum    EXTI_Line;      /* Specifies the EXTI lines to be enabled or disabled. */
    EXTI_GROUP_Enum   GPIO_GPOUP;     /* Specifies the EXTI GPIO number */
    EXTI_Trigger_Enum Trigger;        /* Specifies the trigger signal active edge for the EXTI lines.*/
	  EXTI_Mode_Enum    Mode;
    FunctionalState   LineCmd;        /* Specifies the new state of the selected EXTI lines */
} EXTI_Init_T;

void EXTI_Enable_IT(EXTI_Line_Enum ExtiLine);
void EXTI_Disable_IT(EXTI_Line_Enum ExtiLine);
uint32_t EXTI_IsEnabled_IT(EXTI_Line_Enum ExtiLine);
void EXTI_EnableEvent(EXTI_Line_Enum ExtiLine);
void EXTI_DisableEvent(EXTI_Line_Enum ExtiLine);
uint32_t EXTI_IsEnabledEvent(EXTI_Line_Enum ExtiLine);
void EXTI_EnableRisingTrig(EXTI_Line_Enum ExtiLine);
void EXTI_DisableRisingTrig(EXTI_Line_Enum ExtiLine);
uint32_t EXTI_IsEnabledRisingTrig(EXTI_Line_Enum ExtiLine);
void EXTI_EnableFisingTrig(EXTI_Line_Enum ExtiLine);
void EXTI_DisableFisingTrig(EXTI_Line_Enum ExtiLine);
uint32_t EXTI_IsEnabledFallingTrig(EXTI_Line_Enum ExtiLine);
void EXTI_GenerateSWI(EXTI_Line_Enum ExtiLine);
uint32_t EXTI_IsActiveFlag(EXTI_Line_Enum ExtiLine);
uint32_t EXTI_ReadFlag(EXTI_Line_Enum ExtiLine);
void EXTI_ClearFlag(EXTI_Line_Enum ExtiLine);
void EXTI_DeInit(void);
void EXTI_Init(EXTI_Init_T* EXTI_InitStruct);

#ifdef __cplusplus
}
#endif

#endif /* MS60F3XXX_EXTI_H */

