/**
  ******************************************************************************
  * @file           : ms60f3xxx_flash.h
  * @author         : sinomcu.com-SA
  * @brief          : Header file of FLASH module.
  * @gcc            : toolchain version   5
  *
  ******************************************************************************
  * @attention
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with
	* basic chip information support
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */
#ifndef MS60F3XXX_FLASH_H
#define MS60F3XXX_FLASH_H
#include "stdint.h"
#include "ms60f3xxx.h"

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/



/**
* @brief  Flash Init parameter type definition
*/

//#define USE_RAM_CODE

/* Exported types ------------------------------------------------------------*/
/* Exported constants --------------------------------------------------------*/
/**
  * @brief  FLASH Status
  */
//#define NVR_BOOTLOADER
#ifdef NVR_BOOTLOADER
#define appAddr 0x01000000
#define Address_EnterAPPFlag     0x00801600 /*Update address flag storage address*/
#define Address_Checksum         0x00801604 /*Checksum storage address*/
#define Address_StartTime        0x9FE08    /*Start time storage address*/
#elif defined  Board_MS60F3023_QFN_EVB  /*3023 BP48  32k  */
#define appAddr 0x01004000
#define Address_EnterAPPFlag     0x01003E00 /*Update address flag storage address*/
#define Address_Checksum         0x01003E04 /*Checksum storage address*/
#define Address_StartTime        0x01003E08 /*Start time storage address*/
#define Address_Program_Len      0x01003E0C
#elif defined Board_MS60F3215_QFN_EVB  /*3115 BP48  64k  */
#define appAddr 0x01008000
#define Address_EnterAPPFlag     0x0100FE00 /*Update address flag storage address*/
#define Address_Checksum         0x0100FE04 /*Checksum storage address*/
#define Address_StartTime        0x0100FE08 /*Start time storage address*/
#define Address_Program_Len      0x0100FE0C
#else 
#define appAddr 0x01010000 /*3115 BP48  128k  */
#define Address_EnterAPPFlag     0x0101FE00 /*Update address flag storage address*/
#define Address_Checksum         0x0101FE04 /*Checksum storage address*/
#define Address_StartTime        0x0101FE08 /*Start time storage address*/
#define Address_Program_Len      0x0101FE0C
#endif

#define FLASH_REG_BASE         (0x40000000)
#define FLS_CFG_EN             ( FLASH_REG_BASE + 0x100) /*RW*/
#define CODE_CFG_EN            ( FLASH_REG_BASE + 0x104)
#define DATA_CFG_EN             ( FLASH_REG_BASE + 0x108)
/*Private data NVR area programming/erasing enable, read this register to access 0, write 0x20161118 enable user NVR area programming/erasing, other values are invalid*/
#define PRVT_NVR_EN            ( FLASH_REG_BASE + 0x10C) /*WO*/
/*Manufacturer NVR area programming/erasing enable, read this register to access 0, write 0x6534a315 enable manufacturer NVR area programming/erasing, other values are invalid*/
#define 	FLS_MANU_NVR_EN  ( FLASH_REG_BASE + 0x234)
#define  	FLS_FUND_NVR_EN   ( FLASH_REG_BASE + 0x238)
#define   MAIN_CODE_EN             ( FLASH_REG_BASE + 0x104)
#define   MAIN_DATA_EN            ( FLASH_REG_BASE + 0x108)
#define  FLASH_IR_CRCERR               ((uint32_t)0x00000001<<14)
#define  FLASH_IR_CRCEND               ((uint32_t)0x00000001<<13)
#define  FLASH_IR_PROGCLKERR           ((uint32_t)0x00000001<<12)
#define  FLASH_IR_ERASECLKERR           ((uint32_t)0x00000001<<11)
#define  FLASH_IR_READAUTHERR           ((uint32_t)0x00000001<<10)
#define  FLASH_IR_PROGAUTHERR           ((uint32_t)0x00000001<<9)
#define  FLASH_IR_ERASEAUTHERR           ((uint32_t)0x00000001<<8)
#define  FLASH_IR_PRGCHECKERR            ((uint32_t)0x00000001<<7)
#define  FLASH_IR_ERASECHECKERR          ((uint32_t)0x00000001<<6)
#define  FLASH_IR_RDADDRERR              ((uint32_t)0x00000001<<5)        /*!< Reading address illegal*/
#define  FLASH_IR_PGADDRERR              ((uint32_t)0x00000001<<4)        /*!< Illegal programming address*/
#define  FLASH_IR_ESADDRERR              ((uint32_t)0x00000001<<3)        /*!< Erase address illegal*/
#define  FLASH_IR_PGEND                  ((uint32_t)0x00000001<<2)        /*!< Programming completed*/
#define  FLASH_IR_SECTORESEND            ((uint32_t)0x00000001<<1)        /*!< Full erase completed */
#define  FLASH_IR_CHIPESEND              ((uint32_t)0x00000001)           /*!< Sector erase completed */

#define  APPUpdate_Pass_Flag      0x5555 /*Program update success flag bit*/
#define  APPUpdate_Fail_Flag      0x1234 /*Program update failure flag bit*/
#define  CHECK_HARD 1
#define  NO_CHECK   0
#define  NVR0_ADDRESS  0x00800000
#define  NVR1_ADDRESS  0x00800200
#define  NVR2_ADDRESS  0x00800400
#define  NVR3_ADDRESS  0x00800600
#define  NVR4_ADDRESS  0x00800800
#define  NVR5_ADDRESS  0x00800A00
#define  NVR6_ADDRESS  0x00800C00
#define  NVR7_ADDRESS  0x00800E00
#define  NVR8_ADDRESS  0x00801000
#define  NVR9_ADDRESS  0x00801200
#define  NVR10_ADDRESS 0x00801400


//#define  NVR11_ADDRESS  0x00801600
#define  NVR12_ADDRESS  0x00900000
#define  NVR13_ADDRESS  0x00900200

#define  NVR14_ADDRESS  0x00A00000
#define  NVR15_ADDRESS  0x00B00000
#define  MEM_MAP(ADDRESS)      (*(volatile uint32_t *)(ADDRESS))
#define  READ_PROTECT_ADDRESS NVR12_ADDRESS
#define  READ_PROTECT_ADDRESS_CONTENT() *(unsigned char *)READ_PROTECT_ADDRESS

#define  FLASH_UNLOCK_KEY            (0x7772656e)
#define  FLASH_PROGRAM_MODE          (0x70726F67)
#define  FLASH_SECTOR_ERASE_MODE     (0x73656374)
#define  FLASH_CHIP_ERASE_MODE	      (0x63686970)
#define  FLASH_LOCK_KEY              (0x12345678)
#define  FLASH_CODE_WRITE_EN_KEY     (0x636F6465)

#define  FLASH_PRVT_WRITE_EN_KEY     (0x70727674)
#define  FLASH_BOOT_NVR_EN_KEY       (0x12820320)
#define  FLASH_MANU_NVR_EN_KEY       (0x6D616E75)
#define  FLASH_FUND_NVR_EN_KEY       (0x66756E64)


/**
  * @brief  FLASH Status
*/

#define  FLASH_BASE_ADDR 0
#define  NVR0_ADDR   0x200000
#define  NVR1_ADDR    0x200200
#define  NVR2_ADDR    0x200400
#define  NVR5_ENDADDR 0x200C00
#define  NVR6_ADDR    0x300000
#define  PROGRAM_SPACE_256K 0x40000
#define  DATA_SPACE_0K 0
#define  PROGRAM_SPACE_224K 0x38000
#define  DATA_SPACE_32K 0x8000
#define  PROGRAM_SPACE_128K 0x20000

#define  PROGRAM_SPACE_112K 0x1C000
#define  DATA_SPACE_16K 0x4000
#define  SECTOR_SIZE 0x200


typedef enum /**< \brief Non register operation, only for flags  */
{
    DEFAULT_MODE = 0,
    CHIP_ERASE_MODE = 0xAAAA,
    SECTOR_ERASE_MODE = 0xBBBB,
    CHIP_PROGRAM_MODE = 0x5555,
} FLASH_OPERRATION_MODE;

typedef enum /**< \brief Non register operation, only for flags  */
{
    FLASH_COMPLETE = 1,
    FLASH_BUSY,
    FLASH_ADDR_OVERFLOW,
    FLASH_ERROR_RD_ADDR,
    FLASH_ERROR_PG_ADDR,
    FLASH_ERROR_ERASE_ADDR,
    FLASH_PROGRAM_END,
    FLASH_CHIP_ERASE_END,
    FLASH_SECTOR_ERASE_END,
    FLASH_TIMEOUT,
    FLASH_ERASE_CHECK_ERROR,
    FLASH_PRG_CHECK_ERROR,
    FLSH_ADDR_ERRPR
} FLASH_Status;

/** @defgroup FLASH_Flags
  * @{
  */

#define FLASH_FLAG_ERR_RD_ADDR                 FLASH_IR_RDADDRERR        /*!<  Reading address illegal*/
#define FLASH_FLAG_ERR_PG_ADDR                 FLASH_IR_PGADDRERR        /*!<  Reading address illegal*/
#define FLASH_FLAG_ERR_ERASE_ADDR              FLASH_IR_ESADDRERR        /*!<  Erase address illegal*/
#define FLASH_FLAG_PROGRAM_END                 FLASH_IR_PGEND            /*!<  Programming completed*/
#define FLASH_FLAG_CHIP_ERASE_END              FLASH_IR_CHIPESEND        /*!<  Full erase completed*/
#define FLASH_FLAG_SECTOR_ERASE_END            FLASH_IR_SECTORESEND      /*!<  Sector erase completed*/

#define IS_FLASH_GET_FLAG(FLAG)  (((FLAG) ==  FLASH_FLAG_ERR_RD_ADDR)    || ((FLAG) == FLASH_FLAG_ERR_PG_ADDR) ||    \
                                  ((FLAG) ==  FLASH_FLAG_ERR_ERASE_ADDR) || ((FLAG) == FLASH_FLAG_PROGRAM_END) ||    \
                                  ((FLAG) ==  FLASH_FLAG_CHIP_ERASE_END) || ((FLAG) == FLASH_FLAG_SECTOR_ERASE_END)|| \
                                  ((FLAG) ==  FLASH_IR_PRGCHECKERR) || ((FLAG) == FLASH_IR_PGADDRERR))
#define IS_FLASH_CLEAR_FLAG(FLAG) (IS_FLASH_GET_FLAG(FLAG))

/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */
void Manu_NVR_test(void);
void FLASH_Unlock(void);
void FLASH_Lock(FLASH_OPERRATION_MODE mode);
FLASH_Status FLASH_EraseSector(uint32_t Sector_Address);
FLASH_Status FLASH_Program(uint32_t Address, uint8_t *buff, uint32_t len);
FlagStatus FLASH_GetFlagStatus(uint32_t FLASH_FLAG);
void FLASH_ClearFlag(uint32_t FLASH_FLAG);
FLASH_Status FLASH_WaitForBitStatusDone(uint32_t FLASH_FLAG, uint32_t Timeout);
uint32_t Flash_CrcCalculate(uint32_t start, uint32_t end);
void FLASH_PROGRAM_Unlock(void);
void FLASH_PROGRAM_Lock(void);
void FLASH_NVR_PROGRAM_Unlock(void);
void FLASH_NVR_PROGRAM_Lock(void);
void FLASH_NVR_ERASE_Lock(void);
void FLASH_NVR_ERASE_Unlock(void);
void FLASH_ERASE_SECTOR_Unlock(void);
void FLASH_Read_Protect(void);
FLASH_Status FLASH_EraseChip(void);
FLASH_Status NVR_EraseSector(uint32_t Sector_Address);
void FLASH_ERASE_SECTOR_Lock(void);
void FLASH_Remove_Read_Protect(void);
FLASH_Status FLASH_EraseChip(void);


#ifdef __cplusplus
}
#endif
#endif

