/**
  ******************************************************************************
  * @file           : ms60f3xxx_gpio.h
  * @author         : sinomcu.com-SA
  * @brief          : Header file of GPIO module.
  * @gcc            : toolchain version   5 or 6
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with 
	* basic chip information support
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */
#ifndef MS60F3XXX_GPIO_H
#define MS60F3XXX_GPIO_H
#include "ms60f3xxx.h"

#ifdef __cplusplus
 extern "C" {
#endif
	 
typedef enum /**< \brief (SR) Slew Rate Register */
{
    GPIO_Speed_High = 0,
    GPIO_Speed_Low = 1,
} GPIO_Speed_Enum;

typedef enum /**< \brief (DR) Drive Register  */
{
    Strong_Drive = 0,
    Weak_Drive = 1,
} GPIO_DR_Mode_Enum;

typedef enum /**< \brief (AFRx) Alternative Function Register x  */
{
    GPIO_ALT_SYSTEM = 0,
    GPIO_ALT_PLUI = 1,
    GPIO_ALT_PLUOUT_EXTCLK = 2,
    GPIO_ALT_SDA0 = 3,
    GPIO_ALT_SCL0 = 4,
    GPIO_ALT_SDA1 = 5,
    GPIO_ALT_SCL1 = 6,
    GPIO_ALT_RX0 = 7,
    GPIO_ALT_TX0 = 8,
    GPIO_ALT_RX1 = 9,
    GPIO_ALT_TX1 = 10,
    GPIO_ALT_SPI0 = 11,
    GPIO_ALT_SPI1 = 12,
    GPIO_ALT_TIM0 = 13,
    GPIO_ALT_TIM1 = 14,
    GPIO_ALT_COMP = 15,
    GPIO_ALT_UART2 = 16,
    GPIO_ALT_PWM = 17,
    GPIO_ALT_USART = 18,
} GPIO_ALT_Enum;

typedef enum /**< \brief Non register operation, only for GPIO PIN flags  */
{
    GPIO_PIN0 = 0,
    GPIO_PIN1 = 1,
    GPIO_PIN2 = 2,
    GPIO_PIN3 = 3,
    GPIO_PIN4 = 4,
    GPIO_PIN5 = 5,
    GPIO_PIN6 = 6,
    GPIO_PIN7 = 7,
    GPIO_PIN8 = 8,
    GPIO_PIN9 = 9,
    GPIO_PIN10 = 10,
    GPIO_PIN11 = 11,
    GPIO_PIN12 = 12,
    GPIO_PIN13 = 13,
    GPIO_PIN14 = 14,
    GPIO_PIN15 = 15,
} GPIO_PIN_Enum;

typedef enum /**< \brief Non register operation, only for GPIO Mode flags  */
{
    GPIO_MODE_INPUT_FLOAT = 1,
    GPIO_MODE_INPUT_PU = 2,
    GPIO_MODE_INPUT_PD = 3,
    GPIO_MODE_OUTPUT_PP = 4,
    GPIO_MODE_OUTPUT_OD = 5,
    GPIO_MODE_OUTPUT_OD_PU = 6,
    GPIO_MODE_OUTPUT_OD_PD = 7,
    GPIO_MODE_AF = 8,
    GPIO_MODE_ANALOG = 9,
} GPIO_Mode_Enum;

#define GPIO_PIN_MDR(Port,Pin,Mode)		( GPIO##Port->MODER  = ( GPIO##Port->MODER & ~((u32)0x03ul << ( (Pin) * 2ul ) ) ) | ((u32)Mode << ( (Pin) * 2ul ) ) )
#define GPIO_PIN_PUR(Port,Pin,V)			( GPIO##Port->PU  = ( GPIO##Port->PU & ~( 0x01ul << (Pin) ) ) | ( V << (Pin) ) )
#define GPIO_PIN_PDR(Port,Pin,V)			( GPIO##Port->PD  = ( GPIO##Port->PD & ~( 0x01ul << (Pin) ) ) | ( V << (Pin) ) )
#define GPIO_PIN_ODR(Port,Pin,V)			( GPIO##Port->OD  = ( GPIO##Port->OD & ~( 0x01ul << (Pin) ) ) | ( V << (Pin) ) )
#define GPIO_PIN_DRR(Port,Pin,V)			( GPIO##Port->DR  = ( GPIO##Port->DR & ~( 0x01ul << (Pin) ) ) | ( V << (Pin) ) )
#define GPIO_PIN_SRR(Port,Pin,V)			( GPIO##Port->SR  = ( GPIO##Port->SR & ~( 0x01ul << (Pin) ) ) | ( V << (Pin) ) )
#define GPIO_PIN_IER(Port,Pin,V)			( GPIO##Port->IE  = ( GPIO##Port->IE & ~( 0x01ul << (Pin) ) ) | ( V << (Pin) ) )
#define GPIO_PIN_DOUT(Port,Pin,V)			( GPIO##Port->DOUT  = ( GPIO##Port->DOUT & ~( 0x01ul << (Pin) ) ) | ( V << (Pin) ) )
#define GPIO_PIN_SET(Port,Pin,V)			( GPIO##Port->DOUT_SET |= ( V << (Pin) ) )
#define GPIO_PIN_CLR(Port,Pin,V)			( GPIO##Port->DOUT_RST |= ( V << (Pin) ) )
#define GPIO_PIN_FLP(Port,Pin,V)			( GPIO##Port->DOUT_FLP |= ( V << (Pin) ) )
/* Port   GPIOA GPIOB GPIOC GPIOD   */
/* Pin   PIN00 PIN01 PIN02 PIN03     */
/*Func  reference from GPIO_ALT_TYPE;*/
#define GPIO_PIN_AFR0(Port,Pin,Func)	( GPIO##Port->AFR0 = ( GPIO##Port->AFR0 & ~( 0x3Ful << ((Pin) * 8ul ) ) ) | ( Func << ( (Pin) * 8ul ) ) )
/* Port   GPIOA GPIOB GPIOC GPIOD   */
/* Pin   PIN04 PIN05 PIN06 PIN07     */
/*Func  reference from GPIO_ALT_TYPE;*/
#define GPIO_PIN_AFR1(Port,Pin,Func)	( GPIO##Port->AFR1 = ( GPIO##Port->AFR1& ~( 0x3Ful << ( (Pin-4) * 8ul ) ) ) | ( Func << ( (Pin-4) * 8ul ) ) )
/* Port   GPIOA GPIOB GPIOC GPIOD   */
/* Pin   PIN08 PIN09 PIN10 PIN11     */
/*Func  reference from GPIO_ALT_TYPE;*/

#define GPIO_PIN_AFR2(Port,Pin,Func)	( GPIO##Port->AFR2 = ( GPIO##Port->AFR2 & ~( 0x3Ful << ( (Pin-8) * 8ul ) ) ) | ( Func << ( (Pin-8) * 8ul ) ) )
/* Port   GPIOA GPIOB GPIOC GPIOD   */
/* Pin   PIN12 PIN13 PIN14 PIN15     */
/*Func  reference from GPIO_ALT_TYPE;*/
#define GPIO_PIN_AFR3(Port,Pin,Func)	( GPIO##Port->AFR3 = ( GPIO##Port->AFR3& ~( 0x3Ful << ( (Pin-12) * 8ul ) ) ) | ( Func << ( (Pin-12) * 8ul ) ) )
#define GPIO_PIN0_AF(Port,Func)				( GPIO##Port->AFR0 = ( GPIO##Port->AFR0& ~( 0x3Ful ) | ( Func ) ))
#define GPIO_PIN1_AF(Port,Func)				( GPIO##Port->AFR1 = ( GPIO##Port->AFR0& ~( 0x3Ful << 8ul ) ) ) | ( Func << 8ul ) ) ))
#define GPIO_PIN2_AF(Port,Func)				( GPIO##Port->AFRL = ( GPIO##Port->AFR0& ~( 0x3Ful << 16ul ) ) ) | ( Func << 16ul ) ) ))
#define GPIO_PIN3_AF(Port,Func)				( GPIO##Port->AFRL = ( GPIO##Port->AFR0& ~( 0x3Ful << 24ul ) ) ) | ( Func << 24ul ) ) ))
#define GPIO_PIN4_AF(Port,Func)				( GPIO##Port->AFR1 = ( GPIO##Port->AFR1& ~( 0x3Ful ) ) | ( Func ) ))
#define GPIO_PIN5_AF(Port,Func)				( GPIO##Port->AFR1 = ( GPIO##Port->AFR1& ~( 0x3Ful<<8ul  ) ) | ( Func<<8ul  ) ))
#define GPIO_PIN6_AF(Port,Func)				( GPIO##Port->AFR1 = ( GPIO##Port->AFR1& ~( 0x3Ful<<16ul ) ) | ( Func<<16ul ) ))
#define GPIO_PIN7_AF(Port,Func)				( GPIO##Port->AFR1 = ( GPIO##Port->AFR1& ~( 0x3Ful<<24ul ) ) | ( Func<<8ul  ) ))
#define GPIO_PIN8_AF(Port,Func)				( GPIO##Port->AFR2 = ( GPIO##Port->AFR2& ~( 0x3Ful ) ) | ( Func ) ))
#define GPIO_PIN9_AF(Port,Func)				( GPIO##Port->AFR2 = ( GPIO##Port->AFR2& ~( 0x3Ful<<8ul  ) ) | ( Func<<8ul  ) ))
#define GPIO_PIN10_AF(Port,Func)				( GPIO##Port->AFR2 = ( GPIO##Port->AFR2& ~( 0x3Ful<<16ul ) ) | ( Func<<16ul ) ))
#define GPIO_PIN11_AF(Port,Func)				( GPIO##Port->AFR2 = ( GPIO##Port->AFR2& ~( 0x3Ful<<24ul ) ) | ( Func<<8ul  ) ))
#define GPIO_PIN12_AF(Port,Func)				( GPIO##Port->AFR3 = ( GPIO##Port->AFR3& ~( 0x3Ful ) ) | ( Func ) ))
#define GPIO_PIN13_AF(Port,Func)				( GPIO##Port->AFR3 = ( GPIO##Port->AFR3& ~( 0x3Ful<<8ul  ) ) | ( Func<<8ul  ) ))
#define GPIO_PIN14_AF(Port,Func)				( GPIO##Port->AFR3 = ( GPIO##Port->AFR3& ~( 0x3Ful<<16ul ) ) | ( Func<<16ul ) ))
#define GPIO_PIN15_AF(Port,Func)				( GPIO##Port->AFR3 = ( GPIO##Port->AFR3& ~( 0x3Ful<<24ul ) ) | ( Func<<8ul  ) ))

void GPIO_Init(GPIO_Type* GPIOx, GPIO_PIN_Enum pin, GPIO_Mode_Enum mode);
void GPIO_SetSpeed(GPIO_Type* GPIOx, GPIO_PIN_Enum GPIO_Pin, GPIO_Speed_Enum Speed);
void GPIO_PinRemapConfig(GPIO_Type* GPIOx, GPIO_PIN_Enum GPIO_Pin, GPIO_ALT_Enum GPIO_AFReg);
void GPIO_SetBits(GPIO_Type* GPIOx, GPIO_PIN_Enum GPIO_Pin);
void GPIO_ResetBits(GPIO_Type* GPIOx, GPIO_PIN_Enum GPIO_Pin);
void GPIO_Toggle(GPIO_Type* GPIOx, GPIO_PIN_Enum GPIO_Pin);
void GPIO_Write(GPIO_Type* GPIOx, uint8_t PortVal);
uint16_t GPIO_ReadOutputDataBit(GPIO_Type* GPIOx, GPIO_PIN_Enum GPIO_Pin);
uint16_t GPIO_ReadInputDataBit(GPIO_Type* GPIOx, GPIO_PIN_Enum GPIO_Pin);
uint16_t GPIO_ReadInputData(GPIO_Type* GPIOx);
void GPIO_PullUpConfig(GPIO_Type* GPIOx, GPIO_PIN_Enum GPIO_Pin);
void GPIO_PullDownConfig(GPIO_Type* GPIOx, GPIO_PIN_Enum GPIO_Pin);
void GPIO_SetDriverPower(GPIO_Type* GPIOx, GPIO_PIN_Enum GPIO_Pin, GPIO_DR_Mode_Enum PowerMode);
void GPIO_SetOD(GPIO_Type* GPIOx, GPIO_PIN_Enum GPIO_Pin,FunctionalState NewState);
#ifdef __cplusplus
}
#endif

#endif




