/**
  ******************************************************************************
  * @file           : ms60f3xxx_i2c.h
  * @author         : sinomcu.com-SA
  * @brief          :  Header file of i2c module.
  * @gcc            : toolchain version 5 or 6
  *
  ******************************************************************************
  * @attention
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with
 * basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
*/
#ifndef MS60F3XXX_I2C_H
#define MS60F3XXX_I2C_H
#ifdef __cplusplus
extern "C" {
#endif
#include "ms60f3xxx.h"

#define bl_I2C0_SLAVE_SEND_DR(x)   {I2C0->TDR = x;}
#define bl_I2C1_SLAVE_SEND_DR(x)   {I2C1->TDR = x;}
/* I2C->CR		*/
#define I2C_EN					(1UL << 4)
#define	I2C_START				(1UL << 3)
#define	I2C_STOP				(1UL << 2)
#define	I2C_SI					(1UL << 0)
#define	I2C0_SETFLAG(F)	{ I2C0->CR = I2C_EN|F;  }
#define	I2C1_SETFLAG(F)	{ I2C1->CR = I2C_EN|F;  }
#define I2C_PTCR_TXTEN  (0x1U << 8)
#define I2C_PTCR_TXTDIS (0x1U << 9)
#define I2C_PTCR_RXEN   (0x1U << 0)
#define I2C_PTCR_RXDIS  (0x1U << 1)
#define ACK  						 1
typedef enum/**< \brief  (I2Cx_CR) Choose whether to reply to ACK */
{
    I2C_NOACK = 0,
    I2C_ACK = 2,
} I2C_ACK_ENUM;

typedef enum/**< \brief  Select IIC working mode */
{
    MASTER_MODE = 0,
    SLAVER_MODE = 1
} I2C_MODE_SELE;
typedef enum/**< \brief  (I2Cx_IER/IDR/IMR) Choose I2C_Interrupt Flag */
{
    RDFF    = (1UL << 0),
    RDFHF   = (1UL << 1),
    RDFNE   = (1UL << 2),
    RDFO    = (1UL << 3),
    TDFF    = (1UL << 4),
    TDFHF   = (1UL << 5),
    TDFE    = (1UL << 6),
    TDFO    = (1UL << 7),
    TIMEOUT = (1UL << 8),
    SI 			= (1UL << 9),
    ENDRX		= (1UL << 12),
    ENDTX 	= (1UL << 13),
    RXBUFF 	= (1UL << 14),
    TXBUFE 	= (1UL << 15),
} I2C_Interrupt_Flag_ENUM;
typedef struct
{
    uint32_t frequency;
    uint16_t duty;
    I2C_MODE_SELE mode;
    uint8_t address;
} I2C_INIT_T;

void I2C0_state(void);

void I2C_Init(IIC_Type *pi2c, I2C_INIT_T *i2c_init );

void I2C_Enable_IT(IIC_Type *pi2c, I2C_Interrupt_Flag_ENUM I2C_Interrupt);
void I2C_Disable_IT(IIC_Type *pi2c, I2C_Interrupt_Flag_ENUM I2C_Interrupt);
void delay_us(unsigned long uS);

void I2CStop(IIC_Type *pi2c);

void I2CStart(IIC_Type *pi2c);

uint8_t I2C_Slave_Send_Data(IIC_Type *pi2c, uint8_t byte, I2C_ACK_ENUM ack);

uint8_t I2C_Send_address(IIC_Type *pi2c, uint8_t address, I2C_ACK_ENUM ack);

uint8_t I2C_Send_Byte(IIC_Type *pi2c, uint8_t byte, I2C_ACK_ENUM ack);

uint16_t I2C_Receive_Byte(IIC_Type *pi2c, I2C_ACK_ENUM ack);
uint16_t I2C_Send_Buff(IIC_Type *pi2c, uint8_t address, uint8_t *buff, uint8_t len, I2C_ACK_ENUM ack);
uint16_t I2C_Receive_Buff(IIC_Type *pi2c, uint8_t address, uint8_t *buff, uint8_t len, I2C_ACK_ENUM ack);

#ifdef __cplusplus
}
#endif

#endif
