/**
  ******************************************************************************
  * @file           : ms60f3xxx_iwdg.h
  * @author         : sinomcu.com-SA
  * @brief          :  Header file of iwdg module.
  * @gcc            : toolchain version 5 or 6
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with 
 * basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
*/
#ifndef MS60F3XXX_IWDG_H
#define MS60F3XXX_IWDG_H

#ifdef __cplusplus

 extern "C" {
#endif

#include "ms60f3xxx.h"

#define FEED_DOG() IWDG_ReloadCounter()
#define IWDG_WriteAccess_Enable     ((uint32_t)0x5555)
#define IWDG_START_Enable     ((uint32_t)0xCCCC)
#define IWDG_RELOAD_ENABLE     ((uint32_t)0xAAAA)
#define IWDG_WriteAccess_Disable    ((uint32_t)0x000000)
#define IS_IWDG_WRITE_ACCESS(ACCESS) (((ACCESS) == IWDG_WriteAccess_Enable) || \
                                      ((ACCESS) == IWDG_WriteAccess_Disable))
#define IWDG_Prescaler_Mask          (0x0000FFFF)
#define IS_IWDG_PRESCALER(PRESCALER) ((PRESCALER) &= IWDG_Prescaler_Mask)

#define IWDG_FLAG_OV               (0x01)
#define IWDG_FLAG_NOV              (0x00)

#define IWDG_KEY_RELOAD    ((uint16_t)0xAA)
#define IWDG_KEY_ENABLE    ((uint16_t)0x0001)
#define IWDG_KEY_DISABLE   ((uint16_t)0x0000)

#define IWDG_LOAD_ENABLE   (0x01)
#define IWDG_LOAD_DISABLE  (0x00)

#define IWDG_INT_ENABLE    ((uint8_t)0x01)
#define IWDG_INT_DISABLE   ((uint8_t)0x00)
#define IS_WDG_INT_CMD(FLAG) (((FLAG) == IWDG_INT_ENABLE ) || ((FLAG) == IWDG_INT_DISABLE))

typedef enum/**< \brief (IWDG_PR) Prescaler divider */
{
    IWDG_div4 = 0,
    IWDG_div8 = 1,
    IWDG_div16 = 2,
    IWDG_div32 = 3,
    IWDG_div64 = 4,
    IWDG_div128 = 5,
    IWDG_div256 = 6,

} IWDG_DIV_Enum;

__INLINE static void IWDG_WriteAccessCmd(uint32_t IWDG_WriteAccess);

void IWDG_DeInit(void);

void IWDG_ReloadCounter(void);

void IWDG_Init(IWDG_DIV_Enum div, uint16_t Counter);

void IWDG_Disable(void);

void IWDG_SetPrescaler(uint32_t WDG_Prescaler);

void IWDG_SetCounter(uint16_t Counter);

void IWDG_Start(void);

#ifdef __cplusplus
}
#endif

#endif

