/**
  ******************************************************************************
  * @file           : ms60f3xxx_lptimer.h
  * @author         : sinomcu.com-SA
  * @brief          : Header file of lptimer module.
  * @gcc            : toolchain version 5 or 6
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with 
 * basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
*/
#ifndef MS60F3XXX_LPTIMER_H
#define MS60F3XXX_LPTIMER_H
#ifdef __cplusplus
 extern "C" {
#endif
#include "ms60f3xxx.h"

typedef enum/**< \brief (LPTIM_EN) LPTIMER enable or disable selection */
{
    LPTIMER_DISABLE = 0,
    LPTIMER_ENABLE  = 1
} LPTIMER_ENABLE_Enum;

typedef enum/**< \brief (LPTIM_CR) LPTIMER Single or continuous operation mode selection */
{
    SINGLE_MODE   = 0,
    CONTINUE_MODE = 1,
} LPTIMER_CR_CONT_Enum;

typedef enum/**< \brief (LPTIM_CR) LPTIMER Clock prescaler selection */
{
    CLOCK_Div1       =   0,
    CLOCK_Div2       = ( 1ul << 8),
    CLOCK_Div4       = ( 2ul << 8),
    CLOCK_Div8       = ( 3ul << 8),
    CLOCK_Div16      = ( 4ul << 8),
    CLOCK_Div32      = ( 5ul << 8),
    CLOCK_Div64      = ( 6ul << 8),
    CLOCK_Div128     = ( 7ul << 8),
    CLOCK_Div256     = ( 8ul << 8),
    CLOCK_Div512     = ( 9ul << 8),
    CLOCK_Div1024    = (10ul << 8),
    CLOCK_Div2048    = (11ul << 8),
    CLOCK_Div4096    = (12ul << 8),
    CLOCK_Div8192    = (13ul << 8),
    CLOCK_Div16384   = (14ul << 8),
    CLOCK_Div32768   = (15ul << 8),
} LPTIMER_CLOCK_DIV_Enum;

typedef enum/**< \brief (LPTIM_STR) LPTIM software triggered selection */
{
    LPTIMER_STR_SOFT_TRIG_DISABLE = 0,
    LPTIMER_STR_SOFT_TRIG_ENALBE  = 1,
} LPTIMER_STR_STRIG_Enum;

typedef enum/**< \brief (SCU.CLK_SEL_CR) LPTIMER Clock  selection */
{
    LRC_32K   = 0,
    LXTAL_32K = 1,
} LPTIMER_CLK_SEL_Enum;

typedef struct
{
    uint16_t                 arr_value;
    LPTIMER_CLK_SEL_Enum     clkselect;
    LPTIMER_ENABLE_Enum      lp_enable;
    LPTIMER_CR_CONT_Enum     mode;
    LPTIMER_CLOCK_DIV_Enum	 clock_div;
} LPTIMER_INIT_T;

void LPTIMER_Enable_IT(void);
void LPTIMER_Disable_IT(void);
void LPTIMER_Enable(void);
void LPTIMER_Disable(void);
void LPTIMER_Init(LPTIMER_INIT_T *lp_init);

#ifdef __cplusplus
}
#endif

#endif


