/**
  ******************************************************************************
  * @file           : ms60f3xxx_pga.h
  * @author         : sinomcu.com-SA
  * @brief          :  Header file of PGA module.
  * @gcc            : toolchain version 5 or 6
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with 
 * basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
*/
#ifndef MS60F3XXX_PGA_H
#define MS60F3XXX_PGA_H

#ifdef __cplusplus
 extern "C" {
#endif

#include "ms60f3xxx.h"
typedef enum/**< \brief (PGA_CHSEL) PGA channel selection register */                     
{
    PGA0_CHN_PC4       = 0,    
    PGA0_CHN_PC3       = 1,    
    PGA0_CHN_PB15      = 2,
    PGA0_CHN_PC7       = 3,    
    PGA0_CHN_PC6       = 4,     
    PGA0_CHN_A13       = 5,    
    PGA0_CHN_B14       = 6,     
    PGA0_CHN_C2        = 7,     
    PGA0_CHP_PB11      = (0ul << 3), 
    PGA0_CHP_PB6       = (1ul << 3),   
    PGA0_CHP_PB5       = (2ul << 3),  
    PGA0_CHP_PB4       = (3ul << 3),  
    PGA0_CHP_PB3       = (4ul << 3),  
    PGA0_CHP_PB2       = (5ul << 3),   
    PGA0_CHP_PA15      = (6ul << 3),   
    PGA0_CHP_PA14      = (7ul << 3),   
    PGA1_CHN_PA1       = (0ul << 8),  
    PGA1_CHN_PC8       = (1ul << 8),   
    PGA1_CHN_PC9       = (2ul << 8),  
    PGA1_CHN_PC10      = (3ul << 8),  
    PGA1_CHN_PPC5      = (4ul << 8),   
    PGA1_CHN_PB12      = (5ul << 8),  
    PGA1_CHN_PC1       = (6ul << 8),  
    PGA1_CHN_PC0       = (7ul << 8),  
    PGA1_CHP_PA12      = (0ul << 11),  
    PGA1_CHP_PA11      = (1ul << 11),   
    PGA1_CHP_PA10      = (2ul << 11),   
    PGA1_CHP_PA9       = (3ul << 11),   
    PGA1_CHP_PB1       = (4ul << 11),   
    PGA1_CHP_PB0       = (5ul << 11),   
    PGA1_CHP_PA4       = (6ul << 11),   
    PGA1_CHP_PB13      = (7ul << 11),  
} PGA_CH_Enum;

typedef enum/**< \brief (PGA_MODE) PGA mode control */                       
{
    gain_amplifier = 0,   
    positive_phase_input = 1,
    Single_ended_attenuation = 2,
    User_Mode_inputVDDHalf = 3,
    User_Mode_inputVDD = 4,
} PGA_MODE_Enum;



typedef enum/**< \brief (PGA_MODE) PGA enable*/                        
{
    PGA0_EN_ENABLE          = (1 << 6),  
    PGA1_EN_ENABLE          = (1 << 7),   
} PGA_EN_Enum;



typedef enum/**< \brief (PGA_GAIN) PGA gain controlThe suffix 0_25 represents 0.25x attenuation, and the rest in turn, and the suffix greater than or equal to 1 represents a certain magnification */                        
{
    PGA0_GAIN2_0_25    = 0,    
    PGA0_GAIN2_0_5     = 1,    
    PGA0_GAIN2_0_75    = 2,     
    PGA0_GAIN2_1       = 3,    
    PGA1_GAIN2_0_25    = (0 << 2),  
    PGA1_GAIN2_0_5     = (1 << 2),    
    PGA1_GAIN2_0_75    = (2 << 2),    
    PGA1_GAIN2_1       = (3 << 2),    
    PGA0_GAIN1_1       = (0 << 8),    
    PGA0_GAIN1_2       = (1 << 8),     
    PGA0_GAIN1_4       = (2 << 8),     
    PGA0_GAIN1_8       = (3 << 8),    
    PGA0_GAIN1_16      = (4 << 8),    
    PGA1_GAIN1_1       = (0 << 12),     
    PGA1_GAIN1_2       = (1 << 12),     
    PGA1_GAIN1_4       = (2 << 12),    
    PGA1_GAIN1_8       = (3 << 12),     
    PGA1_GAIN1_16      = (4 << 12),     
} PGA_GAIN_Enum;

typedef struct  
{
		PGA_CH_Enum				        CHP;
		PGA_CH_Enum				        CHN;
    PGA_EN_Enum								PGA_EN;
    PGA_MODE_Enum							PGA_MODE;
    PGA_GAIN_Enum     				GAIN;
} PGA_Init_T;

void PGA_Init(PGA_Init_T* PGAA);

#ifdef __cplusplus
}
#endif

#endif
