/**
  ******************************************************************************
  * @file           : ms60f3xxx_plu.h
  * @author         : sinomcu.com-SA
  * @brief          : Header file of PLU module.
  * @gcc            : toolchain version   5 or 6
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with
  *	basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */  
#ifndef MS60F3XXX_PLU_H
#define MS60F3XXX_PLU_H
#include "ms60f3xxx.h"
#ifdef __cplusplus
 extern "C" {
#endif
	 
#define PLU_UNIT_BASE  PLU_BASE+ 0x20
#define PLU_UNIT0     ((PLU_UNIT_T*)                (PLU_UNIT_BASE))
#define PLU_UNIT1     ((PLU_UNIT_T*)                (PLU_UNIT_BASE+0x10))
#define PLU_UNIT2     ((PLU_UNIT_T*)                (PLU_UNIT_BASE+0x20))
#define PLU_UNIT3     ((PLU_UNIT_T*)                (PLU_UNIT_BASE+0x30))
#define	PLUn_MAXR_SET(A,B)		((A<<4)|B)
/* PLU->FNSEL	*/
#define	PLU_MUXA				0xF0
#define	PLU_MUXB				0xCC
#define PLU_CARRY				0xAA
#define	PLU_NOT(A)			(~A)
#define	PLU_AND(A,B)		(A&B)
#define PLU_OR(A,B)			(A|B)
#define	PLU_XOR(A,B)		(A^B)

#define PLU0_ENABLE 1ul
#define PLU1_ENABLE (1ul<<1)
#define PLU2_ENABLE (1ul<<2)
#define PLU3_ENABLE (1ul<<3)
#define PLU_FILTER_ENABLE (1ul<<15)
#define PLU_DATA0_BASE 0x480030D0ul

typedef enum /**< \brief (MXR0) PLU0 input A multiplexer   */
{
    MXR0A_PLU0OUT = 0,
    MXR0A_PLU1OUT,
    MXR0A_PLU2OUT,
    MXR0A_PLU3OUT,
    MXR0A_TIMER00_TIOA,
    MXR0A_PLU0_DAIN,
    MXR0A_UART0_RXD,
    MXR0A_EXTI0,
    MXR0A_PA1 = 9,
    MXR0A_PA2,
    MXR0A_PA3,
    MXR0A_PA4,
    MXR0A_PA5,
    MXR0A_PA6,
    MXR0A_PA7,
} MXR0_A_Enum;

typedef enum /**< \brief (MXR0) PLU0 input B multiplexer */
{
    MXR0B_PLU0OUT = 0,
    MXR0B_PLU1OUT,
    MXR0B_PLU2OUT,
    MXR0B_PLU3OUT,
    MXR0B_TIMER10_TIOA,
    MXR0B_PLU0_DAIN,
    MXR0B_UART1_RXD,
    MXR0B_EXTI3,
    MXR0B_PA8,
    MXR0B_PA9,
    MXR0B_PA10,
    MXR0B_PA11,
    MXR0B_PA12,
    MXR0B_PA13,
    MXR0B_PA14,
    MXR0B_PA15
} MXR0_B_Enum;

typedef enum /**< \brief (MXR1) PLU1 input A multiplexer   */
{
    MXR1A_PLU0OUT = 0,
    MXR1A_PLU1OUT,
    MXR1A_PLU2OUT,
    MXR1A_PLU3OUT,
    MXR1A_TIMER01_TIOA,
    MXR1A_PLU1_DAIN,
    MXR1A_UART0_RXD,
    MXR1A_EXTI1,
    MXR1A_PA1 = 9,
    MXR1A_PA2,
    MXR1A_PA3,
    MXR1A_PA4,
    MXR1A_PA5,
    MXR1A_PA6,
    MXR1A_PA7,
} MXR1_A_Enum;
typedef enum /**< \brief (MXR1) PLU1 input B multiplexer */
{
    MXR1B_PLU0OUT = 0,
    MXR1B_PLU1OUT,
    MXR1B_PLU2OUT,
    MXR1B_PLU3OUT,
    MXR1B_TIMER11_TIOA,
    MXR1B_PLU1_DAIN,
    MXR1B_UART1_RXD,
    MXR1B_EXTI2,
    MXR1B_PB8,
    MXR1B_PB9,
    MXR1B_PB10,
    MXR1B_PB11,
    MXR1B_PB12,
    MXR1B_PB13,
    MXR1B_PB14,
    MXR1B_PB15,
} MXR1_B_Enum;

typedef enum /**< \brief (MXR2) PLU2 input A multiplexer   */
{
    MXR2A_PLU0OUT = 0,
    MXR2A_PLU1OUT,
    MXR2A_PLU2OUT,
    MXR2A_PLU3OUT,
    MXR2A_TIMER10_TIOA,
    MXR2A_PLU2_DAIN,
    MXR2A_UART1_RXD,
    MXR2A_EXTI2,
    MXR2A_PB0,
    MXR2A_PB1,
    MXR2A_PB2,
    MXR2A_PB3,
    MXR2A_PB4,
    MXR2A_PB5,
    MXR2A_PB6,
    MXR2A_PB7,
} MXR2_A_Enum;
typedef enum /**< \brief (MXR2) PLU2 input B multiplexer */
{
    MXR2B_PLU0OUT = 0,
    MXR2B_PLU1OUT,
    MXR2B_PLU2OUT,
    MXR2B_PLU3OUT,
    MXR2B_TIMER00_TIOA,
    MXR2B_PLU2_DAIN,
    MXR2B_UART0_RXD,
    MXR2B_EXTI1,
    MXR2B_PA8,
    MXR2B_PA9,
    MXR2B_PA10,
    MXR2B_PA11,
    MXR2B_PA12,
    MXR2B_PA13,
    MXR2B_PA14,
    MXR2B_PA15,
} MXR2_B_Enum;


typedef enum /**< \brief (MXR2) PLU2 input A multiplexer   */
{
    MXR3A_PLU0OUT = 0,
    MXR3A_PLU1OUT,
    MXR3A_PLU2OUT,
    MXR3A_PLU3OUT,
    MXR3A_TIMER11_TIOA,
    MXR3A_PLU3_DAIN,
    MXR3A_UART1_RXD,
    MXR3A_EXTI3,
    MXR3A_PB0,
    MXR3A_PB8,
    MXR3A_PB2,
    MXR3A_PB3,
    MXR3A_PB4,
    MXR3A_PB5,
    MXR3A_PB6,
    MXR3A_PB7,
} MXR3_A_Enum;
typedef enum /**< \brief (MXR3) PLU3 input B multiplexer */
{
    MXR3B_PLU0OUT = 0,
    MXR3B_PLU1OUT,
    MXR3B_PLU2OUT,
    MXR3B_PLU3OUT,
    MXR3B_TIMER01_TIOA,
    MXR3B_PLU3_DAIN,
    MXR3B_UART0_RXD,
    MXR3B_EXTI0,
    MXR3B_PB1,
    MXR3B_PB9,
    MXR3B_PB10,
    MXR3B_PB11,
    MXR3B_PB12,
    MXR3B_PB13,
    MXR3B_PB14,
    MXR3B_PB15,
} MXR3_B_Enum;

typedef struct /**< \brief PLU UNIT struct */ 
{
    volatile uint32_t MXR;
    volatile uint32_t FNR;
    volatile uint32_t CFR;
    volatile uint32_t data;
} PLU_UNIT_T;

typedef union  
{
    uint8_t mrx_a;
    MXR0_A_Enum mrx0_a;
    MXR1_A_Enum mrx1_a;
    MXR2_A_Enum mrx2_a;
    MXR3_A_Enum mrx3_a;

} MUXA_UNION_T;


typedef union
{
    uint8_t mrx_b;
    MXR0_B_Enum mrx0_b;
    MXR1_B_Enum mrx1_b;
    MXR2_B_Enum mrx2_b;
    MXR3_B_Enum mrx3_b;

} MUXB_UNION_T;

typedef enum /**< \brief (CFR) OUTSEL Bit */
{
    PLU_DIRECT_OUT = 0,
    PLU_TRIGGER_OUT = (1 << 7),
} PLU_OUT_Enum;
typedef enum /**< \brief (CFR) OEN Bit */
{
    PLU_GPIO_OFF = 0,
    PLU_GPIO_ON = (1 << 6),
} PLU_GPIO_Enum;

typedef enum /**< \brief (CFR) RST Bit */
{
    PLU_D_RESET = (1 << 3),
    PLU_D_NORMAL = 0,
} PLU_D_RESET_Enum;
typedef enum /**< \brief (CFR) CLKINV Bit */
{
    PLU_CLK_NORMAL = 0,
    PLU_CLK_INV = (1 << 2),
} PLU_CLK_INV_Enum;

typedef enum /**< \brief (CFR) CLKSEL Bit */
{
    PLU_CLKSEL_CARRY_IN = 0,
    PLU_CLKSEL_MUXA_INPUT = 1,
    PLU_CLKSEL_SYSCLK = 2,
    PLU_CLKSEL_ALTCLK,
} PLU_TRIGGER_Enum;

typedef enum /**< \brief (CFR) FILT_N Bit */ 
{
    PLU_FILTER_NUM3 =   0,
    PLU_FILTER_NUM4 =   (1ul << 12),
    PLU_FILTER_NUM5 =   (2ul << 12),
    PLU_FILTER_NUM6 =   (3ul << 12),
    PLU_FILTER_NUM7 =   (4ul << 12),
    PLU_FILTER_NUM8 =   (5ul << 12),

} PLU_FILTER_NUM_Enum;


typedef enum /**< \brief (ISR) Interrupt Status Register */
{
    NO_EDGE = 0,
    FALLING_EDGE = 1,
    RISING_EDGE = 2,
    BOTH_EDGE = 3,
} PLU_EDGE_Enum;
typedef enum /**< \brief (CFR) FILT_COEF Bit */
{
    FILTER_CLOCK_DIV0 = 0,
    FILTER_CLOCK_DIV2 =    (1 << 8),
    FILTER_CLOCK_DIV4 =    (2 << 8),
    FILTER_CLOCK_DIV8 =    (3 << 8),
    FILTER_CLOCK_DIV16 =    (4 << 8),
    FILTER_CLOCK_DIV32 =    (5 << 8),
    FILTER_CLOCK_DIV64 =    (6 << 8),
    FILTER_CLOCK_DIV128 =   (7 << 8),
    FILTER_CLOCK_DIV256 =   (8 << 8),
} PLU_FILTER_DIV_Enum;


typedef enum /**< \brief (CFR) FILT_EN Bit */
{
    PLU_FILETER_DISABLE = 0,
    PLU_FILETER_ENABLE = (1 << 15),
} PLU_FILETER_ENABLE_Enum;
typedef struct /**< \brief (CFR) CFR Register */
{
    PLU_OUT_Enum  plu_out;
    PLU_GPIO_Enum plu_gpio;
    PLU_D_RESET_Enum plu_d;
    PLU_CLK_INV_Enum plu_clk_inv;
    PLU_TRIGGER_Enum plu_trigger;
    PLU_FILTER_DIV_Enum plu_filter_div;
    PLU_FILTER_NUM_Enum plu_filter_num;
    PLU_FILETER_ENABLE_Enum plu_filer_enable;

} PLU_CFR_T;

typedef enum /**< \brief (DATAIN) PLU Software Data Register  */
{
    PLU_ADATA_RESET = 0,
    PLU_ADATA_SET   = 2,
} PLU_ADATA_Enum;
typedef enum /**< \brief (DATAIN) PLU Software Data Register  */
{
    PLU_BDATA_RESET = 0,
    PLU_BDATA_SET   = 1,
} PLU_BDATA_Enum;

void PLU_MuxSelect(PLU_UNIT_T *plu_unit, MUXA_UNION_T mux_a, MUXB_UNION_T mux_b);
void PLU_Function(PLU_UNIT_T *plu_unit, uint8_t function);
void PLU_CFR(PLU_UNIT_T *plu_unit, PLU_CFR_T *plu_cfr_type);
void PLU_Enable(uint8_t enable);
void PLU_Disable_IT(uint8_t n, PLU_EDGE_Enum edge);
void PLU_Enable_IT(uint8_t n, PLU_EDGE_Enum edge);
void PLU0_P04IN_P02OUT_NOT(void);
void PLU_IntDeal(uint8_t n);

#ifdef __cplusplus
}
#endif

#endif




