/**
  ******************************************************************************
  * @file           : ms60f3xxx_pwm.h
  * @author         : sinomcu.com-SA
  * @brief          : Header file of pwm module.
  * @gcc            : toolchain version 5 or 6
  *
  ******************************************************************************
  * @attention
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with
  * basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */
#ifndef MS60F3XXX_PWM_H
#define MS60F3XXX_PWM_H

#ifdef __cplusplus
extern "C" {
#endif

#include "ms60f3xxx.h"
#include "stdint.h"

#define PWM_CLOCK_DIV_MAX  256
#define PWM_CLOCK_PRE_MAX  11

#define PWM_CLK_DIVA_Pos                  (0ul)                     /*!< DIVA (Bit 0)                                          */
#define PWM_CLK_DIVA_Msk                  (0xFFul)                  /*!< DIVA (Bitfield-Mask: 0xff)                            */
#define PWM_CLK_PREA_Pos                  (8ul)                     /*!< PREA (Bit 8)                                          */
#define PWM_CLK_PREA_Msk                  (0xF00ul)                 /*!< PREA (Bitfield-Mask: 0x0f)                            */
#define PWM_CLK_DIVB_Pos                  (16ul)                    /*!< DIVB (Bit 16)                                         */
#define PWM_CLK_DIVB_Msk                  (0xFF0000ul)              /*!< DIVB (Bitfield-Mask: 0xff)                            */
#define PWM_CLK_PREB_Pos                  (24ul)                    /*!< PREB (Bit 24)                                         */
#define PWM_CLK_PREB_Msk                  (0xF000000ul)             /*!< PREB (Bitfield-Mask: 0x0f)                            */

#define PWM_CLK_DIVA_0_255(value) (value) 
#define PWM_CLK_DIVA_CLKA_POFF (0x0u << 0) /*(PWM_CLK) CLKA clock is turned off */
#define PWM_CLK_DIVA_PREA (0x1u << 0) /*(PWM_CLK) CLKA clock is clock selected by PREA */

#define PWM_CLK_PREA(value) (value)
#define PWM_CLK_PREA_CLK_DIV1    (0x0u) /*(PWM_CLK) Peripheral clock */
#define PWM_CLK_PREA_CLK_DIV2    (0x1u) /*(PWM_CLK) Peripheral clock/2 */
#define PWM_CLK_PREA_CLK_DIV4    (0x2u) /*(PWM_CLK) Peripheral clock/4 */
#define PWM_CLK_PREA_CLK_DIV8    (0x3u) /*(PWM_CLK) Peripheral clock/8 */
#define PWM_CLK_PREA_CLK_DIV16   (0x4u) /*(PWM_CLK) Peripheral clock/16 */
#define PWM_CLK_PREA_CLK_DIV32   (0x5u) /*(PWM_CLK) Peripheral clock/32 */
#define PWM_CLK_PREA_CLK_DIV64   (0x6u) /*(PWM_CLK) Peripheral clock/64 */
#define PWM_CLK_PREA_CLK_DIV128  (0x7u) /*(PWM_CLK) Peripheral clock/128 */
#define PWM_CLK_PREA_CLK_DIV256  (0x8u) /*(PWM_CLK) Peripheral clock/256 */
#define PWM_CLK_PREA_CLK_DIV512  (0x9u) /*(PWM_CLK) Peripheral clock/512 */
#define PWM_CLK_PREA_CLK_DIV1024 (0xAu) /*(PWM_CLK) Peripheral clock/1024 */

#define PWM_CLK_DIVB_0_255(value) (value)
#define PWM_CLK_DIVB_CLKB_POFF (0x0u << 16) /*(PWM_CLK) CLKB clock is turned off */
#define PWM_CLK_DIVB_PREB (0x1u << 16)      /*(PWM_CLK) CLKB clock is clock selected by PREB */

#define PWM_CLK_PREB(value) (value)
#define PWM_CLK_PREB_CLK_DIV1    (0x0u) /*(PWM_CLK) Peripheral clock */
#define PWM_CLK_PREB_CLK_DIV2    (0x1u) /*(PWM_CLK) Peripheral clock/2 */
#define PWM_CLK_PREB_CLK_DIV4    (0x2u) /*(PWM_CLK) Peripheral clock/4 */
#define PWM_CLK_PREB_CLK_DIV8    (0x3u) /*(PWM_CLK) Peripheral clock/8 */
#define PWM_CLK_PREB_CLK_DIV16   (0x4u) /*(PWM_CLK) Peripheral clock/16 */
#define PWM_CLK_PREB_CLK_DIV32   (0x5u) /*(PWM_CLK) Peripheral clock/32 */
#define PWM_CLK_PREB_CLK_DIV64   (0x6u) /*(PWM_CLK) Peripheral clock/64 */
#define PWM_CLK_PREB_CLK_DIV128  (0x7u) /*(PWM_CLK) Peripheral clock/128 */
#define PWM_CLK_PREB_CLK_DIV256  (0x8u) /*(PWM_CLK) Peripheral clock/256 */
#define PWM_CLK_PREB_CLK_DIV512  (0x9u) /*(PWM_CLK) Peripheral clock/512 */
#define PWM_CLK_PREB_CLK_DIV1024 (0xAu) /*(PWM_CLK) Peripheral clock/1024 */
/* -------- PWM_ENA : (PWM Offset: 0x04) PWM Enable Register -------- */
#define PWM_ENA_CHID0 (0x1u << 0) /*(PWM_ENA) Channel ID */
#define PWM_ENA_CHID1 (0x1u << 1) /*(PWM_ENA) Channel ID */
#define PWM_ENA_CHID2 (0x1u << 2) /*(PWM_ENA) Channel ID */
#define PWM_ENA_CHID3 (0x1u << 3) /*(PWM_ENA) Channel ID */
/* -------- PWM_DIS : (PWM Offset: 0x08) PWM Disable Register -------- */
#define PWM_DIS_CHID0 (0x1u << 0) /*(PWM_DIS) Channel ID */
#define PWM_DIS_CHID1 (0x1u << 1) /*(PWM_DIS) Channel ID */
#define PWM_DIS_CHID2 (0x1u << 2) /*(PWM_DIS) Channel ID */
#define PWM_DIS_CHID3 (0x1u << 3) /*(PWM_DIS) Channel ID */
/* -------- PWM_SR : (PWM Offset: 0x0C) PWM Status Register -------- */
#define PWM_SR_CHID0 (0x1u << 0) /*(PWM_SR) Channel ID */
#define PWM_SR_CHID1 (0x1u << 1) /*(PWM_SR) Channel ID */
#define PWM_SR_CHID2 (0x1u << 2) /*(PWM_SR) Channel ID */
#define PWM_SR_CHID3 (0x1u << 3) /*(PWM_SR) Channel ID */
/* -------- PWM_IER1 : (PWM Offset: 0x10) PWM Interrupt Enable Register 1 -------- */
#define PWM_IER1_CHID0 (0x1u << 0) /*(PWM_IER1) Counter Event on Channel 0 Interrupt Enable */
#define PWM_IER1_CHID1 (0x1u << 1) /*(PWM_IER1) Counter Event on Channel 1 Interrupt Enable */
#define PWM_IER1_CHID2 (0x1u << 2) /*(PWM_IER1) Counter Event on Channel 2 Interrupt Enable */
#define PWM_IER1_CHID3 (0x1u << 3) /*(PWM_IER1) Counter Event on Channel 3 Interrupt Enable */
#define PWM_IER1_FCHID0 (0x1u << 16) /*(PWM_IER1) Fault Protection Trigger on Channel 0 Interrupt Enable */
#define PWM_IER1_FCHID1 (0x1u << 17) /*(PWM_IER1) Fault Protection Trigger on Channel 1 Interrupt Enable */
#define PWM_IER1_FCHID2 (0x1u << 18) /*(PWM_IER1) Fault Protection Trigger on Channel 2 Interrupt Enable */
#define PWM_IER1_FCHID3 (0x1u << 19) /*(PWM_IER1) Fault Protection Trigger on Channel 3 Interrupt Enable */
/* -------- PWM_IDR1 : (PWM Offset: 0x14) PWM Interrupt Disable Register 1 -------- */
#define PWM_IDR1_CHID0 (0x1u << 0) /*(PWM_IDR1) Counter Event on Channel 0 Interrupt Disable */
#define PWM_IDR1_CHID1 (0x1u << 1) /*(PWM_IDR1) Counter Event on Channel 1 Interrupt Disable */
#define PWM_IDR1_CHID2 (0x1u << 2) /*(PWM_IDR1) Counter Event on Channel 2 Interrupt Disable */
#define PWM_IDR1_CHID3 (0x1u << 3) /*(PWM_IDR1) Counter Event on Channel 3 Interrupt Disable */
#define PWM_IDR1_FCHID0 (0x1u << 16) /*(PWM_IDR1) Fault Protection Trigger on Channel 0 Interrupt Disable */
#define PWM_IDR1_FCHID1 (0x1u << 17) /*(PWM_IDR1) Fault Protection Trigger on Channel 1 Interrupt Disable */
#define PWM_IDR1_FCHID2 (0x1u << 18) /*(PWM_IDR1) Fault Protection Trigger on Channel 2 Interrupt Disable */
#define PWM_IDR1_FCHID3 (0x1u << 19) /*(PWM_IDR1) Fault Protection Trigger on Channel 3 Interrupt Disable */
/* -------- PWM_IMR1 : (PWM Offset: 0x18) PWM Interrupt Mask Register 1 -------- */
#define PWM_IMR1_CHID0 (0x1u << 0) /*(PWM_IMR1) Counter Event on Channel 0 Interrupt Mask */
#define PWM_IMR1_CHID1 (0x1u << 1) /*(PWM_IMR1) Counter Event on Channel 1 Interrupt Mask */
#define PWM_IMR1_CHID2 (0x1u << 2) /*(PWM_IMR1) Counter Event on Channel 2 Interrupt Mask */
#define PWM_IMR1_CHID3 (0x1u << 3) /*(PWM_IMR1) Counter Event on Channel 3 Interrupt Mask */
#define PWM_IMR1_FCHID0 (0x1u << 16) /*(PWM_IMR1) Fault Protection Trigger on Channel 0 Interrupt Mask */
#define PWM_IMR1_FCHID1 (0x1u << 17) /*(PWM_IMR1) Fault Protection Trigger on Channel 1 Interrupt Mask */
#define PWM_IMR1_FCHID2 (0x1u << 18) /*(PWM_IMR1) Fault Protection Trigger on Channel 2 Interrupt Mask */
#define PWM_IMR1_FCHID3 (0x1u << 19) /*(PWM_IMR1) Fault Protection Trigger on Channel 3 Interrupt Mask */
/* -------- PWM_ISR1 : (PWM Offset: 0x1C) PWM Interrupt Status Register 1 -------- */
#define PWM_ISR1_CHID0 (0x1u << 0) /*(PWM_ISR1) Counter Event on Channel 0 */
#define PWM_ISR1_CHID1 (0x1u << 1) /*(PWM_ISR1) Counter Event on Channel 1 */
#define PWM_ISR1_CHID2 (0x1u << 2) /*(PWM_ISR1) Counter Event on Channel 2 */
#define PWM_ISR1_CHID3 (0x1u << 3) /*(PWM_ISR1) Counter Event on Channel 3 */
#define PWM_ISR1_FCHID0 (0x1u << 16) /*(PWM_ISR1) Fault Protection Trigger on Channel 0 */
#define PWM_ISR1_FCHID1 (0x1u << 17) /*(PWM_ISR1) Fault Protection Trigger on Channel 1 */
#define PWM_ISR1_FCHID2 (0x1u << 18) /*(PWM_ISR1) Fault Protection Trigger on Channel 2 */
#define PWM_ISR1_FCHID3 (0x1u << 19) /*(PWM_ISR1) Fault Protection Trigger on Channel 3 */
/* -------- PWM_SCM : (PWM Offset: 0x20) PWM Sync Channels Mode Register -------- */
#define PWM_SCM_SYNC0 (0x1u << 0) /*(PWM_SCM) Synchronous Channel 0 */
#define PWM_SCM_SYNC1 (0x1u << 1) /*(PWM_SCM) Synchronous Channel 1 */
#define PWM_SCM_SYNC2 (0x1u << 2) /*(PWM_SCM) Synchronous Channel 2 */
#define PWM_SCM_SYNC3 (0x1u << 3) /*(PWM_SCM) Synchronous Channel 3 */
#define PWM_SCM_UPDM_Msk  (0x30000ul) /*!< UPDM (Bitfield-Mask: 0x03) */

/* =======================================================  PWM_SCUP  ======================================================== */
#define PWM_SCUP_UPR_Pos                  (0ul)                     /*!< UPR (Bit 0)                                           */
#define PWM_SCUP_UPR_Msk                  (0xFul)                   /*!< UPR (Bitfield-Mask: 0x0f)                             */
#define PWM_SCUP_UPRCNT_Pos               (4ul)                     /*!< UPRCNT (Bit 4)                                        */
#define PWM_SCUP_UPRCNT_Msk               (0xF0ul)                  /*!< UPRCNT (Bitfield-Mask: 0x0f)                          */

/* ======================================================  PWM_SCUPUPD  ====================================================== */
#define PWM_SCUPUPD_UPRUPD_Pos            (0ul)                     /*!< UPRUPD (Bit 0)                                        */
#define PWM_SCUPUPD_UPRUPD_Msk            (0xFul)                   /*!< UPRUPD (Bitfield-Mask: 0x0f)                          */

/* -------- PWM_SCUC : (PWM Offset: 0x28) PWM Sync Channels Update Control Register -------- */
#define PWM_SCUC_UPDULOCK (0x1u << 0) /*(PWM_SCUC) Synchronous Channels Update Unlock */
/* -------- PWM_SCUP : (PWM Offset: 0x2C) PWM Sync Channels Update Period Register -------- */
#define PWM_SCUP_UPR(value) ((PWM_SCUP_UPR_Msk & ((value) << PWM_SCUP_UPR_Pos)))
#define PWM_SCUP_UPRCNT(value) ((PWM_SCUP_UPRCNT_Msk & ((value) << PWM_SCUP_UPRCNT_Pos)))
/* -------- PWM_SCUPUPD : (PWM Offset: 0x30) PWM Sync Channels Update Period Update Register -------- */
#define PWM_SCUPUPD_UPRUPD(value) ((PWM_SCUPUPD_UPRUPD_Msk & ((value) << PWM_SCUPUPD_UPRUPD_Pos)))
/* -------- PWM_IER2 : (PWM Offset: 0x34) PWM Interrupt Enable Register 2 -------- */
#define PWM_IER2_WRDY (0x1u << 0) /*(PWM_IER2) Write Ready for Synchronous Channels Update Interrupt Enable */
#define PWM_IER2_UNRE (0x1u << 3) /*(PWM_IER2) Synchronous Channels Update Underrun Error Interrupt Enable */
#define PWM_IER2_CMPM0 (0x1u << 8) /*(PWM_IER2) Comparison 0 Match Interrupt Enable */
#define PWM_IER2_CMPM1 (0x1u << 9) /*(PWM_IER2) Comparison 1 Match Interrupt Enable */
#define PWM_IER2_CMPM2 (0x1u << 10) /*(PWM_IER2) Comparison 2 Match Interrupt Enable */
#define PWM_IER2_CMPM3 (0x1u << 11) /*(PWM_IER2) Comparison 3 Match Interrupt Enable */
#define PWM_IER2_CMPU0 (0x1u << 16) /*(PWM_IER2) Comparison 0 Update Interrupt Enable */
#define PWM_IER2_CMPU1 (0x1u << 17) /*(PWM_IER2) Comparison 1 Update Interrupt Enable */
#define PWM_IER2_CMPU2 (0x1u << 18) /*(PWM_IER2) Comparison 2 Update Interrupt Enable */
#define PWM_IER2_CMPU3 (0x1u << 19) /*(PWM_IER2) Comparison 3 Update Interrupt Enable */
/* -------- PWM_IDR2 : (PWM Offset: 0x38) PWM Interrupt Disable Register 2 -------- */
#define PWM_IDR2_WRDY (0x1u << 0) /*(PWM_IDR2) Write Ready for Synchronous Channels Update Interrupt Disable */
#define PWM_IDR2_UNRE (0x1u << 3) /*(PWM_IDR2) Synchronous Channels Update Underrun Error Interrupt Disable */
#define PWM_IDR2_CMPM0 (0x1u << 8) /*(PWM_IDR2) Comparison 0 Match Interrupt Disable */
#define PWM_IDR2_CMPM1 (0x1u << 9) /*(PWM_IDR2) Comparison 1 Match Interrupt Disable */
#define PWM_IDR2_CMPM2 (0x1u << 10) /*(PWM_IDR2) Comparison 2 Match Interrupt Disable */
#define PWM_IDR2_CMPM3 (0x1u << 11) /*(PWM_IDR2) Comparison 3 Match Interrupt Disable */
#define PWM_IDR2_CMPU0 (0x1u << 16) /*(PWM_IDR2) Comparison 0 Update Interrupt Disable */
#define PWM_IDR2_CMPU1 (0x1u << 17) /*(PWM_IDR2) Comparison 1 Update Interrupt Disable */
#define PWM_IDR2_CMPU2 (0x1u << 18) /*(PWM_IDR2) Comparison 2 Update Interrupt Disable */
#define PWM_IDR2_CMPU3 (0x1u << 19) /*(PWM_IDR2) Comparison 3 Update Interrupt Disable */
/* -------- PWM_IMR2 : (PWM Offset: 0x3C) PWM Interrupt Mask Register 2 -------- */
#define PWM_IMR2_WRDY (0x1u << 0) /*(PWM_IMR2) Write Ready for Synchronous Channels Update Interrupt Mask */
#define PWM_IMR2_UNRE (0x1u << 3) /*(PWM_IMR2) Synchronous Channels Update Underrun Error Interrupt Mask */
#define PWM_IMR2_CMPM0 (0x1u << 8) /*(PWM_IMR2) Comparison 0 Match Interrupt Mask */
#define PWM_IMR2_CMPM1 (0x1u << 9) /*(PWM_IMR2) Comparison 1 Match Interrupt Mask */
#define PWM_IMR2_CMPM2 (0x1u << 10) /*(PWM_IMR2) Comparison 2 Match Interrupt Mask */
#define PWM_IMR2_CMPM3 (0x1u << 11) /*(PWM_IMR2) Comparison 3 Match Interrupt Mask */
#define PWM_IMR2_CMPU0 (0x1u << 16) /*(PWM_IMR2) Comparison 0 Update Interrupt Mask */
#define PWM_IMR2_CMPU1 (0x1u << 17) /*(PWM_IMR2) Comparison 1 Update Interrupt Mask */
#define PWM_IMR2_CMPU2 (0x1u << 18) /*(PWM_IMR2) Comparison 2 Update Interrupt Mask */
#define PWM_IMR2_CMPU3 (0x1u << 19) /*(PWM_IMR2) Comparison 3 Update Interrupt Mask */
/* -------- PWM_ISR2 : (PWM Offset: 0x40) PWM Interrupt Status Register 2 -------- */
#define PWM_ISR2_WRDY (0x1u << 0) /*(PWM_ISR2) Write Ready for Synchronous Channels Update */
#define PWM_ISR2_UNRE (0x1u << 3) /*(PWM_ISR2) Synchronous Channels Update Underrun Error */
#define PWM_ISR2_CMPM0 (0x1u << 8) /*(PWM_ISR2) Comparison 0 Match */
#define PWM_ISR2_CMPM1 (0x1u << 9) /*(PWM_ISR2) Comparison 1 Match */
#define PWM_ISR2_CMPM2 (0x1u << 10) /*(PWM_ISR2) Comparison 2 Match */
#define PWM_ISR2_CMPM3 (0x1u << 11) /*(PWM_ISR2) Comparison 3 Match */
#define PWM_ISR2_CMPM7 (0x1u << 15) /*(PWM_ISR2) Comparison 7 Match */
#define PWM_ISR2_CMPU0 (0x1u << 16) /*(PWM_ISR2) Comparison 0 Update */
#define PWM_ISR2_CMPU1 (0x1u << 17) /*(PWM_ISR2) Comparison 1 Update */
#define PWM_ISR2_CMPU2 (0x1u << 18) /*(PWM_ISR2) Comparison 2 Update */
#define PWM_ISR2_CMPU3 (0x1u << 19) /*(PWM_ISR2) Comparison 3 Update */
/* -------- PWM_OOV : (PWM Offset: 0x44) PWM Output Override Value Register -------- */
#define PWM_OOV_OOVH0 (0x1u << 0) /*(PWM_OOV) Output Override Value for PWMH output of the channel 0 */
#define PWM_OOV_OOVH1 (0x1u << 1) /*(PWM_OOV) Output Override Value for PWMH output of the channel 1 */
#define PWM_OOV_OOVH2 (0x1u << 2) /*(PWM_OOV) Output Override Value for PWMH output of the channel 2 */
#define PWM_OOV_OOVH3 (0x1u << 3) /*(PWM_OOV) Output Override Value for PWMH output of the channel 3 */
#define PWM_OOV_OOVL0 (0x1u << 16) /*(PWM_OOV) Output Override Value for PWML output of the channel 0 */
#define PWM_OOV_OOVL1 (0x1u << 17) /*(PWM_OOV) Output Override Value for PWML output of the channel 1 */
#define PWM_OOV_OOVL2 (0x1u << 18) /*(PWM_OOV) Output Override Value for PWML output of the channel 2 */
#define PWM_OOV_OOVL3 (0x1u << 19) /*(PWM_OOV) Output Override Value for PWML output of the channel 3 */
/* -------- PWM_OS : (PWM Offset: 0x48) PWM Output Selection Register -------- */
#define PWM_OS_OSH0 (0x1u << 0) /*(PWM_OS) Output Selection for PWMH output of the channel 0 */
#define PWM_OS_OSH1 (0x1u << 1) /*(PWM_OS) Output Selection for PWMH output of the channel 1 */
#define PWM_OS_OSH2 (0x1u << 2) /*(PWM_OS) Output Selection for PWMH output of the channel 2 */
#define PWM_OS_OSH3 (0x1u << 3) /*(PWM_OS) Output Selection for PWMH output of the channel 3 */
#define PWM_OS_OSL0 (0x1u << 16) /*(PWM_OS) Output Selection for PWML output of the channel 0 */
#define PWM_OS_OSL1 (0x1u << 17) /*(PWM_OS) Output Selection for PWML output of the channel 1 */
#define PWM_OS_OSL2 (0x1u << 18) /*(PWM_OS) Output Selection for PWML output of the channel 2 */
#define PWM_OS_OSL3 (0x1u << 19) /*(PWM_OS) Output Selection for PWML output of the channel 3 */
/* -------- PWM_OSS : (PWM Offset: 0x4C) PWM Output Selection Set Register -------- */
#define PWM_OSS_OSSH0 (0x1u << 0) /*(PWM_OSS) Output Selection Set for PWMH output of the channel 0 */
#define PWM_OSS_OSSH1 (0x1u << 1) /*(PWM_OSS) Output Selection Set for PWMH output of the channel 1 */
#define PWM_OSS_OSSH2 (0x1u << 2) /*(PWM_OSS) Output Selection Set for PWMH output of the channel 2 */
#define PWM_OSS_OSSH3 (0x1u << 3) /*(PWM_OSS) Output Selection Set for PWMH output of the channel 3 */
#define PWM_OSS_OSSL0 (0x1u << 16) /*(PWM_OSS) Output Selection Set for PWML output of the channel 0 */
#define PWM_OSS_OSSL1 (0x1u << 17) /*(PWM_OSS) Output Selection Set for PWML output of the channel 1 */
#define PWM_OSS_OSSL2 (0x1u << 18) /*(PWM_OSS) Output Selection Set for PWML output of the channel 2 */
#define PWM_OSS_OSSL3 (0x1u << 19) /*(PWM_OSS) Output Selection Set for PWML output of the channel 3 */
/* -------- PWM_OSC : (PWM Offset: 0x50) PWM Output Selection Clear Register -------- */
#define PWM_OSC_OSCH0 (0x1u << 0) /*(PWM_OSC) Output Selection Clear for PWMH output of the channel 0 */
#define PWM_OSC_OSCH1 (0x1u << 1) /*(PWM_OSC) Output Selection Clear for PWMH output of the channel 1 */
#define PWM_OSC_OSCH2 (0x1u << 2) /*(PWM_OSC) Output Selection Clear for PWMH output of the channel 2 */
#define PWM_OSC_OSCH3 (0x1u << 3) /*(PWM_OSC) Output Selection Clear for PWMH output of the channel 3 */
#define PWM_OSC_OSCL0 (0x1u << 16) /*(PWM_OSC) Output Selection Clear for PWML output of the channel 0 */
#define PWM_OSC_OSCL1 (0x1u << 17) /*(PWM_OSC) Output Selection Clear for PWML output of the channel 1 */
#define PWM_OSC_OSCL2 (0x1u << 18) /*(PWM_OSC) Output Selection Clear for PWML output of the channel 2 */
#define PWM_OSC_OSCL3 (0x1u << 19) /*(PWM_OSC) Output Selection Clear for PWML output of the channel 3 */
/* -------- PWM_OSSUPD : (PWM Offset: 0x54) PWM Output Selection Set Update Register -------- */
#define PWM_OSSUPD_OSSUPH0 (0x1u << 0) /*(PWM_OSSUPD) Output Selection Set for PWMH output of the channel 0 */
#define PWM_OSSUPD_OSSUPH1 (0x1u << 1) /*(PWM_OSSUPD) Output Selection Set for PWMH output of the channel 1 */
#define PWM_OSSUPD_OSSUPH2 (0x1u << 2) /*(PWM_OSSUPD) Output Selection Set for PWMH output of the channel 2 */
#define PWM_OSSUPD_OSSUPH3 (0x1u << 3) /*(PWM_OSSUPD) Output Selection Set for PWMH output of the channel 3 */
#define PWM_OSSUPD_OSSUPL0 (0x1u << 16) /*(PWM_OSSUPD) Output Selection Set for PWML output of the channel 0 */
#define PWM_OSSUPD_OSSUPL1 (0x1u << 17) /*(PWM_OSSUPD) Output Selection Set for PWML output of the channel 1 */
#define PWM_OSSUPD_OSSUPL2 (0x1u << 18) /*(PWM_OSSUPD) Output Selection Set for PWML output of the channel 2 */
#define PWM_OSSUPD_OSSUPL3 (0x1u << 19) /*(PWM_OSSUPD) Output Selection Set for PWML output of the channel 3 */
/* -------- PWM_OSCUPD : (PWM Offset: 0x58) PWM Output Selection Clear Update Register -------- */
#define PWM_OSCUPD_OSCUPH0 (0x1u << 0) /*(PWM_OSCUPD) Output Selection Clear for PWMH output of the channel 0 */
#define PWM_OSCUPD_OSCUPH1 (0x1u << 1) /*(PWM_OSCUPD) Output Selection Clear for PWMH output of the channel 1 */
#define PWM_OSCUPD_OSCUPH2 (0x1u << 2) /*(PWM_OSCUPD) Output Selection Clear for PWMH output of the channel 2 */
#define PWM_OSCUPD_OSCUPH3 (0x1u << 3) /*(PWM_OSCUPD) Output Selection Clear for PWMH output of the channel 3 */
#define PWM_OSCUPD_OSCUPL0 (0x1u << 16) /*(PWM_OSCUPD) Output Selection Clear for PWML output of the channel 0 */
#define PWM_OSCUPD_OSCUPL1 (0x1u << 17) /*(PWM_OSCUPD) Output Selection Clear for PWML output of the channel 1 */
#define PWM_OSCUPD_OSCUPL2 (0x1u << 18) /*(PWM_OSCUPD) Output Selection Clear for PWML output of the channel 2 */
#define PWM_OSCUPD_OSCUPL3 (0x1u << 19) /*(PWM_OSCUPD) Output Selection Clear for PWML output of the channel 3 */
/* -------- PWM_FMR : (PWM Offset: 0x5C) PWM Fault Mode Register -------- */
#define PWM_FMR_FPOL(value) ((PWM_FMR_FPOL_Msk & ((value) << PWM_FMR_FPOL_Pos)))
#define PWM_FMR_FMOD(value) ((PWM_FMR_FMOD_Msk & ((value) << PWM_FMR_FMOD_Pos)))
#define PWM_FMR_FFIL(value) ((PWM_FMR_FFIL_Msk & ((value) << PWM_FMR_FFIL_Pos)))
/* -------- PWM_FCR : (PWM Offset: 0x64) PWM Fault Clear Register -------- */
#define PWM_FCR_FCLR(value) ((PWM_FCR_FCLR_Msk & ((value) << PWM_FCR_FCLR_Pos)))
/* -------- PWM_FPV1 : (PWM Offset: 0x68) PWM Fault Protection Value Register 1 -------- */
#define PWM_FPV1_FPVH0 (0x1u << 0) /*(PWM_FPV1) Fault Protection Value for PWMH output on channel 0 */
#define PWM_FPV1_FPVH1 (0x1u << 1) /*(PWM_FPV1) Fault Protection Value for PWMH output on channel 1 */
#define PWM_FPV1_FPVH2 (0x1u << 2) /*(PWM_FPV1) Fault Protection Value for PWMH output on channel 2 */
#define PWM_FPV1_FPVH3 (0x1u << 3) /*(PWM_FPV1) Fault Protection Value for PWMH output on channel 3 */
#define PWM_FPV1_FPVL0 (0x1u << 16) /*(PWM_FPV1) Fault Protection Value for PWML output on channel 0 */
#define PWM_FPV1_FPVL1 (0x1u << 17) /*(PWM_FPV1) Fault Protection Value for PWML output on channel 1 */
#define PWM_FPV1_FPVL2 (0x1u << 18) /*(PWM_FPV1) Fault Protection Value for PWML output on channel 2 */
#define PWM_FPV1_FPVL3 (0x1u << 19) /*(PWM_FPV1) Fault Protection Value for PWML output on channel 3 */
/* -------- PWM_FPE : (PWM Offset: 0x6C) PWM Fault Protection Enable Register -------- */
#define PWM_FPE_FPE0(value) ((PWM_FPE_FPE0_Msk & ((value) << PWM_FPE_FPE0_Pos)))
#define PWM_FPE_FPE1(value) ((PWM_FPE_FPE1_Msk & ((value) << PWM_FPE_FPE1_Pos)))
#define PWM_FPE_FPE2(value) ((PWM_FPE_FPE2_Msk & ((value) << PWM_FPE_FPE2_Pos)))
#define PWM_FPE_FPE3(value) ((PWM_FPE_FPE3_Msk & ((value) << PWM_FPE_FPE3_Pos)))
/* -------- PWM_ELMR[8] : (PWM Offset: 0x7C) PWM Event Line 0 Mode Register -------- */
#define PWM_ELMR_CSEL0 (0x1u << 0) /*(PWM_ELMR[8]) Comparison 0 Selection */
#define PWM_ELMR_CSEL1 (0x1u << 1) /*(PWM_ELMR[8]) Comparison 1 Selection */
#define PWM_ELMR_CSEL2 (0x1u << 2) /*(PWM_ELMR[8]) Comparison 2 Selection */
#define PWM_ELMR_CSEL3 (0x1u << 3) /*(PWM_ELMR[8]) Comparison 3 Selection */
/* -------- PWM_SSPR : (PWM Offset: 0xA0) PWM Spread Spectrum Register -------- */
#define PWM_SSPR_SPRD_Pos 0
#define PWM_SSPR_SPRD_Msk (0xFFFFFFu << PWM_SSPR_SPRD_Pos) /*(PWM_SSPR) Spread Spectrum Limit Value */
#define PWM_SSPR_SPRD(value) ((PWM_SSPR_SPRD_Msk & ((value) << PWM_SSPR_SPRD_Pos)))
#define PWM_SSPR_SPRDM (0x1u << 24) /*(PWM_SSPR) Spread Spectrum Counter Mode */
/* -------- PWM_SSPUP : (PWM Offset: 0xA4) PWM Spread Spectrum Update Register -------- */
#define PWM_SSPUP_SPRDUP_Pos 0
#define PWM_SSPUP_SPRDUP_Msk (0xFFFFFFu << PWM_SSPUP_SPRDUP_Pos) /*(PWM_SSPUP) Spread Spectrum Limit Value Update */
#define PWM_SSPUP_SPRDUP(value) ((PWM_SSPUP_SPRDUP_Msk & ((value) << PWM_SSPUP_SPRDUP_Pos)))
/* -------- PWM_SMMR : (PWM Offset: 0xB0) PWM Stepper Motor Mode Register -------- */
#define PWM_SMMR_GCEN0 (0x1u << 0) /*(PWM_SMMR) Gray Count ENable */
#define PWM_SMMR_GCEN1 (0x1u << 1) /*(PWM_SMMR) Gray Count ENable */
#define PWM_SMMR_DOWN0 (0x1u << 16) /*(PWM_SMMR) DOWN Count */
#define PWM_SMMR_DOWN1 (0x1u << 17) /*(PWM_SMMR) DOWN Count */
/* -------- PWM_FPV2 : (PWM Offset: 0xC0) PWM Fault Protection Value 2 Register -------- */
#define PWM_FPV2_FPZH0 (0x1u << 0) /*(PWM_FPV2) Fault Protection to Hi-Z for PWMH output on channel 0 */
#define PWM_FPV2_FPZH1 (0x1u << 1) /*(PWM_FPV2) Fault Protection to Hi-Z for PWMH output on channel 1 */
#define PWM_FPV2_FPZH2 (0x1u << 2) /*(PWM_FPV2) Fault Protection to Hi-Z for PWMH output on channel 2 */
#define PWM_FPV2_FPZH3 (0x1u << 3) /*(PWM_FPV2) Fault Protection to Hi-Z for PWMH output on channel 3 */
#define PWM_FPV2_FPZL0 (0x1u << 16) /*(PWM_FPV2) Fault Protection to Hi-Z for PWML output on channel 0 */
#define PWM_FPV2_FPZL1 (0x1u << 17) /*(PWM_FPV2) Fault Protection to Hi-Z for PWML output on channel 1 */
#define PWM_FPV2_FPZL2 (0x1u << 18) /*(PWM_FPV2) Fault Protection to Hi-Z for PWML output on channel 2 */
#define PWM_FPV2_FPZL3 (0x1u << 19) /*(PWM_FPV2) Fault Protection to Hi-Z for PWML output on channel 3 */
/* -------- PWM_WPCR : (PWM Offset: 0xE4) PWM Write Protection Control Register -------- */
#define PWM_WPCR_WPCMD(value) ((PWM_WPCR_WPCMD_Msk & ((value) << PWM_WPCR_WPCMD_Pos)))
#define PWM_WPCR_WPCMD_DISABLE_SW_PROT (0x0u << 0) /*(PWM_WPCR) Disables the software write protection of the register groups of which the bit WPRGx is at '1'. */
#define PWM_WPCR_WPCMD_ENABLE_SW_PROT (0x1u << 0) /*(PWM_WPCR) Enables the software write protection of the register groups of which the bit WPRGx is at '1'.   */
#define PWM_WPCR_WPCMD_ENABLE_HW_PROT (0x2u << 0) /*(PWM_WPCR) Enables the hardware write protection of the register groups of which the bit WPRGx is at '1'.   */
#define PWM_WPCR_WPRG0 (0x1u << 2) /*(PWM_WPCR) Write Protection Register Group 0 */
#define PWM_WPCR_WPRG1 (0x1u << 3) /*(PWM_WPCR) Write Protection Register Group 1 */
#define PWM_WPCR_WPRG2 (0x1u << 4) /*(PWM_WPCR) Write Protection Register Group 2 */
#define PWM_WPCR_WPRG3 (0x1u << 5) /*(PWM_WPCR) Write Protection Register Group 3 */
#define PWM_WPCR_WPRG4 (0x1u << 6) /*(PWM_WPCR) Write Protection Register Group 4 */
#define PWM_WPCR_WPRG5 (0x1u << 7) /*(PWM_WPCR) Write Protection Register Group 5 */

#define PWM_WPSR_WPVSRC_Pos  (16ul)         /*!< WPVSRC (Bit 16)                */
#define PWM_WPSR_WPVSRC_Msk  (0xFFFF0000ul) /*!< WPVSRC (Bitfield-Mask: 0xffff) */

#define PWM_WPCR_WPKEY(value) ((PWM_WPCR_WPKEY_Msk & ((value) << PWM_WPCR_WPKEY_Pos)))
#define PWM_WPCR_WPKEY_PASSWD (0x50574Dul << 8) /*(PWM_WPCR) Writing any other value in this field aborts the write operation of the WPCMD field.Always reads as 0 */
/* -------- PWM_WPSR : (PWM Offset: 0xE8) PWM Write Protection Status Register -------- */
#define PWM_WPSR_WPSWS0 (0x1u << 0) /*(PWM_WPSR) Write Protect SW Status */
#define PWM_WPSR_WPSWS1 (0x1u << 1) /*(PWM_WPSR) Write Protect SW Status */
#define PWM_WPSR_WPSWS2 (0x1u << 2) /*(PWM_WPSR) Write Protect SW Status */
#define PWM_WPSR_WPSWS3 (0x1u << 3) /*(PWM_WPSR) Write Protect SW Status */
#define PWM_WPSR_WPSWS4 (0x1u << 4) /*(PWM_WPSR) Write Protect SW Status */
#define PWM_WPSR_WPSWS5 (0x1u << 5) /*(PWM_WPSR) Write Protect SW Status */
#define PWM_WPSR_WPVS (0x1u << 7) /*(PWM_WPSR) Write Protect Violation Status */
#define PWM_WPSR_WPHWS0 (0x1u << 8) /*(PWM_WPSR) Write Protect HW Status */
#define PWM_WPSR_WPHWS1 (0x1u << 9) /*(PWM_WPSR) Write Protect HW Status */
#define PWM_WPSR_WPHWS2 (0x1u << 10) /*(PWM_WPSR) Write Protect HW Status */
#define PWM_WPSR_WPHWS3 (0x1u << 11) /*(PWM_WPSR) Write Protect HW Status */
#define PWM_WPSR_WPHWS4 (0x1u << 12) /*(PWM_WPSR) Write Protect HW Status */
#define PWM_WPSR_WPHWS5 (0x1u << 13) /*(PWM_WPSR) Write Protect HW Status */

/* -------- PWM_CMPV : (PWM Offset: N/A) PWM Comparison 0 Value Register -------- */
#define PWM_CMPV_CV_Pos 0
#define PWM_CMPV_CV_Msk (0xFFFFFFu << PWM_CMPV_CV_Pos) /*(PWM_CMPV) Comparison x Value */
#define PWM_CMPV_CV(value) ((PWM_CMPV_CV_Msk & ((value) << PWM_CMPV_CV_Pos)))
#define PWM_CMPV_CVM (0x1u << 24) /*(PWM_CMPV) Comparison x Value Mode */
/* -------- PWM_CMPVUPD : (PWM Offset: N/A) PWM Comparison 0 Value Update Register -------- */
#define PWM_CMPVUPD_CVUPD_Pos 0
#define PWM_CMPVUPD_CVUPD_Msk (0xFFFFFFu << PWM_CMPVUPD_CVUPD_Pos) /*(PWM_CMPVUPD) Comparison x Value Update */
#define PWM_CMPVUPD_CVUPD(value) ((PWM_CMPVUPD_CVUPD_Msk & ((value) << PWM_CMPVUPD_CVUPD_Pos)))
#define PWM_CMPVUPD_CVMUPD (0x1u << 24) /*(PWM_CMPVUPD) Comparison x Value Mode Update */
/* -------- PWM_CMPM : (PWM Offset: N/A) PWM Comparison 0 Mode Register -------- */
#define PWM_CMPM_CEN (0x1u << 0) /*(PWM_CMPM) Comparison x Enable */
#define PWM_CMPM_CTR_Pos 4
#define PWM_CMPM_CTR_Msk (0xFu << PWM_CMPM_CTR_Pos) /*(PWM_CMPM) Comparison x Trigger */
#define PWM_CMPM_CTR(value) ((PWM_CMPM_CTR_Msk & ((value) << PWM_CMPM_CTR_Pos)))
#define PWM_CMPM_CPR_Pos 8
#define PWM_CMPM_CPR_Msk (0xFu << PWM_CMPM_CPR_Pos) /*(PWM_CMPM) Comparison x Period */
#define PWM_CMPM_CPR(value) ((PWM_CMPM_CPR_Msk & ((value) << PWM_CMPM_CPR_Pos)))
#define PWM_CMPM_CPRCNT_Pos 12
#define PWM_CMPM_CPRCNT_Msk (0xFu << PWM_CMPM_CPRCNT_Pos) /*(PWM_CMPM) Comparison x Period Counter */
#define PWM_CMPM_CPRCNT(value) ((PWM_CMPM_CPRCNT_Msk & ((value) << PWM_CMPM_CPRCNT_Pos)))
#define PWM_CMPM_CUPR_Pos 16
#define PWM_CMPM_CUPR_Msk (0xFu << PWM_CMPM_CUPR_Pos) /*(PWM_CMPM) Comparison x Update Period */
#define PWM_CMPM_CUPR(value) ((PWM_CMPM_CUPR_Msk & ((value) << PWM_CMPM_CUPR_Pos)))
#define PWM_CMPM_CUPRCNT_Pos 20
#define PWM_CMPM_CUPRCNT_Msk (0xFu << PWM_CMPM_CUPRCNT_Pos) /*(PWM_CMPM) Comparison x Update Period Counter */
#define PWM_CMPM_CUPRCNT(value) ((PWM_CMPM_CUPRCNT_Msk & ((value) << PWM_CMPM_CUPRCNT_Pos)))
/* -------- PWM_CMPMUPD : (PWM Offset: N/A) PWM Comparison 0 Mode Update Register -------- */
#define PWM_CMPMUPD_CENUPD (0x1u << 0) /*(PWM_CMPMUPD) Comparison x Enable Update */
#define PWM_CMPMUPD_CTRUPD_Pos 4
#define PWM_CMPMUPD_CTRUPD_Msk (0xFu << PWM_CMPMUPD_CTRUPD_Pos) /*(PWM_CMPMUPD) Comparison x Trigger Update */
#define PWM_CMPMUPD_CTRUPD(value) ((PWM_CMPMUPD_CTRUPD_Msk & ((value) << PWM_CMPMUPD_CTRUPD_Pos)))
#define PWM_CMPMUPD_CPRUPD_Pos 8
#define PWM_CMPMUPD_CPRUPD_Msk (0xFu << PWM_CMPMUPD_CPRUPD_Pos) /*(PWM_CMPMUPD) Comparison x Period Update */
#define PWM_CMPMUPD_CPRUPD(value) ((PWM_CMPMUPD_CPRUPD_Msk & ((value) << PWM_CMPMUPD_CPRUPD_Pos)))
#define PWM_CMPMUPD_CUPRUPD_Pos 16
#define PWM_CMPMUPD_CUPRUPD_Msk (0xFu << PWM_CMPMUPD_CUPRUPD_Pos) /*(PWM_CMPMUPD) Comparison x Update Period Update */
#define PWM_CMPMUPD_CUPRUPD(value) ((PWM_CMPMUPD_CUPRUPD_Msk & ((value) << PWM_CMPMUPD_CUPRUPD_Pos)))
/* -------- PWM_CMR : (PWM Offset: N/A) PWM Channel Mode Register -------- */
#define PWM_CMR_CES (0x1u << 10)   /*(PWM_CMR) Counter Event Selection */
#define PWM_CMR_DPOLI (0x1u << 12) /*(PWM_CMR) Disabled Polarity Inverted */
#define PWM_CMR_DTE (0x1u << 16)   /*(PWM_CMR) Dead-Time Generator Enable */
#define PWM_CMR_DTHI (0x1u << 17)  /*(PWM_CMR) Dead-Time PWMHx Output Inverted */
#define PWM_CMR_DTLI (0x1u << 18)  /*(PWM_CMR) Dead-Time PWMLx Output Inverted */

/* -------- PWM_CDTY : (PWM Offset: N/A) PWM Channel Duty Cycle Register -------- */
#define PWM_CDTY_CDTY_Pos 0
#define PWM_CDTY_CDTY_Msk (0xFFFFFFu << PWM_CDTY_CDTY_Pos) /*(PWM_CDTY) Channel Duty-Cycle */
#define PWM_CDTY_CDTY(value) ((PWM_CDTY_CDTY_Msk & ((value) << PWM_CDTY_CDTY_Pos)))
/* -------- PWM_CDTYUPD : (PWM Offset: N/A) PWM Channel Duty Cycle Update Register -------- */
#define PWM_CDTYUPD_CDTYUPD_Pos 0
#define PWM_CDTYUPD_CDTYUPD_Msk (0xFFFFFFu << PWM_CDTYUPD_CDTYUPD_Pos) /*(PWM_CDTYUPD) Channel Duty-Cycle Update */
#define PWM_CDTYUPD_CDTYUPD(value) ((PWM_CDTYUPD_CDTYUPD_Msk & ((value) << PWM_CDTYUPD_CDTYUPD_Pos)))
/* -------- PWM_CPRD : (PWM Offset: N/A) PWM Channel Period Register -------- */
#define PWM_CPRD_CPRD_Pos 0
#define PWM_CPRD_CPRD_Msk (0xFFFFFFu << PWM_CPRD_CPRD_Pos) /*(PWM_CPRD) Channel Period */
#define PWM_CPRD_CPRD(value) ((PWM_CPRD_CPRD_Msk & ((value) << PWM_CPRD_CPRD_Pos)))
/* -------- PWM_CPRDUPD : (PWM Offset: N/A) PWM Channel Period Update Register -------- */
#define PWM_CPRDUPD_CPRDUPD_Pos 0
#define PWM_CPRDUPD_CPRDUPD_Msk (0xFFFFFFu << PWM_CPRDUPD_CPRDUPD_Pos) /*(PWM_CPRDUPD) Channel Period Update */
#define PWM_CPRDUPD_CPRDUPD(value) ((PWM_CPRDUPD_CPRDUPD_Msk & ((value) << PWM_CPRDUPD_CPRDUPD_Pos)))
/* -------- PWM_CCNT : (PWM Offset: N/A) PWM Channel Counter Register -------- */
#define PWM_CCNT_CNT_Pos 0
#define PWM_CCNT_CNT_Msk (0xFFFFFFu << PWM_CCNT_CNT_Pos) /*(PWM_CCNT) Channel Counter Register */
/* -------- PWM_DT : (PWM Offset: N/A) PWM Channel Dead Time Register -------- */
#define PWM_DT_DTH_Pos 0
#define PWM_DT_DTH_Msk (0xFFFFu << PWM_DT_DTH_Pos) /*(PWM_DT) Dead-Time Value for PWMHx Output */
#define PWM_DT_DTH(value) ((PWM_DT_DTH_Msk & ((value) << PWM_DT_DTH_Pos)))
#define PWM_DT_DTL_Pos 16
#define PWM_DT_DTL_Msk (0xFFFFu << PWM_DT_DTL_Pos) /*(PWM_DT) Dead-Time Value for PWMLx Output */
#define PWM_DT_DTL(value) ((PWM_DT_DTL_Msk & ((value) << PWM_DT_DTL_Pos)))
/* -------- PWM_DTUPD : (PWM Offset: N/A) PWM Channel Dead Time Update Register -------- */
#define PWM_DTUPD_DTHUPD_Pos 0
#define PWM_DTUPD_DTHUPD_Msk (0xFFFFu << PWM_DTUPD_DTHUPD_Pos) /*(PWM_DTUPD) Dead-Time Value Update for PWMHx Output */
#define PWM_DTUPD_DTHUPD(value) ((PWM_DTUPD_DTHUPD_Msk & ((value) << PWM_DTUPD_DTHUPD_Pos)))
#define PWM_DTUPD_DTLUPD_Pos 16
#define PWM_DTUPD_DTLUPD_Msk (0xFFFFu << PWM_DTUPD_DTLUPD_Pos) /*(PWM_DTUPD) Dead-Time Value Update for PWMLx Output */
#define PWM_DTUPD_DTLUPD(value) ((PWM_DTUPD_DTLUPD_Msk & ((value) << PWM_DTUPD_DTLUPD_Pos)))
/* -------- PWM_ETRG1 : (PWM Offset: 0x42C) PWM External Trigger Register (trg_num = 1) -------- */
#define PWM_ETRG_MAXCNT(value) ((PWM_ETRG1_MAXCNT_Msk & ((value) << PWM_ETRG1_MAXCNT_Pos)))
#define PWM_ETRG1_MAXCNT(value) ((PWM_ETRG1_MAXCNT_Msk & ((value) << PWM_ETRG1_MAXCNT_Pos)))
#define PWM_ETRG1_TRGEDGE (0x1u << 28) /*(PWM_ETRG1) Edge Selection */
#define PWM_ETRG1_TRGEDGE_FALLING_ZERO (0x0u << 28) /*(PWM_ETRG1) TRGMODE = 1: TRGINx event detection on falling edge.TRGMODE = 2, 3: TRGINx active level is 0 */
#define PWM_ETRG1_RFEN (0x1u << 31) /*(PWM_ETRG1) Recoverable Fault Enable */

/* -------- PWM_ETRG2 : (PWM Offset: 0x44C) PWM External Trigger Register (trg_num = 2) -------- */
#define PWM_ETRG2_MAXCNT(value) ((PWM_ETRG2_MAXCNT_Msk & ((value) << PWM_ETRG2_MAXCNT_Pos)))
#define PWM_ETRG2_TRGMODE(value) ((PWM_ETRG2_TRGMODE_Msk & ((value) << PWM_ETRG2_TRGMODE_Pos)))
#define PWM_ETRG2_TRGMODE_OFF (0x0u << 24) /*(PWM_ETRG2) External trigger is not enabled. */
#define PWM_ETRG2_TRGMODE_MODE1 (0x1u << 24) /*(PWM_ETRG2) External PWM Reset Mode */
#define PWM_ETRG2_TRGMODE_MODE2 (0x2u << 24) /*(PWM_ETRG2) External PWM Start Mode */
#define PWM_ETRG2_TRGMODE_MODE3 (0x3u << 24) /*(PWM_ETRG2) Cycle-by-cycle Duty Mode */
#define PWM_ETRG2_TRGEDGE (0x1u << 28) /*(PWM_ETRG2) Edge Selection */
#define PWM_ETRG2_TRGEDGE_FALLING_ZERO (0x0u << 28) /*(PWM_ETRG2) TRGMODE = 1: TRGINx event detection on falling edge.TRGMODE = 2, 3: TRGINx active level is 0 */
#define PWM_ETRG2_TRGEDGE_RISING_ONE (0x1u << 28) /*(PWM_ETRG2) TRGMODE = 1: TRGINx event detection on rising edge.TRGMODE = 2, 3: TRGINx active level is 1 */
#define PWM_ETRG2_TRGFILT (0x1u << 29) /*(PWM_ETRG2) Filtered input */
#define PWM_ETRG2_TRGSRC (0x1u << 30) /*(PWM_ETRG2) Trigger Source */
#define PWM_ETRG2_RFEN (0x1u << 31) /*(PWM_ETRG2) Recoverable Fault Enable */

#define PWM_LEBR1_LEBDELAY_Pos  (0ul)
#define PWM_LEBR1_LEBDELAY_Msk  (0x7Ful)
#define PWM_LEBR2_LEBDELAY_Pos  (0ul)
#define PWM_LEBR2_LEBDELAY_Msk  (0x7Ful)
#define PWM_LEBR1_LEBDELAY(value) ((PWM_LEBR1_LEBDELAY_Msk & ((value) << PWM_LEBR1_LEBDELAY_Pos)))
#define PWM_LEBR2_LEBDELAY(value) ((PWM_LEBR2_LEBDELAY_Msk & ((value) << PWM_LEBR2_LEBDELAY_Pos)))

typedef enum /**< \brief Non register operation,PWM channel number*/
{
    PWM_CHANNEL0 = 0,
    PWM_CHANNEL1,
    PWM_CHANNEL2,
    PWM_CHANNEL3,
} PWM_Channel_Enum;
typedef enum /**< \brief Non register operation*/
{
    PWM_UPDATE_NOW,
    PWM_UPDATE_BUFFER,
} PWM_Update_Enum;
typedef enum /**< \brief Non register operation*/
{
    PWM_ETRG_CHANNEL1 = 1,
    PWM_ETRG_CHANNEL2 = 2,
} PWM_EtrgChannel_Enum;
typedef enum /**< \brief (PWM_ETRGx.TRGSRC) Trigger Source */
{
    PWM_ETRG_TRGSRC_PLU,
    PWM_ETRG_TRGSRC_COMP = (0x1u << 30),
} PWM_EtrgTRGSRC_Enum;
typedef enum /**< \brief (PWM_ETRGx.TRGFILT) Filtered input */
{
    PWM_ETRG_TRGFILT_DIS,
    PWM_ETRG_TRGFILT_EN  = (0x1u << 29),
} PWM_EtrgTrgFilt_Enum;
typedef enum /**< \brief (PWM_ETRGx.TRGEDGE)  Edge Selection */
{
    PWM_ETRG_TRGEDGE_FALLING_ZERO,
    PWM_ETRG_TRGEDGE_RISING_ONE   = (0x1u << 28), /*TRGMODE = 1: TRGINx event detection on rising edge.TRGMODE = 2, 3: TRGINx active level is 1 */
} PWM_EtrgTrgEdge_Enum;
typedef enum /**< \brief (PWM_ETRGx.TRGMODE)  External Trigger Mode */
{
    PWM_ETRG1_TRGMODE_OFF   = (0x0u << 24), /* External trigger is not enabled. */
    PWM_ETRG1_TRGMODE_MODE1 = (0x1u << 24), /* External PWM Reset Mode */
    PWM_ETRG1_TRGMODE_MODE2 = (0x2u << 24), /* External PWM Start Mode */
    PWM_ETRG1_TRGMODE_MODE3 = (0x3u << 24), /* Cycle-by-cycle Duty Mode */
} PWM_EtrgTrgMode_Enum;

typedef enum /**< \brief (PWM_CMRx.CPRE) Channel Prescaler */
{
    PWM_CMR_CPRE_CLK_BUS_DIV1   = (0x0u << 0),
    PWM_CMR_CPRE_CLK_BUS_DIV2   = (0x1u << 0),
    PWM_CMR_CPRE_CLK_BUS_DIV4   = (0x2u << 0),
    PWM_CMR_CPRE_CLK_BUS_DIV8   = (0x3u << 0),
    PWM_CMR_CPRE_CLK_BUS_DIV16  = (0x4u << 0),
    PWM_CMR_CPRE_CLK_BUS_DIV32  = (0x5u << 0),
    PWM_CMR_CPRE_CLK_BUS_DIV64  = (0x6u << 0),
    PWM_CMR_CPRE_CLK_BUS_DIV128 = (0x7u << 0),
    PWM_CMR_CPRE_CLK_BUS_DIV256 = (0x8u << 0),
    PWM_CMR_CPRE_CLK_BUS_DIV512 = (0x9u << 0),
    PWM_CMR_CPRE_CLK_BUS_DIV1024 = (0xAu << 0),
    PWM_CMR_CPRE_CLKA            = (0xBu << 0),
    PWM_CMR_CPRE_CLKB            = (0xCu << 0),
} PWM_CMR_CPRE_Enum;
typedef enum /**< \brief (PWM_CMRx.UPDS) Update Selection */
{
    PWM_CMR_UPDS_NEXT_END      = 0,
    PWM_CMR_UPDS_HALF_NEXT_END = (0x1u << 11), /* Update Selection */
} PWM_CMR_UPDS_Enum;

typedef enum /**< \brief (PWM_CMRx.CALG) PWM channel alignment */
{
    PWM_ALIGN_LEFT   = 0,
    PWM_ALIGN_CENTER = (0x1u << 8),
} PWM_Align_Enum;

typedef enum /**< \brief Non register operation,Definitions for PWM level */
{
    PWM_LOW  = 0,
    PWM_HIGH = 1,
    PWM_HIGHZ,
} PWM_Level_Enum;

typedef enum /**< \brief (PWM_CMRx.CPOL) PWM Polarity level */
{
    PWM_CMR_CPOL_LOW  = 0,
    PWM_CMR_CPOL_HIGH = (0x1u << 9),
} PWM_CMR_CPOL_Enum;

typedef enum /**< \brief Non register operation,PWM Output Selection */
{
    PWM_OS_DEAD_OUT = 0,
    PWM_OS_OOV_OUT  = 1,
} PWM_OS_Enum;

typedef enum /**< \brief (PWM_CMR.PPM) Push-Pull Mode */
{
    PWM_CMR_PPM_DIS = 0,
    PWM_CMR_PPM_EN  = (0x1u << 19),
} PWM_CMR_PPM_Enum;

typedef enum /**< \brief Non register operation,Stepper motor channel */
{
    PWM_StepperMotorCh0_1 = 0,  /* Channel 0 and 1 */
    PWM_StepperMotorCh2_3 = 1,  /* Channel 2 and 3 */
} PWM_StepperMotor_Enum;

typedef enum /**< \brief Non register operation,Stepper motor direction */
{
    PWM_StepperMotorDown = 0,
    PWM_StepperMotorUp   = 1,
} PWM_StepperMotor_DIR_Enum;

typedef enum PWM_SCM /**< \brief (PWM_SCM.UPDM) Synchronous Channels Update Mode */
{
    PWM_SCM_UPDM_MODE0 = 0,            /* Manual write of double buffer registers and manual update of synchronous channels */
    PWM_SCM_UPDM_MODE1 = (0x1u << 16), /* Manual write of double buffer registers and automatic update of synchronous channels */
} PWM_SyncUpdateMode_Enum;

typedef enum /**< \brief (PWM_SCM.UPDM)  PWM Counter Event Selection */
{
    PWM_EVENT_PERIOD_END      = 0,            /* The channel counter event occurs at the end of the PWM period. */
    PWM_EVENT_PERIOD_HALF_END = (0x1u << 10), /* Counter Event Selection */
} PWM_CounterEvent_Enum;

typedef enum /**< \brief Non register operation,Definitions for PWM fault input ID */
{
    PWM_FAULT_DISABLE      =  0,
    PWM_FAULT_PWMFI0       = (0x1u << 0),
    PWM_FAULT_CLK          = (0x1u << 1),
    PWM_FAULT_PVD          = (0x1u << 2),
    PWM_FAULT_TIM0         = (0x1u << 3),
    PWM_FAULT_TIM1         = (0x1u << 4),
    PWM_FAULT_ADC_COMP_OUT = (0x1u << 5),
    PWM_FAULT_COMP0_OUT    = (0x1u << 6),
    PWM_FAULT_COMP1_OUT    = (0x1u << 7),
} PWM_FaultId_Enum;

typedef enum /**< \brief Non register operation,Definitions of PWM register group */
{
    PWM_GROUP_CLOCK     = (0x1u << 0),
    PWM_GROUP_DISABLE   = (0x1u << 1),
    PWM_GROUP_MODE      = (0x1u << 2),
    PWM_GROUP_PERIOD    = (0x1u << 3),
    PWM_GROUP_DEAD_TIME = (0x1u << 4),
    PWM_GROUP_FAULT     = (0x1u << 5)
} PWM_ProtectReg_Enum;

typedef enum /**< \brief Non register operation,Definitions of PWM register group write protection mode */
{
    PWM_Disable_SW_Protect = 0,
    PWM_Enable_SW_Protect  = 1,
    PWM_Enable_HW_Protect  = 2,
} PWM_ProtectMode_Enum;

typedef enum /**< \brief Non register operation,Definitions for PWM comparison interrupt */
{
    PWM_CMP_MATCH  = 8,  /* Comparison unit match */
    PWM_CMP_UPDATE = 16  /* Comparison unit update */
} PWM_CMP_IT_Enum;

typedef enum /**< \brief Non register operation,Definitions for PWM comparison unit */
{
    PWM_CMP_UNIT0 = 0,
    PWM_CMP_UNIT1,
    PWM_CMP_UNIT2,
    PWM_CMP_UNIT3,
} PWM_CMP_Unit_Enum;

typedef enum /**< \brief Non register operation,Definitions for PWM synchronous channels interrupt */
{
    PWM_SYNC_WRITE_READY = (1u << 0),  /* Write Ready for Synchronous Channels Update */
    PWM_SYNC_UNDERRUN    = (1u << 3)   /* Synchronous Channels Update Underrun Error */
} PWM_Sync_IT_Enum;

typedef enum /**< \brief (PWM_LEBRx) PWM Leading Edge Blanking */
{
    PWM_LEBRx_PWMLFEN = (0x1ul << 16), /* PWML Falling Edge Enable */
    PWM_LEBRx_PWMLREN = (0x1ul << 17), /* PWML Rising Edge Enable */
    PWM_LEBRx_PWMHFEN = (0x1ul << 18), /* PWMH Falling Edge Enable */
    PWM_LEBRx_PWMHREN = (0x1ul << 19), /* PWMH Rising Edge Enable */
} PWM_LEBR_Enum;

typedef struct
{
    PWM_EtrgChannel_Enum EtrgCh;
    PWM_EtrgTRGSRC_Enum  EtrgTrgSrc;
    PWM_EtrgTrgFilt_Enum EtrgTrgFilt;
    PWM_EtrgTrgEdge_Enum EtrgTrgEdge;
    PWM_EtrgTrgMode_Enum EtrgTrgMode;
    uint32_t             ul_EtrgRfen; /** Recoverable Fault Enable */
    uint32_t             ul_MaxCnt;   /** Maximum Counter value */
} PWM_ETRG_T;

typedef struct
{
    uint32_t ul_clka_prea; /** Frequency of clock A in Hz */
    uint32_t ul_clka_diva; /** set 0 to turn it off*/
    uint32_t ul_clkb_preb; /** Frequency of clock B in Hz */
    uint32_t ul_clkb_divb; /** set 0 to turn it off*/

    uint32_t ul_bus_clk;  /** Frequency of master clock in Hz */
} PWM_ClOCK_T;

/** Configurations of a PWM channel output */
typedef struct
{
    PWM_OS_Enum     PWMH_OutputSelect;
    PWM_OS_Enum     PWML_OutputSelect;
    PWM_Level_Enum  PWMH_OovLevel;
    PWM_Level_Enum  PWML_OovLevel;
    PWM_Update_Enum UpdateReg;
} PWM_OutputSelect_T;

/** Configurations of PWM comparison */
typedef struct
{
    uint32_t ul_value;    /** Comparison value */
    uint32_t ul_trigger;  /** Comparison trigger value */
    uint32_t ul_period;   /** Comparison period value */
    uint32_t ul_update_period;/** Comparison update period value */
    uint8_t  uc_unit;      /** Comparison unit number */
    FunctionalState Enable;/** Boolean of comparison enable */
    FunctionalState Is_Decrementing;/** Comparison mode */
    FunctionalState PulseOnLine0;/** Boolean of generating a match pulse on PWM event line 0 */
    FunctionalState PulseOnLine1;/** Boolean of generating a match pulse on PWM event line 1 */
    FunctionalState PulseOnLine2;/** Boolean of generating a match pulse on PWM event line 2 */
    FunctionalState PulseOnLine3;/** Boolean of generating a match pulse on PWM event line 3 */
} PWM_CMP_T;

/** Configuration of PWM fault input behaviors */
typedef struct
{
    PWM_Channel_Enum Channel; /** Channel number */
    FunctionalState  Clear;   /** Boolean of clearing fault flag */
    FunctionalState  Filtered;/** Boolean of fault filtering */
    PWM_FaultId_Enum Fault_id;/** Fault ID */
    PWM_Level_Enum   Polarity;/** Polarity of fault input */
    PWM_Level_Enum   Fault_Output_PWMH;/** Channel PWMH output level in fault protection */
    PWM_Level_Enum   Fault_Output_PWML;/** Channel PWML output level in fault protection */
} PWM_Fault_T;

/** Structure of PWM write-protect information */
typedef struct
{
    uint32_t ul_hw_status;/** Bitmask of PWM register group for write protect hardware status */
    uint32_t ul_sw_status;/** Bitmask of PWM register group for write protect software status */
    uint32_t ul_offset;   /** Offset address of PWM register in which a write access has been attempted */
} PWM_Protect_T;

typedef struct
{
    PWM_Channel_Enum channel;/** Channel number */
    uint32_t         ul_LeadingEdgeDelay;/** Leading Edge Value */
    PWM_LEBR_Enum    LeadingEdgeBlankingMode;	/** Leading Edge Mode */
} PWM_LeadingEdge_T;

/** Input parameters when configuring a PWM channel mode */
typedef struct
{
    uint32_t ul_pulse;
    uint32_t ul_period;

    uint32_t ul_pwmh_deadtime;
    uint32_t ul_pwml_deadtime;
	
    PWM_CMR_PPM_Enum      PPM_Mode;
    PWM_Align_Enum        Alignment;
    
    PWM_CMR_CPOL_Enum     Polarity;
    PWM_CMR_UPDS_Enum     CMR_UpdateSelect;
    PWM_CounterEvent_Enum CounterEventSelect;
	
    PWM_Channel_Enum      Channel;
	  PWM_CMR_CPRE_Enum     Prescaler;
	  FunctionalState       PolarityInverted;
    FunctionalState       DeadTimeGenerator;
    FunctionalState       PWMH_OutputInverted;
    FunctionalState       PWML_OutputInverted;
} PWM_Channel_T;

void PWM_Channel_Enable_IT(PWM_Channel_Enum Channel);
void PWM_Channel_Disable_IT(PWM_Channel_Enum Channel);

ErrorStatus PWM_ClocksInit(PWM_ClOCK_T *Clock_Config);
ErrorStatus PWM_ChannelUpdatePeriod(PWM_Channel_Enum Channel, uint32_t ul_period);
ErrorStatus PWM_ChannelUpdateDuty(PWM_Channel_Enum Channel, uint32_t ul_pulse);
uint32_t PWM_ChannelGetCounter(PWM_Channel_Enum Channel);
void PWM_ChannelEnable(PWM_Channel_Enum Channel);
void PWM_ChannelDisable(PWM_Channel_Enum Channel);
uint32_t PWM_ChannelGetStatus(void);
uint32_t PWM_ChannelGet_IT1_Status(void);
uint32_t PWM_ChannelGet_IT1_Mask(void);

void PWM_ChannelUpdateOutput(PWM_OutputSelect_T *p_output, PWM_Channel_Enum Channel);
void PWM_ChannelDeadTimeEnable(PWM_Channel_Enum Channel);
void PWM_ChannelDeadTimeDisable(PWM_Channel_Enum Channel);
ErrorStatus PWM_ChannelUpdateDeadTime(PWM_Channel_Enum Channel, uint16_t ui_DeadTimePwmH, uint16_t ui_DeadTimePwmL);
ErrorStatus PWM_ChannelDeadTime(PWM_Channel_Enum Channel, uint16_t ui_DeadTimePwmH, uint16_t ui_DeadTimePwmL);
void PWM_FaultInit(PWM_Fault_T *p_fault);
uint32_t PWM_FaultGetStatus(void);
PWM_Level_Enum PWM_FaultGetInputLevel(PWM_FaultId_Enum id);
void PWM_FaultClearStatus(PWM_FaultId_Enum id);
void PWM_CMP_Init(PWM_CMP_T *p_cmp);
void PWM_CMP_ChangeSetting(PWM_CMP_T *p_cmp);
uint32_t PWM_CMP_GetPeriodCounter(PWM_CMP_Unit_Enum Unit);
uint32_t PWM_CMP_GetUpdateCounter(PWM_CMP_Unit_Enum Unit);
void PWM_CMP_Enable_IT(uint32_t ul_sources, PWM_CMP_IT_Enum IT_Type);
void PWM_CMP_Disable_IT(uint32_t ul_sources, PWM_CMP_IT_Enum IT_Type);
ErrorStatus  PWM_SyncInit(PWM_SyncUpdateMode_Enum mode, uint8_t uc_UpdatePeriod);
void PWM_SyncUnlockUpdate(void);
ErrorStatus PWM_SyncChangePeriod(uint8_t uc_UpdatePeriod);
uint32_t PWM_SyncGetPeriodCounter(void);
void PWM_Sync_Enable_IT(uint32_t ul_sources);
void PWM_Sync_Disable_IT(uint32_t ul_sources);
void PWM_ProtectEnable(PWM_ProtectReg_Enum Group, PWM_ProtectMode_Enum ProtectMode);
void PWM_ProtectDisable(PWM_ProtectReg_Enum Group);
FunctionalState PWM_ProtectGetStatus(PWM_Protect_T *p_protect);
uint32_t PWM_CMP_Get_IT2_Status(void);
uint32_t PWM_CMP_Get_IT2_Mask(void);
void PWM_StepperMotorInit(PWM_StepperMotor_Enum E_Pair, PWM_StepperMotor_DIR_Enum E_DIR, FunctionalState E_EnableGray);
void PWM_ChannelUpdateLeadingEdge(PWM_LeadingEdge_T *p_channel, uint32_t ul_LeadingEdgeDelay, PWM_LEBR_Enum LeadingEdgeBlankingMode);
ErrorStatus PWM_SetExtTrgMode(PWM_ETRG_T *PWM_ETRG_Config);
ErrorStatus PWM_ChannelInit(PWM_Channel_T *p_channel);
void PWM_ChannelSyncEnable(PWM_Channel_Enum Channel);
void PWM_ChannelSyncDisable(PWM_Channel_Enum Channel);

#ifdef __cplusplus
}
#endif

#endif /* MS60F3XXX_PWM_H */
