/**
  ******************************************************************************
  * @file           : ms60f3xxx_scr.h
  * @author         : sinomcu.com-SA
  * @brief          : Header file of SCU module.
  * @gcc            : toolchain version   5 or 6
  *
  ******************************************************************************
  * @attention
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with
	* basic chip information support
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */
#ifndef MS60F3XXX_SCU_H
#define MS60F3XXX_SCU_H

#include "ms60f3xxx.h"

#ifdef __cplusplus
extern "C" {
#endif

#define PLL_REF  0x100
#define PLL_DIVIDER 0x0F
#define PLL_DIV_M  0x03
#define PLL_LOCK_RESET 0x80
#define SCU_SOFT_RESET_KEY 0xdeadbeef
#define SCU_UNLOCK_KEY      0x686868
#define PLL_MASK_REF_DIVIDER_DIV_M 0x13f
#define SCU_ALL_CLKEN            ((uint32_t)0xFFFFFFFF)
#define SCU_ADC_CORE_CLKEN       ((uint32_t)0x20000000)
#define SCU_SYS_CLKEN            ((uint32_t)0x10000000)
#define SCU_GPIOD_CLKEN          ((uint32_t)0x08000000)
#define SCU_GPIOC_CLKEN          ((uint32_t)0x04000000)
#define SCU_GPIOB_CLKEN          ((uint32_t)0x02000000)
#define SCU_GPIOA_CLKEN          ((uint32_t)0x01000000)
#define SCU_PGA_CLKEN            ((uint32_t)0x00800000)
#define SCU_DAC3_CLKEN           ((uint32_t)0x00400000)
#define SCU_DAC2_CLKEN            ((uint32_t)0x00200000)
#define SCU_DAC1_CLKEN           ((uint32_t)0x00100000)
#define SCU_DAC0_CLKEN           ((uint32_t)0x00080000)
#define SCU_ADC_CLKEN           ((uint32_t)0x00040000)
#define SCU_COMP_CLKEN           ((uint32_t)0x00020000)
#define SCU_IIC1_CLKEN           ((uint32_t)0x00010000)
#define SCU_IIC0_CLKEN           ((uint32_t)0x00008000)
#define SCU_CORDIC_CLKEN           ((uint32_t)0x00004000)
#define SCU_PWM_CLKEN            ((uint32_t)0x00002000)
#define SCU_SPI1_CLKEN           ((uint32_t)0x00001000)
#define SCU_SPI0_CLKEN            ((uint32_t)0x00000800)
#define SCU_USART_CLKEN           ((uint32_t)0x00000400)
#define SCU_UART2_CLKEN           ((uint32_t)0x00000200)
#define SCU_UART1_CLKEN           ((uint32_t)0x00000100)
#define SCU_UART0_CLKEN           ((uint32_t)0x00000080)
#define SCU_PLU_CLKEN          ((uint32_t)0x00000040)
#define SCU_CRC_CLKEN          ((uint32_t)0x00000020)
#define SCU_WWDG_CLKEN           ((uint32_t)0x00000010)
#define SCU_LPTIMER_CLKEN        ((uint32_t)0x00000008)
#define SCU_TIM1_CLKEN           ((uint32_t)0x00000004)
#define SCU_TIM0_CLKEN           ((uint32_t)0x00000002)
#define SCU_ALL_RST              ((uint32_t)0x0FFFFFFF)
#define SCU_GPIOD_RST            ((uint32_t)0x04000000)
#define SCU_GPIOC_RST            ((uint32_t)0x02000000)
#define SCU_GPIOB_RST            ((uint32_t)0x01000000)
#define SCU_GPIOA_RST            ((uint32_t)0x00800000)
#define SCU_DAC3_RST             ((uint32_t)0x00400000)
#define SCU_DAC2_RST             ((uint32_t)0x00200000)
#define SCU_DAC1_RST             ((uint32_t)0x00100000)
#define SCU_DAC0_RST             ((uint32_t)0x00080000)
#define SCU_ADC_RST              ((uint32_t)0x00040000)
#define SCU_COMP_RST             ((uint32_t)0x00020000)
#define SCU_IIC1_RST             ((uint32_t)0x00010000)
#define SCU_IIC0_RST             ((uint32_t)0x00008000)
#define SCU_CORDIC_RST           ((uint32_t)0x00004000)
#define SCU_PWM_RST              ((uint32_t)0x00002000)
#define SCU_SPI1_RST             ((uint32_t)0x00001000)
#define SCU_SPI0_RST             ((uint32_t)0x00000800)
#define SCU_USART_RST            ((uint32_t)0x00000400)
#define SCU_UART2_RST             (uint32_t)0x00000200)
#define SCU_UART1_RST            ((uint32_t)0x00000100)
#define SCU_UART0_RST            ((uint32_t)0x00000080)
#define SCU_PLU_RST              ((uint32_t)0x00000040)
#define SCU_CRC_RST              ((uint32_t)0x00000020)
#define SCU_WWDT_RST             ((uint32_t)0x00000010)
#define SCU_LPTIMER_RST          ((uint32_t)0x00000008)
#define SCU_TIM1_RST             ((uint32_t)0x00000004)
#define SCU_TIM0_RST             ((uint32_t)0x00000002)

#define BOR_2P0V					 0x0
#define BOR_2P25V					 0x1<<1
#define BOR_2P5V					 0x2<<1
#define BOR_2P75V					 0x3<<1
#define BOR_3P0V					 0x4<<1
#define BOR_3P3V					 0x5<<1
#define BOR_3P6V					 0x6<<1
#define BOR_4P0V					 0x7<<1

#define PVD_2P0V					 0x0
#define PVD_2P25V					 0x1<<5
#define PVD_2P5V					 0x2<<5
#define PVD_2P75V					 0x3<<5
#define PVD_3P0V					 0x4<<5
#define PVD_3P3V					 0x5<<5
#define PVD_3P6V					 0x6<<5
#define PVD_4P0V					 0x7<<5

typedef enum /**< \brief Non register operation, only for flags  */
{
    SLEEP_MODE = 0,
    STOP_MODE = 1,
    STANDBY_MODE = 2
} LOW_POWER_MODE_Enum;

typedef enum /**< \brief Non register operation, only for flags  */
{
    NO_XTAL   = 0,
    LXTAL_TYPE = 1,
    HXTAL_TYPE = 4,
    HXTAL_LXTAL_TYPE = 5
} XTAL_SEL_Enum;

typedef enum /**< \brief (CLK_DIV_CSR) clock div control status */
{
    DIV_LOADED = 0,
    DIV_LOADING = 0x80
} SYS_DIV_Enum;

typedef enum /**< \brief (CLK_EN_CR) clock enable control register*/
{
    LXTAL_EN_ENUM = 1,
    HRC_EN_ENUM   = 2,
    HXTAL_EN_ENUM = 4,
    PLL_EN_ENUM   = 8
} CLOCK_SOURCE_ENABLE_Enum;
typedef enum /**< \brief (CLK_CSR) clock status control register*/
{
    HXTAL_OSCILATING = 0,
    HXTAL_OSCILATED  = 2
} HXTAL_OSCILATION_Enum;

typedef enum /**< \brief (CLK_CSR) clock status control register*/
{
    LXTAL_OSCILATING = 0,
    LXTAL_OSCILATED  = 1
} LXTAL_OSCILATION_Enum;


typedef enum /**< \brief (CLK_CSR) clock status control register*/
{
    PLL_OSCILATING = 0,
    PLL_OSCILATED  = 4
} PLL_OSCILATION_Enum;
typedef enum /**< \brief Non register operation, only for flags  */
{
    CLK_32K_USE_HRC_LRC = 0,
    CLK_32K_USE_HRC_LXTAL = 1,
    CLK_32K_USE_HXTAL_LRC = 2,
    CLK_32K_USE_HXTAL_LXTAL = 3,
    CLK_16M_USE_HRC_LRC = 4,
    CLK_16M_USE_HRC_LXTAL = 5,
    CLK_16M_USE_HXTAL_LRC = 6,
    CLK_16M_USE_HXTAL_LXTAL = 7,
    CLK_PLL_USE_HRC_LRC = 8,
    CLK_PLL_USE_HRC_LXTAL = 9,
    CLK_PLL_USE_HXTAL_LRC = 10,
    CLK_PLL_USE_HXTAL_LXTAL = 11,
} CLOCK_SEL_Enum;
typedef enum /**< \brief (CLK_CSR) HXTAL_RDY_DIV value*/
{
    HXTAL_RDY_DIV_4M = (0x3F << 3),
    HXTAL_RDY_DIV_8M = (0x7D << 3),
    HXTAL_RDY_DIV_12M = (0xBC << 3),
    HXTAL_RDY_DIV_16M = (0xFA << 3),
} HXTAL_RDY_DIV_ENUM_Enum;

typedef enum /**< \brief (CLK_DIV_CSR)clock div control status */
{
    SCU_SYS_Div1    = 0,
    SCU_SYS_Div2    = 1,
    SCU_SYS_Div4    = 2,
    SCU_SYS_Div8    = 3,
    SCU_SYS_Div16   = 4,
    SCU_SYS_Div32   = 5,
    SCU_SYS_Div64   = 6,
    SCU_SYS_Div128  = 7
} CLOCK_DIV_Enum;

typedef enum /**< \brief (COUT_CR)clock out*/
{
    SCU_OUT_Div1    = 0,
    SCU_OUT_Div2    = 1,
    SCU_OUT_Div4    = 2,
    SCU_OUT_Div8    = 3,

} CLOCK_OUT_DIV_Enum;
typedef enum /**< \brief (PLL_CR)PLL CONTROL register*/
{
    PLL_72M = 8,
    PLL_64M = 11,
    PLL_48M = 0,
    PLL_36M = 12,
    PLL_32M = 15,
    NO_PLL = 15,
} PLL_FREQ_Enum;

typedef enum /**< \brief (PLL_CR) PLL CONTROL register*/
{
    HXTAL_12M = 0,
    HXTAL_8M  = 0x20,
    HXTAL_4M	 = 0x10,
    HXTAL_16M = 0x30,
    HRC_16M   = 0x30,

} HXTAL_FREQ_Enum;

typedef enum /**< \brief (PSM_CSR) voltage down monitor enable  */
{
    PVD_DISABLE = 0,
    PVD_ENABLE = 0x80,

} PVD_ENABLE_Enum;
#define PVD_MODUEL_MASK 0x0F80
#define PVD_ENABLE_MASK 0x0080
typedef enum
{
    PVD_2V = 0,
    PVD_2V25 = (1 << 8),
    PVD_2V5 = (2 << 8),
    PVD_2V75 = (3 << 8),
    PVD_3V =  (4 << 8),
    PVD_3V3 = (5 << 8),
    PVD_3V6 = (6 << 8),
    PVD_4V =  (7 << 8),

} PVD_VALUE_Enum;

typedef enum /**< \brief (PVD_IER) General Purpose Register  */
{
    PVD_F_IE = 1,
    PVD_R_IE = 2
} PVD_IE_Enum;

typedef enum /**< \brief (PVD_IDR) General Purpose Register  */
{
    PVD_F_ID = 1,
    PVD_R_ID = 2
} PVD_ID_Enum;

typedef enum /**< \brief (PVD_IFR) General Purpose Register  */
{
    PVD_F_IF = 1,
    PVD_R_IF = 2
} PVD_IF_Enum;
typedef enum /**< \brief (RST_SR) BOR reset  */
{
    BOR_DISABLE = 0,
    BOR_ENABLE = 1,

} BOR_ENABLE_Enum;


typedef enum /**< \brief (PSM_CSR) BOR falling voltage value */
{
    BOR_FALLING_2V   = 0,
    BOR_FALLING_2V25 = 2,
    BOR_FALLING_2V5  = 4,
    BOR_FALLING_2V75 = 6,
    BOR_FALLING_3V  = 8,
    BOR_FALLING_3V3  = 10,
    BOR_FALLING_3V6 = 12,
    BOR_FALLING_4V = 14,

} BOR_FALLING_VALUE_Enum;

typedef enum /**< \brief (PSM_CSR) BOR rising voltage value  */
{
    BOR_RISING_2V   = 0,
    BOR_RISING_2V25 = 0x10,
    BOR_RISING_2V5  = 0x20,
    BOR_RISING_2V75 = 0x30,
    BOR_RISING_3V  = 0x40,
    BOR_RISING_3V3  = 0x50,
    BOR_RISING_3V6 = 0x60,
    BOR_RISING_4V = 0x70,

} BOR_RISING_VALUE_Enum;

#define BOR_MODUEL_MASK 0x007F
#define BOR_ENABLE_MASK 0x0001
typedef enum /**< \brief Non register operation, only for flags  */
{   ALL_OFF       = 0x00,
    PLL_ON        = 0x01,
    HRC_ON        = 0x02,
    HTXAL_ON      = 0x04,
    LXTAL_ON      = 0x08,
    LXTAL_STB_ON  = 0x10,
    MLDO_ON       = 0x20,

} STOP_MODE_Enum;

typedef enum /**< \brief Non register operation, only for flags  */
{
    EXTI0_WAKEUP     = 1,
    EXTI1_2_WAKEUP     = 2,
    EXTI3_4_WAKEUP     = 4,
    EXTI5_15_WAKEUP     = 8,
    PVD_WAKEUP       = 0x10,
    LPTIMER_WAKEUP   = 0x20
} WAKEUP_MODE_Enum;
typedef enum /**< \brief Non register operation,only an enumeration variable for EXTI Trigger*/
{
    Event_Mode                  = 0,
    Interrupt_Mode              = 0x01,

} SCU_WAKMode_Enum;
typedef enum
{
    EXTI0_WAKEUP_IF     = 1,
    EXTI1_2_WAKEUP_IF     = 2,
    EXTI3_4_WAKEUP_IF     = 4,
    EXTI5_15_WAKEUP_IF     = 8,
    PVD_WAKEUP_IF       = 0x10,
    LPTIMER_WAKEUP_IF   = 0x20
} WAKEUP_STATUS_Enum;

typedef enum /**< \brief Non register operation, only for flags  */
{
    POR_RESET      = 1,
    BOR_RESET      = 2,
    KEY_RESET      = 4,
    IWDT_RESET     = 8,
    WWDT_RESET     = 0x10,
    SOFT_RESET     = 0x20,
    LOCKUP_RESET   = 0x40,
    CPU_RESET      = 0x80
} SCU_RESET_Enum;
typedef enum /**< \brief (COUT_CR) clock out select  */
{
    CLK_LRC = 0,
    CLK_LXTAL = (1 << 2),
    CLK_HXTAL = (2 << 2),
    CLK_HRC = (3 << 2),
    CLK_PLL = (4 << 2),
    CLK_SYS = (5 << 2),
    CLK_BUS = (6 << 2),
    CLK_ADC = (7 << 2),
} CLOCK_OUT_SELECT_Enum;

typedef enum /**< \brief (COUT_CR) Clock out enable*/
{
    CLOCK_OUT_DISABLE = 0,
    CLOCK_OUT_ENABLE = 0x20,
} CLOCK_OUT_ENABLE_Enum;
typedef enum /**< \brief Non register operation, only for flags  */
{
    PLL_DISABLE = 0,
    PLL_ENABLE = 1
} PLL_ENABLE_Enum;

typedef enum /**< \brief Non register operation, only for flags  */
{
    LXTAL_CHANGE_IE = 1,
    HXTAL_CHANGE_IE = 2,
    PLL_LOCK_CHANGE_IE = 4
} CLOCK_INT_ENABLE_Enum;

typedef enum /**< \brief Non register operation, only for flags  */
{
    LXTAL_CHANGE_ID = 1,
    HXTAL_CHANGE_ID = 2,
    PLL_LOCK_CHANGE_ID = 4
} CLOCK_INT_DISABLE_Enum;

typedef enum /**< \brief Non register operation, only for flags  */
{
    LXTAL_CHANGE_IF = 1,
    HXTAL_CHANGE_IF = 2,
    PLL_LOCK_CHANGE_IF = 4
} CLOCK_INT_IF;
typedef enum /**< \brief (RAMADDR) RAM address map register */
{
    BOOT_FROM_FLASH = 0,
    BOOT_FROM_SRAM  = 1
} BOOT_SELECT_Enum;

void SCU_Unlock(void);
void SCU_Lock(void);
void SCU_SetSysClock(CLOCK_SEL_Enum sourcetype, HXTAL_FREQ_Enum hxtal_freq_type, XTAL_SEL_Enum xtal_type, PLL_FREQ_Enum plltype, CLOCK_DIV_Enum clockdiv);
void SCU_MCO(CLOCK_OUT_SELECT_Enum mcosel, CLOCK_OUT_DIV_Enum mcopre, CLOCK_OUT_ENABLE_Enum out_enable);
void SCU_PeriphClockCmd(uint32_t Periph, FunctionalState NewState);

void SCU_ResetPeriphClock(uint32_t Periph);
void SCU_SetBor(BOR_RISING_VALUE_Enum rising_value, BOR_FALLING_VALUE_Enum falling_value, FunctionalState NewState);
void SCU_SetPVD(PVD_VALUE_Enum PVDLevel, PVD_ENABLE_Enum NewState);
void SCU_Sleep_Mode(LOW_POWER_MODE_Enum mode, STOP_MODE_Enum stop_method, SCU_WAKMode_Enum wake_methord);
void SCU_Soft_Reset(void);
void SCU_PVD_Disable_IT(PVD_IE_Enum ID);
void SCU_Enable_IT(uint8_t IE);
void SCU_Disable_IT(uint8_t ID);
void SCU_PVD_Enable_IT(PVD_IE_Enum IE);
uint32_t SCU_Get_frequecny(void);
uint16_t SCU_Get_Wake_IF(void);
void SCU_Set_Wake(uint8_t mode);

#ifdef __cplusplus
}
#endif

#endif




