/**
  ******************************************************************************
  * @file           : ms60f3xxx_tim.h
  * @author         : sinomcu.com-SA
  * @brief          : Header file of tim module.
  * @gcc            : toolchain version 5 or 6
  *
  ******************************************************************************
  * @attention
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with
	* basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */
#ifndef MS60F3XXX_TIM_H
#define MS60F3XXX_TIM_H

#ifdef __cplusplus
extern "C" {
#endif

#include "ms60f3xxx.h"
#include "ms60f3xxx_tim.h"
#include "stdint.h"

/* --------  TIM_TRGIN -------- */
#define TIM_TRGIN_TIM0_0_TIOB_Pos   (0ul)          /* TIM0_0_TIOB (Bit 0)                */
#define TIM_TRGIN_TIM0_0_TIOB_Msk   (0x3ul)        /* TIM0_0_TIOB (Bitfield-Mask: 0x03)  */
#define TIM_TRGIN_TIM0_1_TIOB_Pos   (2ul)          /* TIM0_1_TIOB (Bit 2)                */
#define TIM_TRGIN_TIM0_1_TIOB_Msk   (0xcul)        /* TIM0_1_TIOB (Bitfield-Mask: 0x03)  */
#define TIM_TRGIN_TIM0_2_TIOB_Pos   (4ul)          /* TIM0_2_TIOB (Bit 4)                */
#define TIM_TRGIN_TIM0_2_TIOB_Msk   (0x30ul)       /* TIM0_2_TIOB (Bitfield-Mask: 0x03)  */
#define TIM_TRGIN_TIM1_0_TIOB_Pos   (6ul)          /* TIM1_0_TIOB (Bit 6)                */
#define TIM_TRGIN_TIM1_0_TIOB_Msk   (0xc0ul)       /* TIM1_0_TIOB (Bitfield-Mask: 0x03)  */
#define TIM_TRGIN_TIM1_1_TIOB_Pos   (8ul)          /* TIM1_1_TIOB (Bit 8)                */
#define TIM_TRGIN_TIM1_1_TIOB_Msk   (0x300ul)      /* TIM1_1_TIOB (Bitfield-Mask: 0x03)  */
#define TIM_TRGIN_TIM1_2_TIOB_Pos   (10ul)         /* TIM1_2_TIOB (Bit 10)               */
#define TIM_TRGIN_TIM1_2_TIOB_Msk   (0xC00ul)      /* TIM1_2_TIOB (Bitfield-Mask: 0x03)  */

/* -------- TIM_CCR : (TIM Offset: N/A) Channel Control Register -------- */
#define TIM_CCR_CLKEN  (0x1ul << 0) /*(TIM_CCR) Counter Clock Enable Command */
#define TIM_CCR_CLKDIS (0x1ul << 1) /*(TIM_CCR) Counter Clock Disable Command */
#define TIM_CCR_SWTRG  (0x1ul << 2) /*(TIM_CCR) Software Trigger Command */
/* -------- TIM_CMR : (TIM Offset: N/A) Channel Mode Register -------- */
#define TIM_CMR_BSWTRG_Pos      30
#define TIM_CMR_BSWTRG_Msk      (0x3ul << TIM_CMR_BSWTRG_Pos) /*(TIM_CMR) Software Trigger Effect on TIOB */
#define TIM_CMR_BSWTRG(value)   ((TIM_CMR_BSWTRG_Msk & ((value) << TIM_CMR_BSWTRG_Pos)))
#define TIM_CMR_BSWTRG_NONE   (0x0ul << 30) /*(TIM_CMR) None */  //by zhc ul-->il
#define TIM_CMR_BSWTRG_SET    (0x1ul << 30) /*(TIM_CMR) Set */
#define TIM_CMR_BSWTRG_CLEAR  (0x2ul << 30) /*(TIM_CMR) Clear */
#define TIM_CMR_BSWTRG_TOGGLE (0x3ul << 30) /*(TIM_CMR) Toggle */
/* -------- TIM_SMMR : (TIM Offset: N/A) Stepper Motor Mode Register -------- */
#define TIM_SMMR_GCEN (0x1ul << 0) /*(TIM_SMMR) Gray Count Enable */
#define TIM_SMMR_DOWN (0x1ul << 1) /*(TIM_SMMR) Down Count */
/* -------- TIM_RAB : (TIM Offset: N/A) Register AB -------- */
#define TIM_RAB_RAB_Pos  0
#define TIM_RAB_RAB_Msk (0xFFFFFFFFul << TIM_RAB_RAB_Pos) /*(TIM_RAB) Register A or Register B */
/* -------- TIM_CV : (TIM Offset: N/A) Counter Value -------- */
#define TIM_CV_CV_Pos  0
#define TIM_CV_CV_Msk (0xFFFFFFFFul << TIM_CV_CV_Pos) /*(TIM_CV) Counter Value */
/* -------- TIM_RA : (TIM Offset: N/A) Register A -------- */
#define TIM_RA_RA_Pos  0
#define TIM_RA_RA_Msk (0xFFFFFFFFul << TIM_RA_RA_Pos) /*(TIM_RA) Register A */
#define TIM_RA_RA(value) ((TIM_RA_RA_Msk & ((value) << TIM_RA_RA_Pos)))
/* -------- TIM_RB : (TIM Offset: N/A) Register B -------- */
#define TIM_RB_RB_Pos  0
#define TIM_RB_RB_Msk (0xFFFFFFFFul << TIM_RB_RB_Pos) /*(TIM_RB) Register B */
#define TIM_RB_RB(value) ((TIM_RB_RB_Msk & ((value) << TIM_RB_RB_Pos)))
/* -------- TIM_RC : (TIM Offset: N/A) Register C -------- */
#define TIM_RC_RC_Pos  0
#define TIM_RC_RC_Msk (0xFFFFFFFFul << TIM_RC_RC_Pos) /*(TIM_RC) Register C */
#define TIM_RC_RC(value) ((TIM_RC_RC_Msk & ((value) << TIM_RC_RC_Pos)))
/* -------- TIM_SR : (TIM Offset: N/A) Status Register -------- */
#define TIM_SR_COVFS  (0x1ul << 0) /*(TIM_SR) Counter Overflow Status (cleared on read) */
#define TIM_SR_LOVRS  (0x1ul << 1) /*(TIM_SR) Load Overrun Status (cleared on read) */
#define TIM_SR_CPAS   (0x1ul << 2) /*(TIM_SR) RA Compare Status (cleared on read) */
#define TIM_SR_CPBS   (0x1ul << 3) /*(TIM_SR) RB Compare Status (cleared on read) */
#define TIM_SR_CPCS   (0x1ul << 4) /*(TIM_SR) RC Compare Status (cleared on read) */
#define TIM_SR_LDRAS  (0x1ul << 5) /*(TIM_SR) RA Loading Status (cleared on read) */
#define TIM_SR_LDRBS  (0x1ul << 6) /*(TIM_SR) RB Loading Status (cleared on read) */
#define TIM_SR_ETRGS  (0x1ul << 7) /*(TIM_SR) External Trigger Status (cleared on read) */
#define TIM_SR_CLKSTA (0x1ul << 16) /*(TIM_SR) Clock Enabling Status */
#define TIM_SR_MTIOA  (0x1ul << 17) /*(TIM_SR) TIOA Mirror */
#define TIM_SR_MTIOB  (0x1ul << 18) /*(TIM_SR) TIOB Mirror */
/* -------- TIM_IER : (TIM Offset: N/A) Interrupt Enable Register -------- */
#define TIM_IER_COVFS (0x1ul << 0) /*(TIM_IER) Counter Overflow */
#define TIM_IER_LOVRS (0x1ul << 1) /*(TIM_IER) Load Overrun */
#define TIM_IER_CPAS  (0x1ul << 2) /*(TIM_IER) RA Compare */
#define TIM_IER_CPBS  (0x1ul << 3) /*(TIM_IER) RB Compare */
#define TIM_IER_CPCS  (0x1ul << 4) /*(TIM_IER) RC Compare */
#define TIM_IER_LDRAS (0x1ul << 5) /*(TIM_IER) RA Loading */
#define TIM_IER_LDRBS (0x1ul << 6) /*(TIM_IER) RB Loading */
#define TIM_IER_ETRGS (0x1ul << 7) /*(TIM_IER) External Trigger */
/* -------- TIM_IDR : (TIM Offset: N/A) Interrupt Disable Register -------- */
#define TIM_IDR_COVFS (0x1ul << 0) /*(TIM_IDR) Counter Overflow */
#define TIM_IDR_LOVRS (0x1ul << 1) /*(TIM_IDR) Load Overrun */
#define TIM_IDR_CPAS  (0x1ul << 2) /*(TIM_IDR) RA Compare */
#define TIM_IDR_CPBS  (0x1ul << 3) /*(TIM_IDR) RB Compare */
#define TIM_IDR_CPCS  (0x1ul << 4) /*(TIM_IDR) RC Compare */
#define TIM_IDR_LDRAS (0x1ul << 5) /*(TIM_IDR) RA Loading */
#define TIM_IDR_LDRBS (0x1ul << 6) /*(TIM_IDR) RB Loading */
#define TIM_IDR_ETRGS (0x1ul << 7) /*(TIM_IDR) External Trigger */
/* -------- TIM_IMR : (TIM Offset: N/A) Interrupt Mask Register -------- */
#define TIM_IMR_COVFS (0x1ul << 0) /*(TIM_IMR) Counter Overflow */
#define TIM_IMR_LOVRS (0x1ul << 1) /*(TIM_IMR) Load Overrun */
#define TIM_IMR_CPAS  (0x1ul << 2) /*(TIM_IMR) RA Compare */
#define TIM_IMR_CPBS  (0x1ul << 3) /*(TIM_IMR) RB Compare */
#define TIM_IMR_CPCS  (0x1ul << 4) /*(TIM_IMR) RC Compare */
#define TIM_IMR_LDRAS (0x1ul << 5) /*(TIM_IMR) RA Loading */
#define TIM_IMR_LDRBS (0x1ul << 6) /*(TIM_IMR) RB Loading */
#define TIM_IMR_ETRGS (0x1ul << 7) /*(TIM_IMR) External Trigger */
/* -------- TIM_EMR : (TIM Offset: N/A) Extended Mode Register -------- */
#define TIM_EMR_TRIGSRCA_Pos               0
#define TIM_EMR_TRIGSRCA_Msk              (0x3ul << TIM_EMR_TRIGSRCA_Pos) /*(TIM_EMR) Trigger Source for Input A */
#define TIM_EMR_TRIGSRCA(value)           ((TIM_EMR_TRIGSRCA_Msk & ((value) << TIM_EMR_TRIGSRCA_Pos)))
#define TIM_EMR_TRIGSRCA_EXTERNAL_TIOAx (0x0ul << 0) /*(TIM_EMR) The trigger/capture input A is driven by external pin TIOAx */
#define TIM_EMR_TRIGSRCA_PWMx           (0x1ul << 0) /*(TIM_EMR) The trigger/capture input A is driven internally by PWMx */
#define TIM_EMR_TRIGSRCB_Pos               4
#define TIM_EMR_TRIGSRCB_Msk              (0x3ul << TIM_EMR_TRIGSRCB_Pos) /*(TIM_EMR) Trigger Source for Input B */
#define TIM_EMR_TRIGSRCB(value)           ((TIM_EMR_TRIGSRCB_Msk & ((value) << TIM_EMR_TRIGSRCB_Pos)))
#define TIM_EMR_TRIGSRCB_EXTERNAL_TIOBx (0x0ul << 4) /*(TIM_EMR) The trigger/capture input B is driven by external pin TIOBx */
#define TIM_EMR_TRIGSRCB_PWMx           (0x1ul << 4) /*(TIM_EMR) The trigger/capture input B is driven internally by PWMx */
#define TIM_EMR_NODIVCLK (0x1ul << 8) /*(TIM_EMR) No Divided Clock */
/* -------- TIM_BCR : (TIM Offset: 0xC0) Block Control Register -------- */
#define TIM_BCR_SYNC (0x1ul << 0) /*(TIM_BCR) Synchro Command */
/* -------- TIM_BMR : (TIM Offset: 0xC4) Block Mode Register -------- */
#define TIM_BMR_MAXFILT_Pos     20
#define TIM_BMR_MAXFILT_Msk    (0x3Ful << TIM_BMR_MAXFILT_Pos) /*(TIM_BMR) Maximum Filter */
#define TIM_BMR_MAXFILT(value) ((TIM_BMR_MAXFILT_Msk & ((value) << TIM_BMR_MAXFILT_Pos)))
#define TIM_BMR_MAXCMP_Pos      26 /**< (TIM_BMR) Maximum Consecutive Missing Pulses Position */
#define TIM_BMR_MAXCMP_Msk     (0xFul << TIM_BMR_MAXCMP_Pos) /**< (TIM_BMR) Maximum Consecutive Missing Pulses Mask */
#define TIM_BMR_MAXCMP(value)  (TIM_BMR_MAXCMP_Msk & ((value) << TIM_BMR_MAXCMP_Pos))

/* -------- TIM_QIER : (TIM Offset: 0xC8) QDEC Interrupt Enable Register -------- */
#define TIM_QIER_IDX    (0x1ul << 0) /*(TIM_QIER) Index */
#define TIM_QIER_DIRCHG (0x1ul << 1) /*(TIM_QIER) Direction Change */
#define TIM_QIER_QERR   (0x1ul << 2) /*(TIM_QIER) Quadrature Error */
#define TIM_QIER_MPE    (0x1ul << 3) /*(TIM_QIER) Consecutive Missing Pulse Error */
/* -------- TIM_QIDR : (TIM Offset: 0xCC) QDEC Interrupt Disable Register -------- */
#define TIM_QIDR_IDX    (0x1ul << 0) /*(TIM_QIDR) Index */
#define TIM_QIDR_DIRCHG (0x1ul << 1) /*(TIM_QIDR) Direction Change */
#define TIM_QIDR_QERR   (0x1ul << 2) /*(TIM_QIDR) Quadrature Error */
#define TIM_QIDR_MPE    (0x1ul << 3) /*(TIM_QIDR) Consecutive Missing Pulse Error */
/* -------- TIM_QIMR : (TIM Offset: 0xD0) QDEC Interrupt Mask Register -------- */
#define TIM_QIMR_IDX    (0x1ul << 0) /*(TIM_QIMR) Index */
#define TIM_QIMR_DIRCHG (0x1ul  << 1) /*(TIM_QIMR) Direction Change */
#define TIM_QIMR_QERR   (0x1ul << 2) /*(TIM_QIMR) Quadrature Error */
#define TIM_QIMR_MPE    (0x1ul << 3) /*(TIM_QIMR) Consecutive Missing Pulse Error */
/* -------- TIM_QISR : (TIM Offset: 0xD4) QDEC Interrupt Status Register -------- */
#define TIM_QISR_IDX    (0x1u  << 0) /*(TIM_QISR) Index */
#define TIM_QISR_DIRCHG (0x1ul << 1) /*(TIM_QISR) Direction Change */
#define TIM_QISR_QERR   (0x1ul << 2) /*(TIM_QISR) Quadrature Error */
#define TIM_QISR_DIR    (0x1ul << 8) /*(TIM_QISR) Direction */
#define TIM_QISR_MPE    (0x1ul << 3) /*(TIM_QISR) Consecutive Missing Pulse Error */
/* -------- TIM_WPMR : (TIM Offset: 0xE4) Write Protection Mode Register -------- */
#define TIM_WPMR_WPEN   (0x1ul << 0) /*(TIM_WPMR) Write Protection Enable */
#define TIM_WPMR_WPKEY_Pos     8
#define TIM_WPMR_WPKEY_Msk    (0xFFFFFFul << TIM_WPMR_WPKEY_Pos) /*(TIM_WPMR) Write Protection Key */
#define TIM_WPMR_WPKEY(value) ((TIM_WPMR_WPKEY_Msk & ((value) << TIM_WPMR_WPKEY_Pos)))
#define TIM_WPMR_WPKEY_PASSWD (0x54494Dul << 8) /*(TIM_WPMR) Writing any other value in this field aborts the write operation of the WPEN bit.Always reads as 0. */

typedef enum  /**< \brief Non register operation,only an enumeration variable for TIM_TRGIN Register*/
{
    TIM_TRGIN_TIM0_0_TIOB       = 0,
    TIM_TRGIN_TIM0_0_COMP0_OUT  = 1,
    TIM_TRGIN_TIM0_0_PWM_EVENT1 = 2,
    TIM_TRGIN_TIM0_0_PLU0_OUT   = 3,
} TIM_TRGIN_TIM0_0_TIOB_Enum;

typedef enum /**< \brief Non register operation,only an enumeration variable for TIM_TRGIN Register*/
{
    TIM_TRGIN_TIM0_1_TIOB       = 0,
    TIM_TRGIN_TIM0_1_COMP0_OUT  = 1,
    TIM_TRGIN_TIM0_1_PWM_EVENT2 = 2,
    TIM_TRGIN_TIM0_1_PLU2_OUT   = 3,
} TIM_TRGIN_TIM0_1_TIOB_Enum;

typedef enum /**< \brief Non register operation,only an enumeration variable for TIM_TRGIN Register*/
{
    TIM_TRGIN_TIM0_2_TIM_TIOB   = 0,
    TIM_TRGIN_TIM0_2_COMP0_OUT  = 1,
    TIM_TRGIN_TIM0_2_PWM_EVENT3 = 2,
    TIM_TRGIN_TIM0_2_PLU2_OUT   = 3,
} TIM_TRGIN_TIM0_2_TIOB_Enum;

typedef enum /**< \brief Non register operation,only an enumeration variable for TIM_TRGIN Register*/
{
    TIM_TRGIN_TIM1_0_TIM_TIOB   = 0,
    TIM_TRGIN_TIM1_0_COMP0_OUT  = 1,
    TIM_TRGIN_TIM1_0_PWM_EVENT1 = 2,
    TIM_TRGIN_TIM1_0_PLU0_OUT   = 3,
} TIM_TRGIN_TIM1_0_TIOB_Enum;

typedef enum  /**< \brief Non register operation,only an enumeration variable for TIM_TRGIN Register*/
{
    TIM_TRGIN_TIM1_1_TIM_TIOB   = 0,
    TIM_TRGIN_TIM1_1_COMP0_OUT  = 1,
    TIM_TRGIN_TIM1_1_PWM_EVENT2 = 2,
    TIM_TRGIN_TIM1_1_PLU1_OUT   = 3,
} TIM_TRGIN_TIM1_1_TIOB_Enum;

typedef enum /**< \brief Non register operation,only an enumeration variable for TIM_TRGIN Register*/
{
    TIM_TRGIN_TIM1_2_TIM_TIOB   = 0,
    TIM_TRGIN_TIM1_2_COMP0_OUT  = 1,
    TIM_TRGIN_TIM1_2_PWM_EVENT3 = 2,
    TIM_TRGIN_TIM1_2_PLU2_OUT   = 3,
} TIM_TRGIN_TIM1_2_TIOB_Enum;

typedef enum /**< \brief Non register operation,only an enumeration variable for TIM CHANNEL*/
{
    TIM_CHANNEL0 = 0,
    TIM_CHANNEL1 = 1,
    TIM_CHANNEL2 = 2,
} TIM_CHANNEL_Enum;

typedef enum /**< \brief (TIM_CMRx.TCCLKS) Clock Selection */
{
    TIM_CMR_TIMCLKS_CLK_BUS_DIV2   = (0x0ul << 0),
    TIM_CMR_TIMCLKS_CLK_BUS_DIV8   = (0x1ul << 0),
    TIM_CMR_TIMCLKS_CLK_BUS_DIV32  = (0x2ul << 0),
    TIM_CMR_TIMCLKS_CLK_BUS_DIV128 = (0x3ul << 0),
    TIM_CMR_TIMCLKS_CLK_LRC_32K    = (0x4ul << 0),
    TIM_CMR_TIMCLKS_XC0            = (0x5ul << 0),
    TIM_CMR_TIMCLKS_XC1            = (0x6ul << 0),
    TIM_CMR_TIMCLKS_XC2            = (0x7ul << 0),
} TIM_CMR_TIMCLK_Enum;

typedef enum /**< \brief (TIM_CMRx.CLKI) Clock Invert */
{
    TIM_CMR_CLKI_NOINVERT = 0,
    TIM_CMR_CLKI_INVERT   = (0x1ul << 3),
} TIM_CMR_CLKI_Enum;

typedef enum /**< \brief (TIM_CMRx.BURST) Burst Signal Selection */
{
    TIM_CMR_BURST_NONE = (0x0ul << 4),
    TIM_CMR_BURST_XC0  = (0x1ul << 4),
    TIM_CMR_BURST_XC1  = (0x2ul << 4),
    TIM_CMR_BURST_XC2  = (0x3ul << 4),
} TIM_CMR_BURST_Enum;

typedef enum /**< \brief (TIM_CMRx.LDBSTOP) Counter Clock Stopped with RB Loading */
{
    TIM_CMR_LDBSTOP_DIS = 0,
    TIM_CMR_LDBSTOP     = (0x1ul << 6),
} TIM_CMR_LDBSTOP_Enum;

typedef enum /**< \brief (TIM_CMRx.LDBDIS) Counter Clock Disable with RB Loading */
{
    TIM_CMR_LDBDIS     = (0x1ul << 7),
    TIM_CMR_LDBDIS_DIS = 0,
} TIM_CMR_LDBDIS_Enum;

typedef enum /**< \brief (TIM_CMRx.ETRGEDG) External Trigger Edge Selection */
{
    TIM_CMR_ETRGEDG_NONE    = (0x0ul << 8),
    TIM_CMR_ETRGEDG_RISING  = (0x1ul << 8),
    TIM_CMR_ETRGEDG_FALLING = (0x2ul << 8),
    TIM_CMR_ETRGEDG_EDGE    = (0x3ul << 8),
} TIM_CMR_ETRGEDG_Enum;

typedef enum /**< \brief (TIM_CMRx.ABETRG) TIOAx or TIOBx External Trigger Selection */
{
    TIM_CMR_ABETRG_TIOB = 0,
    TIM_CMR_ABETRG_TIOA = (0x1ul << 10),
} TIM_CMR_ABETRG_Enum;

typedef enum /**< \brief (TIM_CMRx.CPCTRG) RC Compare Trigger Enable */
{
    TIM_CMR_CPCTRG_NONE = 0,
    TIM_CMR_CPCTRG      = (0x1ul << 14),
} TIM_CMR_CPCTRG_Enum;

typedef enum /**< \brief (TIM_CMRx.WAVE) Waveform Mode */
{
    TIM_CMR_CAPTURE_MODE = 0,
    TIM_CMR_WAVE_MODE    = (1ul << 15),
} TIM_CMR_MODE_Enum;

typedef enum /**< \brief (TIM_CMRx.LDRA) RA Loading Edge Selection */
{
    TIM_CMR_LDRA_NONE    = (0x0ul << 16), /* None */
    TIM_CMR_LDRA_RISING  = (0x1ul << 16), /* Rising edge of TIOA */
    TIM_CMR_LDRA_FALLING = (0x2ul << 16), /* Falling edge of TIOA */
    TIM_CMR_LDRA_EDGE    = (0x3ul << 16), /* Each edge of TIOA */
} TIM_CMR_LDRA_Enum;

typedef enum /**< \brief (TIM_CMRx.LDRB) RB Loading Edge Selection */
{
    TIM_CMR_LDRB_NONE    = (0x0ul << 18), /* None */
    TIM_CMR_LDRB_RISING  = (0x1ul << 18), /* Rising edge of TIOA */
    TIM_CMR_LDRB_FALLING = (0x2ul << 18), /* Falling edge of TIOA */
    TIM_CMR_LDRB_EDGE    = (0x3ul << 18), /* Each edge of TIOA */
} TIM_CMR_LDRB_Enum;

typedef enum /**< \brief (TIM_CMRx.SBSMPLR) Loading Edge Subsampling Ratio */
{
    TIM_CMR_SBSMPLR_ONE       = (0x0ul << 20), /* Load a Capture Register each selected edge */
    TIM_CMR_SBSMPLR__HALF     = (0x1ul << 20), /* Load a Capture Register every 2 selected edges */
    TIM_CMR_SBSMPLR_FOURTH    = (0x2ul << 20), /* Load a Capture Register every 4 selected edges */
    TIM_CMR_SBSMPLR_EIGHTH    = (0x3ul << 20), /* Load a Capture Register every 8 selected edges */
    TIM_CMR_SBSMPLR_SIXTEENTH = (0x4ul << 20), /* Load a Capture Register every 16 selected edges */
} TIM_CMR_SBSMPLR_Enum;

typedef enum /**< \brief (TIM_CMRx.CPCSTOP) Counter Clock Stopped with RC Compare */
{
    TIM_CMR_CPCSTOP_NONE = 0,
    TIM_CMR_CPCSTOP      = (0x1ul << 6),
} TIM_CMR_CPCSTOP_Enum;

typedef enum /**< \brief (TIM_CMRx.CPCDIS) Counter Clock Disable with RC Compare */
{
    TIM_CMR_CPCDIS_NONE = 0,
    TIM_CMR_CPCDIS      = (0x1ul << 7),
} TIM_CMR_CPCDIS_Enum;

typedef enum /**< \brief (TIM_CMRx.EEVTEDG) External Event Edge Selection */
{
    TIM_CMR_EEVTEDG_NONE    = (0x0ul << 8),
    TIM_CMR_EEVTEDG_RISING  = (0x1ul << 8),
    TIM_CMR_EEVTEDG_FALLING = (0x2ul << 8),
    TIM_CMR_EEVTEDG_EDGE    = (0x3ul << 8),
} TIM_CMR_EEVTEDG_Enum;

typedef enum /**< \brief (TIM_CMRx.EEVT) External Event Selection */
{
    TIM_CMR_EEVT_TIOB = (0x0ul << 10),
    TIM_CMR_EEVT_XC0  = (0x1ul << 10),
    TIM_CMR_EEVT_XC1  = (0x2ul << 10),
    TIM_CMR_EEVT_XC2  = (0x3ul << 10),
} TIM_CMR_EEVT_Enum;

typedef enum /**< \brief (TIM_CMRx.ENETRG) External Event Trigger Enable */
{
    TIM_CMR_ENETRG_DIS = 0,
    TIM_CMR_ENETRG_EN  = (0x1ul << 12)
} TIM_CMR_ENETRG_Enum;

typedef enum /**< \brief (TIM_CMRx.WAVSEL) Waveform Selection */
{
    TIM_CMR_WAVSEL_UP        = (0x0ul << 13), /* UP mode without automatic trigger on RC Compare */
    TIM_CMR_WAVSEL_UPDOWN    = (0x1ul << 13), /* UPDOWN mode without automatic trigger on RC Compare */
    TIM_CMR_WAVSEL_UP_RC     = (0x2ul << 13), /* UP mode with automatic trigger on RC Compare */
    TIM_CMR_WAVSEL_UPDOWN_RC = (0x3ul << 13), /* UPDOWN mode with automatic trigger on RC Compare */
} TIM_CMR_WAVSEL_Enum;

typedef enum /**< \brief (TIM_CMRx.ACPA) RA Compare Effect on TIOAx */
{
    TIM_CMR_ACPA_NONE   = (0x0ul << 16),
    TIM_CMR_ACPA_SET    = (0x1ul << 16),
    TIM_CMR_ACPA_CLEAR  = (0x2ul << 16),
    TIM_CMR_ACPA_TOGGLE = (0x3ul << 16),
} TIM_CMR_ACPA_Enum;

typedef enum /**< \brief (TIM_CMRx.ACPC) RC Compare Effect on TIOAx */
{
    TIM_CMR_ACPC_NONE   = (0x0ul << 18),
    TIM_CMR_ACPC_SET    = (0x1ul << 18),
    TIM_CMR_ACPC_CLEAR  = (0x2ul << 18),
    TIM_CMR_ACPC_TOGGLE = (0x3ul << 18),
} TIM_CMR_ACPC_Enum;

typedef enum /**< \brief (TIM_CMRx.AEEVT) External Event Effect on TIOAx */
{
    TIM_CMR_AEEVT_NONE   = (0x0ul << 20),
    TIM_CMR_AEEVT_SET    = (0x1ul << 20),
    TIM_CMR_AEEVT_CLEAR  = (0x2ul << 20),
    TIM_CMR_AEEVT_TOGGLE = (0x3ul << 20),
} TIM_CMR_AEEVT_Enum;

typedef enum /**< \brief (TIM_CMRx.ASWTRG) Software Trigger Effect on TIOAx */
{
    TIM_CMR_ASWTRG_NONE   = (0x0ul << 22),
    TIM_CMR_ASWTRG_SET    = (0x1ul << 22),
    TIM_CMR_ASWTRG_CLEAR  = (0x2ul << 22),
    TIM_CMR_ASWTRG_TOGGLE = (0x3ul << 22),
} TIM_CMR_ASWTRG_Enum;

typedef enum /**< \brief (TIM_CMRx.BCPB) RB Compare Effect on TIOBx */
{
    TIM_CMR_BCPB_NONE   = (0x0ul << 24),
    TIM_CMR_BCPB_SET    = (0x1ul << 24),
    TIM_CMR_BCPB_CLEAR  = (0x2ul << 24),
    TIM_CMR_BCPB_TOGGLE = (0x3ul << 24),
} TIM_CMR_BCPB_Enum;

typedef enum /**< \brief (TIM_CMRx.BCPC) RC Compare Effect on TIOBx */
{
    TIM_CMR_BCPC_NONE   = (0x0ul << 26),
    TIM_CMR_BCPC_SET    = (0x1ul << 26),
    TIM_CMR_BCPC_CLEAR  = (0x2ul << 26),
    TIM_CMR_BCPC_TOGGLE = (0x3ul << 26),
} TIM_CMR_BCPC_Enum;

typedef enum /**< \brief (TIM_CMRx.BEEVT) External Event Effect on TIOBx */
{
    TIM_CMR_BEEVT_NONE   = (0x0ul << 28),
    TIM_CMR_BEEVT_SET    = (0x1ul << 28),
    TIM_CMR_BEEVT_CLEAR  = (0x2ul << 28),
    TIM_CMR_BEEVT_TOGGLE = (0x3ul << 28),
} TIM_CMR_BEEVT_Enum;

typedef enum /**< \brief (TIM_BMRx.TC0XC0S)  External Clock Signal 0 Selection */
{
    TIM_BMR_TIM0XC0S_TCLK0 = (0x0ul << 0), /* Signal connected to XC0: TCLK0 */
    TIM_BMR_TIM0XC0S_TIOA1 = (0x2ul << 0), /* Signal connected to XC0: TIOA1 */
    TIM_BMR_TIM0XC0S_TIOA2 = (0x3ul << 0), /* Signal connected to XC0: TIOA2 */
} TIM_BMR_TIM0XC0S_Enum;

typedef enum /**< \brief (TIM_BMRx.TC1XC1S)  External Clock Signal 1 Selection */
{
    TIM_BMR_TIM1XC1S_TCLK1 = (0x0ul << 2), /* Signal connected to XC1: TCLK1 */
    TIM_BMR_TIM1XC1S_TIOA0 = (0x2ul << 2), /* Signal connected to XC1: TIOA0 */
    TIM_BMR_TIM1XC1S_TIOA2 = (0x3ul << 2), /* Signal connected to XC1: TIOA2 */
} TIM_BMR_TIM1XC1S_Enum;

typedef enum /**< \brief (TIM_BMRx.TC2XC2S)  External Clock Signal 2 Selection */
{
    TIM_BMR_TIM2XC2S_TCLK2 = (0x0ul << 4), /* Signal connected to XC2: TCLK2 */
    TIM_BMR_TIM2XC2S_TIOA0 = (0x2ul << 4), /* Signal connected to XC2: TIOA0 */
    TIM_BMR_TIM2XC2S_TIOA1  = (0x3ul << 4), /* Signal connected to XC2: TIOA1 */
} TIM_BMR_TIM2XC2S_Enum;

typedef enum /**< \brief (TIM_BMRx.QDEN)  Quadrature Decoder Enabled */
{
    TIM_BMR_QDEN_DIS = 0,
    TIM_BMR_QDEN     = (0x1ul << 8),
} TIM_BMR_QDEN_Enum;

typedef enum /**< \brief (TIM_BMRx.POSEN) Position Enabled */
{
    TIM_BMR_POSEN_DIS = 0,
    TIM_BMR_POSEN     = (0x1ul << 9),
} TIM_BMR_POSEN_Enum;

typedef enum /**< \brief (TIM_BMRx.SPEEDEN) Speed Enabled */
{
    TIM_BMR_SPEEDEN_DIS = 0,
    TIM_BMR_SPEEDEN     = (0x1ul << 10),
} TIM_BMR_SPEEDEN_Enum;

typedef enum /**< \brief (TIM_BMRx.QDTRANS) Quadrature Decoding Transparent */
{
    TIM_BMR_QDTRANS_INACTIVE = 0,
    TIM_BMR_QDTRANS_ACTIVE   = (0x1ul << 11), /*(TIM_BMR) Quadrature Decoding Transparent */
} TIM_BMR_QDTRANS_Enum;

typedef enum /**< \brief (TIM_BMRx.EDGPHA) Edge on PHA Count Mode */
{
    TIM_BMR_EDGPHA     = 0,
    TIM_BMR_EDGPHA_PHB = (0x1ul << 12),
} TIM_BMR_EDGPHA_Enum;

typedef enum /**< \brief (TIM_BMRx.INVA) Inverted PHA */
{
    TIM_BMR_INVA_NONE = 0,
    TIM_BMR_INVA      = (0x1ul << 13),
} TIM_BMR_INVA_Enum;

typedef enum /**< \brief (TIM_BMRx.INVB) Inverted PHB */
{
    E_TIM_BMR_INVB_NONE = 0,
    TIM_BMR_INVB        = (0x1ul << 14),
} TIM_BMR_INVB_Enum;

typedef enum /**< \brief (TIM_BMRx.INVIDX) Inverted Index */
{
    TIM_BMR_INVIDX_NONE = 0,
    TIM_BMR_INVIDX      = (0x1ul << 15),
} TIM_BMR_INVIDX_Enum;

typedef enum /**< \brief (TIM_BMRx.SWAP) Swap PHA and PHB */
{
    TIM_BMR_SWAP_NONE    = 0,
    TIM_BMR_SWAP         = (0x1ul << 16),
} TIM_BMR_SWAP_Enum;

typedef enum /**< \brief (TIM_BMRx.IDXPHB) Index Pin is PHB Pin */
{
    TIM_BMR_IDXPHA = 0,
    TIM_BMR_IDXPHB = (0x1ul << 17),
} TIM_BMR_IDXPHB_Enum;

typedef enum /**< \brief (TIM_BMRx.AUTOC) AutoCorrection of missing pulses */
{
    TIM_BMR_AUTOC_DIS = 0,
    TIM_BMR_AUTOC     = (0x1ul << 18),
} TIM_BMR_AUTOC_Enum;

typedef enum /**< \brief (TIM_FMRx.ENCF0) Enable Compare Fault Channel 0 */
{
    TIM_FMR_ENCF0_DIS = 0,
    TIM_FMR_ENCF0     = (0x1ul << 0),
} TIM_FMR_ENCF0_Enum;

typedef enum /**< \brief (TIM_FMRx.ENCF1) Enable Compare Fault Channel 1 */
{
    TIM_FMR_ENCF1_DIS = 0,
    TIM_FMR_ENCF1     = (0x1ul << 1),
} TIM_FMR_ENCF1_Enum;

typedef struct
{
    TIM_CHANNEL_Enum     CHANNEL;
    TIM_CMR_TIMCLK_Enum  TIMCLKS;
    TIM_CMR_CLKI_Enum    CLKI;
    TIM_CMR_BURST_Enum   BURST;
    TIM_CMR_LDBSTOP_Enum LDBSTOP;
    TIM_CMR_LDBDIS_Enum  LDBDIS;
    TIM_CMR_ETRGEDG_Enum ETRGEDG;
    TIM_CMR_ABETRG_Enum  ABETRG;
    TIM_CMR_MODE_Enum    WAVE;
    TIM_CMR_CPCTRG_Enum  CPCTRG;
    TIM_CMR_LDRA_Enum    LDRA;
    TIM_CMR_LDRB_Enum    LDRB;
    TIM_CMR_SBSMPLR_Enum SBSMPL;
} TIM_CMR_Capture_T;

typedef struct
{
    TIM_CHANNEL_Enum     CHANNEL;
    TIM_CMR_TIMCLK_Enum  TIMCLKS;
    TIM_CMR_CLKI_Enum    CLKI;
    TIM_CMR_BURST_Enum   BURST;
    TIM_CMR_CPCSTOP_Enum CPCSTOP;
    TIM_CMR_CPCDIS_Enum  CPCDIS;
    TIM_CMR_EEVTEDG_Enum EEVTEDG;
    TIM_CMR_EEVT_Enum    EEVT;
    TIM_CMR_ENETRG_Enum  ENETRG;
    TIM_CMR_WAVSEL_Enum  WAVSEL;
    TIM_CMR_MODE_Enum    WAVE;
    TIM_CMR_ACPA_Enum    ACPA;
    TIM_CMR_ACPC_Enum    ACPC;
    TIM_CMR_AEEVT_Enum   AEEVT;
    TIM_CMR_ASWTRG_Enum  ASWTRG;
    TIM_CMR_BCPB_Enum    BCPB;
    TIM_CMR_BCPC_Enum    BCPC;
    TIM_CMR_BEEVT_Enum   BEEVT;
    uint32_t             BSWTRG;
} TIM_CMR_Wave_T;

typedef struct
{
    TIM_BMR_TIM0XC0S_Enum TIM0XC0S;
    TIM_BMR_TIM1XC1S_Enum TIM1XC1S;
    TIM_BMR_TIM2XC2S_Enum TIM2XC2S;
    TIM_BMR_QDEN_Enum     QDEN;
    TIM_BMR_POSEN_Enum    POSEN;
    TIM_BMR_SPEEDEN_Enum  SPEEDEN;
    TIM_BMR_QDTRANS_Enum  QDTRANS;
    TIM_BMR_EDGPHA_Enum   EDGPHA;
    TIM_BMR_INVA_Enum     INVA;
    TIM_BMR_INVB_Enum     INVB;
    TIM_BMR_INVIDX_Enum   INVIDX;
    TIM_BMR_SWAP_Enum     SWAP;
    TIM_BMR_IDXPHB_Enum   IDXPHB;
    TIM_BMR_AUTOC_Enum    AUTOC;
    uint32_t              MAXFILT;
    uint32_t              MAXCMP;
} TIM_BMR_T;

ErrorStatus TIM_CaptureInit(TIM_Type *TIMx, TIM_CMR_Capture_T *TIM_CMR_CaptureConfig);
ErrorStatus TIM_WaveInit(TIM_Type *TIMx, TIM_CMR_Wave_T *TIM_CMR_WaveConfig);
void TIM0_0_SetTriggerInput(TIM_TRGIN_TIM0_0_TIOB_Enum Trginput);
void TIM0_1_SetTriggerInput(TIM_TRGIN_TIM0_1_TIOB_Enum Trginput);
void TIM0_2_SetTriggerInput(TIM_TRGIN_TIM0_2_TIOB_Enum Trginput);
void TIM1_0_SetTriggerInput(TIM_TRGIN_TIM1_0_TIOB_Enum Trginput);
void TIM1_1_SetTriggerInput(TIM_TRGIN_TIM1_1_TIOB_Enum Trginput);
void TIM1_2_SetTriggerInput(TIM_TRGIN_TIM1_2_TIOB_Enum Trginput);
void TIM_Sync_Trigger(TIM_Type *TIMx);
ErrorStatus TIM_SetBlockMode(TIM_Type *TIMx, TIM_BMR_T *TIM_BMR_QdecConfig);
void TIM_Start(TIM_Type *TIMx, TIM_CHANNEL_Enum TIM_CHANNEL);
void TIM_ClockEnable(TIM_Type *TIMx, TIM_CHANNEL_Enum TIM_CHANNEL);
void TIM_Swtrg(TIM_Type *TIMx, TIM_CHANNEL_Enum TIM_CHANNEL);
void TIM_Stop(TIM_Type *TIMx, TIM_CHANNEL_Enum TIM_CHANNEL);
uint32_t TIM_Read_CV(TIM_Type *TIMx, TIM_CHANNEL_Enum TIM_CHANNEL);
uint32_t TIM_Read_RA(TIM_Type *TIMx, TIM_CHANNEL_Enum TIM_CHANNEL);
uint32_t TIM_Read_RB(TIM_Type *TIMx, TIM_CHANNEL_Enum TIM_CHANNEL);
uint32_t TIM_Read_RC(TIM_Type *TIMx, TIM_CHANNEL_Enum TIM_CHANNEL);
void TIM_Write_RA(TIM_Type *TIMx, TIM_CHANNEL_Enum TIM_CHANNEL, uint32_t ul_value);
void TIM_Write_RB(TIM_Type *TIMx, TIM_CHANNEL_Enum TIM_CHANNEL, uint32_t ul_value);
void TIM_Write_RC(TIM_Type *TIMx, TIM_CHANNEL_Enum TIM_CHANNEL, uint32_t ul_value);
void TIM_Enable_IT(TIM_Type *TIMx, TIM_CHANNEL_Enum TIM_CHANNEL, uint32_t ul_sources);
void TIM_Disable_IT(TIM_Type *TIMx, TIM_CHANNEL_Enum TIM_CHANNEL, uint32_t ul_sources);
uint32_t TIM_Get_IT_Mask(TIM_Type *TIMx, TIM_CHANNEL_Enum TIM_CHANNEL);
uint32_t TIM_Get_Status(TIM_Type *TIMx, TIM_CHANNEL_Enum TIM_CHANNEL);
void TIM_Qdec_Enable_IT(TIM_Type *TIMx, uint32_t ul_sources);
void TIM_Qdec_Disable_IT(TIM_Type *TIMx, uint32_t ul_sources);
uint32_t TIM_GetQdec_IT_Mask(TIM_Type *TIMx);
uint32_t TIM_GetQdec_IT_Status(TIM_Type *TIMx);
void TIM_SetFaultMode(TIM_Type *TIMx, uint32_t ul_faultmode);
void TIM_SetWriteProtect(TIM_Type *TIMx, uint32_t ul_enable);

#ifdef __cplusplus
}
#endif

#endif /* MS60F3XXX_TIM_H */

