/**
  ******************************************************************************
  * @file           : ms60f3xxx_dac.c
  * @author         : sinomcu.com-SA
  * @brief          : DAC module driver.
  * @gcc            : toolchain version 5 or 6
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with 
  * basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */

#include "ms60f3xxx_dac.h"
#include "ms60f3xxx_scu.h"
#include "ms60f3xxx_gpio.h"

/**
  * @brief  Initializes the DACx peripheral according to the specified parameters
  *         in the DAC_InitStruct.
  * @param  DACx: where x can be 0, 1, 2 or 3  to select the DAC peripheral.
  * @param  DAC_InitStruct: pointer to an DAC_InitTypeDef structure that contains
  *         the configuration information for the specified DAC peripheral.
  * @retval None
  */
void DAC_INIT(DAC_Type *dac, DAC_Init_T *dac_init)
{
    uint32_t temp = 0;
    SCU_Unlock();
    if(dac == DAC0)
    {
        SCU_PeriphClockCmd(SCU_DAC0_CLKEN | SCU_GPIOB_CLKEN, ENABLE);
        GPIO_Init(GPIOB, GPIO_PIN9, GPIO_MODE_ANALOG);
    }
    else if(dac == DAC1)
    {
        SCU_PeriphClockCmd(SCU_DAC1_CLKEN | SCU_GPIOB_CLKEN, ENABLE);
        GPIO_Init(GPIOB, GPIO_PIN10, GPIO_MODE_ANALOG);
    }
    else if(dac == DAC2)
    {
        SCU_PeriphClockCmd(SCU_DAC2_CLKEN | SCU_GPIOB_CLKEN, ENABLE);
        GPIO_Init(GPIOB, GPIO_PIN7, GPIO_MODE_ANALOG);
    }
    else
    {
        SCU_PeriphClockCmd(SCU_DAC3_CLKEN | SCU_GPIOB_CLKEN, ENABLE);
        GPIO_Init(GPIOB, GPIO_PIN8, GPIO_MODE_ANALOG);
    }

    temp = dac_init->dac_ref + dac_init->dac_lign;
    dac->CR2 = temp;
    temp = 0;
    temp = dac_init->dac_tsel + dac_init->dac_ten + dac_init->dac_en;

    if(dac_init->dac_tsel == DAC_SOFT_SEL)
    {
        dac->SOFTTRGR = 1;
    }

    dac->CR1 = temp;
    SCU_Lock();
}

/**
  * @brief  Set the values that DAC needs to convert.
  * @param  DACx: where x can be 0, 1, 2 or 3  to select the DAC peripheral.
  * @param  value: Value to be converted
            This parameter must be a 12bit value.
  * @retval None
  */
void DAC_LOAD(DAC_Type *dac, uint16_t value)
{
    dac->DHR = value;
    dac->CR1_b.TEN = 0;
    dac->CR1_b.TEN = 1;
    dac->SOFTTRGR = 1;
}







