/**
  ******************************************************************************
  * @file           : ms60f3xxx_exti.c
  * @author         : sinomcu.com-SA
  * @brief          : This file provides all the exti firmware functions.
  * @gcc            : toolchain version 5 or 6
  *
  ******************************************************************************
  * @attention
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with
	* basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */
#include "ms60f3xxx_exti.h"
/**
  * @brief  Enable ExtiLine Interrupt request for Lines in range 0 to 15
  * @param  ExtiLine This parameter can be one of the following values:
  *         @arg @ref EXTI_LINE0
  *         @arg @ref EXTI_LINE1
  *         @arg @ref EXTI_LINE2
  *         @arg @ref EXTI_LINE3
  *         @arg @ref EXTI_LINE4
  *         @arg @ref EXTI_LINE5
  *         @arg @ref EXTI_LINE6
  *         @arg @ref EXTI_LINE7
  *         @arg @ref EXTI_LINE8
  *         @arg @ref EXTI_LINE9
  *         @arg @ref EXTI_LINE10
  *         @arg @ref EXTI_LINE11
  *         @arg @ref EXTI_LINE12
  *         @arg @ref EXTI_LINE13
  *         @arg @ref EXTI_LINE14
  *         @arg @ref EXTI_LINE15
  *         @arg @ref EXTI_LINE_ALL
  * @retval None
  */
void EXTI_Enable_IT(EXTI_Line_Enum ExtiLine)
{
    SET_BIT(EXTI->IER, ExtiLine);

}
/**
  * @brief  Disable ExtiLine Interrupt request for Lines in range 0 to 15
  * @param  ExtiLine This parameter can be one of the following values:
  *         @arg @ref EXTI_LINE0
  *         @arg @ref EXTI_LINE1
  *         @arg @ref EXTI_LINE2
  *         @arg @ref EXTI_LINE3
  *         @arg @ref EXTI_LINE4
  *         @arg @ref EXTI_LINE5
  *         @arg @ref EXTI_LINE6
  *         @arg @ref EXTI_LINE7
  *         @arg @ref EXTI_LINE8
  *         @arg @ref EXTI_LINE9
  *         @arg @ref EXTI_LINE10
  *         @arg @ref EXTI_LINE11
  *         @arg @ref EXTI_LINE12
  *         @arg @ref EXTI_LINE13
  *         @arg @ref EXTI_LINE14
  *         @arg @ref EXTI_LINE15
  *         @arg @ref EXTI_LINE_ALL
  * @note   Please check each device line mapping for EXTI Line availability
  * @retval None
  */
void EXTI_Disable_IT(EXTI_Line_Enum ExtiLine)
{
    SET_BIT(EXTI->IDR, ExtiLine);
}
/**
  * @brief  Indicate if ExtiLine Interrupt request is enabled for Lines in range 0 to 15
  * @param  ExtiLine This parameter can be one of the following values:
  *         @arg @ref EXTI_LINE0
  *         @arg @ref EXTI_LINE1
  *         @arg @ref EXTI_LINE2
  *         @arg @ref EXTI_LINE3
  *         @arg @ref EXTI_LINE4
  *         @arg @ref EXTI_LINE5
  *         @arg @ref EXTI_LINE6
  *         @arg @ref EXTI_LINE7
  *         @arg @ref EXTI_LINE8
  *         @arg @ref EXTI_LINE9
  *         @arg @ref EXTI_LINE10
  *         @arg @ref EXTI_LINE11
  *         @arg @ref EXTI_LINE12
  *         @arg @ref EXTI_LINE13
  *         @arg @ref EXTI_LINE14
  *         @arg @ref EXTI_LINE15
  * @retval State of bit (1 or 0).
  */
uint32_t EXTI_IsEnabled_IT(EXTI_Line_Enum ExtiLine)
{
    return ((READ_BIT(EXTI->IMR, ExtiLine) == (ExtiLine)) ? 1UL : 0UL);
}
/**
  * @brief  Enable ExtiLine Event request for Lines in range 0 to 15
  * @param  ExtiLine This parameter can be one of the following values:
  *         @arg @ref EXTI_LINE0
  *         @arg @ref EXTI_LINE1
  *         @arg @ref EXTI_LINE2
  *         @arg @ref EXTI_LINE3
  *         @arg @ref EXTI_LINE4
  *         @arg @ref EXTI_LINE5
  *         @arg @ref EXTI_LINE6
  *         @arg @ref EXTI_LINE7
  *         @arg @ref EXTI_LINE8
  *         @arg @ref EXTI_LINE9
  *         @arg @ref EXTI_LINE10
  *         @arg @ref EXTI_LINE11
  *         @arg @ref EXTI_LINE12
  *         @arg @ref EXTI_LINE13
  *         @arg @ref EXTI_LINE14
  *         @arg @ref EXTI_LINE15
  *         @arg @ref EXTI_LINE_ALL
  * @retval None
  */
void EXTI_EnableEvent(EXTI_Line_Enum ExtiLine)
{
    SET_BIT(EXTI->EER, ExtiLine);
}
/**
  * @brief  Disable ExtiLine Event request for Lines in range 0 to 31
  * @param  ExtiLine This parameter can be one of the following values:
  *         @arg @ref EXTI_LINE0
  *         @arg @ref EXTI_LINE1
  *         @arg @ref EXTI_LINE2
  *         @arg @ref EXTI_LINE3
  *         @arg @ref EXTI_LINE4
  *         @arg @ref EXTI_LINE5
  *         @arg @ref EXTI_LINE6
  *         @arg @ref EXTI_LINE7
  *         @arg @ref EXTI_LINE8
  *         @arg @ref EXTI_LINE9
  *         @arg @ref EXTI_LINE10
  *         @arg @ref EXTI_LINE11
  *         @arg @ref EXTI_LINE12
  *         @arg @ref EXTI_LINE13
  *         @arg @ref EXTI_LINE14
  *         @arg @ref EXTI_LINE15
  *         @arg @ref EXTI_LINE_ALL
  * @retval None
  */
void EXTI_DisableEvent(EXTI_Line_Enum ExtiLine)
{
    SET_BIT(EXTI->EDR, ExtiLine);
}
/**
  * @brief  Indicate if ExtiLine Event request is enabled for Lines in range 0 to 31
  *         @arg @ref EXTI_LINE0
  *         @arg @ref EXTI_LINE1
  *         @arg @ref EXTI_LINE2
  *         @arg @ref EXTI_LINE3
  *         @arg @ref EXTI_LINE4
  *         @arg @ref EXTI_LINE5
  *         @arg @ref EXTI_LINE6
  *         @arg @ref EXTI_LINE7
  *         @arg @ref EXTI_LINE8
  *         @arg @ref EXTI_LINE9
  *         @arg @ref EXTI_LINE10
  *         @arg @ref EXTI_LINE11
  *         @arg @ref EXTI_LINE12
  *         @arg @ref EXTI_LINE13
  *         @arg @ref EXTI_LINE14
  *         @arg @ref EXTI_LINE15
  * @retval State of bit (1 or 0).
  */
uint32_t EXTI_IsEnabledEvent(EXTI_Line_Enum ExtiLine)
{
    return ((READ_BIT(EXTI->EMR, ExtiLine) == (ExtiLine)) ? 1UL : 0UL);
}
/**
  * @brief  Enable ExtiLine Rising Edge Trigger for Lines in range 0 to 15
  * @note   The configurable lines are edge-triggered. No glitch must be
  *         generated on these lines. If a Rising edge on a configurable interrupt
  *         line occurs during a write operation in the EXTI_RTSR register, the
  *         pending bit is not set.
  *         Rising and falling edge triggers can be set for the same interrupt line.
  *         In this case, both generate a trigger condition.
  * @param  ExtiLine This parameter can be a combination of the following values:
  *         @arg @ref EXTI_LINE0
  *         @arg @ref EXTI_LINE1
  *         @arg @ref EXTI_LINE2
  *         @arg @ref EXTI_LINE3
  *         @arg @ref EXTI_LINE4
  *         @arg @ref EXTI_LINE5
  *         @arg @ref EXTI_LINE6
  *         @arg @ref EXTI_LINE7
  *         @arg @ref EXTI_LINE8
  *         @arg @ref EXTI_LINE9
  *         @arg @ref EXTI_LINE10
  *         @arg @ref EXTI_LINE11
  *         @arg @ref EXTI_LINE12
  *         @arg @ref EXTI_LINE13
  *         @arg @ref EXTI_LINE14
  *         @arg @ref EXTI_LINE15
  *         @arg @ref EXTI_LINE_ALL
  * @retval None
  */
void EXTI_EnableRisingTrig(EXTI_Line_Enum ExtiLine)
{
    SET_BIT(EXTI->RTSR, ExtiLine);
}
/**
  * @brief  Disable ExtiLine Rising Edge Trigger for Lines in range 0 to 15
  * @note   The configurable lines are edge-triggered. No glitch must be
  *         generated on these lines. If a Rising edge on a configurable interrupt
  *         line occurs during a write operation in the EXTI_RTSR register, the
  *         pending bit is not set.
  *         Rising and falling edge triggers can be set for the same interrupt line.
  *         In this case, both generate a trigger condition.
  * @param  ExtiLine This parameter can be a combination of the following values:
  *         @arg @ref EXTI_LINE0
  *         @arg @ref EXTI_LINE1
  *         @arg @ref EXTI_LINE2
  *         @arg @ref EXTI_LINE3
  *         @arg @ref EXTI_LINE4
  *         @arg @ref EXTI_LINE5
  *         @arg @ref EXTI_LINE6
  *         @arg @ref EXTI_LINE7
  *         @arg @ref EXTI_LINE8
  *         @arg @ref EXTI_LINE9
  *         @arg @ref EXTI_LINE10
  *         @arg @ref EXTI_LINE11
  *         @arg @ref EXTI_LINE12
  *         @arg @ref EXTI_LINE13
  *         @arg @ref EXTI_LINE14
  *         @arg @ref EXTI_LINE15
  *         @arg @ref EXTI_LINE_ALL
  * @retval None
  */
void EXTI_DisableRisingTrig(EXTI_Line_Enum ExtiLine)
{
    CLEAR_BIT(EXTI->RTSR, ExtiLine);
}
/**
  * @brief  Check if rising edge trigger is enabled for Lines in range 0 to 31
  * @param  ExtiLine This parameter can be a combination of the following values:
  *         @arg @ref EXTI_LINE0
  *         @arg @ref EXTI_LINE1
  *         @arg @ref EXTI_LINE2
  *         @arg @ref EXTI_LINE3
  *         @arg @ref EXTI_LINE4
  *         @arg @ref EXTI_LINE5
  *         @arg @ref EXTI_LINE6
  *         @arg @ref EXTI_LINE7
  *         @arg @ref EXTI_LINE8
  *         @arg @ref EXTI_LINE9
  *         @arg @ref EXTI_LINE10
  *         @arg @ref EXTI_LINE11
  *         @arg @ref EXTI_LINE12
  *         @arg @ref EXTI_LINE13
  *         @arg @ref EXTI_LINE14
  *         @arg @ref EXTI_LINE15
  * @retval State of bit (1 or 0).
  */
uint32_t EXTI_IsEnabledRisingTrig(EXTI_Line_Enum ExtiLine)
{
    return ((READ_BIT(EXTI->RTSR, ExtiLine) == (ExtiLine)) ? 1UL : 0UL);
}
/**
  * @brief  Enable ExtiLine falling Edge Trigger for Lines in range 0 to 15
  * @note   The configurable lines are edge-triggered. No glitch must be
  *         generated on these lines. If a Falling edge on a configurable interrupt
  *         line occurs during a write operation in the EXTI_FTSR register, the
  *         pending bit is not set.
  *         Rising and falling edge triggers can be set for the same interrupt line.
  *         In this case, both generate a trigger condition.
  * @param  ExtiLine This parameter can be a combination of the following values:
  *         @arg @ref EXTI_LINE0
  *         @arg @ref EXTI_LINE1
  *         @arg @ref EXTI_LINE2
  *         @arg @ref EXTI_LINE3
  *         @arg @ref EXTI_LINE4
  *         @arg @ref EXTI_LINE5
  *         @arg @ref EXTI_LINE6
  *         @arg @ref EXTI_LINE7
  *         @arg @ref EXTI_LINE8
  *         @arg @ref EXTI_LINE9
  *         @arg @ref EXTI_LINE10
  *         @arg @ref EXTI_LINE11
  *         @arg @ref EXTI_LINE12
  *         @arg @ref EXTI_LINE13
  *         @arg @ref EXTI_LINE14
  *         @arg @ref EXTI_LINE15
  *         @arg @ref EXTI_LINE_ALL
  * @retval None
  */
void EXTI_EnableFisingTrig(EXTI_Line_Enum ExtiLine)
{
    SET_BIT(EXTI->FTSR, ExtiLine);
}
/**
  * @brief  Disable ExtiLine falling Edge Trigger for Lines in range 0 to 15
  * @note   The configurable lines are edge-triggered. No glitch must be
  *         generated on these lines. If a Falling edge on a configurable interrupt
  *         line occurs during a write operation in the EXTI_FTSR register, the
  *         pending bit is not set.
  *         Rising and falling edge triggers can be set for the same interrupt line.
  *         In this case, both generate a trigger condition.
  * @param  ExtiLine This parameter can be a combination of the following values:
  *         @arg @ref EXTI_LINE0
  *         @arg @ref EXTI_LINE1
  *         @arg @ref EXTI_LINE2
  *         @arg @ref EXTI_LINE3
  *         @arg @ref EXTI_LINE4
  *         @arg @ref EXTI_LINE5
  *         @arg @ref EXTI_LINE6
  *         @arg @ref EXTI_LINE7
  *         @arg @ref EXTI_LINE8
  *         @arg @ref EXTI_LINE9
  *         @arg @ref EXTI_LINE10
  *         @arg @ref EXTI_LINE11
  *         @arg @ref EXTI_LINE12
  *         @arg @ref EXTI_LINE13
  *         @arg @ref EXTI_LINE14
  *         @arg @ref EXTI_LINE15
  *         @arg @ref EXTI_LINE_ALL
  * @retval None
  */
void EXTI_DisableFisingTrig(EXTI_Line_Enum ExtiLine)
{
    CLEAR_BIT(EXTI->FTSR, ExtiLine);
}
/**
  * @brief  Check if falling edge trigger is enabled for Lines in range 0 to 31
  * @param  ExtiLine This parameter can be a combination of the following values:
  *         @arg @ref EXTI_LINE0
  *         @arg @ref EXTI_LINE1
  *         @arg @ref EXTI_LINE2
  *         @arg @ref EXTI_LINE3
  *         @arg @ref EXTI_LINE4
  *         @arg @ref EXTI_LINE5
  *         @arg @ref EXTI_LINE6
  *         @arg @ref EXTI_LINE7
  *         @arg @ref EXTI_LINE8
  *         @arg @ref EXTI_LINE9
  *         @arg @ref EXTI_LINE10
  *         @arg @ref EXTI_LINE11
  *         @arg @ref EXTI_LINE12
  *         @arg @ref EXTI_LINE13
  *         @arg @ref EXTI_LINE14
  *         @arg @ref EXTI_LINE15
  * @retval State of bit (1 or 0).
  */
uint32_t EXTI_IsEnabledFallingTrig(EXTI_Line_Enum ExtiLine)
{
    return ((READ_BIT(EXTI->FTSR, ExtiLine) == (ExtiLine)) ? 1UL : 0UL);
}
/**
  * @brief  Generate a software Interrupt Event for Lines in range 0 to 15
  * @note   If the interrupt is enabled on this line in the EXTI_IMR, writing a 1 to
  *         this bit when it is at '0' sets the corresponding pending bit in EXTI_ISR
  *         resulting in an interrupt request generation.
  *         This bit is cleared by clearing the corresponding bit in the EXTI_ISR
  *         register (by writing a 0 into the bit)
  * @param  ExtiLine This parameter can be a combination of the following values:
  *         @arg @ref EXTI_LINE0
  *         @arg @ref EXTI_LINE1
  *         @arg @ref EXTI_LINE2
  *         @arg @ref EXTI_LINE3
  *         @arg @ref EXTI_LINE4
  *         @arg @ref EXTI_LINE5
  *         @arg @ref EXTI_LINE6
  *         @arg @ref EXTI_LINE7
  *         @arg @ref EXTI_LINE8
  *         @arg @ref EXTI_LINE9
  *         @arg @ref EXTI_LINE10
  *         @arg @ref EXTI_LINE11
  *         @arg @ref EXTI_LINE12
  *         @arg @ref EXTI_LINE13
  *         @arg @ref EXTI_LINE14
  *         @arg @ref EXTI_LINE15
  *         @arg @ref EXTI_LINE_ALL
  * @retval None
  */
void EXTI_GenerateSWI(EXTI_Line_Enum ExtiLine)
{
    SET_BIT(EXTI->SWIER, ExtiLine);
}
/**
  * @brief  Check if the ExtLine Flag is set or not for Lines in range 0 to 15
  * @note   This bit is set when the selected edge event arrives on the interrupt
  *         line. This bit is cleared by writing a 0 to the bit.
  * @param  ExtiLine This parameter can be a combination of the following values:
  *         @arg @ref EXTI_LINE0
  *         @arg @ref EXTI_LINE1
  *         @arg @ref EXTI_LINE2
  *         @arg @ref EXTI_LINE3
  *         @arg @ref EXTI_LINE4
  *         @arg @ref EXTI_LINE5
  *         @arg @ref EXTI_LINE6
  *         @arg @ref EXTI_LINE7
  *         @arg @ref EXTI_LINE8
  *         @arg @ref EXTI_LINE9
  *         @arg @ref EXTI_LINE10
  *         @arg @ref EXTI_LINE11
  *         @arg @ref EXTI_LINE12
  *         @arg @ref EXTI_LINE13
  *         @arg @ref EXTI_LINE14
  *         @arg @ref EXTI_LINE15
  * @retval State of bit (1 or 0).
  */
uint32_t EXTI_IsActiveFlag(EXTI_Line_Enum ExtiLine)
{
    return ((READ_BIT(EXTI->ISR, ExtiLine) == (ExtiLine)) ? 1UL : 0UL);
}
/**
  * @brief  Read ExtLine Combination Flag for Lines in range 0 to 15
  * @note   This bit is set when the selected edge event arrives on the interrupt
  *         line. This bit is cleared by writing a 0 to the bit.
  * @param  ExtiLine This parameter can be a combination of the following values:
  *         @arg @ref EXTI_LINE0
  *         @arg @ref EXTI_LINE1
  *         @arg @ref EXTI_LINE2
  *         @arg @ref EXTI_LINE3
  *         @arg @ref EXTI_LINE4
  *         @arg @ref EXTI_LINE5
  *         @arg @ref EXTI_LINE6
  *         @arg @ref EXTI_LINE7
  *         @arg @ref EXTI_LINE8
  *         @arg @ref EXTI_LINE9
  *         @arg @ref EXTI_LINE10
  *         @arg @ref EXTI_LINE11
  *         @arg @ref EXTI_LINE12
  *         @arg @ref EXTI_LINE13
  *         @arg @ref EXTI_LINE14
  *         @arg @ref EXTI_LINE15
  *         @arg @ref EXTI_LINE_ALL
  * @retval This bit is set when the selected edge event arrives on the interrupt
  */
uint32_t EXTI_ReadFlag(EXTI_Line_Enum ExtiLine)
{
    return (uint32_t)(READ_BIT(EXTI->ISR, ExtiLine));
}
/**
  * @brief  Clear ExtLine Flags  for Lines in range 0 to 15
  * @note   This bit is set when the selected edge event arrives on the interrupt
  *         line. This bit is cleared by writing a 0 to the bit.
  * @param  ExtiLine This parameter can be a combination of the following values:
  *         @arg @ref EXTI_LINE0
  *         @arg @ref EXTI_LINE1
  *         @arg @ref EXTI_LINE2
  *         @arg @ref EXTI_LINE3
  *         @arg @ref EXTI_LINE4
  *         @arg @ref EXTI_LINE5
  *         @arg @ref EXTI_LINE6
  *         @arg @ref EXTI_LINE7
  *         @arg @ref EXTI_LINE8
  *         @arg @ref EXTI_LINE9
  *         @arg @ref EXTI_LINE10
  *         @arg @ref EXTI_LINE11
  *         @arg @ref EXTI_LINE12
  *         @arg @ref EXTI_LINE13
  *         @arg @ref EXTI_LINE14
  *         @arg @ref EXTI_LINE15
	*         @arg @ref EXTI_LINE_ALL
  * @retval None
  */
void EXTI_ClearFlag(EXTI_Line_Enum ExtiLine)
{
    CLEAR_BIT(EXTI->ISR, ExtiLine);
}
/**
  * @brief  Deinitializes the EXTI peripheral registers to their default reset
  *         values.
  * @param  None
  * @retval None
  */
void EXTI_DeInit(void)
{
    EXTI->IDR    = 0x0000FFFF;
    EXTI->EDR    = 0x0000FFFF;
    EXTI->RTSR   = 0x00000000;
    EXTI->FTSR   = 0x00000000;
    EXTI->SWIER  = 0x00000000;
    EXTI->ISR    = 0x00000000;
}

/**
  * @brief  Initializes the EXTI peripheral according to the specified
  *         parameters in the EXTI_InitStruct.
  *         EXTI_Line specifies the EXTI line (EXTI0....EXTI15).
  *         EXTI_Mode specifies which EXTI line is used as interrupt or an event.
  *         EXTI_Trigger selects the trigger. When the trigger occurs, interrupt
  *         pending bit will be set.
  *         EXTI_LineCmd controls (Enable/Disable) the EXTI line.
  * @param  EXTI_InitStruct: pointer to a EXTI_InitTypeDef structure that
  *         contains the configuration information for the EXTI peripheral.
  * @retval None
  */
void EXTI_Init(EXTI_Init_T* EXTI_InitStruct)
{
    uint32_t Line_Pos = 0;
    EXTI_DeInit();

    if (EXTI_InitStruct->LineCmd != DISABLE)
    {
        switch( EXTI_InitStruct->Trigger )/*Set trigger mode.*/
        {
            case EXTI_Trigger_NO:
                break;

            case EXTI_Trigger_Rising:
                EXTI->RTSR |=  EXTI_InitStruct->EXTI_Line; /*Both edge trigger mode disable*/
                EXTI->FTSR &= ~EXTI_InitStruct->EXTI_Line; /*Polarity set as positive.*/
                break;

            case EXTI_Trigger_Falling:
                EXTI->RTSR &= ~EXTI_InitStruct->EXTI_Line; /*Both edge trigger mode disable*/
                EXTI->FTSR |= EXTI_InitStruct->EXTI_Line;
                break;

            case EXTI_Trigger_Bothedging:
                EXTI->RTSR |=  EXTI_InitStruct->EXTI_Line; /*Both edge trigger mode disable*/
                EXTI->FTSR |=  EXTI_InitStruct->EXTI_Line ;
                break;
        }

        for(Line_Pos = 0; Line_Pos <= 15; Line_Pos++)
        {
            if((EXTI_InitStruct->EXTI_Line >> Line_Pos) == EXTI_LINE0)
                break;
        }

        /* Set EXTI Interrupt/Event Pins */
        if(EXTI_InitStruct->EXTI_Line <= EXTI_LINE7)
        {

            EXTI->CFGR1 &= ~(EXTI_CFGR1_EXTI0 << (Line_Pos * 3));
            EXTI->CFGR1 |= ((uint32_t)EXTI_InitStruct->GPIO_GPOUP) << (Line_Pos * 3);
        }
        else
        {
            EXTI->CFGR2 &= ~(EXTI_CFGR2_EXTI8 << ((Line_Pos - EXTI_CFGR2_EXTI8 - 1) * 3));
            EXTI->CFGR2 |= ((uint32_t)EXTI_InitStruct->GPIO_GPOUP) << ((Line_Pos - EXTI_CFGR2_EXTI8 - 1) * 3);
        }

        if(EXTI_InitStruct->Mode == EXTI_Event_Mode)
        {
					EXTI_EnableEvent(EXTI_InitStruct->EXTI_Line);
        }
        else if(EXTI_InitStruct->Mode == EXTI_Interrupt_Mode)
        {
					EXTI_Enable_IT(EXTI_InitStruct->EXTI_Line);
					
        }
        else if(EXTI_InitStruct->Mode == EXTI_EventAndInterrupt_Mode)
        {
					EXTI_EnableEvent(EXTI_InitStruct->EXTI_Line);
					EXTI_Enable_IT(EXTI_InitStruct->EXTI_Line);
        }

    }
}

