/**
  ******************************************************************************
  * @file           : ms60f3xxx_lptimer.c
  * @author         : sinomcu.com-SA
  * @brief          : lptimer module driver.
  * @gcc            : toolchain version 5 or 6
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with 
  * basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */ 
	
#include "ms60f3xxx_scu.h"
#include "ms60f3xxx_lptimer.h"

/***
* @brief  Enable the interrupt of Lptimer.
* @param  None.
* @retval None.
*/
void LPTIMER_Enable_IT(void)
{
	 LPTIMER->IER = 1;
}

/***
* @brief  Disable the interrupt of Lptimer.
* @param  None.
* @retval None.
*/
void LPTIMER_Disable_IT(void)
{
	 LPTIMER->IDR = 1;  
}

/**
  * @brief  Lptimer enable.
  * @param  None.
  * @retval None.
  */
void LPTIMER_Enable(void)
{
	  int i = 0,j = 0 ;
    LPTIMER->EN = LPTIMER_ENABLE;
    for( i = 0; i < 72; i++) {
			  for( j = 0; j < 72; j++) {
					__NOP();
				}
		}
}
/**
  * @brief  Lptimer disable.
  * @param  None.
  * @retval None.
  */
void LPTIMER_Disable(void)
{
	  int i = 0,j = 0 ;
    LPTIMER->EN = LPTIMER_DISABLE;
    for( i = 0; i < 72; i++) {
			  for( j = 0; j < 72; j++) {
					__NOP();
				}
		}
}

/***
  * @brief  LPTIMER_Init low power timer init .
  * @param  lp_init: pointer to a LPTIMER_INIT_T structure that contains
  * 			    the configuration information for LPTIMER.
  * @retval None
  */
void LPTIMER_Init(LPTIMER_INIT_T *lp_init)
{
    uint32_t  value = 0;
    if(LPTIMER->EN)
        LPTIMER_Disable();

    if(lp_init->lp_enable == LPTIMER_DISABLE)
        return;
    if(lp_init->clkselect == LXTAL_32K) {
        SCU_Unlock();
        SCU->CLK_SEL_CR_b.LPT_CLK_SEL = LXTAL_32K;
    }
		else {
		    SCU_Unlock();
        SCU->CLK_SEL_CR_b.LPT_CLK_SEL = LRC_32K;
		}
		
    value       += lp_init->mode;
    value       += lp_init->clock_div;
    LPTIMER->CR  = value;
    LPTIMER->ARR = lp_init->arr_value;
    LPTIMER->EN  = lp_init->lp_enable;
    LPTIMER->STR = LPTIMER_STR_SOFT_TRIG_ENALBE;
}
