/**
  ******************************************************************************
  * @file           : ms60f3xxx_pga.c
  * @author         : sinomcu.com-SA
  * @brief          : pga module driver.
  * @gcc            : toolchain version 5 or 6
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with 
  * basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */
#include "ms60f3xxx.h"
#include "ms60f3xxx_gpio.h"
#include "ms60f3xxx_pga.h"

/**
  * @brief  Initializes the PGA peripheral according to the specified parameters
  *         in the PGA_Init_T.
  * @param  pga: pointer to an PGA_Init_T structure that contains
  *         the configuration information for the specified PGA peripheral.
  * @retval None
  */
void PGA_Init(PGA_Init_T* pga)
{
    PGA->CHSEL |= pga->CHP;
    PGA->GAIN |= pga->GAIN;

    if(pga->PGA_EN == PGA0_EN_ENABLE)
    {
        PGA->MODE |= pga->PGA_EN | pga->PGA_MODE;
        pga->PGA_EN = PGA0_EN_ENABLE;
    }
    else if(pga->PGA_EN == PGA1_EN_ENABLE)
    {
        PGA->MODE |= pga->PGA_EN;
        PGA->MODE |= ((uint32_t)pga->PGA_MODE << 3);
        pga->PGA_EN = PGA1_EN_ENABLE;
    }
}

