/**
  ******************************************************************************
  * @file           : ms60f3xxx_wwdg.c
  * @author         : sinomcu.com-SA
  * @brief          : wwdg module driver.
  * @gcc            : toolchain version 5 or 6
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with 
  * basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */

#include "ms60f3xxx_wwdg.h"
#include "ms60f3xxx.h"
#include "ms60f3xxx_scu.h"
//#define __WWDG_INT_ENABLE 1


/**
  * @brief   Enables WWDG and load the counter value.
  * @param   Counter: specifies the window watchdog counter value.
  *          This parameter must be a number between 0x40 and 0x7f
    *@param  WWDG_DIV_enum: system clock div as window watch dog clock.

  * @retval None
  * @conditon Please refer to the user manual for the specific calculation formula
  */
void WWDG_Init(WWDG_DIV_Enum div, uint8_t Counter)
{
    SCU_PeriphClockCmd(SCU_WWDG_CLKEN, ENABLE);
    WWDG->CFR &= (~0x007F);
    WWDG->CFR |= Counter;
    WWDG->CFR &= (~0x0380);
    WWDG->CFR |= div;
    WWDG->CR = 0xFF; /*enable wwdt*/

    #ifdef __WWDG_INT_ENABLE
    WWDG->IER = 1;
    NVIC_EnableIRQ(WWDG_IRQn);
    #else
    WWDG->IDR = 1;
    #endif
}

/**
  * @brief  Reloads WWDG counter with value defined in the reload registerfeed dog
  * @param  None
  * @retval None
  */
void WWDG_ReloadCounter(void)
{
    if(WWDG->CR_b.T > 0x3F && WWDG->CR_b.T < WWDG->CFR_b.W )
    {
       
        WWDG->CR = 0xFF;
    }
}
