/**
  ******************************************************************************
  * @file           : main.c
  * @author         : sinomcu.com-SA
  * @brief          : MAIN module driver.
  * @gcc            : toolchain version 5 or 6
  *
  ******************************************************************************
  * @attention
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with
  * basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */
#include "include.h"
#include "systick.h"

void COMP_init(void);

/**
 * @brief   Main Configuration Function
 * @param   None
 * @retval  None
 */
int	main()
{
    /*set system clock*/
    SCU_SetSysClock(CLK_PLL_USE_HRC_LRC, HRC_16M, NO_XTAL, PLL_72M, SCU_SYS_Div1);
    delay_init();
    COMP_init();
    while(1)
    {
        delay_ms(1000);
    }
}

/**
  * @brief  COMP0 Compare Input Ends Values 
	* 				GPIOB_PIN4 Output COMP0 results
  * @param  None
  * @retval None
  */
void COMP_init(void)
{
    COMP_Init_T  COMP_InitStruct = {0};/*Initialize Structure*/

    SCU_PeriphClockCmd(SCU_COMP_CLKEN | SCU_GPIOB_CLKEN, ENABLE);

    GPIO_Init(GPIOB, GPIO_PIN3, GPIO_MODE_ANALOG);
    GPIO_Init(GPIOB, GPIO_PIN6, GPIO_MODE_ANALOG);
    GPIO_Init(GPIOB, GPIO_PIN4, GPIO_MODE_AF);
    GPIO_PinRemapConfig(GPIOB, GPIO_PIN4, GPIO_ALT_COMP);

    COMP_InitStruct.COMPSelect = COMP0;
    COMP_InitStruct.COMP0_N = COMP0_N_PB6;
    COMP_InitStruct.COMP0_P = COMP0_P_PB3;
    COMP_InitStruct.POLAR   = COMP_NORMAL;

    COMP_InitStruct.NFISL   = COMP_NMUx;
    COMP_InitStruct.PFISL   = COMP_PMUx;

    COMP_InitStruct.FILT_N  = COMP_Pclk_4;
    COMP_InitStruct.VEL_CTL = COMP_Response_7;
    COMP_InitStruct.COMP_en = COMP_ENABLE;
    COMP_Init(&COMP_InitStruct);
}
