/**
  ******************************************************************************
  * @file           : main.c
  * @author         : sinomcu.com-SA
  * @brief          : main program file body.
  * @gcc            : toolchain version 5 or 6
  *
  ******************************************************************************
  * @attention
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with
  * basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */
#include "include.h"
#include  "systick.h"
#include  "board.h"

void cordic_test(void);
void UART_TestInit(void);

int	main()
{

    SCU_SetSysClock(CLK_PLL_USE_HRC_LRC, HRC_16M, NO_XTAL, PLL_72M, SCU_SYS_Div1);
    delay_init();
    CORDIC_Init();
    UART_TestInit();

    while(1)
    {
        delay_ms(3000);

        cordic_test();
    }
}

/**
 * @brief    CRC8 Init
 * @param    None
 * @retval   None
 */
void cordic_test(void)
{
    int32_t line_res = 5, line_div = 3;
    int24_t sin, cos, rad;
    uint24_t x, y, rad1;
   u32 temp;
    CORDIC_DivFun(&line_res, &line_div);
    printf("div result: %d,last:%d\r\n", line_res, line_div);

    rad.value = 0x200000;
    sin.value = 1;
    cos.value = 0x000000;
    CORDIC_SinCosFun(&rad, &sin, &cos);
  
	  printf("SinCos sin: %x\r\n", (sin.value));
	  printf("SinCos cos: %x\r\n", (cos.value));
     temp=sin.value*1000;
    temp>>=22;
      printf("SinCos sin: %d\r\n",temp);
    temp=cos.value*1000;
    temp>>=22;
  
	  printf("SinCos cos: %d\r\n", temp);
      
      
    rad.value = 0x2AAAAA;
    sin.value = 1;
    cos.value = 0x000000;
    
     CORDIC_SinCosFun(&rad, &sin, &cos);
  
	  printf("SinCos sin: %x\r\n", (sin.value));
	  printf("SinCos cos: %x\r\n", (cos.value));
     temp=sin.value*1000;
    temp>>=22;
      printf("SinCos sin: %d\r\n",temp);
    temp=cos.value*1000;
    temp>>=22;
  
	  printf("SinCos cos: %d\r\n", temp);
      
      x.value    = 30;
	  y.value    = 40;
	  rad1.value = 0x0;
    CORDIC_SqrtFun(&x, &y, &rad1);
	  printf("Sqrt RX: %x\r\n", x.value);
	  printf("Sqrt RZ: %x\r\n", rad1.value);

    rad.value = 0x100000;
    sin.value = 0x400000;
    cos.value = 0x400000;
    CODIC_HsincosFun(&sin, &cos, &rad);
    printf("Hsincos sinh: %x\r\n", sin.value);
    printf("Hsincos cosh: %x\r\n", cos.value);

    rad.value = 0x0;
    sin.value = 0x400000;
    cos.value = 0x100000;
    CODIC_HsqrtFun(&sin, &cos, &rad);
    printf("Hsqrt RX: %x\r\n", sin.value);
    printf("Hsqrt RZ: %x\r\n\n", cos.value);
}

/**
 * @brief       UART_TestInit  Serial port configuration initialization
 * @param       None
 * @retval      None
 */
void UART_TestInit(void)
{
    UART_Init_T UART_InitConfig;
    SCU_PeriphClockCmd(UART_PORT_RX_GPIO_CLK | UART_PORT_TX_GPIO_CLK | UART_PORT_CLK, ENABLE);
    SCU_ResetPeriphClock(SCU_UART0_RST);

    GPIO_Init(UART_PORT_RX_GPIO_PORT, UART_PORT_RX_PIN, GPIO_MODE_AF);
    GPIO_PinRemapConfig(UART_PORT_RX_GPIO_PORT, UART_PORT_RX_PIN, GPIO_ALT_RX0);
    GPIO_Init(UART_PORT_TX_GPIO_PORT, UART_PORT_TX_PIN, GPIO_MODE_AF);
    GPIO_PinRemapConfig(UART_PORT_TX_GPIO_PORT, UART_PORT_TX_PIN, GPIO_ALT_TX0);
    UART_InitConfig.BaudRate = 115200;
    UART_InitConfig.Parity = UART_PARITY_NO;
    UART_InitConfig.StopBits = UART_STOPBITS_1;
    UART_InitConfig.WordLength = UART_DATA_8_BIT;
    UART_InitConfig.TimeOut = 10;
    UART_Init(UART_PORT, &UART_InitConfig);
}
