/**
  ******************************************************************************
  * @file           : main.c
  * @author         : sinomcu.com-SA
  * @brief          : main program file.
  * @gcc            : toolchain version 5 or 6
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with 
  * basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */  
#include "include.h"
#include "systick.h"
#include "board.h"

void GPIO_TestInit(void);

int	main()
{
    SCU_SetSysClock(CLK_PLL_USE_HRC_LRC, HRC_16M, NO_XTAL, PLL_72M, SCU_SYS_Div1);  /*set system clock*/
    delay_init();
    GPIO_TestInit();

    while(1)
    {
        /*The LED light will be on for 1 second when the keyis pressed*/
        if(GPIO_ReadInputDataBit(KEY_BUTTON_GPIO_PORT, KEY_BUTTON_PIN) == 0)
        {
            GPIO_SetBits(LED_GPIO_PORT, LED_PIN);
            delay_ms(1000);
            GPIO_ResetBits(LED_GPIO_PORT, LED_PIN);
        }
    }
}

/**
 * @brief    GPIO Init for led and key function
 * @param    None
 * @retval   None
 *
 */
void GPIO_TestInit(void)
{
    SCU_PeriphClockCmd(SCU_GPIOA_CLKEN | SCU_GPIOB_CLKEN, ENABLE);
    GPIO_Init(LED_GPIO_PORT, LED_PIN, GPIO_MODE_OUTPUT_PP);
    GPIO_Init(KEY_BUTTON_GPIO_PORT, KEY_BUTTON_PIN, GPIO_MODE_INPUT_PU);
}
