/**
  ******************************************************************************
  * @file           : bootloader.c
  * @author         : sinomcu.com-SA
  * @brief          : bootloader program body
  * @gcc            : toolchain version   5
  * This file provides example code for Spi transmit data by dma. 
  *         
  ******************************************************************************
   * @attention 
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with basic chip information support
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */  
#include "ms60f3xxx_i2c.h"
#include "ms60f3xxx.h"
#include "board.h"
#include "bootloader.h"
#include "ms60f3xxx_flash.h"
#include "ms60f3xxx_gpio.h"
#include "ms60f3xxx_uart.h"
#include "ms60f3xxx_scu.h"
#include "ms60f3xxx_crc.h"
#include "ms60f3xxx_wwdg.h"
#include "ms60f3xxx_iwdg.h"
uint8_t memBuf[sendbufSize];
uint8_t sendbuf[sendbufSize];
uint16_t  ALLCode_Checksum = 0x1111;
uint16_t  Hex_Checksum = 0x2222;                   /*The initial values of ALLCode_Checksum and Hex_Checksum cannot be the same*/
uint32_t EndAddress = appAddr;
#define I2C_USE_FLAG  0
#define UART_USE_FLAG 1

uint16_t sendbufIdx = 0;
uint16_t sendbufLen = 0;
uint16_t  memBufIdx = 0;
uint8_t readyreset = 0;
uint8_t port_use_flag = UART_USE_FLAG;

/**
  * @brief  appCode_ALLErase
  * @param  None
  * @retval booltyped:truefp or falsefp
  */
booltyped appCode_ALLErase(void)
{

    booltyped stu = truefp;

    MEM_MAP(FLS_CFG_EN) = FLASH_UNLOCK_KEY;
    MEM_MAP(CODE_CFG_EN) =  FLASH_CODE_WRITE_EN_KEY;
    FLASH->PRGKEYR = FLASH_CODE_WRITE_EN_KEY;      /*The erase operation of the main area was enabled*/
    FLASH->MR = FLASH_SECTOR_ERASE_MODE;
    FLASH->IFR = 0;
    *(unsigned long *)0x8000 = 0;

    while(!(FLASH->IFR & 0x02));

    return stu;
}

/**
@brief: appCodeWrite_AutoErase
@note:  Write on flash
@param:  addr relative address,len Data length (byte is the unit),p data cache
@retval: booltyped,truefp or falsefp
**/
booltyped appCodeWrite_AutoErase(uint32_t addr, uint32_t len, uint8_t* p)
{
    uint32_t i;


    uint8_t *a;
    i = (addr + appAddr);
    a = (uint8_t*)(addr + appAddr);

    if((addr + appAddr) >= 0x01020000)             /*Prevent the total Flash capacity from exceeding 128 KB*/
    {
        return falsefp;
    }


    if(0 == (addr & 0x1FF))                        /*If it is the start address of a sector, it is automatically erased*/
    {

        FEED_DOG();
        FLASH->PKEYR = FLASH_UNLOCK_KEY;
        FLASH->PRGKEYR = FLASH_CODE_WRITE_EN_KEY;  /*The erase operation of the main area was enabled*/
        FLASH->IFR = 0;
        FLASH->MR = FLASH_SECTOR_ERASE_MODE;

        *((uint32_t*)(addr + appAddr)) = 0;        /*APP start address + command address (from 0)*/
        i = 0;

        while((FLASH->IFR & FLASH_IR_SECTORESEND) == 0)
        {
            i++;

            if(i >= 32 * 6000) return falsefp;     /*If it is not erased after 6ms, it is considered that erasure failed*/
        }

    }

    FLASH->IFR = 0;                                /*The flag bit is cleared to zero*/
    FLASH->MR = FLASH_PROGRAM_MODE;

    *((uint32_t*)(Address_EnterAPPFlag)) = 0x0;    /*The update program flag bit is forcibly written to 0 to prevent data from being written to Flash after the program upgrade is complete*/


    while((FLASH->IFR & FLASH_IR_PGEND) == 0) {}

    FLASH->IFR = 0;                                /*The flag bit is cleared to zero*/

    *((uint32_t*)(Address_Checksum)) = 0x0;        /*Change the checksum to 0 to prevent writing data to Flash after the program has been upgraded*/

    while((FLASH->IFR & FLASH_IR_PGEND) == 0)
    {}

    FLASH->IFR = 0;                                /*The flag bit is cleared to zero*/

    FLASH->PRGKEYR = FLASH_CODE_WRITE_EN_KEY;      /*The erase operation of the main area was enabled*/

    FLASH->MR = FLASH_PROGRAM_MODE;
    FLASH->IFR = 0;
    a = ( uint8_t*)(addr + appAddr);               /*APP start address + command address (from 0)*/

    for(i = 0; i < len; i++)
    {
        *a = *p;
        a++;
        p++;
        EndAddress++;

        while(!(FLASH->IFR & FLASH_IR_PGEND))
        {
        }

        FLASH->IFR = 0;                            /*The flag bit is cleared to zero*/
    }

    return truefp;

}

/**
  * @brief  Flash_Erase_APPUpdate_Flag
  * @param  uint32_t flagaddr:flag address
  * @retval booltyped:truefp or falsefp
  */
booltyped Flash_Erase_APPUpdate_Flag(uint32_t flagaddr)
{
    uint32_t i;
    FLASH_ERASE_SECTOR_Unlock();
    FLASH->IFR = 0;

    *((volatile uint32_t*)(flagaddr)) = 0;
    i = 0;

    while((FLASH->IFR & FLASH_IR_SECTORESEND) == 0)
    {
        i++;

        if(i >= 32 * 6000) return falsefp;         /*If it is not erased after 6ms, it is considered that erasure failed*/
    }

    FLASH->IFR = 0;
    return truefp;
}

/**
  * @brief  Flash_WriteAPPUpdate_Flag
  * @param  uint32_t flagaddr:flag address
  * @param  uint16_t data
  * @retval booltyped:truefp or falsefp
  */
booltyped  Flash_WriteAPPUpdate_Flag(uint32_t flagaddr, uint16_t data)
{

    FLASH->IFR = 0;
    //FLASH->ACHKR = 0x2;                          /*The automatic verification function after programming completion was enabled*/
    FLASH->MR = FLASH_PROGRAM_MODE;

    *((uint32_t*)(flagaddr)) = data;               /*Write flag bit*/

    while(FLASH_IR_PGEND != FLASH->IFR);

    FLASH->IFR = 0;

    return truefp;
}

/**
  * @brief  CRC16_Check
  * @param  None
  * @retval uint16_t :result
  */
uint16_t CRC16_Check(void)
{
    uint16_t wCRCin = 0;
    wCRCin  = CRC_Calculate(CRC_16, (uint8_t*)appAddr, ((EndAddress - appAddr) / 512 + 1) * 512);
    return wCRCin;
}

/**
  * @brief  Uart_Init
  * @param  None
  * @retval None
  */
void Uart_Init(void)
{
    uint32_t cd, fp, cd_fp, UART_BaudRate = 115200;      /*set baudrate*/
    GPIO_Init(UART_PORT_RX_GPIO_PORT, UART_PORT_RX_PIN, GPIO_MODE_AF);
    GPIO_PinRemapConfig(UART_PORT_RX_GPIO_PORT, UART_PORT_RX_PIN, GPIO_ALT_RX0);
    GPIO_Init(UART_PORT_TX_GPIO_PORT, UART_PORT_TX_PIN, GPIO_MODE_AF);
    GPIO_PinRemapConfig(UART_PORT_TX_GPIO_PORT, UART_PORT_TX_PIN, GPIO_ALT_TX0);

    UART_PORT->CR = UART_CR_RSTRX | UART_CR_RSTTX | UART_CR_RXDIS | UART_CR_TXDIS | UART_CR_RSTSTA;
    UART_PORT->MR = 0x008C0;

    cd_fp = (8 * SCU_Get_frequecny() + (16 * UART_BaudRate) / 2) / (16 * UART_BaudRate);
    cd = (cd_fp >> 3);                               /*cd =cd_fp/8*/
    fp = cd_fp & 0x07;                               /*fp=cd_fp % 8*/


    UART_PORT->BRGR = cd + ((uint32_t)fp << 16);
    UART_PORT->RTOR = 100;
    UART_PORT->CR = UART_CR_RXEN | UART_CR_TXEN;

    UART_PORT->PTCR = UART_PTCR_RXTDIS;
    UART_PORT->RPR = (uint32_t)&memBuf;
    UART_PORT->RCR = 300;
    UART_PORT->PTCR = UART_PTCR_RXTEN;
    UART_PORT->IER = 0x108;                          /*enable endrx and timeout int*/
    NVIC_EnableIRQ(UART_PORT_IRQn);
}

/**
  * @brief  checksum8bit
  * @param  int8_t *p:data address
  * @param  uint16_t len:data len
  * @retval None
  */
uint8_t checksum8bit(uint8_t *p, uint16_t len)
{
    uint16_t i;
    uint8_t sum = 0;

    for(i = 0; i < len; i++)
    {
        sum += p[i];
    }

    return sum;
}

extern uint32_t EndAddress;

/**
  * @brief  uartCmdDecode
  * @param  None
  * @retval None
  */
void uartCmdDecode(void)
{
    uint8_t stu = 0x55;
    uint8_t  OwnAPPCode = 0xAA;                      /*By default, no APP program exists*/
    uint32_t addr;


    if( (memBuf[0] != 0x7c) || (memBuf[memBufIdx - 1] != 0x7e)) /*Check the end of the packet*/
    {
        stu = stu;
        return;
    }

    if( memBuf[1] != (memBuf[2] ^ 0xFF) )            /*Commands are inverse codes of each other*/
    {
        stu = stu;
        return;
    }

    if(memBuf[memBufIdx - 2] != checksum8bit(&memBuf[1], memBufIdx - 3)) /*checksum the entire packet (remove the header and tail)*/
    {
        stu = stu;
        return;
    }

    sendbufIdx = 0;
    sendbufLen = 0;

    sendbuf[sendbufLen++] = 0x7C;                    /*Head of package*/

    sendbuf[sendbufLen++] = memBuf[1];               /*command*/
    sendbuf[sendbufLen++] = ~memBuf[1];              /*Command reverse code*/

    switch (memBuf[1])
    {
        case 0x01:                 /*Get the Bootloader version number*/


            if (((*(__IO uint32_t*)appAddr) & 0x2FFE0000 ) == 0x20000000)
            {
                OwnAPPCode = 0x55;                   /*There are programs in the APP area*/
            }

            sendbuf[sendbufLen++] = stu;	           /*Status, 0x55 success, 0xAA failure*/
            sendbuf[sendbufLen++] = OwnAPPCode;      /*Feedback if an APP exists*/
            sendbuf[sendbufLen++] = (*(uint16_t*)Address_Checksum) >> 8;
            sendbuf[sendbufLen++] = (*(uint16_t*)Address_Checksum) & 0xff;
            sendbuf[sendbufLen++] = iap_i2c_version; /*Version number*/
            break;

        case 0x02:                /*Disable FLASH write protection*/
        {

            MEM_MAP(FLS_CFG_EN) = FLASH_UNLOCK_KEY;
            sendbuf[sendbufLen++] = stu;             /*Status, 0x55 success, 0xAA failure*/
            sendbuf[sendbufLen++] = 0;
            sendbuf[sendbufLen++] = 0;
            sendbuf[sendbufLen++] = 0;
            sendbuf[sendbufLen++] = 0;               /*Transfer information*/
            EndAddress = appAddr;
        }
        break;

        case 0x03:               /*Enable FLASH write protection*/

            MEM_MAP(FLS_CFG_EN) = FLASH_UNLOCK_KEY;
            sendbuf[sendbufLen++] = stu;             /*Status, 0x55 success, 0xAA failure*/
            sendbuf[sendbufLen++] = 0;
            sendbuf[sendbufLen++] = 0;
            sendbuf[sendbufLen++] = 0;
            sendbuf[sendbufLen++] = 0;               /*Transfer information*/
            break;

        case 0x04:               /*The APP program area is completely erased*/
            if(truefp != appCode_ALLErase())
            {
                stu = 0xAA;
            }

            sendbuf[sendbufLen++] = stu;             /*Status, 0x55 success, 0xAA failure*/
            sendbuf[sendbufLen++] = 0;
            sendbuf[sendbufLen++] = 0;
            sendbuf[sendbufLen++] = 0;
            sendbuf[sendbufLen++] = 0;               /*Transfer information*/
            break;

        case 0x05:               /*Burning FLASH*/
            addr = memBuf[3];
            addr <<= 8;
            addr |= memBuf[4];
            addr <<= 8;
            addr |= memBuf[5];
            addr <<= 8;
            addr |= memBuf[6];                       /*Burn program address (upgrade device send address format from 0 address)*/

            if (memBuf[7] != checksum8bit(&memBuf[3], 4)) /*Data address checksum*/
            {
                stu = 0xAA;
            }

            else if(truefp != appCodeWrite_AutoErase(addr, memBuf[8] + 1, &memBuf[9]))
            {

                stu = 0xAA;

            }

            sendbuf[sendbufLen++] = stu;             /*Status, 0x55 success, 0xAA failure*/
            sendbuf[sendbufLen++] = 0;
            sendbuf[sendbufLen++] = 0;
            sendbuf[sendbufLen++] = 0;
            sendbuf[sendbufLen++] = 0;               /*Transfer information*/
            break;

        case 0x06:              /*The checksum for the entire download must be executed after the download is complete, sector by sector*/


            Hex_Checksum = (memBuf[5] << 8);
            Hex_Checksum |= memBuf[6];
            ALLCode_Checksum = CRC16_Check();        /*APP program verification*/

            Flash_Erase_APPUpdate_Flag(Address_EnterAPPFlag);                         /*The flag bits are erased first*/

            if(ALLCode_Checksum != Hex_Checksum)
            {
                Flash_WriteAPPUpdate_Flag(Address_EnterAPPFlag, APPUpdate_Fail_Flag); /*Writing 0x1234 means that the upgrade failed*/

                stu = 0xAA;
            }
            else
            {
                extern uint32_t EndAddress;
                Flash_WriteAPPUpdate_Flag(Address_EnterAPPFlag, APPUpdate_Pass_Flag); /*Writing 0x5555 means that the upgrade was successful*/
                Flash_WriteAPPUpdate_Flag(Address_Checksum, ALLCode_Checksum); /*Write checksum*/
                readyreset = 0xAA;
                Flash_WriteAPPUpdate_Flag(Address_Program_Len, EndAddress - appAddr);
            }

            sendbuf[sendbufLen++] = stu;              /*Status, 0x55 success, 0xAA failure*/
            sendbuf[sendbufLen++] = 0;
            sendbuf[sendbufLen++] = 0;
            sendbuf[sendbufLen++] = (ALLCode_Checksum >> 8) & 0xff;  /*checksum is 8 bits higher*/
            sendbuf[sendbufLen++] = (ALLCode_Checksum & 0xff);       /*checksum is 8 bits lower*/

            break;

        case 0x07:              /*The upgrade was successful, and the APP should be redirected (check this option on the host computer)*/
            if(ALLCode_Checksum == Hex_Checksum)     /*Check whether checksum is correct*/
            {
                //gotoBootloaderFlag = falsefp;      /*Only if checksum jumps to APP correctly*/
            }
            else
            {
                stu = 0xAA;                          /*checksum is incorrect. We can't go to the APP*/
            }

            sendbuf[sendbufLen++] = stu;             /*Status, 0x55 success, 0xAA failure*/
            sendbuf[sendbufLen++] = 0;
            sendbuf[sendbufLen++] = 0;
            sendbuf[sendbufLen++] = 0;
            sendbuf[sendbufLen++] = 0;               /*Transfer information*/
            break;


        default:
            sendbuf[sendbufLen++] = 0xAA;            /*Error command*/
            sendbuf[sendbufLen++] = 0;
            sendbuf[sendbufLen++] = 0;
            sendbuf[sendbufLen++] = 0;
            sendbuf[sendbufLen++] = 0;               /*Transfer information*/
            break;
    }

    sendbuf[sendbufLen++] = checksum8bit(&sendbuf[1], 7); /*checksum*/
    sendbuf[sendbufLen++] = 0x7E;                    /*End of package*/

    if(port_use_flag == UART_USE_FLAG)
        UART_DMASend(UART0, sendbuf, sendbufLen);

}





