/**
  ******************************************************************************
  * @file           : main.c
  * @author         : sinomcu.com-SA
  * @brief          : Main program body
  * @gcc            : toolchain version   5
  *
  ******************************************************************************
   * @attention
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with basic chip information support
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */
#include "ms60f3xxx_gpio.h"
#include "ms60f3xxx_flash.h"
#include "ms60f3xxx_scu.h"
#include "ms60f3xxx_wwdg.h"
#include "ms60f3xxx_iwdg.h"
#include "ms60f3xxx.h"
#include "systick.h"
#include <stdio.h>
#include "ms60f3xxx_uart.h"
#include "bootloader.h"
#include "board.h"
#pragma pack(1)
uint8_t uart_receive_flag = 0;
#define appAddress 0x01001000
extern uint8_t readyreset;
extern uint8_t readyreset;
extern uint8_t memBuf[];
void Sram_Remap(void);
void Enter_BootLoader(void);

/* This project needs to be used in conjunction with the bootloder project. First download the 
bootloader project program and then download the app program. The download address of the app 
must be changed to 0x1001000*/

/**
  * @brief  Enter_BootLoader
  * @param  None
  * @retval None
  */
int	main()
{
    uint32_t counter = 0;
    Sram_Remap();

    SCU_SetSysClock(CLK_PLL_USE_HRC_LRC, HRC_16M, NO_XTAL, PLL_72M, SCU_SYS_Div1);
    SCU_PeriphClockCmd(SCU_GPIOB_CLKEN | SCU_GPIOA_CLKEN | SCU_CRC_CLKEN | SCU_UART0_CLKEN, ENABLE);

    GPIO_Init(GPIOA, GPIO_PIN2, GPIO_MODE_OUTPUT_PP);
    CRC->CR = 0x1B;
    CRC->CRC_POLY = 0x8005;
    Uart_Init();
    IWDG_Init(IWDG_div32, 1000);
    FEED_DOG();
    printf("APP  test version 10.6\r\n");

    while (1)
    {
        FEED_DOG();

        if(uart_receive_flag == 0xAA)
        {
            uartCmdDecode();
            uart_receive_flag = 0;
            UART_PORT->PTCR = UART_PTCR_RXTDIS;
            UART_PORT->RPR = (uint32_t)&memBuf;
            UART_PORT->RCR = 300;
            UART_PORT->PTCR = UART_PTCR_RXTEN;
        }

        if(readyreset == 0xAA)
        {
            counter = 0;
            readyreset = 0xBB;
        }

        counter++;

        if(counter > 0x8000)
        {
            if(readyreset == 0xBB)
            {
                Enter_BootLoader();
            }

            counter = 0;
            GPIOA->DOUTFLP = 0x4;
        }
    }
}

void Sram_Remap(void)
{
    uint8_t i;

    for(i = 0; i < 48; i++)
    {
        *((uint32_t*)(0x20000000 + (i << 2))) = *(__IO uint32_t*)(appAddress + (i << 2));
    }

    SCU_Unlock();
    SCU->RAMADDR = 1;
}

/**
  * @brief  Enter_BootLoader
  * @param  None
  * @retval None
  */
void Enter_BootLoader(void)
{
    __NVIC_SystemReset();
}

/**
  * @brief  fpSetVectorTableSRAM
  * @param  None
  * @retval None
  */
void fpSetVectorTableSRAM(void)
{
    uint8_t i;

    for(i = 0; i < 48; i++)
    {
        *((uint32_t*)(0x20000000 + (i << 2))) = *(__IO uint32_t*)(appAddr + (i << 2));
    }
    SCU_Unlock();
    SCU->RAMADDR = 1;
}

/**
  * @brief  UART0_Handler
  * @param  None
  * @retval None
  */
void UART0_Handler(void)
{
    if ((UART0->SR & UART_SR_TIMEOUT) != 0)
    {
        extern uint16_t memBufIdx;

        memBufIdx = 300 - UART0->RCR;

        UART0->CR = UART_CR_STTTO;
        uart_receive_flag = 0xAA;
    }
}

