
/**
  ******************************************************************************
  * @file           : systick.c
  * @author         : sinomcu.com-SA
  * @brief          : Main program body
  * @gcc            : toolchain version   5
  *         
  ******************************************************************************
   * @attention 
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with basic chip information support
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */  

#include  "ms60f3xxx.h"
#include  "ms60f3xxx_scu.h"
#include  "systick.h"

#define USE_SYSTICK_DELAY 1
#if USE_SYSTICK_DELAY

__IO uint32_t TimingDelay;

/**
  * @brief  Systick Delay Function Initialization
  * @param  None
  * @retval None
  */

void delay_init(void)
{
    if (SysTick_Config(SCU_Get_frequecny() / 1000)) //1ms
    {
        /* Capture error */
        while (1)
					;
    }

    /* Configure the SysTick handler priority */
    NVIC_SetPriority(SysTick_IRQn, 15);
}

/**
  * @brief  Decreasing at a rate of 1ms
  * @param  None
  * @retval None
  */
void TimingDelay_Decrement(void)
{
    if (TimingDelay != 0x00)
    {
        TimingDelay--;
    }
}

/**
  * @brief  Delay in program application calls, using systick
  * @param  None
  * @retval None
  */
void delay_ms(__IO uint32_t nTime)
{
    TimingDelay = nTime;

    while(TimingDelay != 0)
    {
    }
}

#endif
