/**
  ******************************************************************************
  * @file           : main.c
  * @author         : sinomcu.com-SA
  * @brief          : main program file.
  * @gcc            : toolchain version 5 or 6
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with 
  * basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */
#include "ms60f3xxx.h"
#include "ms60f3xxx_scu.h"
#include "ms60f3xxx_uart.h"
#include "ms60f3xxx_gpio.h"
#include "ms60f3xxx_flash.h"
#include <stdio.h>

#define appAddr1  0x01001000
extern unsigned long SystemCoreClock;

booltyped gotoBootloaderFlag = truefp;
#define blSyscfgRemapMemorySram()   SCU->WPR = 0x686868; SCU->RAMADDR = 1; SCU->WPR = 0
typedef  void (*pFunction)(void);
pFunction Jump_To_Application;
unsigned char buff[10] = {0, 1, 2, 3, 4, 5, 6, 7, 8, 9};
unsigned char rbuff[10];
unsigned char write_flag = 0;
unsigned char read_flag = 0;
unsigned char write_address = 0;
uint16_t reset_source;
booltyped Flash_Erase_APPUpdate_Flag(uint32_t flagaddr);
void fpSetVectorTableSRAM(void);
uint8_t GotoAppEntry(void);
void SCU_Init(void);

/**
  * @brief  main
  * @param  None
  * @retval None
  */
int	main()
{
 
    if( (*(volatile uint32_t *)Address_EnterAPPFlag) == 0x5555)
    {
        gotoBootloaderFlag = falsefp;
    }

    while (1)
    {

        if(truefp == gotoBootloaderFlag)
        {
            GotoAppEntry();
        }
        else
        {
            if( (*(volatile uint32_t *)Address_EnterAPPFlag) == 0x5555)
            {
                uint32_t len;
                uint32_t i;

                len = *(volatile uint32_t *)Address_Program_Len ;
                len = len / 512 + 1;

                for(i = 0; i < len ; i++)
                {
                    FLASH_EraseSector(0x1001000 + i * 512);
                    FLASH_Program(0x1001000 + i * 512, (uint8_t *)(0x1008000 + i * 512), 512);
                }
                i = *(volatile uint32_t *)Address_Checksum;
                Flash_Erase_APPUpdate_Flag(Address_EnterAPPFlag);
                FLASH_Program(Address_Checksum, (uint8_t *)&i, 4);
                gotoBootloaderFlag = truefp;
            }
        }
    }
}

/**
  * @brief  fpSetVectorTableSRAM
  * @param  None
  * @retval None
  */
void fpSetVectorTableSRAM(void)
{
    uint8_t i;

    for(i = 0; i < 64; i++)
    {
        *((uint32_t*)(0x20000000 + (i << 2))) = *(volatile uint32_t*)(appAddr1 + (i << 2));
    }
    blSyscfgRemapMemorySram();

}

/**
  * @brief  GotoAppEntry
  * @param  None
  * @retval None
  */
uint8_t GotoAppEntry(void)
{
    uint32_t JumpAddress = 0;

    if (((*(volatile uint32_t*)appAddr1) & 0x2FFE0000 ) == 0x20000000)
    {
        /* Jump to user application */
        JumpAddress = *(__IO uint32_t*) (appAddr1 + 4);
        Jump_To_Application = (pFunction) JumpAddress;

        /* Initialize user application's Stack Pointer */
        __set_MSP(*(__IO uint32_t*) appAddr1);

        /* Jump to application */
        Jump_To_Application();
    }
    return truefp;
}

/**
  * @brief  SCU_Init
  * @param  None
  * @retval None
  */
void SCU_Init(void)
{
    SCU_Unlock();
    SCU_SetSysClock(CLK_16M_USE_HRC_LRC, HRC_16M, NO_XTAL, PLL_32M, SCU_SYS_Div1);
    SystemCoreClock = 160000000;;
}

/**
  * @brief  Flash_Erase_APPUpdate_Flag
  * @param  uint32_t flagaddr:flag address
  * @retval booltyped:turefp or falsefp
  */
booltyped Flash_Erase_APPUpdate_Flag(uint32_t flagaddr)
{
    uint32_t i;

    FLASH_ERASE_SECTOR_Unlock();
    
    FLASH->IFR = 0;
    *((volatile uint32_t*)(flagaddr)) = 0;
    i = 0;

    while((FLASH->IFR & FLASH_IR_SECTORESEND) == 0)
    {
        i++;

        if(i >= 32 * 6000) return falsefp;     /*If it has not been erased after 6ms, it is considered that the erasure failed*/
    }

    FLASH->IFR = 0;
    return truefp;
}
