/**
  ******************************************************************************
  * @file           : main.c
  * @author         : sinomcu.com-SA
  * @brief          : main program file.
  * @gcc            : toolchain version 5 or 6
  *
  ******************************************************************************
  * @attention
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with
  * basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */
#include "include.h"
#include  "systick.h"
#include "board.h"




void I2C0MasterCfg(void);
uint8_t read_eeprom_one(IIC_Type *pi2c, uint8_t *dest, uint16_t addr, uint8_t n, uint8_t address_mode);
uint8_t write_eeprom_one(IIC_Type *pi2c, uint8_t *dest, uint16_t addr, uint8_t n, uint8_t address_mode);
void GPIO_TestInit(void);

uint8_t result, I2C_Buffer[8] = {0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8};
uint8_t I2C_Buffer1[8] ;

int	main()
{
   
    SCU_SetSysClock(CLK_PLL_USE_HRC_LRC, HRC_16M, NO_XTAL, PLL_72M, SCU_SYS_Div1);
    delay_init();
    I2C0MasterCfg();
    GPIO_TestInit();


    while(1)
    {



        if(GPIO_ReadInputDataBit(KEY_BUTTON_GPIO_PORT, KEY_BUTTON_PIN) == 0)
        {
            while(GPIO_ReadInputDataBit(KEY_BUTTON_GPIO_PORT, KEY_BUTTON_PIN) == 0)
                ;

            GPIO_SetBits(LED_GPIO_PORT, LED_PIN);
            write_eeprom_one(I2C0, I2C_Buffer, 0, 8, 1);
            read_eeprom_one(I2C0, I2C_Buffer1, 0, 8, 1);
            delay_ms(1000);
            GPIO_ResetBits(LED_GPIO_PORT, LED_PIN);

        }
    }
}

/**
  * @brief   Configure I2C1 Master pin multiplexing
  * @param   None
  * @retval  None
  */
void I2C0MasterCfg(void)
{
    I2C_INIT_T i2c;
    SCU_Unlock();
    SCU_PeriphClockCmd(SCU_IIC0_CLKEN | SCU_GPIOB_CLKEN | SCU_GPIOC_CLKEN, ENABLE);
    GPIO_Init(GPIOB, GPIO_PIN9, GPIO_MODE_AF);
    GPIO_Init(GPIOB, GPIO_PIN8, GPIO_MODE_AF);
    GPIO_PinRemapConfig(GPIOB, GPIO_PIN9, GPIO_ALT_SCL0);
    GPIO_PinRemapConfig(GPIOB, GPIO_PIN8, GPIO_ALT_SDA0);
    GPIO_PullUpConfig(GPIOB, GPIO_PIN9);
    GPIO_PullUpConfig(GPIOB, GPIO_PIN8);
    GPIO_SetOD(GPIOB, GPIO_PIN9, ENABLE);
    GPIO_SetOD(GPIOB, GPIO_PIN8, ENABLE);

    i2c.mode = MASTER_MODE;
    i2c.frequency = 100000;
    i2c.duty = 50;
    I2C_Init(I2C0, &i2c);
}



/**
 * @brief    GPIO Init for led and key function
 * @param    None
 * @retval   None
 *
 */
void GPIO_TestInit(void)
{
    SCU_PeriphClockCmd(SCU_GPIOA_CLKEN | SCU_GPIOB_CLKEN, ENABLE);
    GPIO_Init(LED_GPIO_PORT, LED_PIN, GPIO_MODE_OUTPUT_PP);
    GPIO_Init(KEY_BUTTON_GPIO_PORT, KEY_BUTTON_PIN, GPIO_MODE_INPUT_PU);
}


u8 status;

#define  _SlaveAddr 0xa0
#define PAGE_SIZE 64
/***********************************************************************************
* Function	: read_eeprom
* Description	:עʹõeepromͺţʾвͺΪ24C256
* Input Para	:
* Output Para	:
* Return Value: 1 OR 0
***********************************************************************************/

uint8_t read_eeprom_one(IIC_Type *pi2c, uint8_t *dest, uint16_t addr, uint8_t n, uint8_t address_mode)
{
    uint8_t result = 0;
    uint8_t i = 0;
    I2CStart(pi2c);
    result = I2C_Send_address(pi2c, _SlaveAddr, I2C_ACK);


    if(result == 0)
        return 0;


    if(address_mode)
    {
        result = I2C_Send_Byte(pi2c, addr / 256, I2C_ACK);

        if(result == 0)
            return 0;
    }

    result = I2C_Send_Byte(pi2c, addr, I2C_ACK);

    if(result == 0)
        return 0;

    I2CStart(pi2c);
    result = I2C_Send_address(pi2c, _SlaveAddr + 1, I2C_ACK);
    status = result;

    if(result == 0)
        return 0;

    for(i = 0; i < n; i++)
    {
        if(i == n - 1)
        {

            *dest++ = I2C_Receive_Byte(pi2c, I2C_NOACK);
        }
        else
        {
            *dest++ = I2C_Receive_Byte(pi2c, I2C_ACK);
        }

    }

    I2CStop(pi2c);


    return	1;
}


/***********************************************************************************
* Function	: read_eeprom
* Description	:
* Input Para	:
* Output Para	:
* Return Value: 1 OR 0
***********************************************************************************/
uint8_t write_eeprom_one(IIC_Type *pi2c, uint8_t *dest, uint16_t addr, uint8_t n, uint8_t address_mode)
{
    uint8_t result = 0;
    uint8_t i = 0;

    I2CStart(pi2c);
    result = I2C_Send_address(pi2c, _SlaveAddr, I2C_ACK);

    if(result == 0)
        return 0;


    if(address_mode)
    {
        result = I2C_Send_Byte(pi2c, addr / 256, I2C_ACK);

        if(result == 0)
            return 0;
    }

    result = I2C_Send_Byte(pi2c, addr, I2C_ACK);

    if(result == 0)
        return 0;

    for(i = 0; i < n; i++)
    {

        if(i == n - 1)
        {
            I2C_Send_Byte(pi2c, dest[i], I2C_NOACK);
        }
        else
            I2C_Send_Byte(pi2c, dest[i], I2C_ACK);

        delay_us(1);

    }

    delay_us(10000);
    I2CStop(pi2c);

    return	1;
}

