/**
  ******************************************************************************
  * @file           : main.c
  * @author         : sinomcu.com-SA
  * @brief          : MAIN module driver.
  * @gcc            : toolchain version 5 or 6
  *
  ******************************************************************************
  * @attention
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with
  * basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */ 
#include "include.h"
#include "board.h"

void LED_Init(void);
void LPTIMER_Config(void);

/**
 * @brief     Main program
 * @param     None
 * @retval    int
 */
int	main()
{
    SCU_SetSysClock(CLK_PLL_USE_HRC_LXTAL, HRC_16M, LXTAL_TYPE, PLL_72M, SCU_SYS_Div1);
    LED_Init();
    LPTIMER_Config();
    while(1)
    { 
    }
}

/**
 * @brief       GPIO Init for led and key function
 * @param       None
 * @retval      None
 *
 */
void LED_Init(void)
{
    SCU_PeriphClockCmd(SCU_GPIOA_CLKEN, ENABLE);
    GPIO_Init(LED_GPIO_PORT, LED_PIN, GPIO_MODE_OUTPUT_PP);
}

/**
	* @brief  LPTIMER Config:Interrupt once in 1 second
  * @param  None
  * @retval None
  */
void LPTIMER_Config(void)
{
    LPTIMER_INIT_T lp_init;
    SCU_PeriphClockCmd(SCU_LPTIMER_CLKEN, ENABLE);
    lp_init.mode      = CONTINUE_MODE;
    lp_init.clkselect = LRC_32K;
    lp_init.clock_div = CLOCK_Div512;
    lp_init.arr_value = 32 * 2; /*1s*/
    lp_init.lp_enable = LPTIMER_ENABLE;
    LPTIMER_Init(&lp_init);
	  LPTIMER_Enable_IT();
    NVIC_SetPriority(LPTIMER_IRQn, 0);
    NVIC_EnableIRQ(LPTIMER_IRQn);
}

