/**
  ******************************************************************************
  * @file           : main.c
  * @author         : sinomcu.com-SA
  * @brief          : Main program body
  * @gcc            : toolchain version   5 or 6
  * This file provides example code for PLU and the result of this test will be displayed by GPIOB PIN11(LED state change on or off).
  *
  ******************************************************************************
   * @attention
  *                           DISCLAIMER
  * The present firmware which is for guidance only aims at providing customers
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */

#include "include.h"
#include "systick.h"
#include "Board.h"

void PLU1_TestInit(void);

/**
  * @brief  mian
  * @param  None
  * @retval None
  */
int	main()
{
    SCU_SetSysClock(CLK_PLL_USE_HRC_LRC, HRC_16M, NO_XTAL, PLL_72M, SCU_SYS_Div1);
    PLU1_TestInit();
    delay_init();
    while(1)
    {
        if(PLU->OUTR_b.P1OUT)
        {
            GPIO_SetBits(LED_GPIO_PORT, LED_PIN);
        }
        else
        {
            GPIO_ResetBits(LED_GPIO_PORT, LED_PIN);
        }
    }
}

/**
 * @brief       PLU1_TestInit
 * @param       None
 * @retval      None
 *
 */
void PLU1_TestInit(void)
{
    MUXA_UNION_T mux_a;
    MUXB_UNION_T mux_b;
    PLU_CFR_T plu_cfr;

    SCU_PeriphClockCmd(SCU_PLU_CLKEN | SCU_GPIOA_CLKEN | SCU_GPIOB_CLKEN, ENABLE);
    SCU_ResetPeriphClock(SCU_PLU_RST);

    GPIO_Init(GPIOA, GPIO_PIN4, GPIO_MODE_AF);
	  GPIO_PullDownConfig(GPIOA, GPIO_PIN4);
    GPIO_PinRemapConfig(GPIOA, GPIO_PIN4, GPIO_ALT_PLUI);
    GPIO_Init(GPIOB, GPIO_PIN10, GPIO_MODE_AF);
	  GPIO_PullDownConfig(GPIOB, GPIO_PIN10);
    GPIO_PinRemapConfig(GPIOB, GPIO_PIN10, GPIO_ALT_PLUI);
    
    /*The LED pin is used for PLU operation results show that when GPIO_PIN3 or GPIO_PIN10 is set to high, the LED is lit*/
    GPIO_Init(LED_GPIO_PORT, LED_PIN, GPIO_MODE_OUTPUT_PP);

    mux_a.mrx_a = MXR1A_PA4;
    mux_b.mrx_b = MXR1B_PB10;
    PLU_MuxSelect(PLU_UNIT1, mux_a, mux_b);
    PLU_Function(PLU_UNIT1, (uint8_t)PLU_OR(PLU_MUXA, PLU_MUXB));

    plu_cfr.plu_clk_inv = PLU_CLK_NORMAL;
    plu_cfr.plu_d = PLU_D_NORMAL;
    plu_cfr.plu_out = PLU_DIRECT_OUT;
    plu_cfr.plu_gpio = PLU_GPIO_ON;
    plu_cfr.plu_trigger = PLU_CLKSEL_SYSCLK;
    plu_cfr.plu_filer_enable = PLU_FILETER_ENABLE;
    plu_cfr.plu_filter_div = FILTER_CLOCK_DIV16;
    plu_cfr.plu_filter_num = PLU_FILTER_NUM4;
    PLU_CFR(PLU_UNIT1, &plu_cfr);

    PLU_Enable(PLU1_ENABLE);
    PLU_Enable_IT(0, BOTH_EDGE);
    NVIC_EnableIRQ(PLU_IRQn);
}


