/**
  ******************************************************************************
  * @file           : main.c
  * @author         : sinomcu.com-SAE
  * @brief          : Main program body
  * @gcc            : toolchain version   5 or 6
  * This file provides example code for SCU sleep mode test.
  *
  ******************************************************************************
  * @attention
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with
  *	basic chip information support.
	*
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */


#include "include.h"
#include  "systick.h"
#include "Board.h"

void Sleep_TestInit(void);

/**
 * @brief   main
 * @param   None
 * @retval  None
 */
int	main()
{
    SCU_SetSysClock(CLK_PLL_USE_HRC_LRC, HRC_16M, NO_XTAL, PLL_72M, SCU_SYS_Div1); /*The pll is frequency doubled to 72Mhz based on the internal HRC*/

    SCU_PeriphClockCmd(SCU_GPIOB_CLKEN, ENABLE);
    GPIO_Init(GPIOB, GPIO_PIN0, GPIO_MODE_INPUT_PU);
    GPIO_Init(LED_GPIO_PORT, LED_PIN, GPIO_MODE_OUTPUT_PP);
    delay_init();
 
    GPIO_SetBits(LED_GPIO_PORT, LED_PIN);

    while(1)
    {
        if(GPIO_ReadOutputDataBit(GPIOB, GPIO_PIN0) == 0)
        {
						GPIO_ResetBits(LED_GPIO_PORT, LED_PIN);
						Sleep_TestInit();
						GPIO_SetBits(LED_GPIO_PORT, LED_PIN);
        }
    }
}

/**
 * @brief   Sleep_TestInit
* @param   LOW_POWER_MODE_Enum mode:SLEEP_MODE,
 * @retval  None
 */
void Sleep_TestInit(void)
{
    EXTI_Init_T  exti_init;
    SCU_PeriphClockCmd(KEY_BUTTON_GPIO_CLK, ENABLE);
    GPIO_Init(KEY_BUTTON_GPIO_PORT, KEY_BUTTON_PIN, GPIO_MODE_INPUT_PU);
    exti_init.EXTI_Line= EXTI_LINE15;
	  exti_init.Mode = EXTI_Interrupt_Mode;
    exti_init.LineCmd = ENABLE;
    exti_init.GPIO_GPOUP = EXTI_GROUPA;
    exti_init.Trigger = EXTI_Trigger_Falling;
    EXTI_Init(&exti_init);
	  NVIC_EnableIRQ(EXTI5_15_IRQn);
	
    SCU_Set_Wake(EXTI5_15_WAKEUP);
    SysTick->CTRL &= 0xFFFE;/*disable SysTick Interrupt,or will wakeup at once */
    SCU_Sleep_Mode(STOP_MODE, ALL_OFF, Interrupt_Mode);
    SysTick->CTRL |= 0x01; /*enable SysTick Interrupt */
}
