
/**
  ******************************************************************************
  * @file           : systick.c
  * @author         : sinomcu.com-SA
  * @brief          : Main program body
  * @gcc            : toolchain version   5 or 6  
  *         
  ******************************************************************************
   * @attention 
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with
  *	basic chip information support.
	*
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */  

#include  "ms60f3xxx.h"
#include  "ms60f3xxx_scu.h"
#include  "systick.h"

#define USE_SYSTICK_DELAY 1
#if USE_SYSTICK_DELAY

__IO uint32_t TimingDelay;

/**
  * @brief  Systick Delay Function Initialization
  * @param  None
  * @retval None
  */

void delay_init(void)
{
    if (SysTick_Config(SCU_Get_frequecny() / 1000)) //1ms
    {
        /* Capture error */
        while (1)
					;
    }

    /* Configure the SysTick handler priority */
    NVIC_SetPriority(SysTick_IRQn, 15);
}

/**
  * @brief  Decreasing at a rate of 1ms
  * @param  None
  * @retval None
  */

void TimingDelay_Decrement(void)
{
    if (TimingDelay != 0x00)
    {
        TimingDelay--;
    }
}
/**
  * @brief  Enable ExtiLine Interrupt request for Lines in range 0 to 15
  * @param  ExtiLine This parameter can be one of the following values:
  *         @arg @ref EXTI_LINE0
  *         @arg @ref EXTI_LINE1
  *         @arg @ref EXTI_LINE2
  *         @arg @ref EXTI_LINE3
  *         @arg @ref EXTI_LINE4
  *         @arg @ref EXTI_LINE5
  *         @arg @ref EXTI_LINE6
  *         @arg @ref EXTI_LINE7
  *         @arg @ref EXTI_LINE8
  *         @arg @ref EXTI_LINE9
  *         @arg @ref EXTI_LINE10
  *         @arg @ref EXTI_LINE11
  *         @arg @ref EXTI_LINE12
  *         @arg @ref EXTI_LINE13
  *         @arg @ref EXTI_LINE14
  *         @arg @ref EXTI_LINE15
  *         @arg @ref EXTI_LINE_ALL
  * @retval None
  */
void systick_Enable_IT(void)
{
    SysTick->CTRL |= 0x01; /*enable SysTick Interrupt */

}
/**
  * @brief  Disable ExtiLine Interrupt request for Lines in range 0 to 15
  * @param  ExtiLine This parameter can be one of the following values:
  *         @arg @ref EXTI_LINE0
  *         @arg @ref EXTI_LINE1
  *         @arg @ref EXTI_LINE2
  *         @arg @ref EXTI_LINE3
  *         @arg @ref EXTI_LINE4
  *         @arg @ref EXTI_LINE5
  *         @arg @ref EXTI_LINE6
  *         @arg @ref EXTI_LINE7
  *         @arg @ref EXTI_LINE8
  *         @arg @ref EXTI_LINE9
  *         @arg @ref EXTI_LINE10
  *         @arg @ref EXTI_LINE11
  *         @arg @ref EXTI_LINE12
  *         @arg @ref EXTI_LINE13
  *         @arg @ref EXTI_LINE14
  *         @arg @ref EXTI_LINE15
  *         @arg @ref EXTI_LINE_ALL
  * @note   Please check each device line mapping for EXTI Line availability
  * @retval None
  */
void systick_Disable_IT(void)
{
    SysTick->CTRL &= 0xFFFE;/*disable SysTick Interrupt,or will wakeup at once */
}
/**
  * @brief  Delay in program application calls, using systick
  * @param  None
  * @retval None
  */
void delay_ms(__IO uint32_t nTime)
{
    TimingDelay = nTime;

    while(TimingDelay != 0)
    {
    }
}

#endif
