/**
  ******************************************************************************
  * @file           : tim_rc.c
  * @author         : sinomcu.com-SA
  * @brief          : Timer timing function
  * @gcc            : toolchain version 5 or 6
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with basic chip information support
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */ 
#include "include.h"
#include "tim_fre.h"

strTimer gTimer = { 0 };
/**
  * @brief  This function is executed in case of error occurrence.
  * @retval None
  */
void Error_Handler(void)
{
  __disable_irq();
  while (1)
  {
  }
}

/**
 * @brief   TIM GPIO Initialization
 * @param   TIMx: TIMx base address, which can be configured as TIM0 or TIM1.
 * @param   TIM_CHANNEL: Channel to configure
 * @retval  None
 */ 
void TIM_Fre_Gpio(TIM_Type *TIMx,TIM_CHANNEL_Enum TIM_CHANNEL)
{
	GPIO_ALT_Enum  GPIO_ALT_TIM = GPIO_ALT_TIM0;
	
	SCU_PeriphClockCmd( SCU_GPIOA_CLKEN | SCU_GPIOB_CLKEN | SCU_GPIOC_CLKEN,ENABLE);
	
	if( TIMx == TIM1 )
		GPIO_ALT_TIM = GPIO_ALT_TIM1;				

	if( TIM_CHANNEL == TIM_CHANNEL0 )
	{
		GPIO_Init(GPIOA, GPIO_PIN8,GPIO_MODE_AF);               //TA0
		GPIO_PinRemapConfig(GPIOA, GPIO_PIN8,GPIO_ALT_TIM);
	}
	else if( TIM_CHANNEL == TIM_CHANNEL1 )
	{
		GPIO_Init(GPIOC, GPIO_PIN5,GPIO_MODE_AF);                //TA1
		GPIO_PinRemapConfig(GPIOC, GPIO_PIN5,GPIO_ALT_TIM);
	}
	else if( TIM_CHANNEL == TIM_CHANNEL2 )
	{
		 GPIO_Init(GPIOA, GPIO_PIN11,GPIO_MODE_AF);               //TA2
		 GPIO_PinRemapConfig(GPIOA, GPIO_PIN11,GPIO_ALT_TIM);
	}
}

/**
 * @brief   Timer channel interrupt enable
 * @param   TIMx: TIMx base address, which can be configured as TIM0 or TIM1.
 * @param   TIM_CHANNEL: Channel to configure
 * @retval  None
 */ 
void Channel_IE_Enable(TIM_Type *TIMx,TIM_CHANNEL_Enum TIM_CHANNEL)
{
   if(TIMx == TIM0) 
	 {
			if(TIM_CHANNEL == TIM_CHANNEL0 )
				NVIC_EnableIRQ(TIM0_0_IRQn);
			else if(TIM_CHANNEL == TIM_CHANNEL1 ) 
				NVIC_EnableIRQ(TIM0_1_IRQn);
			else
				NVIC_EnableIRQ(TIM0_2_IRQn);
	 }
	 else
	 {	
			if(TIM_CHANNEL == TIM_CHANNEL0 )
				NVIC_EnableIRQ(TIM1_0_IRQn);
			else if(TIM_CHANNEL == TIM_CHANNEL1 ) 
				NVIC_EnableIRQ(TIM1_1_IRQn);
			else
				NVIC_EnableIRQ(TIM1_2_IRQn);
	 }	
}

/**
 * @brief   Timer frequency initialization
 * @param   TIMx: TIMx base address, which can be configured as TIM0 or TIM1.
 * @param   TIM_CHANNEL: Channel to configure
 * @retval  None
 */ 
void TIM_Fre_Init(TIM_Type *TIMx,TIM_CHANNEL_Enum TIM_CHANNEL)
{
	TIM_CMR_Capture_T TIM_CMR_CaptureConfig = { TIM_CHANNEL0 }; 
	
  TIM_Fre_Gpio(TIMx,TIM_CHANNEL);
	
	TIM_CMR_CaptureConfig.CHANNEL = TIM_CHANNEL;
	TIM_CMR_CaptureConfig.TIMCLKS  = TIM_CMR_TIMCLKS_CLK_BUS_DIV2;
	TIM_CMR_CaptureConfig.ETRGEDG = TIM_CMR_ETRGEDG_RISING; 
	TIM_CMR_CaptureConfig.LDRA    = TIM_CMR_LDRA_FALLING;   //ѡA ڲƵ 
	TIM_CMR_CaptureConfig.LDRB    = TIM_CMR_LDRB_RISING;
	TIM_CMR_CaptureConfig.ABETRG  = TIM_CMR_ABETRG_TIOA;
	TIM_CMR_CaptureConfig.LDBSTOP = TIM_CMR_LDBSTOP;
 
	if(TIM_CaptureInit(TIMx,&TIM_CMR_CaptureConfig) == ERROR)
	{
		Error_Handler();
	}

	TIM_Enable_IT(TIMx,TIM_CHANNEL,TIM_IER_LDRBS);
	
  Channel_IE_Enable(TIMx,TIM_CHANNEL);
	
	TIM_ClockEnable(TIMx,TIM_CHANNEL);
}

/**
 * @brief   Timer frequency Process
 * @param   TIMx: TIMx base address, which can be configured as TIM0 or TIM1.
 * @param   TIM_CHANNEL: Channel to configure
 * @retval  None
 */ 
void TIM_Fre_Process(TIM_Type *TIMx,TIM_CHANNEL_Enum TIM_CHANNEL)
{
	gTimer.m_ul_PulseWidth = TIM_Read_RA(TIMx,TIM_CHANNEL);
	gTimer.m_ul_FrePeriod  = TIM_Read_RB(TIMx,TIM_CHANNEL) / ( gTimer.m_ul_SysClock / 1000000 / 2 );
  gTimer.m_ul_Fre        = 1000 * 1000 / gTimer.m_ul_FrePeriod;	
}

/**
 * @brief   Read Timer frequency
 * @param   TIMx: TIMx base address, which can be configured as TIM0 or TIM1.
 * @param   TIM_CHANNEL: Channel to configure
 * @retval  None
 */ 
void Read_Fre(TIM_Type *TIMx,TIM_CHANNEL_Enum TIM_CHANNEL)
{
	if((TIMx->CHANNEL[TIM_CHANNEL].SR  & TIM_SR_LDRBS) >= 1) //Ƶʼ
	{
		 TIM_Fre_Process(TIMx,TIM_CHANNEL);
	}	
}

/**
 * @brief   Timer configuration
 * @param   TIMx:        TIMx base address, which can be configured as TIM0 or TIM1.
 * @param   TIM_CHANNEL: Channel to configure
 * @retval  None
 */ 
void TIM_Config( TIM_Type *TIMx,TIM_CHANNEL_Enum TIM_CHANNEL)
{		
		if(TIMx == TIM0)
		{
				SCU_PeriphClockCmd( SCU_TIM0_CLKEN,ENABLE );
				if( TIM_CHANNEL == TIM_CHANNEL0 )
					NVIC_EnableIRQ(TIM0_0_IRQn);
				else if( TIM_CHANNEL == TIM_CHANNEL1 )
					NVIC_EnableIRQ(TIM0_1_IRQn);
				else
					NVIC_EnableIRQ(TIM0_2_IRQn);	
		}
		else
		{
				SCU_PeriphClockCmd( SCU_TIM1_CLKEN,ENABLE );
				if( TIM_CHANNEL == TIM_CHANNEL0 )
					NVIC_EnableIRQ(TIM1_0_IRQn);
				else if( TIM_CHANNEL == TIM_CHANNEL1 )
					NVIC_EnableIRQ(TIM1_1_IRQn);
				else
					NVIC_EnableIRQ(TIM1_2_IRQn);
		}
		TIM_Fre_Init(TIMx,TIM_CHANNEL);
    gTimer.m_ul_SysClock = SCU_Get_frequecny();		
}

