/**
  ******************************************************************************
  * @file           : tim_rc.c
  * @author         : sinomcu.com-SA
  * @brief          : Timer timing function
  * @gcc            : toolchain version 5 or 6
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with basic chip information support
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */  
#include "include.h"
#include "tim_trg.h" 

/**
  * @brief  This function is executed in case of error occurrence.
  * @retval None
  */
void Error_Handler(void)
{
		__disable_irq();
		while (1)
		{
		}
}

/**
 * @brief   TIM RC Counter Initialization, Interrupt once in 1 second
 * @param:  TIMx: TIMx base address, which can be configured as TIM0 or TIM1.
 * @param:  TIM_CHANNEL: Channel to configure
 * @retval  None
 */
void TIM_RC_Counter_Init(TIM_Type *TIMx,TIM_CHANNEL_Enum TIM_CHANNEL)
{
		uint32_t ul_RC = 9000000;

		TIM_CMR_Wave_T TIM_CMR_WaveConfig = { TIM_CHANNEL0 };
		
		if(TIMx == TIM0)
		{
				SCU_PeriphClockCmd( SCU_TIM0_CLKEN,ENABLE );
				if( TIM_CHANNEL == TIM_CHANNEL0 )
					NVIC_EnableIRQ(TIM0_0_IRQn);
				else if( TIM_CHANNEL == TIM_CHANNEL1 )
					NVIC_EnableIRQ(TIM0_1_IRQn);
				else
					NVIC_EnableIRQ(TIM0_2_IRQn);	
		}
		else
		{
				SCU_PeriphClockCmd( SCU_TIM1_CLKEN,ENABLE );
				if( TIM_CHANNEL == TIM_CHANNEL0 )
					NVIC_EnableIRQ(TIM1_0_IRQn);
				else if( TIM_CHANNEL == TIM_CHANNEL1 )
					NVIC_EnableIRQ(TIM1_1_IRQn);
				else
					NVIC_EnableIRQ(TIM1_2_IRQn);
		}
		
		TIM_CMR_WaveConfig.CHANNEL  = TIM_CHANNEL;
		TIM_CMR_WaveConfig.WAVE     = TIM_CMR_WAVE_MODE;
		TIM_CMR_WaveConfig.TIMCLKS  = TIM_CMR_TIMCLKS_CLK_BUS_DIV8;
		TIM_CMR_WaveConfig.WAVSEL   = TIM_CMR_WAVSEL_UP_RC;
		
		TIM_CMR_WaveConfig.EEVT     = TIM_CMR_EEVT_TIOB;
		TIM_CMR_WaveConfig.EEVTEDG  = TIM_CMR_EEVTEDG_FALLING;
		TIM_CMR_WaveConfig.ENETRG   = TIM_CMR_ENETRG_EN;
		
		if(TIM_WaveInit(TIMx,&TIM_CMR_WaveConfig) == ERROR)
		{
			  Error_Handler();
		}
		TIM_Write_RC(TIMx,TIM_CHANNEL,ul_RC);
		
#if TIM1_2_TIOB_Pin
		SCU_PeriphClockCmd(SCU_GPIOA_CLKEN,ENABLE);
		GPIO_Init(GPIOA,GPIO_PIN7,GPIO_MODE_AF);               /* TIOB0 PA7 */
		GPIO_PinRemapConfig(GPIOA,GPIO_PIN7,GPIO_ALT_TIM1);
#elif COMP0_OUT
		TIM1_0_SetTriggerInput(TIM_TRGIN_TIM1_0_COMP0_OUT);
#endif
		
		TIM_Enable_IT(TIMx,TIM_CHANNEL,TIM_IER_CPCS);
		TIM_ClockEnable(TIMx,TIM_CHANNEL);
}

/**
  * @brief  COMP0 Compare Input Ends Values 
	* 				GPIOB_PIN4 Output COMP0 results
  * @param  None
  * @retval None
  */
void COMP_test(void)
{
    COMP_Init_T  COMP_InitStruct = {0};  /*Initialize Structure*/

    SCU_PeriphClockCmd(SCU_COMP_CLKEN | SCU_GPIOB_CLKEN, ENABLE);

    GPIO_Init(GPIOB, GPIO_PIN3, GPIO_MODE_ANALOG);
    GPIO_Init(GPIOB, GPIO_PIN6, GPIO_MODE_ANALOG);
    GPIO_Init(GPIOB, GPIO_PIN4, GPIO_MODE_AF);
    GPIO_PinRemapConfig(GPIOB, GPIO_PIN4, GPIO_ALT_COMP);

    COMP_InitStruct.COMPSelect = COMP0;
    COMP_InitStruct.COMP0_N = COMP0_N_PB6;
    COMP_InitStruct.COMP0_P = COMP0_P_PB3;
    COMP_InitStruct.POLAR   = COMP_NORMAL;

    COMP_InitStruct.NFISL   = COMP_NMUx;
    COMP_InitStruct.PFISL   = COMP_PMUx;

    COMP_InitStruct.FILT_N  = COMP_Pclk_4;
    COMP_InitStruct.VEL_CTL = COMP_Response_7;
    COMP_InitStruct.COMP_en = COMP_ENABLE;
    COMP_Init(&COMP_InitStruct);
}
