/**
  ******************************************************************************
  * @file           : tim_rc.c
  * @author         : sinomcu.com-SA
  * @brief          : Timer timing function
  * @gcc            : toolchain version 5 or 6
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with basic chip information support
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */  
#include "include.h"
#include "tim_wave.h" 

/**
  * @brief  This function is executed in case of error occurrence.
  * @retval None
  */
void Error_Handler(void)
{
		__disable_irq();
		while (1)
		{
		}
}

/**
 * @brief   TIMx GPIO Initialization
 * @param:  TIMx: TIMx base address, which can be configured as TIM0 or TIM1.
 * @param:  TIM_CHANNEL: Channel to configure
 * @retval  None
 */
void TIM_Wave_GPIO(TIM_Type *TIMx,TIM_CHANNEL_Enum TIM_CHANNEL)
{
		GPIO_ALT_Enum  GPIO_ALT_TIM = GPIO_ALT_TIM0;

		SCU_PeriphClockCmd(SCU_GPIOA_CLKEN | SCU_GPIOB_CLKEN ,ENABLE);

		if( TIMx == TIM1 )
				GPIO_ALT_TIM = GPIO_ALT_TIM1;
		
    if( TIM_CHANNEL == TIM_CHANNEL0 )
		{
				GPIO_Init(GPIOB, GPIO_PIN7,GPIO_MODE_AF);                 /* TA0 PB7 */
				GPIO_PinRemapConfig(GPIOB, GPIO_PIN7,GPIO_ALT_TIM);
			  
			  GPIO_Init(GPIOA, GPIO_PIN7,GPIO_MODE_AF);                 /* TB0 PA7 */
		    GPIO_PinRemapConfig(GPIOA, GPIO_PIN7,GPIO_ALT_TIM);
			  
			  GPIO_Init(GPIOA, GPIO_PIN2,GPIO_MODE_AF);                 /* TIMLK0 PA2 */
		    GPIO_PinRemapConfig(GPIOA, GPIO_PIN2,GPIO_ALT_TIM);
    }
		if( TIM_CHANNEL == TIM_CHANNEL1 )
		{
				GPIO_Init(GPIOB, GPIO_PIN11,GPIO_MODE_AF);                /* TA1 PB11 */
				GPIO_PinRemapConfig(GPIOB, GPIO_PIN11,GPIO_ALT_TIM);
				
				GPIO_Init(GPIOA, GPIO_PIN5,GPIO_MODE_AF);                 /* TB1 PA5 */
				GPIO_PinRemapConfig(GPIOA, GPIO_PIN5,GPIO_ALT_TIM);	
				
				GPIO_Init(GPIOA, GPIO_PIN1,GPIO_MODE_AF);                 /* TIMLK1 PA1 */
				GPIO_PinRemapConfig(GPIOA, GPIO_PIN1,GPIO_ALT_TIM);
		}
		if( TIM_CHANNEL == TIM_CHANNEL2 )
		{
				GPIO_Init(GPIOB, GPIO_PIN9,GPIO_MODE_AF);                 /* TA2 PB9 */
				GPIO_PinRemapConfig(GPIOB, GPIO_PIN9,GPIO_ALT_TIM);
				
				GPIO_Init(GPIOA, GPIO_PIN3,GPIO_MODE_AF);                 /* TB2 PA3 */
				GPIO_PinRemapConfig(GPIOA, GPIO_PIN3,GPIO_ALT_TIM);

				GPIO_Init(GPIOB, GPIO_PIN0,GPIO_MODE_AF);                 /* TIMLK2 PB0 */
				GPIO_PinRemapConfig(GPIOB, GPIO_PIN0,GPIO_ALT_TIM);
		}
}

/**
 * @brief   TIMx Wave Mode Configuration
 * @param:  TIMx: TIMx base address, which can be configured as TIM0 or TIM1.
 * @param:  TIM_CMR_WAVSEL: waveform selection
 * @param:  TIM_CHANNEL: Channel to configure
 * @retval  None
 */
void TIM_Wave_Config(TIM_Type *TIMx, TIM_CMR_WAVSEL_Enum TIM_CMR_WAVSEL,TIM_CHANNEL_Enum TIM_CHANNEL)
{
		uint32_t ul_RA   = 50000;
		uint32_t ul_RB   = 60000;
		uint32_t ul_RC   = 80000;
		TIM_CMR_Wave_T   TIM_CMR_WaveConfig = { TIM_CHANNEL0 };
		
		if(TIMx==TIM0)
		    SCU_PeriphClockCmd(SCU_TIM0_CLKEN,ENABLE);
		else
			  SCU_PeriphClockCmd(SCU_TIM1_CLKEN,ENABLE);
		
		TIM_Wave_GPIO(TIMx,TIM_CHANNEL);
		
		TIM_CMR_WaveConfig.CHANNEL = TIM_CHANNEL;
		TIM_CMR_WaveConfig.WAVE    = TIM_CMR_WAVE_MODE;
		TIM_CMR_WaveConfig.TIMCLKS = TIM_CMR_TIMCLKS_CLK_BUS_DIV2;        
		TIM_CMR_WaveConfig.CLKI    = TIM_CMR_CLKI_NOINVERT;       /* The counter increments on the rising edge of the clock */
		TIM_CMR_WaveConfig.CPCSTOP = TIM_CMR_CPCSTOP_NONE;        /* RC Compare Stop Count Clock */
		TIM_CMR_WaveConfig.CPCDIS  = TIM_CMR_CPCDIS_NONE;
		
		TIM_CMR_WaveConfig.EEVTEDG = TIM_CMR_EEVTEDG_FALLING;     /* External events trigger rising and falling edges */
		TIM_CMR_WaveConfig.EEVT    = TIM_CMR_EEVT_XC0; 
		TIM_CMR_WaveConfig.ENETRG  = TIM_CMR_ENETRG_EN;
		
		TIM_CMR_WaveConfig.WAVSEL  = TIM_CMR_WAVSEL;              /* waveform selection */
		
		if( TIM_CMR_WAVSEL == TIM_CMR_WAVSEL_UP || TIM_CMR_WAVSEL == TIM_CMR_WAVSEL_UP_RC)
		{
				TIM_CMR_WaveConfig.ACPA    = TIM_CMR_ACPA_SET;
				TIM_CMR_WaveConfig.ACPC    = TIM_CMR_ACPC_CLEAR;
				
				TIM_CMR_WaveConfig.AEEVT   = TIM_CMR_AEEVT_CLEAR;     /* ⲿ,TIOA */
				TIM_CMR_WaveConfig.ASWTRG  = TIM_CMR_ASWTRG_CLEAR;    /* ʱTIOA */
				
				TIM_CMR_WaveConfig.BCPB    = TIM_CMR_BCPB_SET;
				TIM_CMR_WaveConfig.BCPC    = TIM_CMR_BCPC_CLEAR;
				
				TIM_CMR_WaveConfig.BEEVT   = TIM_CMR_BEEVT_CLEAR;     /* ⲿ,TIOB */
				TIM_CMR_WaveConfig.BSWTRG  = TIM_CMR_BSWTRG_NONE;     /* ʱTIOB */
		}
		else if( TIM_CMR_WAVSEL == TIM_CMR_WAVSEL_UPDOWN  ||  TIM_CMR_WAVSEL == TIM_CMR_WAVSEL_UPDOWN_RC )
		{
				TIM_CMR_WaveConfig.ACPA    = TIM_CMR_ACPA_TOGGLE;
				TIM_CMR_WaveConfig.ACPC    = TIM_CMR_ACPC_TOGGLE;
				
				TIM_CMR_WaveConfig.AEEVT   = TIM_CMR_AEEVT_CLEAR;
				TIM_CMR_WaveConfig.ASWTRG  = TIM_CMR_ASWTRG_CLEAR;
				
				TIM_CMR_WaveConfig.BCPB    = TIM_CMR_BCPB_TOGGLE;
				TIM_CMR_WaveConfig.BCPC    = TIM_CMR_BCPC_TOGGLE;
				
				TIM_CMR_WaveConfig.BEEVT   = TIM_CMR_BEEVT_CLEAR;
				TIM_CMR_WaveConfig.BSWTRG  = TIM_CMR_BSWTRG_CLEAR;
		}
		
		if(TIM_WaveInit(TIMx,&TIM_CMR_WaveConfig) == ERROR)
		{
				Error_Handler();
		}
		
		TIM_Write_RA(TIMx,TIM_CHANNEL,ul_RA);
		TIM_Write_RB(TIMx,TIM_CHANNEL,ul_RB);
		TIM_Write_RC(TIMx,TIM_CHANNEL,ul_RC);
		
		TIM_ClockEnable(TIMx,TIM_CHANNEL);
		
		TIM_Swtrg(TIMx,TIM_CHANNEL);
}
