/**
  ******************************************************************************
  * @file           : usart.c
  * @author         : sinomcu.com-SA
  * @brief          : UART Mode initialization
  * @gcc            : toolchain version 5 or 6
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with basic chip information support
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */ 
#include "include.h"
#include "uart.h" 
#include "Board.h"

unsigned char uart_port;
UART_DATA_T g_UartRx;
uint8_t data_send[8] = {0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08};
/**
 * @brief   UART GPIO Initialization
 * @param   None
 * @retval  None
 */ 
void UART_GPIO_Init(void)
{	
		SCU_PeriphClockCmd(UART_PORT_TX_GPIO_CLK | UART_PORT_RX_GPIO_CLK, ENABLE);
		GPIO_Init(UART_PORT_RX_GPIO_PORT, UART_PORT_RX_PIN, GPIO_MODE_AF);
    GPIO_PinRemapConfig(UART_PORT_RX_GPIO_PORT, UART_PORT_RX_PIN, GPIO_ALT_RX0);
    GPIO_Init(UART_PORT_TX_GPIO_PORT, UART_PORT_TX_PIN, GPIO_MODE_AF);
    GPIO_PinRemapConfig(UART_PORT_TX_GPIO_PORT, UART_PORT_TX_PIN, GPIO_ALT_TX0);
}

/**
 * @brief   USART RS485 Mode initialization
 * @param   None
 * @retval  None
 */ 
/**
 * @brief       UART Init
 * @param       None
 * @retval      None
 */
void UART_TestInit(void)
{
    UART_Init_T UART_InitConfig;
    SCU_PeriphClockCmd(UART_PORT_CLK, ENABLE);
    SCU_ResetPeriphClock(UART_PORT_RST);
	
    UART_GPIO_Init();
    UART_InitConfig.BaudRate     = 115200;
    UART_InitConfig.Parity       = UART_PARITY_NO;
    UART_InitConfig.StopBits     = UART_STOPBITS_1;
    UART_InitConfig.WordLength   = UART_DATA_8_BIT;
	  UART_InitConfig.OverSampling = UART_OVERSAMPLING_8;
    UART_InitConfig.TimeOut      = 10;
    UART_Init(UART_PORT, &UART_InitConfig);
	
	  UART_DMA_Receive(UART_PORT,g_UartRx.buf,50);
	  UART_Enable_IT(UART_PORT, UART_IER_TIMEOUT);
    NVIC_EnableIRQ(UART0_IRQn);
}

