#include "include.h"
#include "usart_lin.h"

LIN_Message_T MasterSend = { 0 };
LIN_Message_T MasterReceived = { 0 };

LIN_Message_T SlaveSend = { 0 };
LIN_Message_T SlaveReceived = { 0 };

/**
 * @brief   USART LIN Initialization Function
 * @param   none
 * @retval  none
 */
void USART_LIN_MasterInit(void)
{
    SCU_PeriphClockCmd(SCU_GPIOB_CLKEN | SCU_GPIOD_CLKEN | SCU_USART_CLKEN, ENABLE);

    GPIO_Init(GPIOB, GPIO_PIN6, GPIO_MODE_AF);            //RX,PB6
    GPIO_PinRemapConfig(GPIOB, GPIO_PIN6, GPIO_ALT_USART);
    GPIO_Init(GPIOB, GPIO_PIN4, GPIO_MODE_AF);            //TX,PB4
    GPIO_PinRemapConfig(GPIOB, GPIO_PIN4, GPIO_ALT_USART);

    SCU_ResetPeriphClock(SCU_USART_RST);

    USART_InitLinMaster(USART, 9600, SCU_Get_frequecny());
    /* If using software check, simply mask the following three lines*/
    USART_LinEnableParity(USART);                         /* Enable ID parity check */
    USART_LinEnableChecksum(USART);                       /* Enable hardware checksum */
    USART_LinSetChecksumType(USART, 0);                   /* 0 for LIN 2.0 Enhanced checksum or 1 for LIN 1.3 Classic checksum */

    USART_LinSetDataLenMode(USART, 0);
    USART_LinEnableFrameSlot(USART);
    USART_LinSetResponseDataLen(USART, 8);                /* Data length 8+1 byte */
    USART_LinSetNodeAction(USART, 0);                     /* 0 for publish, 1 for subscribe, 2 for ignore */
}

/**
 * @brief   lin master send frame head(interval+sync+id)
 * @param   uint8_t id
 * @retval  none
 */
void LIN_MasterSendHead(uint8_t id)
{
    MasterSend.ID = id;

    USART_LinSetTxIdentifier(USART, MasterSend.ID);       /* LINIDдUSART_LINIR֡ͷʼ */

    while( ( USART->SR & USART_SR_LINID ) == 0 ) { ; }
}

/**
 * @brief   lin master send frame answer(8data+checksum)
 * @param   LIN_Message_T* LINMessage
 * @retval  none
 */
void LIN_MasterSendAnswer(LIN_Message_T* LINMessage)
{
    MasterSend.Tx_Data[0] = 0x11;
    MasterSend.Tx_Data[1] = 0x22;
    MasterSend.Tx_Data[2] = 0x33;
    MasterSend.Tx_Data[3] = 0x44;
    MasterSend.Tx_Data[4] = 0x55;
    MasterSend.Tx_Data[5] = 0x66;
    MasterSend.Tx_Data[6] = 0x77;
    MasterSend.Tx_Data[7] = 0x88;

    uint8_t uc_LinDataLen;
    uc_LinDataLen = USART_LinGetDataLength(USART);        /* Get data length */

    USART_DMA_Send(USART, &LINMessage->Tx_Data[0], uc_LinDataLen);

    while( ( USART->SR & USART_SR_LINTC ) == 0 ) { ; }
}

/**
 * @brief   lin master send one frame(interval+sync+pid+8data+checksum)
 * @param   none
 * @retval  none
 */
void Send_LinFrame(uint8_t ID)
{
    if(ID == 0x3C || ID == 0x3D)
    {
        USART_LinSetChecksumType(USART, 1);
    }
    LIN_MasterSendHead(ID);
    LIN_MasterSendAnswer(&MasterSend);
    USART->CR = USART_CR_RSTSTA;
}

