/**
  ******************************************************************************
  * @file           : usart.c
  * @author         : sinomcu.com-SA
  * @brief          : USART RS485 Mode initialization
  * @gcc            : toolchain version 5 or 6
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with basic chip information support
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */ 
#include "include.h"
#include "usart.h" 

#define USART_TX_GPIO  GPIOA
#define USART_RX_GPIO  GPIOA
#define USART_RTS_GPIO GPIOA
#define USART_TX_PIN  GPIO_PIN2
#define USART_RX_PIN  GPIO_PIN4
#define USART_RTS_PIN GPIO_PIN1

uint8_t uc_RxBuffer0[RX_LEN] = {0};
uint8_t uc_TxBuffer0[RX_LEN] = {0};
/**
 * @brief   USART GPIO Initialization
 * @param   None
 * @retval  None
 */ 
void USART_GPIO_Init(void)
{	
    SCU_PeriphClockCmd(SCU_GPIOA_CLKEN,ENABLE);
		
		GPIO_Init(USART_TX_GPIO, USART_TX_PIN,GPIO_MODE_AF);
		GPIO_PinRemapConfig(USART_TX_GPIO, USART_TX_PIN,GPIO_ALT_USART);
		GPIO_Init(USART_RX_GPIO, USART_RX_PIN,GPIO_MODE_AF);
		GPIO_PinRemapConfig(USART_RX_GPIO, USART_RX_PIN,GPIO_ALT_USART);

    GPIO_Init(USART_RTS_GPIO, USART_RTS_PIN,GPIO_MODE_AF);
		GPIO_PinRemapConfig(USART_RTS_GPIO, USART_RTS_PIN,GPIO_ALT_USART);	
}

/**
 * @brief   USART RS485 Mode initialization
 * @param   None
 * @retval  None
 */ 
void USART_RS485_Mode_Init(void)
{
		USART_Init_T  USART_Config = { 0 };

		USART_GPIO_Init();
		SCU_PeriphClockCmd(SCU_USART_CLKEN,ENABLE);  

		USART_Config.BaudRate   = 115200;                 
		USART_Config.Parity     = USART_PARITY_NO;
		USART_Config.StopBits   = USART_STOPBITS_1;
		USART_Config.WordLength = USART_DATA_8_BIT;
    USART_Config.Mode       = RS485_MODE;
    USART_Config.TimeOut    = 10;
    USART_Config.TimeGuard  = 10;    
   	USART_Init(USART,&USART_Config);
		
		USART_DMA_Receive(USART,uc_RxBuffer0,RX_LEN);
		
		USART_Enable_IT(USART,USART_IER_TIMEOUT);
  	NVIC_EnableIRQ(USART_IRQn);
		
		USART->CR = USART_CR_TXEN | USART_CR_RXEN;
}

