/**
  ******************************************************************************
  * @file           : main.c
  * @author         : sinomcu.com-SA
  * @brief          : Main program body.
  * @gcc            : toolchain version 5 or 6
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with 
  * basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */
#include "include.h"
#include  "systick.h"

uint8_t receive_buff[64];

void USART_SPI_TEST(USART_Type* p_usart);

uint8_t data_send[8] = {0x9f, 0x5F, 0x1F, 0x55, 0x9f, 0x5F, 0x1F, 0x55};
/**
 * @brief       main
 * @param       None
 * @retval      None
 */
int	main()
{
    SCU_SetSysClock(CLK_PLL_USE_HRC_LRC, HRC_16M, NO_XTAL, PLL_72M, SCU_SYS_Div1);
    USART_SPI_TEST(USART);
    delay_init();
    while(1)
    {
        USART_DMA_Send(USART, data_send, sizeof(data_send));
        delay_ms(1000);
    }
}

/**
 * @brief      USART_SPI_TEST
 * @param      USART_Type* p_usart:USART
 * @retval     None
 */
void USART_SPI_TEST(USART_Type* p_usart)
{
    USART_SPI_T usart_spi;
    SCU_PeriphClockCmd(SCU_GPIOB_CLKEN | SCU_GPIOA_CLKEN | SCU_USART_CLKEN, ENABLE); /*enable GPIOA and UART0 clock*/

    GPIO_Init(GPIOA, GPIO_PIN5, GPIO_MODE_AF);                                        /*MOSI*/
    GPIO_Init(GPIOA, GPIO_PIN4, GPIO_MODE_AF);                                        /*MISO*/
    GPIO_Init(GPIOB, GPIO_PIN1, GPIO_MODE_AF);                                        /*RTS*/
    GPIO_Init(GPIOA, GPIO_PIN3, GPIO_MODE_AF);                                        /*CLK*/
    GPIO_PinRemapConfig(GPIOA, GPIO_PIN5, GPIO_ALT_USART);
    GPIO_PinRemapConfig(GPIOA, GPIO_PIN4, GPIO_ALT_USART);
    GPIO_PinRemapConfig(GPIOB, GPIO_PIN1, GPIO_ALT_USART);
    GPIO_PinRemapConfig(GPIOA, GPIO_PIN3, GPIO_ALT_USART);

    usart_spi.baudrate     = 500000;                                                 /*4MHz*/
    usart_spi.char_length  = USART_DATA_8_BIT;
    usart_spi.spi_mode     = SPI_MODE_0;
    usart_spi.channel_mode = USART_NORMAL;

    USART_SPI_MasterInit(p_usart, &usart_spi, SCU_Get_frequecny());
    USART_DMA_Receive(USART, receive_buff, 64);
}
