/**
  ******************************************************************************
  * @file           : main.c
  * @author         : sinomcu.com-SA
  * @brief          : MAIN module driver.
  * @gcc            : toolchain version 5 or 6
  *
  ******************************************************************************
  * @attention
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with
  * basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */
#include "include.h"
#include "stdio.h"
#include "Board.h"
#include  "systick.h"
uint16_t adc_buffer[50];

void ADC_init(void);
void UART_TestInit(void);
/**
 * @brief   Main Configuration Function
 * @param   None
 * @retval  None
 */
int	main()
{
    uint16_t temp[50];
    int i;
    SCU_SetSysClock(CLK_PLL_USE_HRC_LRC, HRC_16M, NO_XTAL, PLL_72M, SCU_SYS_Div1);
    UART_TestInit();
    delay_init();
    ADC_init();
  
    while(1)
    {
        for(i = 0; i < 4; i++)
        {
            temp[i] = adc_buffer[i] * 2400 / 4096;
        }
        delay_ms(1000);
        printf("\r\nresult of \r\nADC00:%dmv\r\nADC10:%dmv\r\nADC01:%dmv\r\nADC11:%dmv\r\n", temp[0], temp[1], temp[2], temp[3]);
    }
}
 /**
 * @brief   UART Configuration Function
 * @param   None
 * @retval  None
 */
 
void UART_TestInit(void)
{
    UART_Init_T UART_InitConfig;
    SCU_PeriphClockCmd(UART_PORT_TX_GPIO_CLK | UART_PORT_RX_GPIO_CLK | UART_PORT_CLK, ENABLE);
    SCU_ResetPeriphClock(UART_PORT_RST);

    GPIO_Init(UART_PORT_RX_GPIO_PORT, UART_PORT_RX_PIN, GPIO_MODE_AF);
    GPIO_PinRemapConfig(UART_PORT_RX_GPIO_PORT, UART_PORT_RX_PIN, GPIO_ALT_RX0);
    GPIO_Init(UART_PORT_TX_GPIO_PORT, UART_PORT_TX_PIN, GPIO_MODE_AF);
    GPIO_PinRemapConfig(UART_PORT_TX_GPIO_PORT, UART_PORT_TX_PIN, GPIO_ALT_TX0);
    UART_InitConfig.BaudRate = 115200;
    UART_InitConfig.Parity = UART_PARITY_NO;
    UART_InitConfig.StopBits = UART_STOPBITS_1;
    UART_InitConfig.WordLength = UART_DATA_8_BIT;
    UART_InitConfig.TimeOut = 10;
    UART_Init(UART_PORT, &UART_InitConfig);
}

/**
 * @brief   ADC Configuration Function
 * @param   None
 * @retval  None
 */
void ADC_init(void)
{
    ADC_Init_T				 adc_init;
	  SCU_PeriphClockCmd(SCU_ADC_CLKEN | SCU_ADC_CORE_CLKEN|SCU_GPIOB_CLKEN | SCU_GPIOA_CLKEN, ENABLE);
    
    GPIO_Init(GPIOB, GPIO_PIN11, GPIO_MODE_ANALOG);				/*ADC00*/
    GPIO_Init(GPIOA, GPIO_PIN12, GPIO_MODE_ANALOG);				/*ADC10*/
    GPIO_Init(GPIOB, GPIO_PIN6,  GPIO_MODE_ANALOG);				/*ADC01*/
    GPIO_Init(GPIOA, GPIO_PIN11, GPIO_MODE_ANALOG); 			/*ADC11*/
	  NVIC_EnableIRQ(ADC_IRQn);
	
    adc_init.ADC_Resolution = ADC_RESOLUTION_12B; 				/*resolution ratio*/
    adc_init.ADC_ScanConvMode = ADC_SCAN_ENALBE; 					/*SCAN*/
    adc_init.ADC_ContinuousConvMode = ADC_CONTINUE;				/*Continuous mode*/
    adc_init.ADC_DataAlign = ADC_DataAlign_Right; 				/*Data alignment*/
    adc_init.ADC_Mode = ADC_SINGLE_MOD;										/*Single ended mode*/
    adc_init.ADC_Prescaler = ADC_CLK_Div6;								/*ADC system frequency division*/
    adc_init.ADC_CLK_SEL = ADC_PLL_CLK_SEL;								/*ADC clock selection*/
    adc_init.ADC_DMAAccessMode = ADC_DMA_ENABLE_16BIT;		/*DMA*/
    ADC_Init(ADC, &adc_init);

    ADC_RegularNbrOfChannel(ADC_SQLNUM_4CH);							/*Set the number of ADC conversion channels*/
    ADC_RegularOddChannelConfig( ADC, ADC_PB11_CHANNEL, 0, ADC_SampleTime_2Cycles);/*Set ADC conversion channel sampling time*/
    ADC_RegularEvenChannelConfig(ADC, ADC_PA12_CHANNEL, 0, ADC_SampleTime_2Cycles);
    ADC_RegularOddChannelConfig( ADC, ADC_PB6_CHANNEL,  1, ADC_SampleTime_2Cycles);
    ADC_RegularEvenChannelConfig(ADC, ADC_PA11_CHANNEL, 1, ADC_SampleTime_2Cycles);

    ADC_VREF_OUT(ADC_VREF_OUT_2v4, ADC_VREF_SEL);				  /*ADC vref selection*/
    ADC_DMA_Configure(4, adc_buffer);											/*DMA configuration */
    ADC_Enable_IT(ADC, ADC_IER_EOC);				     			  	/*Set ADC interrupt enable*/
    ADC_DMACmd(ADC, ENABLE);															/*Enable DMA*/
    ADC_Cmd(ADC, ENABLE);																	/*Enable ADC*/
    ADC_ExternalTrigConv(ADC_REGULAR_SOFTWARE_TRIGER);		/*Set ADC trigger method*/ 
}


