/**
  ******************************************************************************
  * @file           : main.c
  * @author         : sinomcu.com-SA
  * @brief          : Main program body
  * @gcc            : toolchain version 5 or 6
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with 
  * basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */
#include "include.h"

void EXTI5_15_TriggerInit(void);

/**
 * @brief     Main program
 * @param     None
 * @retval    int
 */
int	main()
{
    SCU_SetSysClock(CLK_PLL_USE_HRC_LRC, HRC_16M, NO_XTAL, PLL_72M, SCU_SYS_Div1); 
	
	  GPIO_ResetBits(GPIOB, GPIO_PIN11);
	  SCU_PeriphClockCmd(SCU_GPIOB_CLKEN, ENABLE);
    GPIO_Init(GPIOB, GPIO_PIN11, GPIO_MODE_OUTPUT_PP);
	
    EXTI5_15_TriggerInit();
	  EXTI_Enable_IT(EXTI_LINE15);
	  NVIC_SetPriority( EXTI5_15_IRQn, 0 );
	  NVIC_EnableIRQ( EXTI5_15_IRQn );
    while(1)
    {
       
    }
}

/**
  * @brief  Deinitializes the EXTI peripheral registers to their default reset
  *         values.
  * @param  None
  * @retval None
  */
void EXTI5_15_TriggerInit(void)
{
    EXTI_Init_T  EXTI_InitConfig;
	  
    SCU_PeriphClockCmd(SCU_GPIOA_CLKEN, ENABLE);
	
    GPIO_Init(GPIOA, GPIO_PIN15, GPIO_MODE_INPUT_PU);
    EXTI_InitConfig.EXTI_Line  = EXTI_LINE15;
    EXTI_InitConfig.LineCmd    = ENABLE;
		EXTI_InitConfig.Mode       = EXTI_Interrupt_Mode;
    EXTI_InitConfig.GPIO_GPOUP = EXTI_GROUPA;

    EXTI_InitConfig.Trigger    = EXTI_Trigger_Falling;
    EXTI_Init(&EXTI_InitConfig);
}
