/**
  ******************************************************************************
  * @file           : main.c
  * @author         : sinomcu.com-SA
  * @brief          : MAIN module driver.
  * @gcc            : toolchain version 5 or 6
  *
  ******************************************************************************
  * @attention
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with
  * basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */
#include "include.h"
#include "systick.h"
#include "Board.h"

uint16_t adc_buffer[50];
void UART_TestInit(void);
void ADC_REGULAR_SCAN(void);
void PGA_Single_ended_attenuation(void);

int	main()
{
    /*set system clock*/
    SCU_SetSysClock(CLK_PLL_USE_HRC_LRC, HRC_16M, NO_XTAL, PLL_72M, SCU_SYS_Div1);
    delay_init();
    UART_TestInit();
    PGA_Single_ended_attenuation();
    ADC_REGULAR_SCAN();

    while(1)
    {
        delay_ms(1000);
        printf("\r\nresult of \r\nPGA:%dmv\r\n", adc_buffer[0] * 3300 / 4096);
    }
}

/**
  * @brief  UART0 TestInit
  * @param  None
  * @retval None
  */
void UART_TestInit(void)
{
    UART_Init_T 			UART_InitConfig;
    SCU_PeriphClockCmd(SCU_GPIOA_CLKEN | UART_PORT_CLK, ENABLE);

    GPIO_Init(UART_PORT_RX_GPIO_PORT, UART_PORT_RX_PIN, GPIO_MODE_AF);
    GPIO_PinRemapConfig(UART_PORT_RX_GPIO_PORT, UART_PORT_RX_PIN, GPIO_ALT_RX0);
    GPIO_Init(UART_PORT_TX_GPIO_PORT, UART_PORT_TX_PIN, GPIO_MODE_AF);
    GPIO_PinRemapConfig(UART_PORT_TX_GPIO_PORT, UART_PORT_TX_PIN, GPIO_ALT_TX0);
    UART_InitConfig.BaudRate = 115200;
    UART_InitConfig.Parity = UART_PARITY_NO;
    UART_InitConfig.StopBits = UART_STOPBITS_1;
    UART_InitConfig.WordLength = UART_DATA_8_BIT;
    UART_InitConfig.TimeOut = 10;
    UART_Init(UART_PORT, &UART_InitConfig);
}


/**
  * @brief  ADC mode configuration detection PGA output
  * @param  None
  * @retval None
  */
void ADC_REGULAR_SCAN()
{
	  ADC_Init_T 			adc_init;
	
	  SCU_PeriphClockCmd(SCU_ADC_CLKEN | SCU_GPIOB_CLKEN, ENABLE);
    NVIC_EnableIRQ(ADC_IRQn);
	
    adc_init.ADC_Resolution = ADC_RESOLUTION_12B; 			/*resolution ratio*/
    adc_init.ADC_ScanConvMode = ADC_SCAN_DISABLE; 			/*SCAN*/
    adc_init.ADC_ContinuousConvMode = ADC_CONTINUE;			/*Continuous mode*/
    adc_init.ADC_DataAlign = ADC_DataAlign_Right; 			/*Data alignment*/
    adc_init.ADC_Mode = ADC_SINGLE_MOD; 								/*Single ended mode*/
    adc_init.ADC_Prescaler = ADC_CLK_Div6; 							/*ADC system frequency division*/
    adc_init.ADC_DMAAccessMode = ADC_DMA_ENABLE_16BIT; 	/*DMA*/
    adc_init.ADC_CLK_SEL = ADC_PLL_CLK_SEL; 						/*ADC clock selection*/
    ADC_Init(ADC, &adc_init);

    ADC_RegularNbrOfChannel(ADC_SQLNUM_2CH);						/*Set the number of ADC conversion channels*/
    ADC_RegularOddChannelConfig(ADC, ADC_PGA0_CHANNEL, 0, ADC_SampleTime_2Cycles);/*Set ADC conversion channel sampling time*/
    ADC_VREF_OUT(ADC_VREF_OUT_NO, ADC_AVDD_SEL);				/*ADC vref selection*/
    ADC_DMA_Configure(2, adc_buffer); 									/*DMA  configuration */

    ADC_Enable_IT(ADC, ADC_IER_EOC); 					        	/*Set ADC interrupt enable*/
    ADC_DMACmd(ADC, ENABLE); 														/*Enable DMA*/
    ADC_Cmd(ADC, ENABLE);																/*Enable ADC*/
    ADC_ExternalTrigConv(ADC_REGULAR_SOFTWARE_TRIGER); 	/*Set ADC trigger method*/
}

/**
  * @brief  PGA0 Single_ended_attenuation
  * @param  None
  * @retval None
  */
void PGA_Single_ended_attenuation(void)
{
    PGA_Init_T pga;
    SCU_PeriphClockCmd(SCU_GPIOB_CLKEN | SCU_PGA_CLKEN, ENABLE);
    GPIO_Init(GPIOB, GPIO_PIN2, GPIO_MODE_ANALOG);
	
    pga.CHP = PGA0_CHP_PB2; 		/*PGA0_CHP_SEL*/
    pga.GAIN = PGA0_GAIN2_0_5; 	/*0.5*/
    pga.PGA_MODE = Single_ended_attenuation;
    pga.PGA_EN = PGA0_EN_ENABLE;
    PGA_Init(&pga);
}


