/**
  ******************************************************************************
  * @file           : main.c
  * @author         : sinomcu.com-SA
  * @brief          : Main program body
  * @gcc            : toolchain version   5 or 6
  * This file provides example code for Spi transmit data by dma.
  *
  ******************************************************************************
  * @attention
  *                           DISCLAIMER
  * This firmware is for guidance only and is designed to provide customers with
 * basic chip information support.
  *
  * Copyright (c) 2023 sinomcu.com All rights reserved.
  *
  ******************************************************************************
  */
#include "include.h"
#include "pwm.h"
#include "tim_fre.h"
#include "board.h"
#include  "systick.h"

#pragma pack(1)

#define SEL_HXTAL_PLL_MODE  0
#define SEL_HRC_PLL_MODE    1
#define SEL_HXTAL_MODE      0
#define SEL_HRC_MODE        0
extern strTimer gTimer;
void UART_TestInit(void);

/**
 * @brief     Main program
 * @param     None
 * @retval    int
 */
int	main(void)
{

    #if SEL_HXTAL_PLL_MODE
    SCU_SetSysClock(CLK_PLL_USE_HXTAL_LXTAL, HXTAL_8M, HXTAL_LXTAL_TYPE, PLL_48M, SCU_SYS_Div1); 
    #elif SEL_HRC_PLL_MODE
    SCU_SetSysClock(CLK_PLL_USE_HRC_LRC, HRC_16M, NO_XTAL, PLL_72M, SCU_SYS_Div1);
    #elif SEL_HXTAL_MODE
    SCU_SetSysClock(CLK_16M_USE_HXTAL_LRC, HXTAL_12M, HXTAL_TYPE, PLL_48M, SCU_SYS_Div1); 
    #elif SEL_HRC_MODE
    SCU_SetSysClock(CLK_16M_USE_HRC_LRC, HRC_16M, NO_XTAL, PLL_48M, SCU_SYS_Div1); 
    #endif

    PWM_AsyncMode_Init();
    TIM_Config(TIM1, TIM_CHANNEL0);
    UART_TestInit();
	  delay_init();

    while (1)
    {
        printf("The waveform frequency is:%d HZ\n", gTimer.m_ul_Fre );
        delay_ms(1000);
    }
}

/**
* @brief   UART Configuration Function
* @param   None
* @retval  None
*/
void UART_TestInit(void)
{
    UART_Init_T UART_InitConfig;
    SCU_PeriphClockCmd(UART_PORT_TX_GPIO_CLK | UART_PORT_RX_GPIO_CLK | UART_PORT_CLK, ENABLE);
    SCU_ResetPeriphClock(UART_PORT_RST);

    GPIO_Init(UART_PORT_RX_GPIO_PORT, UART_PORT_RX_PIN, GPIO_MODE_AF);
    GPIO_PinRemapConfig(UART_PORT_RX_GPIO_PORT, UART_PORT_RX_PIN, GPIO_ALT_RX0);
    GPIO_Init(UART_PORT_TX_GPIO_PORT, UART_PORT_TX_PIN, GPIO_MODE_AF);
    GPIO_PinRemapConfig(UART_PORT_TX_GPIO_PORT, UART_PORT_TX_PIN, GPIO_ALT_TX0);
    UART_InitConfig.BaudRate = 115200;
    UART_InitConfig.Parity = UART_PARITY_NO;
    UART_InitConfig.StopBits = UART_STOPBITS_1;
    UART_InitConfig.WordLength = UART_DATA_8_BIT;
    UART_InitConfig.TimeOut = 10;
    UART_Init(UART_PORT, &UART_InitConfig);
}
